Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V0ErrorsErrorCode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The error reason represented by type and enum.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsErrorCode

Returns a new instance of GoogleAdsSearchads360V0ErrorsErrorCode.



168
169
170
# File 'lib/google/apis/searchads360_v23/classes.rb', line 168

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_errorString

Indicates failure to properly authenticate user. Corresponds to the JSON property authenticationError

Returns:

  • (String)


101
102
103
# File 'lib/google/apis/searchads360_v23/classes.rb', line 101

def authentication_error
  @authentication_error
end

#authorization_errorString

An error encountered when trying to authorize a user. Corresponds to the JSON property authorizationError

Returns:

  • (String)


106
107
108
# File 'lib/google/apis/searchads360_v23/classes.rb', line 106

def authorization_error
  @authorization_error
end

#conversion_custom_variable_errorString

The reasons for the conversion custom variable error Corresponds to the JSON property conversionCustomVariableError

Returns:

  • (String)


111
112
113
# File 'lib/google/apis/searchads360_v23/classes.rb', line 111

def conversion_custom_variable_error
  @conversion_custom_variable_error
end

#custom_column_errorString

The reasons for the custom column error Corresponds to the JSON property customColumnError

Returns:

  • (String)


116
117
118
# File 'lib/google/apis/searchads360_v23/classes.rb', line 116

def custom_column_error
  @custom_column_error
end

#date_errorString

The reasons for the date error Corresponds to the JSON property dateError

Returns:

  • (String)


121
122
123
# File 'lib/google/apis/searchads360_v23/classes.rb', line 121

def date_error
  @date_error
end

#date_range_errorString

The reasons for the date range error Corresponds to the JSON property dateRangeError

Returns:

  • (String)


126
127
128
# File 'lib/google/apis/searchads360_v23/classes.rb', line 126

def date_range_error
  @date_range_error
end

#distinct_errorString

The reasons for the distinct error Corresponds to the JSON property distinctError

Returns:

  • (String)


131
132
133
# File 'lib/google/apis/searchads360_v23/classes.rb', line 131

def distinct_error
  @distinct_error
end

#header_errorString

The reasons for the header error. Corresponds to the JSON property headerError

Returns:

  • (String)


136
137
138
# File 'lib/google/apis/searchads360_v23/classes.rb', line 136

def header_error
  @header_error
end

#internal_errorString

An unexpected server-side error. Corresponds to the JSON property internalError

Returns:

  • (String)


141
142
143
# File 'lib/google/apis/searchads360_v23/classes.rb', line 141

def internal_error
  @internal_error
end

#invalid_parameter_errorString

The reasons for invalid parameter errors. Corresponds to the JSON property invalidParameterError

Returns:

  • (String)


146
147
148
# File 'lib/google/apis/searchads360_v23/classes.rb', line 146

def invalid_parameter_error
  @invalid_parameter_error
end

#query_errorString

An error with the query Corresponds to the JSON property queryError

Returns:

  • (String)


151
152
153
# File 'lib/google/apis/searchads360_v23/classes.rb', line 151

def query_error
  @query_error
end

#quota_errorString

An error with the amount of quota remaining. Corresponds to the JSON property quotaError

Returns:

  • (String)


156
157
158
# File 'lib/google/apis/searchads360_v23/classes.rb', line 156

def quota_error
  @quota_error
end

#request_errorString

An error caused by the request Corresponds to the JSON property requestError

Returns:

  • (String)


161
162
163
# File 'lib/google/apis/searchads360_v23/classes.rb', line 161

def request_error
  @request_error
end

#size_limit_errorString

The reasons for the size limit error Corresponds to the JSON property sizeLimitError

Returns:

  • (String)


166
167
168
# File 'lib/google/apis/searchads360_v23/classes.rb', line 166

def size_limit_error
  @size_limit_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/google/apis/searchads360_v23/classes.rb', line 173

def update!(**args)
  @authentication_error = args[:authentication_error] if args.key?(:authentication_error)
  @authorization_error = args[:authorization_error] if args.key?(:authorization_error)
  @conversion_custom_variable_error = args[:conversion_custom_variable_error] if args.key?(:conversion_custom_variable_error)
  @custom_column_error = args[:custom_column_error] if args.key?(:custom_column_error)
  @date_error = args[:date_error] if args.key?(:date_error)
  @date_range_error = args[:date_range_error] if args.key?(:date_range_error)
  @distinct_error = args[:distinct_error] if args.key?(:distinct_error)
  @header_error = args[:header_error] if args.key?(:header_error)
  @internal_error = args[:internal_error] if args.key?(:internal_error)
  @invalid_parameter_error = args[:invalid_parameter_error] if args.key?(:invalid_parameter_error)
  @query_error = args[:query_error] if args.key?(:query_error)
  @quota_error = args[:quota_error] if args.key?(:quota_error)
  @request_error = args[:request_error] if args.key?(:request_error)
  @size_limit_error = args[:size_limit_error] if args.key?(:size_limit_error)
end