Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V0ErrorsErrorDetails
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V0ErrorsErrorDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Additional error details.
Instance Attribute Summary collapse
-
#quota_error_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V0ErrorsQuotaErrorDetails
Additional quota error details when there is QuotaError.
-
#unpublished_error_code ⇒ String
The error code that should have been returned, but wasn't.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsErrorDetails
constructor
A new instance of GoogleAdsSearchads360V0ErrorsErrorDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsErrorDetails
Returns a new instance of GoogleAdsSearchads360V0ErrorsErrorDetails.
206 207 208 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#quota_error_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V0ErrorsQuotaErrorDetails
Additional quota error details when there is QuotaError.
Corresponds to the JSON property quotaErrorDetails
198 199 200 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 198 def quota_error_details @quota_error_details end |
#unpublished_error_code ⇒ String
The error code that should have been returned, but wasn't. This is used when
the error code is not published in the client specified version.
Corresponds to the JSON property unpublishedErrorCode
204 205 206 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 204 def unpublished_error_code @unpublished_error_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
211 212 213 214 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 211 def update!(**args) @quota_error_details = args[:quota_error_details] if args.key?(:quota_error_details) @unpublished_error_code = args[:unpublished_error_code] if args.key?(:unpublished_error_code) end |