Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V0ErrorsErrorLocationFieldPathElement
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V0ErrorsErrorLocationFieldPathElement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A part of a field path.
Instance Attribute Summary collapse
-
#field_name ⇒ String
The name of a field or a oneof Corresponds to the JSON property
fieldName. -
#index ⇒ Fixnum
If field_name is a repeated field, this is the element that failed Corresponds to the JSON property
index.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsErrorLocationFieldPathElement
constructor
A new instance of GoogleAdsSearchads360V0ErrorsErrorLocationFieldPathElement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsErrorLocationFieldPathElement
Returns a new instance of GoogleAdsSearchads360V0ErrorsErrorLocationFieldPathElement.
83 84 85 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 83 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_name ⇒ String
The name of a field or a oneof
Corresponds to the JSON property fieldName
76 77 78 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 76 def field_name @field_name end |
#index ⇒ Fixnum
If field_name is a repeated field, this is the element that failed
Corresponds to the JSON property index
81 82 83 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 81 def index @index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
88 89 90 91 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 88 def update!(**args) @field_name = args[:field_name] if args.key?(:field_name) @index = args[:index] if args.key?(:index) end |