Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V0ErrorsSearchAds360Failure
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V0ErrorsSearchAds360Failure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Describes how a Search Ads 360 API call failed. It's returned inside google. rpc.Status.details when a call fails.
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V0ErrorsSearchAds360Error>
The list of errors that occurred.
-
#request_id ⇒ String
The unique ID of the request that is used for debugging purposes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsSearchAds360Failure
constructor
A new instance of GoogleAdsSearchads360V0ErrorsSearchAds360Failure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsSearchAds360Failure
Returns a new instance of GoogleAdsSearchads360V0ErrorsSearchAds360Failure.
326 327 328 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 326 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V0ErrorsSearchAds360Error>
The list of errors that occurred.
Corresponds to the JSON property errors
319 320 321 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 319 def errors @errors end |
#request_id ⇒ String
The unique ID of the request that is used for debugging purposes.
Corresponds to the JSON property requestId
324 325 326 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 324 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
331 332 333 334 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 331 def update!(**args) @errors = args[:errors] if args.key?(:errors) @request_id = args[:request_id] if args.key?(:request_id) end |