Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdAppDeepLinkAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdAppDeepLinkAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An app deep link used inside an ad.
Instance Attribute Summary collapse
-
#asset ⇒ String
The Asset resource name of this app deep link asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdAppDeepLinkAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonAdAppDeepLinkAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdAppDeepLinkAsset
Returns a new instance of GoogleAdsSearchads360V23CommonAdAppDeepLinkAsset.
701 702 703 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 701 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset ⇒ String
The Asset resource name of this app deep link asset.
Corresponds to the JSON property asset
699 700 701 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 699 def asset @asset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
706 707 708 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 706 def update!(**args) @asset = args[:asset] if args.key?(:asset) end |