Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdDemandGenCarouselCardAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Demand Gen carousel card asset used inside an ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdDemandGenCarouselCardAsset

Returns a new instance of GoogleAdsSearchads360V23CommonAdDemandGenCarouselCardAsset.



771
772
773
# File 'lib/google/apis/searchads360_v23/classes.rb', line 771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetString

The Asset resource name of this discovery carousel card. Corresponds to the JSON property asset

Returns:

  • (String)


769
770
771
# File 'lib/google/apis/searchads360_v23/classes.rb', line 769

def asset
  @asset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



776
777
778
# File 'lib/google/apis/searchads360_v23/classes.rb', line 776

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
end