Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAssetLinkFeatureControl
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAssetLinkFeatureControl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
YouTube Video Asset feature controls.
Instance Attribute Summary collapse
-
#allow_youtube_comments ⇒ Boolean
(also: #allow_youtube_comments?)
Defines if YouTube comments should be enabled for the creative using this YouTube video asset served on YouTube Shorts.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdVideoAssetLinkFeatureControl
constructor
A new instance of GoogleAdsSearchads360V23CommonAdVideoAssetLinkFeatureControl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdVideoAssetLinkFeatureControl
Returns a new instance of GoogleAdsSearchads360V23CommonAdVideoAssetLinkFeatureControl.
967 968 969 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 967 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_youtube_comments ⇒ Boolean Also known as: allow_youtube_comments?
Defines if YouTube comments should be enabled for the creative using this
YouTube video asset served on YouTube Shorts.
Corresponds to the JSON property allowYoutubeComments
964 965 966 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 964 def allow_youtube_comments @allow_youtube_comments end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
972 973 974 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 972 def update!(**args) @allow_youtube_comments = args[:allow_youtube_comments] if args.key?(:allow_youtube_comments) end |