Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Additional information about the application/tool issuing the request. This field is only used by ContentCreatorInsightsService, AudienceInsightsService, and ReachPlanService APIs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdditionalApplicationInfo

Returns a new instance of GoogleAdsSearchads360V23CommonAdditionalApplicationInfo.



1055
1056
1057
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#application_idString

The unique identifier of the agency proprietary application. This identifier is generated by Google. Reach out to your Google representative to request an application_id for each new application being integrated. Corresponds to the JSON property applicationId

Returns:

  • (String)


1048
1049
1050
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1048

def application_id
  @application_id
end

#application_instanceString

The instance type of the application sending the request. Corresponds to the JSON property applicationInstance

Returns:

  • (String)


1053
1054
1055
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1053

def application_instance
  @application_instance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1060
1061
1062
1063
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1060

def update!(**args)
  @application_id = args[:application_id] if args.key?(:application_id)
  @application_instance = args[:application_instance] if args.key?(:application_instance)
end