Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeDimension
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeDimension
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Dimension specifying users by their age.
Instance Attribute Summary collapse
-
#age_ranges ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeSegment>
Contiguous age range to be included in the dimension.
-
#include_undetermined ⇒ Boolean
(also: #include_undetermined?)
Include users whose age is not determined.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAgeDimension
constructor
A new instance of GoogleAdsSearchads360V23CommonAgeDimension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAgeDimension
Returns a new instance of GoogleAdsSearchads360V23CommonAgeDimension.
1077 1078 1079 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age_ranges ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeSegment>
Contiguous age range to be included in the dimension.
Corresponds to the JSON property ageRanges
1069 1070 1071 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1069 def age_ranges @age_ranges end |
#include_undetermined ⇒ Boolean Also known as: include_undetermined?
Include users whose age is not determined.
Corresponds to the JSON property includeUndetermined
1074 1075 1076 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1074 def include_undetermined @include_undetermined end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1082 1083 1084 1085 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1082 def update!(**args) @age_ranges = args[:age_ranges] if args.key?(:age_ranges) @include_undetermined = args[:include_undetermined] if args.key?(:include_undetermined) end |