Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppAdInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An app ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAppAdInfo

Returns a new instance of GoogleAdsSearchads360V23CommonAppAdInfo.



1236
1237
1238
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

An app deep link used inside an ad. Corresponds to the JSON property appDeepLink



1202
1203
1204
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1202

def app_deep_link
  @app_deep_link
end

#descriptionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

List of text assets for descriptions. When the ad serves the descriptions will be selected from this list. Corresponds to the JSON property descriptions



1208
1209
1210
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1208

def descriptions
  @descriptions
end

#headlinesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

List of text assets for headlines. When the ad serves the headlines will be selected from this list. Corresponds to the JSON property headlines



1214
1215
1216
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1214

def headlines
  @headlines
end

#html5_media_bundlesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdMediaBundleAsset>

List of media bundle assets that may be used with the ad. Corresponds to the JSON property html5MediaBundles



1219
1220
1221
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1219

def html5_media_bundles
  @html5_media_bundles
end

#imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

List of image assets that may be displayed with the ad. Corresponds to the JSON property images



1224
1225
1226
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1224

def images
  @images
end

#mandatory_ad_textGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset

A text asset used inside an ad. Corresponds to the JSON property mandatoryAdText



1229
1230
1231
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1229

def mandatory_ad_text
  @mandatory_ad_text
end

#youtube_videosArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAsset>

List of YouTube video assets that may be displayed with the ad. Corresponds to the JSON property youtubeVideos



1234
1235
1236
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1234

def youtube_videos
  @youtube_videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1241
1242
1243
1244
1245
1246
1247
1248
1249
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1241

def update!(**args)
  @app_deep_link = args[:app_deep_link] if args.key?(:app_deep_link)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @headlines = args[:headlines] if args.key?(:headlines)
  @html5_media_bundles = args[:html5_media_bundles] if args.key?(:html5_media_bundles)
  @images = args[:images] if args.key?(:images)
  @mandatory_ad_text = args[:mandatory_ad_text] if args.key?(:mandatory_ad_text)
  @youtube_videos = args[:youtube_videos] if args.key?(:youtube_videos)
end