Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppDeepLinkAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An app deep link asset

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAppDeepLinkAsset

Returns a new instance of GoogleAdsSearchads360V23CommonAppDeepLinkAsset.



1262
1263
1264
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1262

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

The uri for the app deep link, The uri can be either a custom scheme uri (e.g. mystore://shoes) or universal uri (e.g. http://www.mystore.com/shoes). Corresponds to the JSON property appDeepLinkUri

Returns:

  • (String)


1260
1261
1262
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1260

def app_deep_link_uri
  @app_deep_link_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1267
1268
1269
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1267

def update!(**args)
  @app_deep_link_uri = args[:app_deep_link_uri] if args.key?(:app_deep_link_uri)
end