Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppEngagementAdInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppEngagementAdInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
App engagement ads allow you to write text encouraging a specific action in the app, like checking in, making a purchase, or booking a flight. They allow you to send users to a specific part of your app where they can find what they' re looking for easier and faster.
Instance Attribute Summary collapse
-
#descriptions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets for descriptions.
-
#headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets for headlines.
-
#images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
List of image assets that may be displayed with the ad.
-
#videos ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAsset>
List of video assets that may be displayed with the ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAppEngagementAdInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonAppEngagementAdInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAppEngagementAdInfo
Returns a new instance of GoogleAdsSearchads360V23CommonAppEngagementAdInfo.
1301 1302 1303 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1301 def initialize(**args) update!(**args) end |
Instance Attribute Details
#descriptions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets for descriptions. When the ad serves the descriptions will
be selected from this list.
Corresponds to the JSON property descriptions
1283 1284 1285 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1283 def descriptions @descriptions end |
#headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets for headlines. When the ad serves the headlines will be
selected from this list.
Corresponds to the JSON property headlines
1289 1290 1291 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1289 def headlines @headlines end |
#images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
List of image assets that may be displayed with the ad.
Corresponds to the JSON property images
1294 1295 1296 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1294 def images @images end |
#videos ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAsset>
List of video assets that may be displayed with the ad.
Corresponds to the JSON property videos
1299 1300 1301 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1299 def videos @videos end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1306 1307 1308 1309 1310 1311 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1306 def update!(**args) @descriptions = args[:descriptions] if args.key?(:descriptions) @headlines = args[:headlines] if args.key?(:headlines) @images = args[:images] if args.key?(:images) @videos = args[:videos] if args.key?(:videos) end |