Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetLinkPrimaryStatusDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Provides the detail of a PrimaryStatus. Each asset link has a PrimaryStatus value (e.g. NOT_ELIGIBLE, meaning not serving), and list of corroborating PrimaryStatusReasons (e.g. [ASSET_DISAPPROVED]). Each reason may have some additional details annotated with it. For instance, when the reason is ASSET_DISAPPROVED, the details field will contain additional information about the offline evaluation errors which led to the asset being disapproved.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAssetLinkPrimaryStatusDetails

Returns a new instance of GoogleAdsSearchads360V23CommonAssetLinkPrimaryStatusDetails.



1447
1448
1449
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_disapprovedGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetDisapproved

Details related to AssetLinkPrimaryStatusReasonPB.ASSET_DISAPPROVED Corresponds to the JSON property assetDisapproved



1435
1436
1437
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1435

def asset_disapproved
  @asset_disapproved
end

#reasonString

Provides the reason of this PrimaryStatus. Corresponds to the JSON property reason

Returns:

  • (String)


1440
1441
1442
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1440

def reason
  @reason
end

#statusString

Provides the PrimaryStatus of this status detail. Corresponds to the JSON property status

Returns:

  • (String)


1445
1446
1447
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1445

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1452
1453
1454
1455
1456
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1452

def update!(**args)
  @asset_disapproved = args[:asset_disapproved] if args.key?(:asset_disapproved)
  @reason = args[:reason] if args.key?(:reason)
  @status = args[:status] if args.key?(:status)
end