Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceDimension
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceDimension
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Positive dimension specifying user's audience.
Instance Attribute Summary collapse
-
#age ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeDimension
Dimension specifying users by their age.
-
#audience_segments ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceSegmentDimension
Dimension specifying users by their membership in other audience segments.
-
#gender ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderDimension
Dimension specifying users by their gender.
-
#household_income ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHouseholdIncomeDimension
Dimension specifying users by their household income.
-
#parental_status ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusDimension
Dimension specifying users by their parental status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAudienceDimension
constructor
A new instance of GoogleAdsSearchads360V23CommonAudienceDimension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAudienceDimension
Returns a new instance of GoogleAdsSearchads360V23CommonAudienceDimension.
1513 1514 1515 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1513 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeDimension
Dimension specifying users by their age.
Corresponds to the JSON property age
1491 1492 1493 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1491 def age @age end |
#audience_segments ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceSegmentDimension
Dimension specifying users by their membership in other audience segments.
Corresponds to the JSON property audienceSegments
1496 1497 1498 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1496 def audience_segments @audience_segments end |
#gender ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderDimension
Dimension specifying users by their gender.
Corresponds to the JSON property gender
1501 1502 1503 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1501 def gender @gender end |
#household_income ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHouseholdIncomeDimension
Dimension specifying users by their household income.
Corresponds to the JSON property householdIncome
1506 1507 1508 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1506 def household_income @household_income end |
#parental_status ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusDimension
Dimension specifying users by their parental status.
Corresponds to the JSON property parentalStatus
1511 1512 1513 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1511 def parental_status @parental_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1518 1519 1520 1521 1522 1523 1524 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1518 def update!(**args) @age = args[:age] if args.key?(:age) @audience_segments = args[:audience_segments] if args.key?(:audience_segments) @gender = args[:gender] if args.key?(:gender) @household_income = args[:household_income] if args.key?(:household_income) @parental_status = args[:parental_status] if args.key?(:parental_status) end |