Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttribute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An audience attribute that can be used to request insights about the audience.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAudienceInsightsAttribute

Returns a new instance of GoogleAdsSearchads360V23CommonAudienceInsightsAttribute.



1635
1636
1637
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1635

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_rangeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo

An age range criterion. Corresponds to the JSON property ageRange



1572
1573
1574
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1572

def age_range
  @age_range
end

#categoryGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsCategory

A Product and Service category. Corresponds to the JSON property category



1577
1578
1579
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1577

def category
  @category
end

#deviceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo

A device criterion. Corresponds to the JSON property device



1582
1583
1584
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1582

def device
  @device
end

#entityGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsEntity

A Knowledge Graph entity, represented by its machine id. Corresponds to the JSON property entity



1587
1588
1589
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1587

def entity
  @entity
end

#genderGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo

A gender criterion. Corresponds to the JSON property gender



1592
1593
1594
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1592

def gender
  @gender
end

#income_rangeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIncomeRangeInfo

An income range criterion. Corresponds to the JSON property incomeRange



1597
1598
1599
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1597

def income_range
  @income_range
end

#lineupGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsLineup

A YouTube Lineup. Corresponds to the JSON property lineup



1602
1603
1604
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1602

def lineup
  @lineup
end

#locationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo

A location criterion. Corresponds to the JSON property location



1607
1608
1609
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1607

def location
  @location
end

#parental_statusGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo

A parental status criterion. Corresponds to the JSON property parentalStatus



1612
1613
1614
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1612

def parental_status
  @parental_status
end

#user_interestGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserInterestInfo

Represents a particular interest-based topic to be targeted. Corresponds to the JSON property userInterest



1617
1618
1619
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1617

def user_interest
  @user_interest
end

#user_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListInfo

A User List criterion. Represents a user list that is defined by the advertiser to be targeted. Corresponds to the JSON property userList



1623
1624
1625
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1623

def user_list
  @user_list
end

#youtube_channelGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo

A YouTube Channel criterion. Corresponds to the JSON property youtubeChannel



1628
1629
1630
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1628

def youtube_channel
  @youtube_channel
end

#youtube_videoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo

A YouTube Video criterion. Corresponds to the JSON property youtubeVideo



1633
1634
1635
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1633

def youtube_video
  @youtube_video
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1640

def update!(**args)
  @age_range = args[:age_range] if args.key?(:age_range)
  @category = args[:category] if args.key?(:category)
  @device = args[:device] if args.key?(:device)
  @entity = args[:entity] if args.key?(:entity)
  @gender = args[:gender] if args.key?(:gender)
  @income_range = args[:income_range] if args.key?(:income_range)
  @lineup = args[:lineup] if args.key?(:lineup)
  @location = args[:location] if args.key?(:location)
  @parental_status = args[:parental_status] if args.key?(:parental_status)
  @user_interest = args[:user_interest] if args.key?(:user_interest)
  @user_list = args[:user_list] if args.key?(:user_list)
  @youtube_channel = args[:youtube_channel] if args.key?(:youtube_channel)
  @youtube_video = args[:youtube_video] if args.key?(:youtube_video)
end