Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceSegmentDimension

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Dimension specifying users by their membership in other audience segments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAudienceSegmentDimension

Returns a new instance of GoogleAdsSearchads360V23CommonAudienceSegmentDimension.



1892
1893
1894
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#segmentsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceSegment>

Included audience segments. Users are included if they belong to at least one segment. Corresponds to the JSON property segments



1890
1891
1892
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1890

def segments
  @segments
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1897
1898
1899
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1897

def update!(**args)
  @segments = args[:segments] if args.key?(:segments)
end