Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a Brand Criterion used for targeting based on commercial knowledge graph.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBrandInfo

Returns a new instance of GoogleAdsSearchads360V23CommonBrandInfo.



1965
1966
1967
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. A text representation of a brand. Corresponds to the JSON property displayName

Returns:

  • (String)


1943
1944
1945
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1943

def display_name
  @display_name
end

#entity_idString

The Commercial KG MID for the brand. Corresponds to the JSON property entityId

Returns:

  • (String)


1948
1949
1950
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1948

def entity_id
  @entity_id
end

#primary_urlString

Output only. The primary url of a brand. Corresponds to the JSON property primaryUrl

Returns:

  • (String)


1953
1954
1955
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1953

def primary_url
  @primary_url
end

#rejection_reasonString

Output only. The rejection reason when a brand status is REJECTED. Corresponds to the JSON property rejectionReason

Returns:

  • (String)


1958
1959
1960
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1958

def rejection_reason
  @rejection_reason
end

#statusString

Output only. The status of a brand. Corresponds to the JSON property status

Returns:

  • (String)


1963
1964
1965
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1963

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1970
1971
1972
1973
1974
1975
1976
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1970

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
  @primary_url = args[:primary_url] if args.key?(:primary_url)
  @rejection_reason = args[:rejection_reason] if args.key?(:rejection_reason)
  @status = args[:status] if args.key?(:status)
end