Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBudgetSimulationPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Projected metrics for a specific budget amount.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBudgetSimulationPoint

Returns a new instance of GoogleAdsSearchads360V23CommonBudgetSimulationPoint.



2053
2054
2055
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2053

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#biddable_conversionsFloat

Projected number of biddable conversions. Corresponds to the JSON property biddableConversions

Returns:

  • (Float)


2007
2008
2009
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2007

def biddable_conversions
  @biddable_conversions
end

#biddable_conversions_valueFloat

Projected total value of biddable conversions. Corresponds to the JSON property biddableConversionsValue

Returns:

  • (Float)


2012
2013
2014
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2012

def biddable_conversions_value
  @biddable_conversions_value
end

#budget_amount_microsFixnum

The simulated budget upon which projected metrics are based. Corresponds to the JSON property budgetAmountMicros

Returns:

  • (Fixnum)


2017
2018
2019
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2017

def budget_amount_micros
  @budget_amount_micros
end

#clicksFixnum

Projected number of clicks. Corresponds to the JSON property clicks

Returns:

  • (Fixnum)


2022
2023
2024
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2022

def clicks
  @clicks
end

#cost_microsFixnum

Projected cost in micros. Corresponds to the JSON property costMicros

Returns:

  • (Fixnum)


2027
2028
2029
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2027

def cost_micros
  @cost_micros
end

#impressionsFixnum

Projected number of impressions. Corresponds to the JSON property impressions

Returns:

  • (Fixnum)


2032
2033
2034
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2032

def impressions
  @impressions
end

#interactionsFixnum

Projected number of interactions. Only discovery advertising channel type supports this field. Corresponds to the JSON property interactions

Returns:

  • (Fixnum)


2038
2039
2040
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2038

def interactions
  @interactions
end

#required_cpc_bid_ceiling_microsFixnum

Projected required daily cpc bid ceiling that the advertiser must set to realize this simulation, in micros of the advertiser currency. Only campaigns with the Target Spend bidding strategy support this field. Corresponds to the JSON property requiredCpcBidCeilingMicros

Returns:

  • (Fixnum)


2045
2046
2047
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2045

def required_cpc_bid_ceiling_micros
  @required_cpc_bid_ceiling_micros
end

#top_slot_impressionsFixnum

Projected number of top slot impressions. Only search advertising channel type supports this field. Corresponds to the JSON property topSlotImpressions

Returns:

  • (Fixnum)


2051
2052
2053
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2051

def top_slot_impressions
  @top_slot_impressions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2058

def update!(**args)
  @biddable_conversions = args[:biddable_conversions] if args.key?(:biddable_conversions)
  @biddable_conversions_value = args[:biddable_conversions_value] if args.key?(:biddable_conversions_value)
  @budget_amount_micros = args[:budget_amount_micros] if args.key?(:budget_amount_micros)
  @clicks = args[:clicks] if args.key?(:clicks)
  @cost_micros = args[:cost_micros] if args.key?(:cost_micros)
  @impressions = args[:impressions] if args.key?(:impressions)
  @interactions = args[:interactions] if args.key?(:interactions)
  @required_cpc_bid_ceiling_micros = args[:required_cpc_bid_ceiling_micros] if args.key?(:required_cpc_bid_ceiling_micros)
  @top_slot_impressions = args[:top_slot_impressions] if args.key?(:top_slot_impressions)
end