Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessMessageAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A business message asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBusinessMessageAsset

Returns a new instance of GoogleAdsSearchads360V23CommonBusinessMessageAsset.



2124
2125
2126
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2124

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_to_actionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessMessageCallToActionInfo

Display information that encourages the user to take action. Corresponds to the JSON property callToAction



2097
2098
2099
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2097

def call_to_action
  @call_to_action
end

#facebook_messenger_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFacebookMessengerBusinessMessageInfo

Facebook Messenger information to use for messaging. Corresponds to the JSON property facebookMessengerInfo



2102
2103
2104
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2102

def facebook_messenger_info
  @facebook_messenger_info
end

#message_providerString

Required. Message provider of the business message asset. Corresponds to the JSON property messageProvider

Returns:

  • (String)


2107
2108
2109
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2107

def message_provider
  @message_provider
end

#starter_messageString

Required. A welcome message to prompt the user to initiate a conversation. Corresponds to the JSON property starterMessage

Returns:

  • (String)


2112
2113
2114
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2112

def starter_message
  @starter_message
end

#whatsapp_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWhatsappBusinessMessageInfo

Whatsapp information to use for messaging. Corresponds to the JSON property whatsappInfo



2117
2118
2119
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2117

def whatsapp_info
  @whatsapp_info
end

#zalo_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonZaloBusinessMessageInfo

Zalo information to use for messaging. Corresponds to the JSON property zaloInfo



2122
2123
2124
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2122

def zalo_info
  @zalo_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2129
2130
2131
2132
2133
2134
2135
2136
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2129

def update!(**args)
  @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
  @facebook_messenger_info = args[:facebook_messenger_info] if args.key?(:facebook_messenger_info)
  @message_provider = args[:message_provider] if args.key?(:message_provider)
  @starter_message = args[:starter_message] if args.key?(:starter_message)
  @whatsapp_info = args[:whatsapp_info] if args.key?(:whatsapp_info)
  @zalo_info = args[:zalo_info] if args.key?(:zalo_info)
end