Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Business Profile location data synced from the linked Business Profile account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBusinessProfileLocation

Returns a new instance of GoogleAdsSearchads360V23CommonBusinessProfileLocation.



2213
2214
2215
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsArray<String>

Advertiser specified label for the location on the Business Profile account. This is synced from the Business Profile account. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


2199
2200
2201
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2199

def labels
  @labels
end

#listing_idFixnum

Listing ID of this Business Profile location. This is synced from the linked Business Profile account. Corresponds to the JSON property listingId

Returns:

  • (Fixnum)


2205
2206
2207
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2205

def listing_id
  @listing_id
end

#store_codeString

Business Profile store code of this location. This is synced from the Business Profile account. Corresponds to the JSON property storeCode

Returns:

  • (String)


2211
2212
2213
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2211

def store_code
  @store_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2218
2219
2220
2221
2222
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2218

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @listing_id = args[:listing_id] if args.key?(:listing_id)
  @store_code = args[:store_code] if args.key?(:store_code)
end