Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileLocationGroup
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileLocationGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Information about a Business Profile dynamic location group. Only applicable if the sync level AssetSet's type is LOCATION_SYNC and sync source is Business Profile.
Instance Attribute Summary collapse
-
#dynamic_business_profile_location_group_filter ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicBusinessProfileLocationGroupFilter
Represents a filter on Business Profile locations in an asset set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBusinessProfileLocationGroup
constructor
A new instance of GoogleAdsSearchads360V23CommonBusinessProfileLocationGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBusinessProfileLocationGroup
Returns a new instance of GoogleAdsSearchads360V23CommonBusinessProfileLocationGroup.
2177 2178 2179 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2177 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dynamic_business_profile_location_group_filter ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicBusinessProfileLocationGroupFilter
Represents a filter on Business Profile locations in an asset set. If multiple
filters are provided, they are AND'ed together.
Corresponds to the JSON property dynamicBusinessProfileLocationGroupFilter
2175 2176 2177 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2175 def dynamic_business_profile_location_group_filter @dynamic_business_profile_location_group_filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2182 2183 2184 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2182 def update!(**args) @dynamic_business_profile_location_group_filter = args[:dynamic_business_profile_location_group_filter] if args.key?(:dynamic_business_profile_location_group_filter) end |