Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCallAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Call asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCallAsset

Returns a new instance of GoogleAdsSearchads360V23CommonCallAsset.



2285
2286
2287
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2285

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_schedule_targetsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>

List of non-overlapping schedules specifying all time intervals for which the asset may serve. There can be a maximum of 6 schedules per day, 42 in total. Corresponds to the JSON property adScheduleTargets



2258
2259
2260
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2258

def ad_schedule_targets
  @ad_schedule_targets
end

#call_conversion_actionString

The conversion action to attribute a call conversion to. If not set, the default conversion action is used. This field only has effect if call_conversion_reporting_state is set to USE_RESOURCE_LEVEL_CALL_CONVERSION_ACTION. Corresponds to the JSON property callConversionAction

Returns:

  • (String)


2266
2267
2268
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2266

def call_conversion_action
  @call_conversion_action
end

#call_conversion_reporting_stateString

Indicates whether this CallAsset should use its own call conversion setting, follow the account level setting, or disable call conversion. Corresponds to the JSON property callConversionReportingState

Returns:

  • (String)


2272
2273
2274
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2272

def call_conversion_reporting_state
  @call_conversion_reporting_state
end

#country_codeString

Required. Two-letter country code of the phone number. Examples: 'US', 'us'. Corresponds to the JSON property countryCode

Returns:

  • (String)


2277
2278
2279
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2277

def country_code
  @country_code
end

#phone_numberString

Required. The advertiser's raw phone number. Examples: '1234567890', '(123)456- 7890' Corresponds to the JSON property phoneNumber

Returns:

  • (String)


2283
2284
2285
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2283

def phone_number
  @phone_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2290
2291
2292
2293
2294
2295
2296
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2290

def update!(**args)
  @ad_schedule_targets = args[:ad_schedule_targets] if args.key?(:ad_schedule_targets)
  @call_conversion_action = args[:call_conversion_action] if args.key?(:call_conversion_action)
  @call_conversion_reporting_state = args[:call_conversion_reporting_state] if args.key?(:call_conversion_reporting_state)
  @country_code = args[:country_code] if args.key?(:country_code)
  @phone_number = args[:phone_number] if args.key?(:phone_number)
end