Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCampaignGoalSettingsCampaignNewCustomerAcquisitionGoalSettings
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCampaignGoalSettingsCampaignNewCustomerAcquisitionGoalSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
New Customer Acquisition campaign goal settings.
Instance Attribute Summary collapse
-
#target_option ⇒ String
New Customer Acquisition goal optimization mode for this campaign.
-
#value_settings_override ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerLifecycleOptimizationValueSettings
Lifecycle goal optimization value settings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCampaignGoalSettingsCampaignNewCustomerAcquisitionGoalSettings
constructor
A new instance of GoogleAdsSearchads360V23CommonCampaignGoalSettingsCampaignNewCustomerAcquisitionGoalSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCampaignGoalSettingsCampaignNewCustomerAcquisitionGoalSettings
Returns a new instance of GoogleAdsSearchads360V23CommonCampaignGoalSettingsCampaignNewCustomerAcquisitionGoalSettings.
386 387 388 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 386 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_option ⇒ String
New Customer Acquisition goal optimization mode for this campaign. Defaults to
TARGET_ALL. Whether the campaign is targeting new customers only.
Corresponds to the JSON property targetOption
379 380 381 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 379 def target_option @target_option end |
#value_settings_override ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerLifecycleOptimizationValueSettings
Lifecycle goal optimization value settings.
Corresponds to the JSON property valueSettingsOverride
384 385 386 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 384 def value_settings_override @value_settings_override end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
391 392 393 394 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 391 def update!(**args) @target_option = args[:target_option] if args.key?(:target_option) @value_settings_override = args[:value_settings_override] if args.key?(:value_settings_override) end |