Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonChainSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Data used to configure a location set populated with the specified chains.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonChainSet

Returns a new instance of GoogleAdsSearchads360V23CommonChainSet.



2742
2743
2744
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2742

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chainsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonChainFilter>

Required. A list of chain level filters, all filters are OR'ed together. Corresponds to the JSON property chains



2734
2735
2736
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2734

def chains
  @chains
end

#relationship_typeString

Required. Immutable. Relationship type the specified chains have with this advertiser. Corresponds to the JSON property relationshipType

Returns:

  • (String)


2740
2741
2742
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2740

def relationship_type
  @relationship_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2747
2748
2749
2750
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2747

def update!(**args)
  @chains = args[:chains] if args.key?(:chains)
  @relationship_type = args[:relationship_type] if args.key?(:relationship_type)
end