Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonClickLocation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonClickLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Location criteria associated with a click.
Instance Attribute Summary collapse
-
#city ⇒ String
The city location criterion associated with the impression.
-
#country ⇒ String
The country location criterion associated with the impression.
-
#metro ⇒ String
The metro location criterion associated with the impression.
-
#most_specific ⇒ String
The most specific location criterion associated with the impression.
-
#region ⇒ String
The region location criterion associated with the impression.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonClickLocation
constructor
A new instance of GoogleAdsSearchads360V23CommonClickLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonClickLocation
Returns a new instance of GoogleAdsSearchads360V23CommonClickLocation.
2722 2723 2724 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2722 def initialize(**args) update!(**args) end |
Instance Attribute Details
#city ⇒ String
The city location criterion associated with the impression.
Corresponds to the JSON property city
2700 2701 2702 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2700 def city @city end |
#country ⇒ String
The country location criterion associated with the impression.
Corresponds to the JSON property country
2705 2706 2707 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2705 def country @country end |
#metro ⇒ String
The metro location criterion associated with the impression.
Corresponds to the JSON property metro
2710 2711 2712 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2710 def metro @metro end |
#most_specific ⇒ String
The most specific location criterion associated with the impression.
Corresponds to the JSON property mostSpecific
2715 2716 2717 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2715 def most_specific @most_specific end |
#region ⇒ String
The region location criterion associated with the impression.
Corresponds to the JSON property region
2720 2721 2722 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2720 def region @region end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2727 2728 2729 2730 2731 2732 2733 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2727 def update!(**args) @city = args[:city] if args.key?(:city) @country = args[:country] if args.key?(:country) @metro = args[:metro] if args.key?(:metro) @most_specific = args[:most_specific] if args.key?(:most_specific) @region = args[:region] if args.key?(:region) end |