Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCommission

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Commission is an automatic bidding strategy in which the advertiser pays a certain portion of the conversion value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCommission

Returns a new instance of GoogleAdsSearchads360V23CommonCommission.



2768
2769
2770
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commission_rate_microsFixnum

Commission rate defines the portion of the conversion value that the advertiser will be billed. A commission rate of x should be passed into this field as (x * 1,000,000). For example, 106,000 represents a commission rate of 0.106 (10.6%). Corresponds to the JSON property commissionRateMicros

Returns:

  • (Fixnum)


2766
2767
2768
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2766

def commission_rate_micros
  @commission_rate_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2773
2774
2775
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2773

def update!(**args)
  @commission_rate_micros = args[:commission_rate_micros] if args.key?(:commission_rate_micros)
end