Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryChannelAvailability
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryChannelAvailability
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Information of advertising channel type and subtypes a category is available in.
Instance Attribute Summary collapse
-
#advertising_channel_sub_type ⇒ Array<String>
Channel subtypes under the channel type the category is available to.
-
#advertising_channel_type ⇒ String
Channel type the category is available to.
-
#availability_mode ⇒ String
Format of the channel availability.
-
#include_default_channel_sub_type ⇒ Boolean
(also: #include_default_channel_sub_type?)
Whether default channel sub type is included.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCriterionCategoryChannelAvailability
constructor
A new instance of GoogleAdsSearchads360V23CommonCriterionCategoryChannelAvailability.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCriterionCategoryChannelAvailability
Returns a new instance of GoogleAdsSearchads360V23CommonCriterionCategoryChannelAvailability.
3113 3114 3115 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3113 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertising_channel_sub_type ⇒ Array<String>
Channel subtypes under the channel type the category is available to.
Corresponds to the JSON property advertisingChannelSubType
3087 3088 3089 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3087 def advertising_channel_sub_type @advertising_channel_sub_type end |
#advertising_channel_type ⇒ String
Channel type the category is available to.
Corresponds to the JSON property advertisingChannelType
3092 3093 3094 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3092 def advertising_channel_type @advertising_channel_type end |
#availability_mode ⇒ String
Format of the channel availability. Can be ALL_CHANNELS (the rest of the
fields will not be set), CHANNEL_TYPE (only advertising_channel_type type will
be set, the category is available to all sub types under it) or
CHANNEL_TYPE_AND_SUBTYPES (advertising_channel_type,
advertising_channel_sub_type, and include_default_channel_sub_type will all be
set).
Corresponds to the JSON property availabilityMode
3102 3103 3104 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3102 def availability_mode @availability_mode end |
#include_default_channel_sub_type ⇒ Boolean Also known as: include_default_channel_sub_type?
Whether default channel sub type is included. For example,
advertising_channel_type being DISPLAY and include_default_channel_sub_type
being false means that the default display campaign where channel sub type is
not set is not included in this availability configuration.
Corresponds to the JSON property includeDefaultChannelSubType
3110 3111 3112 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3110 def include_default_channel_sub_type @include_default_channel_sub_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3118 3119 3120 3121 3122 3123 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3118 def update!(**args) @advertising_channel_sub_type = args[:advertising_channel_sub_type] if args.key?(:advertising_channel_sub_type) @advertising_channel_type = args[:advertising_channel_type] if args.key?(:advertising_channel_type) @availability_mode = args[:availability_mode] if args.key?(:availability_mode) @include_default_channel_sub_type = args[:include_default_channel_sub_type] if args.key?(:include_default_channel_sub_type) end |