Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCrmBasedUserListInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCrmBasedUserListInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
UserList of CRM users provided by the advertiser.
Instance Attribute Summary collapse
-
#app_id ⇒ String
A string that uniquely identifies a mobile application from which the data was collected.
-
#data_source_type ⇒ String
Data source of the list.
-
#upload_key_type ⇒ String
Matching key type of the list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCrmBasedUserListInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonCrmBasedUserListInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCrmBasedUserListInfo
Returns a new instance of GoogleAdsSearchads360V23CommonCrmBasedUserListInfo.
3188 3189 3190 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3188 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ String
A string that uniquely identifies a mobile application from which the data was
collected. For iOS, the ID string is the 9 digit string that appears at the
end of an App Store URL (for example, "476943146" for "Flood-It! 2" whose App
Store link is http://itunes.apple.com/us/app/flood-it!-2/id476943146). For
Android, the ID string is the application's package name (for example, "com.
labpixies.colordrips" for "Color Drips" given Google Play link https://play.
google.com/store/apps/details?id=com.labpixies.colordrips). Required when
creating CrmBasedUserList for uploading mobile advertising IDs.
Corresponds to the JSON property appId
3174 3175 3176 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3174 def app_id @app_id end |
#data_source_type ⇒ String
Data source of the list. Default value is FIRST_PARTY. Only customers on the
allow-list can create third-party sourced CRM lists.
Corresponds to the JSON property dataSourceType
3180 3181 3182 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3180 def data_source_type @data_source_type end |
#upload_key_type ⇒ String
Matching key type of the list. Mixed data types are not allowed on the same
list. This field is required for an ADD operation.
Corresponds to the JSON property uploadKeyType
3186 3187 3188 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3186 def upload_key_type @upload_key_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3193 3194 3195 3196 3197 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3193 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @data_source_type = args[:data_source_type] if args.key?(:data_source_type) @upload_key_type = args[:upload_key_type] if args.key?(:upload_key_type) end |