Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Metadata for customer match user list.
Instance Attribute Summary collapse
-
#consent ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonConsent
Consent Corresponds to the JSON property
consent. -
#user_list ⇒ String
The resource name of remarketing list to update data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata
constructor
A new instance of GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata
Returns a new instance of GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata.
3346 3347 3348 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consent ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonConsent
Consent
Corresponds to the JSON property consent
3338 3339 3340 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3338 def @consent end |
#user_list ⇒ String
The resource name of remarketing list to update data. Required for job of
CUSTOMER_MATCH_USER_LIST type.
Corresponds to the JSON property userList
3344 3345 3346 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3344 def user_list @user_list end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3351 3352 3353 3354 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3351 def update!(**args) @consent = args[:consent] if args.key?(:consent) @user_list = args[:user_list] if args.key?(:user_list) end |