Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerThirdPartyBrandLiftIntegrationPartner

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Container for third party Brand Lift integration data for Customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomerThirdPartyBrandLiftIntegrationPartner

Returns a new instance of GoogleAdsSearchads360V23CommonCustomerThirdPartyBrandLiftIntegrationPartner.



3372
3373
3374
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_share_costBoolean Also known as: allow_share_cost?

If true, cost data can be shared with this vendor. Corresponds to the JSON property allowShareCost

Returns:

  • (Boolean)


3364
3365
3366
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3364

def allow_share_cost
  @allow_share_cost
end

#brand_lift_integration_partnerString

Allowed Third Party integration partners for Brand Lift verification. Corresponds to the JSON property brandLiftIntegrationPartner

Returns:

  • (String)


3370
3371
3372
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3370

def brand_lift_integration_partner
  @brand_lift_integration_partner
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3377
3378
3379
3380
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3377

def update!(**args)
  @allow_share_cost = args[:allow_share_cost] if args.key?(:allow_share_cost)
  @brand_lift_integration_partner = args[:brand_lift_integration_partner] if args.key?(:brand_lift_integration_partner)
end