Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerThirdPartyReachIntegrationPartner

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Container for third party reach integration data for Customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomerThirdPartyReachIntegrationPartner

Returns a new instance of GoogleAdsSearchads360V23CommonCustomerThirdPartyReachIntegrationPartner.



3454
3455
3456
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3454

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_share_costBoolean Also known as: allow_share_cost?

If true, cost data can be shared with this vendor. Corresponds to the JSON property allowShareCost

Returns:

  • (Boolean)


3446
3447
3448
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3446

def allow_share_cost
  @allow_share_cost
end

#reach_integration_partnerString

Allowed Third Party integration partners for reach verification. Corresponds to the JSON property reachIntegrationPartner

Returns:

  • (String)


3452
3453
3454
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3452

def reach_integration_partner
  @reach_integration_partner
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3459
3460
3461
3462
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3459

def update!(**args)
  @allow_share_cost = args[:allow_share_cost] if args.key?(:allow_share_cost)
  @reach_integration_partner = args[:reach_integration_partner] if args.key?(:reach_integration_partner)
end