Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerThirdPartyViewabilityIntegrationPartner

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Container for third party viewability integration data for Customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomerThirdPartyViewabilityIntegrationPartner

Returns a new instance of GoogleAdsSearchads360V23CommonCustomerThirdPartyViewabilityIntegrationPartner.



3480
3481
3482
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3480

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_share_costBoolean Also known as: allow_share_cost?

If true, cost data can be shared with this vendor. Corresponds to the JSON property allowShareCost

Returns:

  • (Boolean)


3472
3473
3474
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3472

def allow_share_cost
  @allow_share_cost
end

#viewability_integration_partnerString

Allowed third party integration partners for YouTube viewability verification. Corresponds to the JSON property viewabilityIntegrationPartner

Returns:

  • (String)


3478
3479
3480
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3478

def viewability_integration_partner
  @viewability_integration_partner
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3485
3486
3487
3488
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3485

def update!(**args)
  @allow_share_cost = args[:allow_share_cost] if args.key?(:allow_share_cost)
  @viewability_integration_partner = args[:viewability_integration_partner] if args.key?(:viewability_integration_partner)
end