Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenCarouselCardAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenCarouselCardAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Demand Gen Carousel Card asset.
Instance Attribute Summary collapse
-
#call_to_action_text ⇒ String
Call to action text.
-
#headline ⇒ String
Required.
-
#marketing_image_asset ⇒ String
Asset resource name of the associated 1.91:1 marketing image.
-
#portrait_marketing_image_asset ⇒ String
Asset resource name of the associated 4:5 portrait marketing image.
-
#square_marketing_image_asset ⇒ String
Asset resource name of the associated square marketing image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDemandGenCarouselCardAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonDemandGenCarouselCardAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDemandGenCarouselCardAsset
Returns a new instance of GoogleAdsSearchads360V23CommonDemandGenCarouselCardAsset.
3625 3626 3627 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#call_to_action_text ⇒ String
Call to action text.
Corresponds to the JSON property callToActionText
3601 3602 3603 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3601 def call_to_action_text @call_to_action_text end |
#headline ⇒ String
Required. Headline of the carousel card.
Corresponds to the JSON property headline
3606 3607 3608 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3606 def headline @headline end |
#marketing_image_asset ⇒ String
Asset resource name of the associated 1.91:1 marketing image. This and/or
square marketing image asset is required.
Corresponds to the JSON property marketingImageAsset
3612 3613 3614 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3612 def marketing_image_asset @marketing_image_asset end |
#portrait_marketing_image_asset ⇒ String
Asset resource name of the associated 4:5 portrait marketing image.
Corresponds to the JSON property portraitMarketingImageAsset
3617 3618 3619 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3617 def portrait_marketing_image_asset @portrait_marketing_image_asset end |
#square_marketing_image_asset ⇒ String
Asset resource name of the associated square marketing image. This and/or a
marketing image asset is required.
Corresponds to the JSON property squareMarketingImageAsset
3623 3624 3625 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3623 def square_marketing_image_asset @square_marketing_image_asset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3630 3631 3632 3633 3634 3635 3636 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3630 def update!(**args) @call_to_action_text = args[:call_to_action_text] if args.key?(:call_to_action_text) @headline = args[:headline] if args.key?(:headline) @marketing_image_asset = args[:marketing_image_asset] if args.key?(:marketing_image_asset) @portrait_marketing_image_asset = args[:portrait_marketing_image_asset] if args.key?(:portrait_marketing_image_asset) @square_marketing_image_asset = args[:square_marketing_image_asset] if args.key?(:square_marketing_image_asset) end |