Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenVideoResponsiveAdInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Demand Gen video responsive ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDemandGenVideoResponsiveAdInfo

Returns a new instance of GoogleAdsSearchads360V23CommonDemandGenVideoResponsiveAdInfo.



3830
3831
3832
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3830

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

First part of text that appears in the ad with the displayed URL. Corresponds to the JSON property breadcrumb1

Returns:

  • (String)


3781
3782
3783
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3781

def breadcrumb1
  @breadcrumb1
end

Second part of text that appears in the ad with the displayed URL. Corresponds to the JSON property breadcrumb2

Returns:

  • (String)


3786
3787
3788
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3786

def breadcrumb2
  @breadcrumb2
end

#business_nameGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset

A text asset used inside an ad. Corresponds to the JSON property businessName



3791
3792
3793
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3791

def business_name
  @business_name
end

#call_to_actionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdCallToActionAsset>

Assets of type CallToActionAsset used for the "Call To Action" button. Corresponds to the JSON property callToActions



3796
3797
3798
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3796

def call_to_actions
  @call_to_actions
end

#companion_bannersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

List of image assets used for the companion banner. Currently, only a single value for the companion banner asset is supported. Corresponds to the JSON property companionBanners



3802
3803
3804
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3802

def companion_banners
  @companion_banners
end

#descriptionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

List of text assets used for the description. Corresponds to the JSON property descriptions



3807
3808
3809
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3807

def descriptions
  @descriptions
end

#headlinesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

List of text assets used for the short headline. Corresponds to the JSON property headlines



3812
3813
3814
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3812

def headlines
  @headlines
end

#logo_imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

Logo image to be used in the ad. Valid image types are GIF, JPEG, and PNG. The minimum size is 128x128 and the aspect ratio must be 1:1 (+-1%). Corresponds to the JSON property logoImages



3818
3819
3820
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3818

def logo_images
  @logo_images
end

#long_headlinesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

List of text assets used for the long headline. Corresponds to the JSON property longHeadlines



3823
3824
3825
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3823

def long_headlines
  @long_headlines
end

#videosArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAsset>

List of YouTube video assets used for the ad. Corresponds to the JSON property videos



3828
3829
3830
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3828

def videos
  @videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3835
3836
3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3835

def update!(**args)
  @breadcrumb1 = args[:breadcrumb1] if args.key?(:breadcrumb1)
  @breadcrumb2 = args[:breadcrumb2] if args.key?(:breadcrumb2)
  @business_name = args[:business_name] if args.key?(:business_name)
  @call_to_actions = args[:call_to_actions] if args.key?(:call_to_actions)
  @companion_banners = args[:companion_banners] if args.key?(:companion_banners)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @headlines = args[:headlines] if args.key?(:headlines)
  @logo_images = args[:logo_images] if args.key?(:logo_images)
  @long_headlines = args[:long_headlines] if args.key?(:long_headlines)
  @videos = args[:videos] if args.key?(:videos)
end