Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicEducationAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Dynamic Education asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicEducationAsset

Returns a new instance of GoogleAdsSearchads360V23CommonDynamicEducationAsset.



4160
4161
4162
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

School address which can be specified in one of the following formats. (1) City, state, code, country, for example, Mountain View, CA, USA. (2) Full address, for example, 123 Boulevard St, Mountain View, CA 94043. (3) Latitude- longitude in the DDD format, for example, 41.40338, 2.17403 Corresponds to the JSON property address

Returns:

  • (String)


4087
4088
4089
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4087

def address
  @address
end

Android deep link, for example, android-app://com.example.android/http/example. com/gizmos?1234. Corresponds to the JSON property androidAppLink

Returns:

  • (String)


4093
4094
4095
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4093

def android_app_link
  @android_app_link
end

#contextual_keywordsArray<String>

Contextual keywords, for example, Nursing certification, Health, Mountain View. Corresponds to the JSON property contextualKeywords

Returns:

  • (Array<String>)


4098
4099
4100
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4098

def contextual_keywords
  @contextual_keywords
end

#image_urlString

Image url, for example, http://www.example.com/image.png. The image will not be uploaded as image asset. Corresponds to the JSON property imageUrl

Returns:

  • (String)


4104
4105
4106
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4104

def image_url
  @image_url
end

iOS deep link, for example, exampleApp://content/page. Corresponds to the JSON property iosAppLink

Returns:

  • (String)


4109
4110
4111
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4109

def ios_app_link
  @ios_app_link
end

#ios_app_store_idFixnum

iOS app store ID. This is used to check if the user has the app installed on their device before deep linking. If this field is set, then the ios_app_link field must also be present. Corresponds to the JSON property iosAppStoreId

Returns:

  • (Fixnum)


4116
4117
4118
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4116

def ios_app_store_id
  @ios_app_store_id
end

#location_idString

Location ID which can be any sequence of letters and digits and must be unique. Corresponds to the JSON property locationId

Returns:

  • (String)


4121
4122
4123
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4121

def location_id
  @location_id
end

#program_descriptionString

Program description, for example, Nursing Certification. Corresponds to the JSON property programDescription

Returns:

  • (String)


4126
4127
4128
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4126

def program_description
  @program_description
end

#program_idString

Required. Program ID which can be any sequence of letters and digits, and must be unique and match the values of remarketing tag. Required. Corresponds to the JSON property programId

Returns:

  • (String)


4132
4133
4134
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4132

def program_id
  @program_id
end

#program_nameString

Required. Program name, for example, Nursing. Required. Corresponds to the JSON property programName

Returns:

  • (String)


4137
4138
4139
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4137

def program_name
  @program_name
end

#school_nameString

School name, for example, Mountain View School of Nursing. Corresponds to the JSON property schoolName

Returns:

  • (String)


4142
4143
4144
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4142

def school_name
  @school_name
end

#similar_program_idsArray<String>

Similar program IDs. Corresponds to the JSON property similarProgramIds

Returns:

  • (Array<String>)


4147
4148
4149
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4147

def similar_program_ids
  @similar_program_ids
end

#subjectString

Subject of study, for example, Health. Corresponds to the JSON property subject

Returns:

  • (String)


4152
4153
4154
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4152

def subject
  @subject
end

#thumbnail_image_urlString

Thumbnail image url, for example, http://www.example.com/thumbnail.png. The thumbnail image will not be uploaded as image asset. Corresponds to the JSON property thumbnailImageUrl

Returns:

  • (String)


4158
4159
4160
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4158

def thumbnail_image_url
  @thumbnail_image_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4165
4166
4167
4168
4169
4170
4171
4172
4173
4174
4175
4176
4177
4178
4179
4180
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4165

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @android_app_link = args[:android_app_link] if args.key?(:android_app_link)
  @contextual_keywords = args[:contextual_keywords] if args.key?(:contextual_keywords)
  @image_url = args[:image_url] if args.key?(:image_url)
  @ios_app_link = args[:ios_app_link] if args.key?(:ios_app_link)
  @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id)
  @location_id = args[:location_id] if args.key?(:location_id)
  @program_description = args[:program_description] if args.key?(:program_description)
  @program_id = args[:program_id] if args.key?(:program_id)
  @program_name = args[:program_name] if args.key?(:program_name)
  @school_name = args[:school_name] if args.key?(:school_name)
  @similar_program_ids = args[:similar_program_ids] if args.key?(:similar_program_ids)
  @subject = args[:subject] if args.key?(:subject)
  @thumbnail_image_url = args[:thumbnail_image_url] if args.key?(:thumbnail_image_url)
end