Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicHotelsAndRentalsAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A dynamic hotels and rentals asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicHotelsAndRentalsAsset

Returns a new instance of GoogleAdsSearchads360V23CommonDynamicHotelsAndRentalsAsset.



4401
4402
4403
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Address which can be specified in one of the following formats. (1) City, state, code, country, for example, Mountain View, CA, USA. (2) Full address, for example, 123 Boulevard St, Mountain View, CA 94043. (3) Latitude-longitude in the DDD format, for example, 41.40338, 2.17403 Corresponds to the JSON property address

Returns:

  • (String)


4310
4311
4312
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4310

def address
  @address
end

Android deep link, for example, android-app://com.example.android/http/example. com/gizmos?1234. Corresponds to the JSON property androidAppLink

Returns:

  • (String)


4316
4317
4318
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4316

def android_app_link
  @android_app_link
end

#categoryString

Category, for example, Hotel suite. Corresponds to the JSON property category

Returns:

  • (String)


4321
4322
4323
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4321

def category
  @category
end

#contextual_keywordsArray<String>

Contextual keywords, for example, Mountain View "Hotels", South Bay hotels. Corresponds to the JSON property contextualKeywords

Returns:

  • (Array<String>)


4326
4327
4328
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4326

def contextual_keywords
  @contextual_keywords
end

#descriptionString

Description, for example, Close to SJC Airport. Corresponds to the JSON property description

Returns:

  • (String)


4331
4332
4333
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4331

def description
  @description
end

#destination_nameString

Destination name, for example, Downtown Mountain View. Corresponds to the JSON property destinationName

Returns:

  • (String)


4336
4337
4338
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4336

def destination_name
  @destination_name
end

#formatted_priceString

Formatted price which can be any characters. If set, this attribute will be used instead of 'price', for example, Starting at $100.00. Corresponds to the JSON property formattedPrice

Returns:

  • (String)


4342
4343
4344
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4342

def formatted_price
  @formatted_price
end

#formatted_sale_priceString

Formatted sale price which can be any characters. If set, this attribute will be used instead of 'sale price', for example, On sale for $80.00. Corresponds to the JSON property formattedSalePrice

Returns:

  • (String)


4348
4349
4350
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4348

def formatted_sale_price
  @formatted_sale_price
end

#image_urlString

Image URL, for example, http://www.example.com/image.png. The image will not be uploaded as image asset. Corresponds to the JSON property imageUrl

Returns:

  • (String)


4354
4355
4356
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4354

def image_url
  @image_url
end

iOS deep link, for example, exampleApp://content/page. Corresponds to the JSON property iosAppLink

Returns:

  • (String)


4359
4360
4361
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4359

def ios_app_link
  @ios_app_link
end

#ios_app_store_idFixnum

iOS app store ID. This is used to check if the user has the app installed on their device before deep linking. If this field is set, then the ios_app_link field must also be present. Corresponds to the JSON property iosAppStoreId

Returns:

  • (Fixnum)


4366
4367
4368
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4366

def ios_app_store_id
  @ios_app_store_id
end

#priceString

Price which can be number followed by the alphabetic currency code, ISO 4217 standard. Use '.' as the decimal mark, for example, 100.00 USD. Corresponds to the JSON property price

Returns:

  • (String)


4372
4373
4374
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4372

def price
  @price
end

#property_idString

Required. Property ID which can be any sequence of letters and digits, and must be unique and match the values of remarketing tag. Required. Corresponds to the JSON property propertyId

Returns:

  • (String)


4378
4379
4380
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4378

def property_id
  @property_id
end

#property_nameString

Required. Property name, for example, Mountain View Hotel. Required. Corresponds to the JSON property propertyName

Returns:

  • (String)


4383
4384
4385
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4383

def property_name
  @property_name
end

#sale_priceString

ISO 4217 standard. Use '.' as the decimal mark, for example, 80.00 USD. Must be less than the 'price' field. Corresponds to the JSON property salePrice

Returns:

  • (String)


4389
4390
4391
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4389

def sale_price
  @sale_price
end

#similar_property_idsArray<String>

Similar property IDs. Corresponds to the JSON property similarPropertyIds

Returns:

  • (Array<String>)


4394
4395
4396
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4394

def similar_property_ids
  @similar_property_ids
end

#star_ratingFixnum

Star rating. Must be a number between 1 to 5, inclusive. Corresponds to the JSON property starRating

Returns:

  • (Fixnum)


4399
4400
4401
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4399

def star_rating
  @star_rating
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4406
4407
4408
4409
4410
4411
4412
4413
4414
4415
4416
4417
4418
4419
4420
4421
4422
4423
4424
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4406

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @android_app_link = args[:android_app_link] if args.key?(:android_app_link)
  @category = args[:category] if args.key?(:category)
  @contextual_keywords = args[:contextual_keywords] if args.key?(:contextual_keywords)
  @description = args[:description] if args.key?(:description)
  @destination_name = args[:destination_name] if args.key?(:destination_name)
  @formatted_price = args[:formatted_price] if args.key?(:formatted_price)
  @formatted_sale_price = args[:formatted_sale_price] if args.key?(:formatted_sale_price)
  @image_url = args[:image_url] if args.key?(:image_url)
  @ios_app_link = args[:ios_app_link] if args.key?(:ios_app_link)
  @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id)
  @price = args[:price] if args.key?(:price)
  @property_id = args[:property_id] if args.key?(:property_id)
  @property_name = args[:property_name] if args.key?(:property_name)
  @sale_price = args[:sale_price] if args.key?(:sale_price)
  @similar_property_ids = args[:similar_property_ids] if args.key?(:similar_property_ids)
  @star_rating = args[:star_rating] if args.key?(:star_rating)
end