Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicRealEstateAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A dynamic real estate asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicRealEstateAsset

Returns a new instance of GoogleAdsSearchads360V23CommonDynamicRealEstateAsset.



4744
4745
4746
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Address which can be specified in one of the following formats. (1) City, state, code, country, for example, Mountain View, CA, USA. (2) Full address, for example, 123 Boulevard St, Mountain View, CA 94043. (3) Latitude-longitude in the DDD format, for example, 41.40338, 2.17403 Corresponds to the JSON property address

Returns:

  • (String)


4665
4666
4667
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4665

def address
  @address
end

Android deep link, for example, android-app://com.example.android/http/example. com/gizmos?1234. Corresponds to the JSON property androidAppLink

Returns:

  • (String)


4671
4672
4673
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4671

def android_app_link
  @android_app_link
end

#city_nameString

City name, for example, Mountain View, California. Corresponds to the JSON property cityName

Returns:

  • (String)


4676
4677
4678
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4676

def city_name
  @city_name
end

#contextual_keywordsArray<String>

Contextual keywords, for example, For sale; Houses for sale. Corresponds to the JSON property contextualKeywords

Returns:

  • (Array<String>)


4681
4682
4683
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4681

def contextual_keywords
  @contextual_keywords
end

#descriptionString

Description, for example, 3 beds, 2 baths, 1568 sq. ft. Corresponds to the JSON property description

Returns:

  • (String)


4686
4687
4688
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4686

def description
  @description
end

#formatted_priceString

Formatted price which can be any characters. If set, this attribute will be used instead of 'price', for example, Starting at $200,000.00. Corresponds to the JSON property formattedPrice

Returns:

  • (String)


4692
4693
4694
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4692

def formatted_price
  @formatted_price
end

#image_urlString

Image URL, for example, http://www.example.com/image.png. The image will not be uploaded as image asset. Corresponds to the JSON property imageUrl

Returns:

  • (String)


4698
4699
4700
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4698

def image_url
  @image_url
end

iOS deep link, for example, exampleApp://content/page. Corresponds to the JSON property iosAppLink

Returns:

  • (String)


4703
4704
4705
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4703

def ios_app_link
  @ios_app_link
end

#ios_app_store_idFixnum

iOS app store ID. This is used to check if the user has the app installed on their device before deep linking. If this field is set, then the ios_app_link field must also be present. Corresponds to the JSON property iosAppStoreId

Returns:

  • (Fixnum)


4710
4711
4712
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4710

def ios_app_store_id
  @ios_app_store_id
end

#listing_idString

Required. Listing ID which can be any sequence of letters and digits, and must be unique and match the values of remarketing tag. Required. Corresponds to the JSON property listingId

Returns:

  • (String)


4716
4717
4718
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4716

def listing_id
  @listing_id
end

#listing_nameString

Required. Listing name, for example, Boulevard Bungalow. Required. Corresponds to the JSON property listingName

Returns:

  • (String)


4721
4722
4723
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4721

def listing_name
  @listing_name
end

#listing_typeString

Listing type, for example, For sale. Corresponds to the JSON property listingType

Returns:

  • (String)


4726
4727
4728
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4726

def listing_type
  @listing_type
end

#priceString

Price which can be number followed by the alphabetic currency code, ISO 4217 standard. Use '.' as the decimal mark, for example, 200,000.00 USD. Corresponds to the JSON property price

Returns:

  • (String)


4732
4733
4734
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4732

def price
  @price
end

#property_typeString

Property type, for example, House. Corresponds to the JSON property propertyType

Returns:

  • (String)


4737
4738
4739
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4737

def property_type
  @property_type
end

#similar_listing_idsArray<String>

Similar listing IDs. Corresponds to the JSON property similarListingIds

Returns:

  • (Array<String>)


4742
4743
4744
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4742

def similar_listing_ids
  @similar_listing_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4749
4750
4751
4752
4753
4754
4755
4756
4757
4758
4759
4760
4761
4762
4763
4764
4765
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4749

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @android_app_link = args[:android_app_link] if args.key?(:android_app_link)
  @city_name = args[:city_name] if args.key?(:city_name)
  @contextual_keywords = args[:contextual_keywords] if args.key?(:contextual_keywords)
  @description = args[:description] if args.key?(:description)
  @formatted_price = args[:formatted_price] if args.key?(:formatted_price)
  @image_url = args[:image_url] if args.key?(:image_url)
  @ios_app_link = args[:ios_app_link] if args.key?(:ios_app_link)
  @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id)
  @listing_id = args[:listing_id] if args.key?(:listing_id)
  @listing_name = args[:listing_name] if args.key?(:listing_name)
  @listing_type = args[:listing_type] if args.key?(:listing_type)
  @price = args[:price] if args.key?(:price)
  @property_type = args[:property_type] if args.key?(:property_type)
  @similar_listing_ids = args[:similar_listing_ids] if args.key?(:similar_listing_ids)
end