Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicTravelAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicTravelAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A dynamic travel asset.
Instance Attribute Summary collapse
-
#android_app_link ⇒ String
Android deep link, for example, android-app://com.example.android/http/example.
-
#category ⇒ String
Category, for example, Express.
-
#contextual_keywords ⇒ Array<String>
Contextual keywords, for example, Paris trains.
-
#destination_address ⇒ String
Destination address which can be specified in one of the following formats.
-
#destination_id ⇒ String
Required.
-
#destination_name ⇒ String
Destination name, for example, Paris.
-
#formatted_price ⇒ String
Formatted price which can be any characters.
-
#formatted_sale_price ⇒ String
Formatted sale price which can be any characters.
-
#image_url ⇒ String
Image URL, for example, http://www.example.com/image.png.
-
#ios_app_link ⇒ String
iOS deep link, for example, exampleApp://content/page.
-
#ios_app_store_id ⇒ Fixnum
iOS app store ID.
-
#origin_id ⇒ String
Origin ID which can be any sequence of letters and digits.
-
#origin_name ⇒ String
Origin name, for example, London.
-
#price ⇒ String
Price which can be a number followed by the alphabetic currency code, ISO 4217 standard.
-
#sale_price ⇒ String
Sale price which can be a number followed by the alphabetic currency code, ISO 4217 standard.
-
#similar_destination_ids ⇒ Array<String>
Similar destination IDs, for example, NYC.
-
#title ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicTravelAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonDynamicTravelAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicTravelAsset
Returns a new instance of GoogleAdsSearchads360V23CommonDynamicTravelAsset.
4871 4872 4873 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#android_app_link ⇒ String
Android deep link, for example, android-app://com.example.android/http/example.
com/gizmos?1234.
Corresponds to the JSON property androidAppLink
4776 4777 4778 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4776 def android_app_link @android_app_link end |
#category ⇒ String
Category, for example, Express.
Corresponds to the JSON property category
4781 4782 4783 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4781 def category @category end |
#contextual_keywords ⇒ Array<String>
Contextual keywords, for example, Paris trains.
Corresponds to the JSON property contextualKeywords
4786 4787 4788 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4786 def contextual_keywords @contextual_keywords end |
#destination_address ⇒ String
Destination address which can be specified in one of the following formats. (1)
City, state, code, country, for example, Mountain View, CA, USA. (2) Full
address, for example, 123 Boulevard St, Mountain View, CA 94043. (3) Latitude-
longitude in the DDD format, for example, 41.40338, 2.17403.
Corresponds to the JSON property destinationAddress
4794 4795 4796 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4794 def destination_address @destination_address end |
#destination_id ⇒ String
Required. Destination ID which can be any sequence of letters and digits, and
must be unique and match the values of remarketing tag. Required.
Corresponds to the JSON property destinationId
4800 4801 4802 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4800 def destination_id @destination_id end |
#destination_name ⇒ String
Destination name, for example, Paris.
Corresponds to the JSON property destinationName
4805 4806 4807 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4805 def destination_name @destination_name end |
#formatted_price ⇒ String
Formatted price which can be any characters. If set, this attribute will be
used instead of 'price', for example, Starting at $100.00.
Corresponds to the JSON property formattedPrice
4811 4812 4813 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4811 def formatted_price @formatted_price end |
#formatted_sale_price ⇒ String
Formatted sale price which can be any characters. If set, this attribute will
be used instead of 'sale price', for example, On sale for $80.00.
Corresponds to the JSON property formattedSalePrice
4817 4818 4819 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4817 def formatted_sale_price @formatted_sale_price end |
#image_url ⇒ String
Image URL, for example, http://www.example.com/image.png. The image will not
be uploaded as image asset.
Corresponds to the JSON property imageUrl
4823 4824 4825 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4823 def image_url @image_url end |
#ios_app_link ⇒ String
iOS deep link, for example, exampleApp://content/page.
Corresponds to the JSON property iosAppLink
4828 4829 4830 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4828 def ios_app_link @ios_app_link end |
#ios_app_store_id ⇒ Fixnum
iOS app store ID. This is used to check if the user has the app installed on
their device before deep linking. If this field is set, then the ios_app_link
field must also be present.
Corresponds to the JSON property iosAppStoreId
4835 4836 4837 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4835 def ios_app_store_id @ios_app_store_id end |
#origin_id ⇒ String
Origin ID which can be any sequence of letters and digits. The ID sequence (
destination ID + origin ID) must be unique.
Corresponds to the JSON property originId
4841 4842 4843 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4841 def origin_id @origin_id end |
#origin_name ⇒ String
Origin name, for example, London.
Corresponds to the JSON property originName
4846 4847 4848 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4846 def origin_name @origin_name end |
#price ⇒ String
Price which can be a number followed by the alphabetic currency code, ISO 4217
standard. Use '.' as the decimal mark, for example, 100.00 USD.
Corresponds to the JSON property price
4852 4853 4854 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4852 def price @price end |
#sale_price ⇒ String
Sale price which can be a number followed by the alphabetic currency code, ISO
4217 standard. Use '.' as the decimal mark, for example, 80.00 USD. Must be
less than the 'price' field.
Corresponds to the JSON property salePrice
4859 4860 4861 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4859 def sale_price @sale_price end |
#similar_destination_ids ⇒ Array<String>
Similar destination IDs, for example, NYC.
Corresponds to the JSON property similarDestinationIds
4864 4865 4866 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4864 def similar_destination_ids @similar_destination_ids end |
#title ⇒ String
Required. Title, for example, Book your train ticket. Required.
Corresponds to the JSON property title
4869 4870 4871 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4869 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 4892 4893 4894 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4876 def update!(**args) @android_app_link = args[:android_app_link] if args.key?(:android_app_link) @category = args[:category] if args.key?(:category) @contextual_keywords = args[:contextual_keywords] if args.key?(:contextual_keywords) @destination_address = args[:destination_address] if args.key?(:destination_address) @destination_id = args[:destination_id] if args.key?(:destination_id) @destination_name = args[:destination_name] if args.key?(:destination_name) @formatted_price = args[:formatted_price] if args.key?(:formatted_price) @formatted_sale_price = args[:formatted_sale_price] if args.key?(:formatted_sale_price) @image_url = args[:image_url] if args.key?(:image_url) @ios_app_link = args[:ios_app_link] if args.key?(:ios_app_link) @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id) @origin_id = args[:origin_id] if args.key?(:origin_id) @origin_name = args[:origin_name] if args.key?(:origin_name) @price = args[:price] if args.key?(:price) @sale_price = args[:sale_price] if args.key?(:sale_price) @similar_destination_ids = args[:similar_destination_ids] if args.key?(:similar_destination_ids) @title = args[:title] if args.key?(:title) end |