Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFlexibleRuleOperandInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Flexible rule that wraps the common rule and a lookback window.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonFlexibleRuleOperandInfo

Returns a new instance of GoogleAdsSearchads360V23CommonFlexibleRuleOperandInfo.



5150
5151
5152
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lookback_window_daysFixnum

Lookback window for this rule in days. From now until X days ago. Corresponds to the JSON property lookbackWindowDays

Returns:

  • (Fixnum)


5142
5143
5144
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5142

def lookback_window_days
  @lookback_window_days
end

#ruleGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleInfo

A client defined rule based on custom parameters sent by web sites or uploaded by the advertiser. Corresponds to the JSON property rule



5148
5149
5150
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5148

def rule
  @rule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5155
5156
5157
5158
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5155

def update!(**args)
  @lookback_window_days = args[:lookback_window_days] if args.key?(:lookback_window_days)
  @rule = args[:rule] if args.key?(:rule)
end