Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFlexibleRuleUserListInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Flexible rule representation of visitors with one or multiple actions. The flexible user list is defined by two lists of operands – inclusive_operands and exclusive_operands; each operand represents a set of users based on actions they took in a given timeframe. These lists of operands are combined with the AND_NOT operator, so that users represented by the inclusive operands are included in the user list, minus the users represented by the exclusive operands.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonFlexibleRuleUserListInfo

Returns a new instance of GoogleAdsSearchads360V23CommonFlexibleRuleUserListInfo.



5189
5190
5191
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5189

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exclusive_operandsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFlexibleRuleOperandInfo>

Rules representing users that should be excluded from the user list. These are located on the right side of the AND_NOT operator, and joined together by OR. Corresponds to the JSON property exclusiveOperands



5175
5176
5177
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5175

def exclusive_operands
  @exclusive_operands
end

#inclusive_operandsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFlexibleRuleOperandInfo>

Rules representing users that should be included in the user list. These are located on the left side of the AND_NOT operator, and joined together by either AND/OR as specified by the inclusive_rule_operator. Corresponds to the JSON property inclusiveOperands



5182
5183
5184
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5182

def inclusive_operands
  @inclusive_operands
end

#inclusive_rule_operatorString

Operator that defines how the inclusive operands are combined. Corresponds to the JSON property inclusiveRuleOperator

Returns:

  • (String)


5187
5188
5189
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5187

def inclusive_rule_operator
  @inclusive_rule_operator
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5194
5195
5196
5197
5198
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5194

def update!(**args)
  @exclusive_operands = args[:exclusive_operands] if args.key?(:exclusive_operands)
  @inclusive_operands = args[:inclusive_operands] if args.key?(:inclusive_operands)
  @inclusive_rule_operator = args[:inclusive_rule_operator] if args.key?(:inclusive_rule_operator)
end