Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelLengthOfStayInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Criterion for length of hotel stay in nights.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonHotelLengthOfStayInfo

Returns a new instance of GoogleAdsSearchads360V23CommonHotelLengthOfStayInfo.



5583
5584
5585
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_nightsFixnum

High end of the number of nights in the stay. Corresponds to the JSON property maxNights

Returns:

  • (Fixnum)


5576
5577
5578
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5576

def max_nights
  @max_nights
end

#min_nightsFixnum

Low end of the number of nights in the stay. Corresponds to the JSON property minNights

Returns:

  • (Fixnum)


5581
5582
5583
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5581

def min_nights
  @min_nights
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5588
5589
5590
5591
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5588

def update!(**args)
  @max_nights = args[:max_nights] if args.key?(:max_nights)
  @min_nights = args[:min_nights] if args.key?(:min_nights)
end