Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordConcept
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordConcept
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The concept for the keyword.
Instance Attribute Summary collapse
-
#concept_group ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonConceptGroup
The concept group for the keyword concept.
-
#name ⇒ String
The concept name for the keyword in the concept_group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonKeywordConcept
constructor
A new instance of GoogleAdsSearchads360V23CommonKeywordConcept.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonKeywordConcept
Returns a new instance of GoogleAdsSearchads360V23CommonKeywordConcept.
5996 5997 5998 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5996 def initialize(**args) update!(**args) end |
Instance Attribute Details
#concept_group ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonConceptGroup
The concept group for the keyword concept.
Corresponds to the JSON property conceptGroup
5989 5990 5991 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5989 def concept_group @concept_group end |
#name ⇒ String
The concept name for the keyword in the concept_group.
Corresponds to the JSON property name
5994 5995 5996 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5994 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6001 6002 6003 6004 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6001 def update!(**args) @concept_group = args[:concept_group] if args.key?(:concept_group) @name = args[:name] if args.key?(:name) end |