Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanAggregateMetricResults
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanAggregateMetricResults
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The aggregated historical metrics for keyword plan keywords.
Instance Attribute Summary collapse
-
#device_searches ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanDeviceSearches>
The aggregate searches for all the keywords segmented by device for the specified time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonKeywordPlanAggregateMetricResults
constructor
A new instance of GoogleAdsSearchads360V23CommonKeywordPlanAggregateMetricResults.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonKeywordPlanAggregateMetricResults
Returns a new instance of GoogleAdsSearchads360V23CommonKeywordPlanAggregateMetricResults.
5984 5985 5986 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5984 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_searches ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanDeviceSearches>
The aggregate searches for all the keywords segmented by device for the
specified time. Supports the following device types: MOBILE, TABLET, DESKTOP.
This is only set when KeywordPlanAggregateMetricTypeEnum.DEVICE is set in the
KeywordPlanAggregateMetrics field in the request.
Corresponds to the JSON property deviceSearches
5982 5983 5984 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5982 def device_searches @device_searches end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5989 5990 5991 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5989 def update!(**args) @device_searches = args[:device_searches] if args.key?(:device_searches) end |