Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLeadFormAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Lead Form asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLeadFormAsset

Returns a new instance of GoogleAdsSearchads360V23CommonLeadFormAsset.



6321
6322
6323
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#background_image_assetString

Asset resource name of the background image. The image dimensions must be exactly 1200x628. Corresponds to the JSON property backgroundImageAsset

Returns:

  • (String)


6238
6239
6240
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6238

def background_image_asset
  @background_image_asset
end

#business_nameString

Required. The name of the business being advertised. Corresponds to the JSON property businessName

Returns:

  • (String)


6243
6244
6245
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6243

def business_name
  @business_name
end

#call_to_action_descriptionString

Required. Text giving a clear value proposition of what users expect once they expand the form. Corresponds to the JSON property callToActionDescription

Returns:

  • (String)


6249
6250
6251
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6249

def call_to_action_description
  @call_to_action_description
end

#call_to_action_typeString

Required. Pre-defined display text that encourages user to expand the form. Corresponds to the JSON property callToActionType

Returns:

  • (String)


6254
6255
6256
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6254

def call_to_action_type
  @call_to_action_type
end

#custom_disclosureString

Custom disclosure shown along with Google disclaimer on the lead form. Accessible to allowed customers only. Corresponds to the JSON property customDisclosure

Returns:

  • (String)


6260
6261
6262
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6260

def custom_disclosure
  @custom_disclosure
end

#custom_question_fieldsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLeadFormCustomQuestionField>

Ordered list of custom question fields. This field is subject to a limit of 5 qualifying questions per form. Corresponds to the JSON property customQuestionFields



6266
6267
6268
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6266

def custom_question_fields
  @custom_question_fields
end

#delivery_methodsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLeadFormDeliveryMethod>

Configured methods for collected lead data to be delivered to advertiser. Only one method typed as WebhookDelivery can be configured. Corresponds to the JSON property deliveryMethods



6272
6273
6274
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6272

def delivery_methods
  @delivery_methods
end

#descriptionString

Required. Detailed description of the expanded form to describe what the form is asking for or facilitating. Corresponds to the JSON property description

Returns:

  • (String)


6278
6279
6280
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6278

def description
  @description
end

#desired_intentString

Chosen intent for the lead form, for example, more volume or more qualified. Corresponds to the JSON property desiredIntent

Returns:

  • (String)


6283
6284
6285
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6283

def desired_intent
  @desired_intent
end

#fieldsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLeadFormField>

Ordered list of input fields. This field can be updated by reordering questions, but not by adding or removing questions. Corresponds to the JSON property fields



6289
6290
6291
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6289

def fields
  @fields
end

#headlineString

Required. Headline of the expanded form to describe what the form is asking for or facilitating. Corresponds to the JSON property headline

Returns:

  • (String)


6295
6296
6297
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6295

def headline
  @headline
end

#post_submit_call_to_action_typeString

Pre-defined display text that encourages user action after the form is submitted. Corresponds to the JSON property postSubmitCallToActionType

Returns:

  • (String)


6301
6302
6303
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6301

def post_submit_call_to_action_type
  @post_submit_call_to_action_type
end

#post_submit_descriptionString

Detailed description shown after form submission that describes how the advertiser will follow up with the user. Corresponds to the JSON property postSubmitDescription

Returns:

  • (String)


6307
6308
6309
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6307

def post_submit_description
  @post_submit_description
end

#post_submit_headlineString

Headline of text shown after form submission that describes how the advertiser will follow up with the user. Corresponds to the JSON property postSubmitHeadline

Returns:

  • (String)


6313
6314
6315
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6313

def post_submit_headline
  @post_submit_headline
end

#privacy_policy_urlString

Required. Link to a page describing the policy on how the collected data is handled by the advertiser/business. Corresponds to the JSON property privacyPolicyUrl

Returns:

  • (String)


6319
6320
6321
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6319

def privacy_policy_url
  @privacy_policy_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6326
6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6326

def update!(**args)
  @background_image_asset = args[:background_image_asset] if args.key?(:background_image_asset)
  @business_name = args[:business_name] if args.key?(:business_name)
  @call_to_action_description = args[:call_to_action_description] if args.key?(:call_to_action_description)
  @call_to_action_type = args[:call_to_action_type] if args.key?(:call_to_action_type)
  @custom_disclosure = args[:custom_disclosure] if args.key?(:custom_disclosure)
  @custom_question_fields = args[:custom_question_fields] if args.key?(:custom_question_fields)
  @delivery_methods = args[:delivery_methods] if args.key?(:delivery_methods)
  @description = args[:description] if args.key?(:description)
  @desired_intent = args[:desired_intent] if args.key?(:desired_intent)
  @fields = args[:fields] if args.key?(:fields)
  @headline = args[:headline] if args.key?(:headline)
  @post_submit_call_to_action_type = args[:post_submit_call_to_action_type] if args.key?(:post_submit_call_to_action_type)
  @post_submit_description = args[:post_submit_description] if args.key?(:post_submit_description)
  @post_submit_headline = args[:post_submit_headline] if args.key?(:post_submit_headline)
  @privacy_policy_url = args[:privacy_policy_url] if args.key?(:privacy_policy_url)
end