Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLeadFormField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

One input field instance within a form.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLeadFormField

Returns a new instance of GoogleAdsSearchads360V23CommonLeadFormField.



6370
6371
6372
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6370

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#has_location_answerBoolean Also known as: has_location_answer?

Answer configuration for location question. If true, campaign/account level location data (state, city, business name etc) will be rendered on the Lead Form. Starting V13.1, has_location_answer can only be set for "What is your preferred dealership?" question, for advertisers with Location Assets setup at campaign/account level. Corresponds to the JSON property hasLocationAnswer

Returns:

  • (Boolean)


6355
6356
6357
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6355

def has_location_answer
  @has_location_answer
end

#input_typeString

Describes the input type, which may be a predefined type such as "full name" or a pre-vetted question like "What kind of vehicle do you have?". Corresponds to the JSON property inputType

Returns:

  • (String)


6362
6363
6364
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6362

def input_type
  @input_type
end

#single_choice_answersGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLeadFormSingleChoiceAnswers

Defines possible answers for a single choice question, usually presented as a single-choice drop-down list. Corresponds to the JSON property singleChoiceAnswers



6368
6369
6370
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6368

def single_choice_answers
  @single_choice_answers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6375
6376
6377
6378
6379
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6375

def update!(**args)
  @has_location_answer = args[:has_location_answer] if args.key?(:has_location_answer)
  @input_type = args[:input_type] if args.key?(:input_type)
  @single_choice_answers = args[:single_choice_answers] if args.key?(:single_choice_answers)
end