Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLegacyResponsiveDisplayAdInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A legacy responsive display ad. Ads of this type are labeled 'Responsive ads' in the Google Ads UI.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLegacyResponsiveDisplayAdInfo

Returns a new instance of GoogleAdsSearchads360V23CommonLegacyResponsiveDisplayAdInfo.



6593
6594
6595
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6593

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accent_colorString

The accent color of the ad in hexadecimal, for example, #ffffff for white. If one of main_color and accent_color is set, the other is required as well. Corresponds to the JSON property accentColor

Returns:

  • (String)


6515
6516
6517
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6515

def accent_color
  @accent_color
end

#allow_flexible_colorBoolean Also known as: allow_flexible_color?

Advertiser's consent to allow flexible color. When true, the ad may be served with different color if necessary. When false, the ad will be served with the specified colors or a neutral color. The default value is true. Must be true if main_color and accent_color are not set. Corresponds to the JSON property allowFlexibleColor

Returns:

  • (Boolean)


6523
6524
6525
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6523

def allow_flexible_color
  @allow_flexible_color
end

#business_nameString

The business name in the ad. Corresponds to the JSON property businessName

Returns:

  • (String)


6529
6530
6531
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6529

def business_name
  @business_name
end

#call_to_action_textString

The call-to-action text for the ad. Corresponds to the JSON property callToActionText

Returns:

  • (String)


6534
6535
6536
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6534

def call_to_action_text
  @call_to_action_text
end

#descriptionString

The description of the ad. Corresponds to the JSON property description

Returns:

  • (String)


6539
6540
6541
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6539

def description
  @description
end

#format_settingString

Specifies which format the ad will be served in. Default is ALL_FORMATS. Corresponds to the JSON property formatSetting

Returns:

  • (String)


6544
6545
6546
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6544

def format_setting
  @format_setting
end

#logo_imageString

The MediaFile resource name of the logo image used in the ad. Corresponds to the JSON property logoImage

Returns:

  • (String)


6549
6550
6551
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6549

def logo_image
  @logo_image
end

#long_headlineString

The long version of the ad's headline. Corresponds to the JSON property longHeadline

Returns:

  • (String)


6554
6555
6556
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6554

def long_headline
  @long_headline
end

#main_colorString

The main color of the ad in hexadecimal, for example, #ffffff for white. If one of main_color and accent_color is set, the other is required as well. Corresponds to the JSON property mainColor

Returns:

  • (String)


6560
6561
6562
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6560

def main_color
  @main_color
end

#marketing_imageString

The MediaFile resource name of the marketing image used in the ad. Corresponds to the JSON property marketingImage

Returns:

  • (String)


6565
6566
6567
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6565

def marketing_image
  @marketing_image
end

#price_prefixString

Prefix before price. For example, 'as low as'. Corresponds to the JSON property pricePrefix

Returns:

  • (String)


6570
6571
6572
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6570

def price_prefix
  @price_prefix
end

#promo_textString

Promotion text used for dynamic formats of responsive ads. For example 'Free two-day shipping'. Corresponds to the JSON property promoText

Returns:

  • (String)


6576
6577
6578
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6576

def promo_text
  @promo_text
end

#short_headlineString

The short version of the ad's headline. Corresponds to the JSON property shortHeadline

Returns:

  • (String)


6581
6582
6583
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6581

def short_headline
  @short_headline
end

#square_logo_imageString

The MediaFile resource name of the square logo image used in the ad. Corresponds to the JSON property squareLogoImage

Returns:

  • (String)


6586
6587
6588
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6586

def square_logo_image
  @square_logo_image
end

#square_marketing_imageString

The MediaFile resource name of the square marketing image used in the ad. Corresponds to the JSON property squareMarketingImage

Returns:

  • (String)


6591
6592
6593
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6591

def square_marketing_image
  @square_marketing_image
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6598
6599
6600
6601
6602
6603
6604
6605
6606
6607
6608
6609
6610
6611
6612
6613
6614
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6598

def update!(**args)
  @accent_color = args[:accent_color] if args.key?(:accent_color)
  @allow_flexible_color = args[:allow_flexible_color] if args.key?(:allow_flexible_color)
  @business_name = args[:business_name] if args.key?(:business_name)
  @call_to_action_text = args[:call_to_action_text] if args.key?(:call_to_action_text)
  @description = args[:description] if args.key?(:description)
  @format_setting = args[:format_setting] if args.key?(:format_setting)
  @logo_image = args[:logo_image] if args.key?(:logo_image)
  @long_headline = args[:long_headline] if args.key?(:long_headline)
  @main_color = args[:main_color] if args.key?(:main_color)
  @marketing_image = args[:marketing_image] if args.key?(:marketing_image)
  @price_prefix = args[:price_prefix] if args.key?(:price_prefix)
  @promo_text = args[:promo_text] if args.key?(:promo_text)
  @short_headline = args[:short_headline] if args.key?(:short_headline)
  @square_logo_image = args[:square_logo_image] if args.key?(:square_logo_image)
  @square_marketing_image = args[:square_marketing_image] if args.key?(:square_marketing_image)
end