Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingDimensionPath
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingDimensionPath
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The path of dimensions defining a listing group.
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingDimensionInfo>
The complete path of dimensions through the listing group hierarchy, from the root (excluding the root itself) to this listing group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonListingDimensionPath
constructor
A new instance of GoogleAdsSearchads360V23CommonListingDimensionPath.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonListingDimensionPath
Returns a new instance of GoogleAdsSearchads360V23CommonListingDimensionPath.
6833 6834 6835 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6833 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimensions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingDimensionInfo>
The complete path of dimensions through the listing group hierarchy, from the
root (excluding the root itself) to this listing group.
Corresponds to the JSON property dimensions
6831 6832 6833 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6831 def dimensions @dimensions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6838 6839 6840 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6838 def update!(**args) @dimensions = args[:dimensions] if args.key?(:dimensions) end |