Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingGroupInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingGroupInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A listing group criterion.
Instance Attribute Summary collapse
-
#case_value ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingDimensionInfo
Listing dimensions for listing group criterion.
-
#parent_ad_group_criterion ⇒ String
Resource name of ad group criterion which is the parent listing group subdivision.
-
#path ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingDimensionPath
The path of dimensions defining a listing group.
-
#type ⇒ String
Type of the listing group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonListingGroupInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonListingGroupInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonListingGroupInfo
Returns a new instance of GoogleAdsSearchads360V23CommonListingGroupInfo.
6868 6869 6870 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6868 def initialize(**args) update!(**args) end |
Instance Attribute Details
#case_value ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingDimensionInfo
Listing dimensions for listing group criterion.
Corresponds to the JSON property caseValue
6850 6851 6852 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6850 def case_value @case_value end |
#parent_ad_group_criterion ⇒ String
Resource name of ad group criterion which is the parent listing group
subdivision. Null for the root group.
Corresponds to the JSON property parentAdGroupCriterion
6856 6857 6858 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6856 def parent_ad_group_criterion @parent_ad_group_criterion end |
#path ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingDimensionPath
The path of dimensions defining a listing group.
Corresponds to the JSON property path
6861 6862 6863 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6861 def path @path end |
#type ⇒ String
Type of the listing group.
Corresponds to the JSON property type
6866 6867 6868 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6866 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6873 6874 6875 6876 6877 6878 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6873 def update!(**args) @case_value = args[:case_value] if args.key?(:case_value) @parent_ad_group_criterion = args[:parent_ad_group_criterion] if args.key?(:parent_ad_group_criterion) @path = args[:path] if args.key?(:path) @type = args[:type] if args.key?(:type) end |