Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalAdInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A local ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLocalAdInfo

Returns a new instance of GoogleAdsSearchads360V23CommonLocalAdInfo.



7015
7016
7017
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_to_actionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

List of text assets for call-to-actions. When the ad serves the call-to- actions will be selected from this list. At least 1 and at most 5 call-to- actions must be specified. Corresponds to the JSON property callToActions



6969
6970
6971
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6969

def call_to_actions
  @call_to_actions
end

#descriptionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

List of text assets for descriptions. When the ad serves the descriptions will be selected from this list. At least 1 and at most 5 descriptions must be specified. Corresponds to the JSON property descriptions



6976
6977
6978
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6976

def descriptions
  @descriptions
end

#headlinesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

List of text assets for headlines. When the ad serves the headlines will be selected from this list. At least 1 and at most 5 headlines must be specified. Corresponds to the JSON property headlines



6982
6983
6984
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6982

def headlines
  @headlines
end

#logo_imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

List of logo image assets that may be displayed with the ad. The images must be 128x128 pixels and not larger than 120KB. At least 1 and at most 5 image assets must be specified. Corresponds to the JSON property logoImages



6989
6990
6991
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6989

def logo_images
  @logo_images
end

#marketing_imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

List of marketing image assets that may be displayed with the ad. The images must be 314x600 pixels or 320x320 pixels. At least 1 and at most 20 image assets must be specified. Corresponds to the JSON property marketingImages



6996
6997
6998
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6996

def marketing_images
  @marketing_images
end

#path1String

First part of optional text that can be appended to the URL in the ad. Corresponds to the JSON property path1

Returns:

  • (String)


7001
7002
7003
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7001

def path1
  @path1
end

#path2String

Second part of optional text that can be appended to the URL in the ad. This field can only be set when path1 is also set. Corresponds to the JSON property path2

Returns:

  • (String)


7007
7008
7009
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7007

def path2
  @path2
end

#videosArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAsset>

List of YouTube video assets that may be displayed with the ad. At least 1 and at most 20 video assets must be specified. Corresponds to the JSON property videos



7013
7014
7015
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7013

def videos
  @videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7020
7021
7022
7023
7024
7025
7026
7027
7028
7029
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7020

def update!(**args)
  @call_to_actions = args[:call_to_actions] if args.key?(:call_to_actions)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @headlines = args[:headlines] if args.key?(:headlines)
  @logo_images = args[:logo_images] if args.key?(:logo_images)
  @marketing_images = args[:marketing_images] if args.key?(:marketing_images)
  @path1 = args[:path1] if args.key?(:path1)
  @path2 = args[:path2] if args.key?(:path2)
  @videos = args[:videos] if args.key?(:videos)
end