Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationGroupInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A radius around a list of locations specified through a feed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLocationGroupInfo

Returns a new instance of GoogleAdsSearchads360V23CommonLocationGroupInfo.



7180
7181
7182
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_customer_level_location_asset_setBoolean Also known as: enable_customer_level_location_asset_set?

Denotes that the latest customer level asset set is used for targeting. Used with radius and radius_units. Cannot be used with feed, geo target constants or feed item sets. When using asset sets, either this field or location_group_asset_sets should be specified. Both cannot be used at the same time. This can only be set in CREATE operations. Corresponds to the JSON property enableCustomerLevelLocationAssetSet

Returns:

  • (Boolean)


7140
7141
7142
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7140

def enable_customer_level_location_asset_set
  @enable_customer_level_location_asset_set
end

#feed_item_setsArray<String>

FeedItemSets whose FeedItems are targeted. If multiple IDs are specified, then all items that appear in at least one set are targeted. This field cannot be used with geo_target_constants. This is optional and can only be set in CREATE operations. Corresponds to the JSON property feedItemSets

Returns:

  • (Array<String>)


7149
7150
7151
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7149

def feed_item_sets
  @feed_item_sets
end

#geo_target_constantsArray<String>

Geo target constant(s) restricting the scope of the geographic area within the feed. Currently only one geo target constant is allowed. Corresponds to the JSON property geoTargetConstants

Returns:

  • (Array<String>)


7155
7156
7157
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7155

def geo_target_constants
  @geo_target_constants
end

#location_group_asset_setsArray<String>

AssetSets whose Assets are targeted. If multiple IDs are specified, then all items that appear in at least one set are targeted. This field cannot be used with feed, geo target constants or feed item sets. When using asset sets, either this field or enable_customer_level_location_asset_set should be specified. Both cannot be used at the same time. This can only be set in CREATE operations. Corresponds to the JSON property locationGroupAssetSets

Returns:

  • (Array<String>)


7165
7166
7167
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7165

def location_group_asset_sets
  @location_group_asset_sets
end

#radiusFixnum

Distance in units specifying the radius around targeted locations. This is required and must be set in CREATE operations. Corresponds to the JSON property radius

Returns:

  • (Fixnum)


7171
7172
7173
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7171

def radius
  @radius
end

#radius_unitsString

Unit of the radius. Miles and meters are supported for geo target constants. Milli miles and meters are supported for feed item sets. This is required and must be set in CREATE operations. Corresponds to the JSON property radiusUnits

Returns:

  • (String)


7178
7179
7180
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7178

def radius_units
  @radius_units
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7185
7186
7187
7188
7189
7190
7191
7192
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7185

def update!(**args)
  @enable_customer_level_location_asset_set = args[:enable_customer_level_location_asset_set] if args.key?(:enable_customer_level_location_asset_set)
  @feed_item_sets = args[:feed_item_sets] if args.key?(:feed_item_sets)
  @geo_target_constants = args[:geo_target_constants] if args.key?(:geo_target_constants)
  @location_group_asset_sets = args[:location_group_asset_sets] if args.key?(:location_group_asset_sets)
  @radius = args[:radius] if args.key?(:radius)
  @radius_units = args[:radius_units] if args.key?(:radius_units)
end