Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLogicalUserListInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a user list that is a custom combination of user lists.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLogicalUserListInfo

Returns a new instance of GoogleAdsSearchads360V23CommonLogicalUserListInfo.



7207
7208
7209
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7207

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rulesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListLogicalRuleInfo>

Logical list rules that define this user list. The rules are defined as a logical operator (ALL/ANY/NONE) and a list of user lists. All the rules are ANDed when they are evaluated. Required for creating a logical user list. Corresponds to the JSON property rules



7205
7206
7207
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7205

def rules
  @rules
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7212
7213
7214
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7212

def update!(**args)
  @rules = args[:rules] if args.key?(:rules)
end