Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An asset representing a mobile app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonMobileAppAsset

Returns a new instance of GoogleAdsSearchads360V23CommonMobileAppAsset.



8625
8626
8627
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8625

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

Required. A string that uniquely identifies a mobile application. It should just contain the platform native id, like "com.android.ebay" for Android or " 12345689" for iOS. Corresponds to the JSON property appId

Returns:

  • (String)


8600
8601
8602
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8600

def app_id
  @app_id
end

#app_storeString

Required. The application store that distributes this specific app. Corresponds to the JSON property appStore

Returns:

  • (String)


8605
8606
8607
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8605

def app_store
  @app_store
end

#end_dateString

Last date of when this asset is effective and still serving, in yyyy-MM-dd format. Corresponds to the JSON property endDate

Returns:

  • (String)


8611
8612
8613
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8611

def end_date
  @end_date
end

Required. The visible text displayed when the link is rendered in an ad. The length of this string should be between 1 and 25, inclusive. Corresponds to the JSON property linkText

Returns:

  • (String)


8617
8618
8619
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8617

def link_text
  @link_text
end

#start_dateString

Start date of when this asset is effective and can begin serving, in yyyy-MM- dd format. Corresponds to the JSON property startDate

Returns:

  • (String)


8623
8624
8625
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8623

def start_date
  @start_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8630
8631
8632
8633
8634
8635
8636
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8630

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @app_store = args[:app_store] if args.key?(:app_store)
  @end_date = args[:end_date] if args.key?(:end_date)
  @link_text = args[:link_text] if args.key?(:link_text)
  @start_date = args[:start_date] if args.key?(:start_date)
end