Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A mobile application criterion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonMobileApplicationInfo

Returns a new instance of GoogleAdsSearchads360V23CommonMobileApplicationInfo.



8616
8617
8618
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8616

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

A string that uniquely identifies a mobile application to Google Ads API. The format of this string is "platform-platform_native_id", where platform is " 1" for iOS apps and "2" for Android apps, and where platform_native_id is the mobile application identifier native to the corresponding platform. For iOS, this native identifier is the 9 digit string that appears at the end of an App Store URL (for example, "476943146" for "Flood-It! 2" whose App Store link is " http://itunes.apple.com/us/app/flood-it!-2/id476943146"). For Android, this native identifier is the application's package name (for example, "com. labpixies.colordrips" for "Color Drips" given Google Play link "https://play. google.com/store/apps/details?id=com.labpixies.colordrips"). A well formed app id for Google Ads API would thus be "1-476943146" for iOS and "2-com.labpixies. colordrips" for Android. This field is required and must be set in CREATE operations. Corresponds to the JSON property appId

Returns:

  • (String)


8609
8610
8611
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8609

def app_id
  @app_id
end

#nameString

Name of this mobile application. Corresponds to the JSON property name

Returns:

  • (String)


8614
8615
8616
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8614

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8621
8622
8623
8624
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8621

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @name = args[:name] if args.key?(:name)
end