Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonNegativeKeywordListInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Negative Keyword List criterion. Represents a shared set of negative keywords that can be excluded at the account-level. Only one negative keyword list criterion can be attached per account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonNegativeKeywordListInfo

Returns a new instance of GoogleAdsSearchads360V23CommonNegativeKeywordListInfo.



8782
8783
8784
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#shared_setString

The NegativeKeywordListInfo shared set resource name. Corresponds to the JSON property sharedSet

Returns:

  • (String)


8780
8781
8782
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8780

def shared_set
  @shared_set
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8787
8788
8789
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8787

def update!(**args)
  @shared_set = args[:shared_set] if args.key?(:shared_set)
end