Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPercentCpc

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A bidding strategy where bids are a fraction of the advertised price for some good or service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPercentCpc

Returns a new instance of GoogleAdsSearchads360V23CommonPercentCpc.



8892
8893
8894
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpc_bid_ceiling_microsFixnum

Maximum bid limit that can be set by the bid strategy. This is an optional field entered by the advertiser and specified in local micros. Note: A zero value is interpreted in the same way as having bid_ceiling undefined. Corresponds to the JSON property cpcBidCeilingMicros

Returns:

  • (Fixnum)


8882
8883
8884
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8882

def cpc_bid_ceiling_micros
  @cpc_bid_ceiling_micros
end

#enhanced_cpc_enabledBoolean Also known as: enhanced_cpc_enabled?

Adjusts the bid for each auction upward or downward, depending on the likelihood of a conversion. Individual bids may exceed cpc_bid_ceiling_micros, but the average bid amount for a campaign should not. Corresponds to the JSON property enhancedCpcEnabled

Returns:

  • (Boolean)


8889
8890
8891
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8889

def enhanced_cpc_enabled
  @enhanced_cpc_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8897
8898
8899
8900
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8897

def update!(**args)
  @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros)
  @enhanced_cpc_enabled = args[:enhanced_cpc_enabled] if args.key?(:enhanced_cpc_enabled)
end