Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPercentCpcBidSimulationPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Projected metrics for a specific percent CPC amount. Only Hotel advertising channel type supports this field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPercentCpcBidSimulationPoint

Returns a new instance of GoogleAdsSearchads360V23CommonPercentCpcBidSimulationPoint.



9013
9014
9015
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9013

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#biddable_conversionsFloat

Projected number of biddable conversions. Corresponds to the JSON property biddableConversions

Returns:

  • (Float)


8979
8980
8981
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8979

def biddable_conversions
  @biddable_conversions
end

#biddable_conversions_valueFloat

Projected total value of biddable conversions in local currency. Corresponds to the JSON property biddableConversionsValue

Returns:

  • (Float)


8984
8985
8986
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8984

def biddable_conversions_value
  @biddable_conversions_value
end

#clicksFixnum

Projected number of clicks. Corresponds to the JSON property clicks

Returns:

  • (Fixnum)


8989
8990
8991
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8989

def clicks
  @clicks
end

#cost_microsFixnum

Projected cost in micros. Corresponds to the JSON property costMicros

Returns:

  • (Fixnum)


8994
8995
8996
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8994

def cost_micros
  @cost_micros
end

#impressionsFixnum

Projected number of impressions. Corresponds to the JSON property impressions

Returns:

  • (Fixnum)


8999
9000
9001
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8999

def impressions
  @impressions
end

#percent_cpc_bid_microsFixnum

The simulated percent CPC upon which projected metrics are based. Percent CPC expressed as fraction of the advertised price for some good or service. The value stored here is 1,000,000 * [fraction]. Corresponds to the JSON property percentCpcBidMicros

Returns:

  • (Fixnum)


9006
9007
9008
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9006

def percent_cpc_bid_micros
  @percent_cpc_bid_micros
end

#top_slot_impressionsFixnum

Projected number of top slot impressions. Corresponds to the JSON property topSlotImpressions

Returns:

  • (Fixnum)


9011
9012
9013
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9011

def top_slot_impressions
  @top_slot_impressions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9018
9019
9020
9021
9022
9023
9024
9025
9026
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9018

def update!(**args)
  @biddable_conversions = args[:biddable_conversions] if args.key?(:biddable_conversions)
  @biddable_conversions_value = args[:biddable_conversions_value] if args.key?(:biddable_conversions_value)
  @clicks = args[:clicks] if args.key?(:clicks)
  @cost_micros = args[:cost_micros] if args.key?(:cost_micros)
  @impressions = args[:impressions] if args.key?(:impressions)
  @percent_cpc_bid_micros = args[:percent_cpc_bid_micros] if args.key?(:percent_cpc_bid_micros)
  @top_slot_impressions = args[:top_slot_impressions] if args.key?(:top_slot_impressions)
end