Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraint
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Describes the effect on serving that a policy topic entry will have.
Instance Attribute Summary collapse
-
#certificate_domain_mismatch_in_country_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList
A list of countries where a resource's serving is constrained.
-
#certificate_missing_in_country_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList
A list of countries where a resource's serving is constrained.
-
#country_constraint_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList
A list of countries where a resource's serving is constrained.
-
#reseller_constraint ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintResellerConstraint
Indicates that a policy topic was constrained due to disapproval of the website for reseller purposes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicConstraint
constructor
A new instance of GoogleAdsSearchads360V23CommonPolicyTopicConstraint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicConstraint
Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicConstraint.
9145 9146 9147 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9145 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_domain_mismatch_in_country_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList
A list of countries where a resource's serving is constrained.
Corresponds to the JSON property certificateDomainMismatchInCountryList
9127 9128 9129 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9127 def certificate_domain_mismatch_in_country_list @certificate_domain_mismatch_in_country_list end |
#certificate_missing_in_country_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList
A list of countries where a resource's serving is constrained.
Corresponds to the JSON property certificateMissingInCountryList
9132 9133 9134 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9132 def certificate_missing_in_country_list @certificate_missing_in_country_list end |
#country_constraint_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList
A list of countries where a resource's serving is constrained.
Corresponds to the JSON property countryConstraintList
9137 9138 9139 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9137 def country_constraint_list @country_constraint_list end |
#reseller_constraint ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintResellerConstraint
Indicates that a policy topic was constrained due to disapproval of the
website for reseller purposes.
Corresponds to the JSON property resellerConstraint
9143 9144 9145 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9143 def reseller_constraint @reseller_constraint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9150 9151 9152 9153 9154 9155 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9150 def update!(**args) @certificate_domain_mismatch_in_country_list = args[:certificate_domain_mismatch_in_country_list] if args.key?(:certificate_domain_mismatch_in_country_list) @certificate_missing_in_country_list = args[:certificate_missing_in_country_list] if args.key?(:certificate_missing_in_country_list) @country_constraint_list = args[:country_constraint_list] if args.key?(:country_constraint_list) @reseller_constraint = args[:reseller_constraint] if args.key?(:reseller_constraint) end |