Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Indicates that a resource's ability to serve in a particular country is constrained.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint

Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint.



484
485
486
# File 'lib/google/apis/searchads360_v23/classes.rb', line 484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_criterionString

Geo target constant resource name of the country in which serving is constrained. Corresponds to the JSON property countryCriterion

Returns:

  • (String)


482
483
484
# File 'lib/google/apis/searchads360_v23/classes.rb', line 482

def country_criterion
  @country_criterion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



489
490
491
# File 'lib/google/apis/searchads360_v23/classes.rb', line 489

def update!(**args)
  @country_criterion = args[:country_criterion] if args.key?(:country_criterion)
end