Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Policy finding attached to a resource (for example, alcohol policy associated with a site that sells alcohol). Each PolicyTopicEntry has a topic that indicates the specific ads policy the entry is about and a type to indicate the effect that the entry will have on serving. It may optionally have one or more evidences that indicate the reason for the finding. It may also optionally have one or more constraints that provide details about how serving may be restricted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicEntry

Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicEntry.



9193
9194
9195
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9193

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constraintsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraint>

Indicates how serving of this resource may be affected (for example, not serving in a country). Corresponds to the JSON property constraints



9172
9173
9174
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9172

def constraints
  @constraints
end

#evidencesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidence>

Additional information that explains policy finding (for example, the brand name for a trademark finding). Corresponds to the JSON property evidences



9178
9179
9180
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9178

def evidences
  @evidences
end

#topicString

Policy topic this finding refers to. For example, "ALCOHOL", " TRADEMARKS_IN_AD_TEXT", or "DESTINATION_NOT_WORKING". The set of possible policy topics is not fixed for a particular API version and may change at any time. Corresponds to the JSON property topic

Returns:

  • (String)


9186
9187
9188
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9186

def topic
  @topic
end

#typeString

Describes the negative or positive effect this policy will have on serving. Corresponds to the JSON property type

Returns:

  • (String)


9191
9192
9193
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9191

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9198
9199
9200
9201
9202
9203
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9198

def update!(**args)
  @constraints = args[:constraints] if args.key?(:constraints)
  @evidences = args[:evidences] if args.key?(:evidences)
  @topic = args[:topic] if args.key?(:topic)
  @type = args[:type] if args.key?(:type)
end