Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationNotWorking

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Evidence details when the destination is returning an HTTP error code or isn't functional in all locations for commonly used devices.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationNotWorking

Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationNotWorking.



583
584
585
# File 'lib/google/apis/searchads360_v23/classes.rb', line 583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deviceString

The type of device that failed to load the URL. Corresponds to the JSON property device

Returns:

  • (String)


560
561
562
# File 'lib/google/apis/searchads360_v23/classes.rb', line 560

def device
  @device
end

#dns_error_typeString

The type of DNS error. Corresponds to the JSON property dnsErrorType

Returns:

  • (String)


565
566
567
# File 'lib/google/apis/searchads360_v23/classes.rb', line 565

def dns_error_type
  @dns_error_type
end

#expanded_urlString

The full URL that didn't work. Corresponds to the JSON property expandedUrl

Returns:

  • (String)


570
571
572
# File 'lib/google/apis/searchads360_v23/classes.rb', line 570

def expanded_url
  @expanded_url
end

#http_error_codeFixnum

The HTTP error code. Corresponds to the JSON property httpErrorCode

Returns:

  • (Fixnum)


575
576
577
# File 'lib/google/apis/searchads360_v23/classes.rb', line 575

def http_error_code
  @http_error_code
end

#last_checked_date_timeString

The time the URL was last checked. The format is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34:30" Corresponds to the JSON property lastCheckedDateTime

Returns:

  • (String)


581
582
583
# File 'lib/google/apis/searchads360_v23/classes.rb', line 581

def last_checked_date_time
  @last_checked_date_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



588
589
590
591
592
593
594
# File 'lib/google/apis/searchads360_v23/classes.rb', line 588

def update!(**args)
  @device = args[:device] if args.key?(:device)
  @dns_error_type = args[:dns_error_type] if args.key?(:dns_error_type)
  @expanded_url = args[:expanded_url] if args.key?(:expanded_url)
  @http_error_code = args[:http_error_code] if args.key?(:http_error_code)
  @last_checked_date_time = args[:last_checked_date_time] if args.key?(:last_checked_date_time)
end