Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceTextList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A list of fragments of text that violated a policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicEvidenceTextList

Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicEvidenceTextList.



625
626
627
# File 'lib/google/apis/searchads360_v23/classes.rb', line 625

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#textsArray<String>

The fragments of text from the resource that caused the policy finding. Corresponds to the JSON property texts

Returns:

  • (Array<String>)


623
624
625
# File 'lib/google/apis/searchads360_v23/classes.rb', line 623

def texts
  @texts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



630
631
632
# File 'lib/google/apis/searchads360_v23/classes.rb', line 630

def update!(**args)
  @texts = args[:texts] if args.key?(:texts)
end