Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyValidationParameter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Parameter for controlling how policy exemption is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyValidationParameter

Returns a new instance of GoogleAdsSearchads360V23CommonPolicyValidationParameter.



9219
9220
9221
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9219

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exempt_policy_violation_keysArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyViolationKey>

The list of policy violation keys that should not cause a PolicyViolationError to be reported. Not all policy violations are exemptable. Refer to the is_exemptible field in the returned PolicyViolationError. This field is used for keyword policy exemptions. If this field is populated, then ignorable_policy_topics must be empty. Resources that violate these policies will be saved, but will not be eligible to serve. They may begin serving at a later time due to a change in policies, re-review of the resource, or a change in advertiser certificates. Corresponds to the JSON property exemptPolicyViolationKeys



9206
9207
9208
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9206

def exempt_policy_violation_keys
  @exempt_policy_violation_keys
end

#ignorable_policy_topicsArray<String>

The list of policy topics that should not cause a PolicyFindingError to be reported. This field is used for ad policy exemptions. It corresponds to the PolicyTopicEntry.topic field. If this field is populated, then exempt_policy_violation_keys must be empty. Resources that violate these policies will be saved, but will not be eligible to serve. They may begin serving at a later time due to a change in policies, re-review of the resource, or a change in advertiser certificates. Corresponds to the JSON property ignorablePolicyTopics

Returns:

  • (Array<String>)


9217
9218
9219
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9217

def ignorable_policy_topics
  @ignorable_policy_topics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9224
9225
9226
9227
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9224

def update!(**args)
  @exempt_policy_violation_keys = args[:exempt_policy_violation_keys] if args.key?(:exempt_policy_violation_keys)
  @ignorable_policy_topics = args[:ignorable_policy_topics] if args.key?(:ignorable_policy_topics)
end