Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPriceOffering

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single price offering within a PriceAsset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPriceOffering

Returns a new instance of GoogleAdsSearchads360V23CommonPriceOffering.



9401
9402
9403
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Required. The description of the price offering. The length of this string should be between 1 and 25, inclusive. Corresponds to the JSON property description

Returns:

  • (String)


9373
9374
9375
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9373

def description
  @description
end

#final_mobile_urlString

The final mobile URL after all cross domain redirects. Corresponds to the JSON property finalMobileUrl

Returns:

  • (String)


9378
9379
9380
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9378

def final_mobile_url
  @final_mobile_url
end

#final_urlString

Required. The final URL after all cross domain redirects. Corresponds to the JSON property finalUrl

Returns:

  • (String)


9383
9384
9385
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9383

def final_url
  @final_url
end

#headerString

Required. The header of the price offering. The length of this string should be between 1 and 25, inclusive. Corresponds to the JSON property header

Returns:

  • (String)


9389
9390
9391
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9389

def header
  @header
end

#priceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMoney

Represents a price in a particular currency. Corresponds to the JSON property price



9394
9395
9396
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9394

def price
  @price
end

#unitString

The price unit of the price offering. Corresponds to the JSON property unit

Returns:

  • (String)


9399
9400
9401
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9399

def unit
  @unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9406
9407
9408
9409
9410
9411
9412
9413
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9406

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @header = args[:header] if args.key?(:header)
  @price = args[:price] if args.key?(:price)
  @unit = args[:unit] if args.key?(:unit)
end