Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPromotionBarcodeInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPromotionBarcodeInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Barcode info to generate promotion barcode.
Instance Attribute Summary collapse
-
#barcode_content ⇒ String
Promotion message to be encoded in the barcode.
-
#type ⇒ String
Barcode type used to generate barcode with the correct format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPromotionBarcodeInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonPromotionBarcodeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPromotionBarcodeInfo
Returns a new instance of GoogleAdsSearchads360V23CommonPromotionBarcodeInfo.
9737 9738 9739 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#barcode_content ⇒ String
Promotion message to be encoded in the barcode.
Corresponds to the JSON property barcodeContent
9730 9731 9732 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9730 def @barcode_content end |
#type ⇒ String
Barcode type used to generate barcode with the correct format.
Corresponds to the JSON property type
9735 9736 9737 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9735 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9742 9743 9744 9745 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9742 def update!(**args) @barcode_content = args[:barcode_content] if args.key?(:barcode_content) @type = args[:type] if args.key?(:type) end |