Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProximityInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProximityInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Proximity criterion. The geo point and radius determine what geographical area is included. The address is a description of the geo point that does not affect ad serving. There are two ways to create a proximity. First, by setting an address and radius. The geo point will be automatically computed. Second, by setting a geo point and radius. The address is an optional label that won't be validated.
Instance Attribute Summary collapse
-
#address ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAddressInfo
Address for proximity criterion.
-
#geo_point ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGeoPointInfo
Geo point for proximity criterion.
-
#radius ⇒ Float
The radius of the proximity.
-
#radius_units ⇒ String
The unit of measurement of the radius.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonProximityInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonProximityInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonProximityInfo
Returns a new instance of GoogleAdsSearchads360V23CommonProximityInfo.
9864 9865 9866 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9864 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAddressInfo
Address for proximity criterion.
Corresponds to the JSON property address
9847 9848 9849 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9847 def address @address end |
#geo_point ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGeoPointInfo
Geo point for proximity criterion.
Corresponds to the JSON property geoPoint
9852 9853 9854 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9852 def geo_point @geo_point end |
#radius ⇒ Float
The radius of the proximity.
Corresponds to the JSON property radius
9857 9858 9859 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9857 def radius @radius end |
#radius_units ⇒ String
The unit of measurement of the radius. Default is KILOMETERS.
Corresponds to the JSON property radiusUnits
9862 9863 9864 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9862 def radius_units @radius_units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9869 9870 9871 9872 9873 9874 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9869 def update!(**args) @address = args[:address] if args.key?(:address) @geo_point = args[:geo_point] if args.key?(:geo_point) @radius = args[:radius] if args.key?(:radius) @radius_units = args[:radius_units] if args.key?(:radius_units) end |