Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveDisplayAdControlSpec
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveDisplayAdControlSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Specification for various creative controls for a responsive display ad.
Instance Attribute Summary collapse
-
#enable_asset_enhancements ⇒ Boolean
(also: #enable_asset_enhancements?)
Whether the advertiser has opted into the asset enhancements feature.
-
#enable_autogen_video ⇒ Boolean
(also: #enable_autogen_video?)
Whether the advertiser has opted into auto-gen video feature.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonResponsiveDisplayAdControlSpec
constructor
A new instance of GoogleAdsSearchads360V23CommonResponsiveDisplayAdControlSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonResponsiveDisplayAdControlSpec
Returns a new instance of GoogleAdsSearchads360V23CommonResponsiveDisplayAdControlSpec.
9914 9915 9916 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9914 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_asset_enhancements ⇒ Boolean Also known as: enable_asset_enhancements?
Whether the advertiser has opted into the asset enhancements feature.
Corresponds to the JSON property enableAssetEnhancements
9905 9906 9907 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9905 def enable_asset_enhancements @enable_asset_enhancements end |
#enable_autogen_video ⇒ Boolean Also known as: enable_autogen_video?
Whether the advertiser has opted into auto-gen video feature.
Corresponds to the JSON property enableAutogenVideo
9911 9912 9913 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9911 def enable_autogen_video @enable_autogen_video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9919 9920 9921 9922 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9919 def update!(**args) @enable_asset_enhancements = args[:enable_asset_enhancements] if args.key?(:enable_asset_enhancements) @enable_autogen_video = args[:enable_autogen_video] if args.key?(:enable_autogen_video) end |