Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveDisplayAdInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A responsive display ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonResponsiveDisplayAdInfo

Returns a new instance of GoogleAdsSearchads360V23CommonResponsiveDisplayAdInfo.



10033
10034
10035
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accent_colorString

The accent color of the ad in hexadecimal, for example, #ffffff for white. If one of main_color and accent_color is set, the other is required as well. Corresponds to the JSON property accentColor

Returns:

  • (String)


9933
9934
9935
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9933

def accent_color
  @accent_color
end

#allow_flexible_colorBoolean Also known as: allow_flexible_color?

Advertiser's consent to allow flexible color. When true, the ad may be served with different color if necessary. When false, the ad will be served with the specified colors or a neutral color. The default value is true. Must be true if main_color and accent_color are not set. Corresponds to the JSON property allowFlexibleColor

Returns:

  • (Boolean)


9941
9942
9943
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9941

def allow_flexible_color
  @allow_flexible_color
end

#business_nameString

The advertiser/brand name. Maximum display width is 25. Corresponds to the JSON property businessName

Returns:

  • (String)


9947
9948
9949
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9947

def business_name
  @business_name
end

#call_to_action_textString

The call-to-action text for the ad. Maximum display width is 30. Corresponds to the JSON property callToActionText

Returns:

  • (String)


9952
9953
9954
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9952

def call_to_action_text
  @call_to_action_text
end

#control_specGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveDisplayAdControlSpec

Specification for various creative controls for a responsive display ad. Corresponds to the JSON property controlSpec



9957
9958
9959
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9957

def control_spec
  @control_spec
end

#descriptionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

Descriptive texts for the ad. The maximum length is 90 characters. At least 1 and max 5 headlines can be specified. Corresponds to the JSON property descriptions



9963
9964
9965
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9963

def descriptions
  @descriptions
end

#format_settingString

Specifies which format the ad will be served in. Default is ALL_FORMATS. Corresponds to the JSON property formatSetting

Returns:

  • (String)


9968
9969
9970
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9968

def format_setting
  @format_setting
end

#headlinesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

Short format headlines for the ad. The maximum length is 30 characters. At least 1 and max 5 headlines can be specified. Corresponds to the JSON property headlines



9974
9975
9976
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9974

def headlines
  @headlines
end

#logo_imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

Logo images to be used in the ad. Valid image types are GIF, JPEG, and PNG. The minimum size is 512x128 and the aspect ratio must be 4:1 (+-1%). Combined with square_logo_images, the maximum is 5. Corresponds to the JSON property logoImages



9981
9982
9983
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9981

def logo_images
  @logo_images
end

#long_headlineGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset

A text asset used inside an ad. Corresponds to the JSON property longHeadline



9986
9987
9988
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9986

def long_headline
  @long_headline
end

#main_colorString

The main color of the ad in hexadecimal, for example, #ffffff for white. If one of main_color and accent_color is set, the other is required as well. Corresponds to the JSON property mainColor

Returns:

  • (String)


9992
9993
9994
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9992

def main_color
  @main_color
end

#marketing_imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

Marketing images to be used in the ad. Valid image types are GIF, JPEG, and PNG. The minimum size is 600x314 and the aspect ratio must be 1.91:1 (+-1%). At least one marketing_image is required. Combined with square_marketing_images, the maximum is 15. Corresponds to the JSON property marketingImages



10000
10001
10002
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10000

def marketing_images
  @marketing_images
end

#price_prefixString

Prefix before price. For example, 'as low as'. Corresponds to the JSON property pricePrefix

Returns:

  • (String)


10005
10006
10007
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10005

def price_prefix
  @price_prefix
end

#promo_textString

Promotion text used for dynamic formats of responsive ads. For example 'Free two-day shipping'. Corresponds to the JSON property promoText

Returns:

  • (String)


10011
10012
10013
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10011

def promo_text
  @promo_text
end

#square_logo_imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

Square logo images to be used in the ad. Valid image types are GIF, JPEG, and PNG. The minimum size is 128x128 and the aspect ratio must be 1:1 (+-1%). Combined with logo_images, the maximum is 5. Corresponds to the JSON property squareLogoImages



10018
10019
10020
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10018

def square_logo_images
  @square_logo_images
end

#square_marketing_imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

Square marketing images to be used in the ad. Valid image types are GIF, JPEG, and PNG. The minimum size is 300x300 and the aspect ratio must be 1:1 (+-1%). At least one square marketing_image is required. Combined with marketing_images, the maximum is 15. Corresponds to the JSON property squareMarketingImages



10026
10027
10028
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10026

def square_marketing_images
  @square_marketing_images
end

#youtube_videosArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAsset>

Optional YouTube videos for the ad. A maximum of 5 videos can be specified. Corresponds to the JSON property youtubeVideos



10031
10032
10033
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10031

def youtube_videos
  @youtube_videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10038
10039
10040
10041
10042
10043
10044
10045
10046
10047
10048
10049
10050
10051
10052
10053
10054
10055
10056
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10038

def update!(**args)
  @accent_color = args[:accent_color] if args.key?(:accent_color)
  @allow_flexible_color = args[:allow_flexible_color] if args.key?(:allow_flexible_color)
  @business_name = args[:business_name] if args.key?(:business_name)
  @call_to_action_text = args[:call_to_action_text] if args.key?(:call_to_action_text)
  @control_spec = args[:control_spec] if args.key?(:control_spec)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @format_setting = args[:format_setting] if args.key?(:format_setting)
  @headlines = args[:headlines] if args.key?(:headlines)
  @logo_images = args[:logo_images] if args.key?(:logo_images)
  @long_headline = args[:long_headline] if args.key?(:long_headline)
  @main_color = args[:main_color] if args.key?(:main_color)
  @marketing_images = args[:marketing_images] if args.key?(:marketing_images)
  @price_prefix = args[:price_prefix] if args.key?(:price_prefix)
  @promo_text = args[:promo_text] if args.key?(:promo_text)
  @square_logo_images = args[:square_logo_images] if args.key?(:square_logo_images)
  @square_marketing_images = args[:square_marketing_images] if args.key?(:square_marketing_images)
  @youtube_videos = args[:youtube_videos] if args.key?(:youtube_videos)
end