Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSegments
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSegments
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Segment only fields.
Instance Attribute Summary collapse
-
#ad_format_type ⇒ String
Ad Format type.
-
#ad_network_type ⇒ String
Ad network type.
-
#asset_interaction_target ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetInteractionTarget
An AssetInteractionTarget segment.
-
#conversion_action ⇒ String
Resource name of the conversion action.
-
#conversion_action_category ⇒ String
Conversion action category.
-
#conversion_action_name ⇒ String
Conversion action name.
-
#conversion_custom_dimensions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonValue>
The conversion custom dimensions.
-
#date ⇒ String
Date to which metrics apply.
-
#day_of_week ⇒ String
Day of the week, for example, MONDAY.
-
#device ⇒ String
Device to which metrics apply.
-
#geo_target_city ⇒ String
Resource name of the geo target constant that represents a city.
-
#geo_target_country ⇒ String
Resource name of the geo target constant that represents a country.
-
#geo_target_metro ⇒ String
Resource name of the geo target constant that represents a metro.
-
#geo_target_postal_code ⇒ String
Resource name of the geo target constant that represents a postal code.
-
#geo_target_region ⇒ String
Resource name of the geo target constant that represents a region.
-
#hour ⇒ Fixnum
Hour of day as a number between 0 and 23, inclusive.
-
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeyword
A Keyword criterion segment.
-
#mobile_device_platform ⇒ String
Mobile device platform to which metrics apply.
-
#month ⇒ String
Month as represented by the date of the first day of a month.
-
#product_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product.
-
#product_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product.
-
#product_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product.
-
#product_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product.
-
#product_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product.
-
#product_brand ⇒ String
Brand of the product.
-
#product_channel ⇒ String
Channel of the product.
-
#product_channel_exclusivity ⇒ String
Channel exclusivity of the product.
-
#product_condition ⇒ String
Condition of the product.
-
#product_country ⇒ String
Resource name of the geo target constant for the country of sale of the product.
-
#product_custom_attribute0 ⇒ String
Custom attribute 0 of the product.
-
#product_custom_attribute1 ⇒ String
Custom attribute 1 of the product.
-
#product_custom_attribute2 ⇒ String
Custom attribute 2 of the product.
-
#product_custom_attribute3 ⇒ String
Custom attribute 3 of the product.
-
#product_custom_attribute4 ⇒ String
Custom attribute 4 of the product.
-
#product_item_id ⇒ String
Item ID of the product.
-
#product_language ⇒ String
Resource name of the language constant for the language of the product.
-
#product_sold_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product sold.
-
#product_sold_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product sold.
-
#product_sold_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product sold.
-
#product_sold_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product sold.
-
#product_sold_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product sold.
-
#product_sold_brand ⇒ String
Brand of the product sold.
-
#product_sold_condition ⇒ String
Condition of the product sold.
-
#product_sold_custom_attribute0 ⇒ String
Custom attribute 0 of the product sold.
-
#product_sold_custom_attribute1 ⇒ String
Custom attribute 1 of the product sold.
-
#product_sold_custom_attribute2 ⇒ String
Custom attribute 2 of the product sold.
-
#product_sold_custom_attribute3 ⇒ String
Custom attribute 3 of the product sold.
-
#product_sold_custom_attribute4 ⇒ String
Custom attribute 4 of the product sold.
-
#product_sold_item_id ⇒ String
Item ID of the product sold.
-
#product_sold_title ⇒ String
Title of the product sold.
-
#product_sold_type_l1 ⇒ String
Type (level 1) of the product sold.
-
#product_sold_type_l2 ⇒ String
Type (level 2) of the product sold.
-
#product_sold_type_l3 ⇒ String
Type (level 3) of the product sold.
-
#product_sold_type_l4 ⇒ String
Type (level 4) of the product sold.
-
#product_sold_type_l5 ⇒ String
Type (level 5) of the product sold.
-
#product_store_id ⇒ String
Store ID of the product.
-
#product_title ⇒ String
Title of the product.
-
#product_type_l1 ⇒ String
Type (level 1) of the product.
-
#product_type_l2 ⇒ String
Type (level 2) of the product.
-
#product_type_l3 ⇒ String
Type (level 3) of the product.
-
#product_type_l4 ⇒ String
Type (level 4) of the product.
-
#product_type_l5 ⇒ String
Type (level 5) of the product.
-
#quarter ⇒ String
Quarter as represented by the date of the first day of a quarter.
-
#raw_event_conversion_dimensions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonValue>
The raw event conversion dimensions.
-
#vertical_ads_event_participant_display_names ⇒ String
The display names of participants in an event listing, like performers, speakers, or teams.
-
#vertical_ads_hotel_class ⇒ Fixnum
The class of the hotel.
-
#vertical_ads_listing ⇒ String
The listing associated with a listing impression, click or conversion.
-
#vertical_ads_listing_brand ⇒ String
The brand associated with a specific listing within a Vertical Ads context, for example, the brand of a car rental, a vacation home, or an event.
-
#vertical_ads_listing_city ⇒ String
The city where the vertical ads listing is located.
-
#vertical_ads_listing_country ⇒ String
The country where the vertical ads listing is located.
-
#vertical_ads_listing_region ⇒ String
The region where the vertical ads listing is located.
-
#vertical_ads_partner_account ⇒ Fixnum
A specific partner account within a Partner Center (for example, Hotel Center) that supplies inventory feed data for Vertical Ads.
-
#vertical_ads_vertical ⇒ String
Type of vertical ad, such as Vacation Rentals, Car Rentals, or Events, used to categorize and segment data in the context of Vertical Ads.
-
#week ⇒ String
Week as defined as Monday through Sunday, and represented by the date of Monday.
-
#year ⇒ Fixnum
Year, formatted as yyyy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSegments
constructor
A new instance of GoogleAdsSearchads360V23CommonSegments.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSegments
Returns a new instance of GoogleAdsSearchads360V23CommonSegments.
10753 10754 10755 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10753 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_format_type ⇒ String
Ad Format type.
Corresponds to the JSON property adFormatType
10371 10372 10373 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10371 def ad_format_type @ad_format_type end |
#ad_network_type ⇒ String
Ad network type.
Corresponds to the JSON property adNetworkType
10376 10377 10378 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10376 def ad_network_type @ad_network_type end |
#asset_interaction_target ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetInteractionTarget
An AssetInteractionTarget segment.
Corresponds to the JSON property assetInteractionTarget
10381 10382 10383 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10381 def asset_interaction_target @asset_interaction_target end |
#conversion_action ⇒ String
Resource name of the conversion action.
Corresponds to the JSON property conversionAction
10386 10387 10388 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10386 def conversion_action @conversion_action end |
#conversion_action_category ⇒ String
Conversion action category.
Corresponds to the JSON property conversionActionCategory
10391 10392 10393 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10391 def conversion_action_category @conversion_action_category end |
#conversion_action_name ⇒ String
Conversion action name.
Corresponds to the JSON property conversionActionName
10396 10397 10398 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10396 def conversion_action_name @conversion_action_name end |
#conversion_custom_dimensions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonValue>
The conversion custom dimensions.
Corresponds to the JSON property conversionCustomDimensions
10401 10402 10403 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10401 def conversion_custom_dimensions @conversion_custom_dimensions end |
#date ⇒ String
Date to which metrics apply. yyyy-MM-dd format, for example, 2018-04-17.
Corresponds to the JSON property date
10406 10407 10408 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10406 def date @date end |
#day_of_week ⇒ String
Day of the week, for example, MONDAY.
Corresponds to the JSON property dayOfWeek
10411 10412 10413 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10411 def day_of_week @day_of_week end |
#device ⇒ String
Device to which metrics apply.
Corresponds to the JSON property device
10416 10417 10418 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10416 def device @device end |
#geo_target_city ⇒ String
Resource name of the geo target constant that represents a city.
Corresponds to the JSON property geoTargetCity
10421 10422 10423 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10421 def geo_target_city @geo_target_city end |
#geo_target_country ⇒ String
Resource name of the geo target constant that represents a country.
Corresponds to the JSON property geoTargetCountry
10426 10427 10428 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10426 def geo_target_country @geo_target_country end |
#geo_target_metro ⇒ String
Resource name of the geo target constant that represents a metro.
Corresponds to the JSON property geoTargetMetro
10431 10432 10433 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10431 def geo_target_metro @geo_target_metro end |
#geo_target_postal_code ⇒ String
Resource name of the geo target constant that represents a postal code.
Corresponds to the JSON property geoTargetPostalCode
10436 10437 10438 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10436 def geo_target_postal_code @geo_target_postal_code end |
#geo_target_region ⇒ String
Resource name of the geo target constant that represents a region.
Corresponds to the JSON property geoTargetRegion
10441 10442 10443 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10441 def geo_target_region @geo_target_region end |
#hour ⇒ Fixnum
Hour of day as a number between 0 and 23, inclusive.
Corresponds to the JSON property hour
10446 10447 10448 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10446 def hour @hour end |
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeyword
A Keyword criterion segment.
Corresponds to the JSON property keyword
10451 10452 10453 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10451 def keyword @keyword end |
#mobile_device_platform ⇒ String
Mobile device platform to which metrics apply.
Corresponds to the JSON property mobileDevicePlatform
10456 10457 10458 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10456 def mobile_device_platform @mobile_device_platform end |
#month ⇒ String
Month as represented by the date of the first day of a month. Formatted as
yyyy-MM-dd.
Corresponds to the JSON property month
10462 10463 10464 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10462 def month @month end |
#product_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product.
Corresponds to the JSON property productBiddingCategoryLevel1
10467 10468 10469 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10467 def product_bidding_category_level1 @product_bidding_category_level1 end |
#product_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product.
Corresponds to the JSON property productBiddingCategoryLevel2
10472 10473 10474 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10472 def product_bidding_category_level2 @product_bidding_category_level2 end |
#product_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product.
Corresponds to the JSON property productBiddingCategoryLevel3
10477 10478 10479 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10477 def product_bidding_category_level3 @product_bidding_category_level3 end |
#product_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product.
Corresponds to the JSON property productBiddingCategoryLevel4
10482 10483 10484 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10482 def product_bidding_category_level4 @product_bidding_category_level4 end |
#product_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product.
Corresponds to the JSON property productBiddingCategoryLevel5
10487 10488 10489 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10487 def product_bidding_category_level5 @product_bidding_category_level5 end |
#product_brand ⇒ String
Brand of the product.
Corresponds to the JSON property productBrand
10492 10493 10494 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10492 def product_brand @product_brand end |
#product_channel ⇒ String
Channel of the product.
Corresponds to the JSON property productChannel
10497 10498 10499 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10497 def product_channel @product_channel end |
#product_channel_exclusivity ⇒ String
Channel exclusivity of the product.
Corresponds to the JSON property productChannelExclusivity
10502 10503 10504 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10502 def product_channel_exclusivity @product_channel_exclusivity end |
#product_condition ⇒ String
Condition of the product.
Corresponds to the JSON property productCondition
10507 10508 10509 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10507 def product_condition @product_condition end |
#product_country ⇒ String
Resource name of the geo target constant for the country of sale of the
product.
Corresponds to the JSON property productCountry
10513 10514 10515 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10513 def product_country @product_country end |
#product_custom_attribute0 ⇒ String
Custom attribute 0 of the product.
Corresponds to the JSON property productCustomAttribute0
10518 10519 10520 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10518 def product_custom_attribute0 @product_custom_attribute0 end |
#product_custom_attribute1 ⇒ String
Custom attribute 1 of the product.
Corresponds to the JSON property productCustomAttribute1
10523 10524 10525 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10523 def product_custom_attribute1 @product_custom_attribute1 end |
#product_custom_attribute2 ⇒ String
Custom attribute 2 of the product.
Corresponds to the JSON property productCustomAttribute2
10528 10529 10530 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10528 def product_custom_attribute2 @product_custom_attribute2 end |
#product_custom_attribute3 ⇒ String
Custom attribute 3 of the product.
Corresponds to the JSON property productCustomAttribute3
10533 10534 10535 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10533 def product_custom_attribute3 @product_custom_attribute3 end |
#product_custom_attribute4 ⇒ String
Custom attribute 4 of the product.
Corresponds to the JSON property productCustomAttribute4
10538 10539 10540 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10538 def product_custom_attribute4 @product_custom_attribute4 end |
#product_item_id ⇒ String
Item ID of the product.
Corresponds to the JSON property productItemId
10543 10544 10545 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10543 def product_item_id @product_item_id end |
#product_language ⇒ String
Resource name of the language constant for the language of the product.
Corresponds to the JSON property productLanguage
10548 10549 10550 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10548 def product_language @product_language end |
#product_sold_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel1
10553 10554 10555 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10553 def product_sold_bidding_category_level1 @product_sold_bidding_category_level1 end |
#product_sold_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel2
10558 10559 10560 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10558 def product_sold_bidding_category_level2 @product_sold_bidding_category_level2 end |
#product_sold_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel3
10563 10564 10565 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10563 def product_sold_bidding_category_level3 @product_sold_bidding_category_level3 end |
#product_sold_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel4
10568 10569 10570 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10568 def product_sold_bidding_category_level4 @product_sold_bidding_category_level4 end |
#product_sold_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel5
10573 10574 10575 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10573 def product_sold_bidding_category_level5 @product_sold_bidding_category_level5 end |
#product_sold_brand ⇒ String
Brand of the product sold.
Corresponds to the JSON property productSoldBrand
10578 10579 10580 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10578 def product_sold_brand @product_sold_brand end |
#product_sold_condition ⇒ String
Condition of the product sold.
Corresponds to the JSON property productSoldCondition
10583 10584 10585 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10583 def product_sold_condition @product_sold_condition end |
#product_sold_custom_attribute0 ⇒ String
Custom attribute 0 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute0
10588 10589 10590 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10588 def product_sold_custom_attribute0 @product_sold_custom_attribute0 end |
#product_sold_custom_attribute1 ⇒ String
Custom attribute 1 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute1
10593 10594 10595 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10593 def product_sold_custom_attribute1 @product_sold_custom_attribute1 end |
#product_sold_custom_attribute2 ⇒ String
Custom attribute 2 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute2
10598 10599 10600 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10598 def product_sold_custom_attribute2 @product_sold_custom_attribute2 end |
#product_sold_custom_attribute3 ⇒ String
Custom attribute 3 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute3
10603 10604 10605 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10603 def product_sold_custom_attribute3 @product_sold_custom_attribute3 end |
#product_sold_custom_attribute4 ⇒ String
Custom attribute 4 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute4
10608 10609 10610 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10608 def product_sold_custom_attribute4 @product_sold_custom_attribute4 end |
#product_sold_item_id ⇒ String
Item ID of the product sold.
Corresponds to the JSON property productSoldItemId
10613 10614 10615 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10613 def product_sold_item_id @product_sold_item_id end |
#product_sold_title ⇒ String
Title of the product sold.
Corresponds to the JSON property productSoldTitle
10618 10619 10620 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10618 def product_sold_title @product_sold_title end |
#product_sold_type_l1 ⇒ String
Type (level 1) of the product sold.
Corresponds to the JSON property productSoldTypeL1
10623 10624 10625 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10623 def product_sold_type_l1 @product_sold_type_l1 end |
#product_sold_type_l2 ⇒ String
Type (level 2) of the product sold.
Corresponds to the JSON property productSoldTypeL2
10628 10629 10630 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10628 def product_sold_type_l2 @product_sold_type_l2 end |
#product_sold_type_l3 ⇒ String
Type (level 3) of the product sold.
Corresponds to the JSON property productSoldTypeL3
10633 10634 10635 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10633 def product_sold_type_l3 @product_sold_type_l3 end |
#product_sold_type_l4 ⇒ String
Type (level 4) of the product sold.
Corresponds to the JSON property productSoldTypeL4
10638 10639 10640 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10638 def product_sold_type_l4 @product_sold_type_l4 end |
#product_sold_type_l5 ⇒ String
Type (level 5) of the product sold.
Corresponds to the JSON property productSoldTypeL5
10643 10644 10645 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10643 def product_sold_type_l5 @product_sold_type_l5 end |
#product_store_id ⇒ String
Store ID of the product.
Corresponds to the JSON property productStoreId
10648 10649 10650 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10648 def product_store_id @product_store_id end |
#product_title ⇒ String
Title of the product.
Corresponds to the JSON property productTitle
10653 10654 10655 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10653 def product_title @product_title end |
#product_type_l1 ⇒ String
Type (level 1) of the product.
Corresponds to the JSON property productTypeL1
10658 10659 10660 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10658 def product_type_l1 @product_type_l1 end |
#product_type_l2 ⇒ String
Type (level 2) of the product.
Corresponds to the JSON property productTypeL2
10663 10664 10665 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10663 def product_type_l2 @product_type_l2 end |
#product_type_l3 ⇒ String
Type (level 3) of the product.
Corresponds to the JSON property productTypeL3
10668 10669 10670 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10668 def product_type_l3 @product_type_l3 end |
#product_type_l4 ⇒ String
Type (level 4) of the product.
Corresponds to the JSON property productTypeL4
10673 10674 10675 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10673 def product_type_l4 @product_type_l4 end |
#product_type_l5 ⇒ String
Type (level 5) of the product.
Corresponds to the JSON property productTypeL5
10678 10679 10680 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10678 def product_type_l5 @product_type_l5 end |
#quarter ⇒ String
Quarter as represented by the date of the first day of a quarter. Uses the
calendar year for quarters, for example, the second quarter of 2018 starts on
2018-04-01. Formatted as yyyy-MM-dd.
Corresponds to the JSON property quarter
10685 10686 10687 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10685 def quarter @quarter end |
#raw_event_conversion_dimensions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonValue>
The raw event conversion dimensions.
Corresponds to the JSON property rawEventConversionDimensions
10690 10691 10692 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10690 def raw_event_conversion_dimensions @raw_event_conversion_dimensions end |
#vertical_ads_event_participant_display_names ⇒ String
The display names of participants in an event listing, like performers,
speakers, or teams.
Corresponds to the JSON property verticalAdsEventParticipantDisplayNames
10696 10697 10698 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10696 def vertical_ads_event_participant_display_names @vertical_ads_event_participant_display_names end |
#vertical_ads_hotel_class ⇒ Fixnum
The class of the hotel. Generally in the range of 1 to 5 stars, but fully
customizable in the hotel feed.
Corresponds to the JSON property verticalAdsHotelClass
10702 10703 10704 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10702 def vertical_ads_hotel_class @vertical_ads_hotel_class end |
#vertical_ads_listing ⇒ String
The listing associated with a listing impression, click or conversion.
Corresponds to the JSON property verticalAdsListing
10707 10708 10709 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10707 def vertical_ads_listing @vertical_ads_listing end |
#vertical_ads_listing_brand ⇒ String
The brand associated with a specific listing within a Vertical Ads context,
for example, the brand of a car rental, a vacation home, or an event.
Corresponds to the JSON property verticalAdsListingBrand
10713 10714 10715 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10713 def vertical_ads_listing_brand @vertical_ads_listing_brand end |
#vertical_ads_listing_city ⇒ String
The city where the vertical ads listing is located.
Corresponds to the JSON property verticalAdsListingCity
10718 10719 10720 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10718 def vertical_ads_listing_city @vertical_ads_listing_city end |
#vertical_ads_listing_country ⇒ String
The country where the vertical ads listing is located.
Corresponds to the JSON property verticalAdsListingCountry
10723 10724 10725 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10723 def vertical_ads_listing_country @vertical_ads_listing_country end |
#vertical_ads_listing_region ⇒ String
The region where the vertical ads listing is located.
Corresponds to the JSON property verticalAdsListingRegion
10728 10729 10730 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10728 def vertical_ads_listing_region @vertical_ads_listing_region end |
#vertical_ads_partner_account ⇒ Fixnum
A specific partner account within a Partner Center (for example, Hotel Center)
that supplies inventory feed data for Vertical Ads.
Corresponds to the JSON property verticalAdsPartnerAccount
10734 10735 10736 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10734 def vertical_ads_partner_account @vertical_ads_partner_account end |
#vertical_ads_vertical ⇒ String
Type of vertical ad, such as Vacation Rentals, Car Rentals, or Events, used to
categorize and segment data in the context of Vertical Ads.
Corresponds to the JSON property verticalAdsVertical
10740 10741 10742 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10740 def vertical_ads_vertical @vertical_ads_vertical end |
#week ⇒ String
Week as defined as Monday through Sunday, and represented by the date of
Monday. Formatted as yyyy-MM-dd.
Corresponds to the JSON property week
10746 10747 10748 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10746 def week @week end |
#year ⇒ Fixnum
Year, formatted as yyyy.
Corresponds to the JSON property year
10751 10752 10753 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10751 def year @year end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10758 10759 10760 10761 10762 10763 10764 10765 10766 10767 10768 10769 10770 10771 10772 10773 10774 10775 10776 10777 10778 10779 10780 10781 10782 10783 10784 10785 10786 10787 10788 10789 10790 10791 10792 10793 10794 10795 10796 10797 10798 10799 10800 10801 10802 10803 10804 10805 10806 10807 10808 10809 10810 10811 10812 10813 10814 10815 10816 10817 10818 10819 10820 10821 10822 10823 10824 10825 10826 10827 10828 10829 10830 10831 10832 10833 10834 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10758 def update!(**args) @ad_format_type = args[:ad_format_type] if args.key?(:ad_format_type) @ad_network_type = args[:ad_network_type] if args.key?(:ad_network_type) @asset_interaction_target = args[:asset_interaction_target] if args.key?(:asset_interaction_target) @conversion_action = args[:conversion_action] if args.key?(:conversion_action) @conversion_action_category = args[:conversion_action_category] if args.key?(:conversion_action_category) @conversion_action_name = args[:conversion_action_name] if args.key?(:conversion_action_name) @conversion_custom_dimensions = args[:conversion_custom_dimensions] if args.key?(:conversion_custom_dimensions) @date = args[:date] if args.key?(:date) @day_of_week = args[:day_of_week] if args.key?(:day_of_week) @device = args[:device] if args.key?(:device) @geo_target_city = args[:geo_target_city] if args.key?(:geo_target_city) @geo_target_country = args[:geo_target_country] if args.key?(:geo_target_country) @geo_target_metro = args[:geo_target_metro] if args.key?(:geo_target_metro) @geo_target_postal_code = args[:geo_target_postal_code] if args.key?(:geo_target_postal_code) @geo_target_region = args[:geo_target_region] if args.key?(:geo_target_region) @hour = args[:hour] if args.key?(:hour) @keyword = args[:keyword] if args.key?(:keyword) @mobile_device_platform = args[:mobile_device_platform] if args.key?(:mobile_device_platform) @month = args[:month] if args.key?(:month) @product_bidding_category_level1 = args[:product_bidding_category_level1] if args.key?(:product_bidding_category_level1) @product_bidding_category_level2 = args[:product_bidding_category_level2] if args.key?(:product_bidding_category_level2) @product_bidding_category_level3 = args[:product_bidding_category_level3] if args.key?(:product_bidding_category_level3) @product_bidding_category_level4 = args[:product_bidding_category_level4] if args.key?(:product_bidding_category_level4) @product_bidding_category_level5 = args[:product_bidding_category_level5] if args.key?(:product_bidding_category_level5) @product_brand = args[:product_brand] if args.key?(:product_brand) @product_channel = args[:product_channel] if args.key?(:product_channel) @product_channel_exclusivity = args[:product_channel_exclusivity] if args.key?(:product_channel_exclusivity) @product_condition = args[:product_condition] if args.key?(:product_condition) @product_country = args[:product_country] if args.key?(:product_country) @product_custom_attribute0 = args[:product_custom_attribute0] if args.key?(:product_custom_attribute0) @product_custom_attribute1 = args[:product_custom_attribute1] if args.key?(:product_custom_attribute1) @product_custom_attribute2 = args[:product_custom_attribute2] if args.key?(:product_custom_attribute2) @product_custom_attribute3 = args[:product_custom_attribute3] if args.key?(:product_custom_attribute3) @product_custom_attribute4 = args[:product_custom_attribute4] if args.key?(:product_custom_attribute4) @product_item_id = args[:product_item_id] if args.key?(:product_item_id) @product_language = args[:product_language] if args.key?(:product_language) @product_sold_bidding_category_level1 = args[:product_sold_bidding_category_level1] if args.key?(:product_sold_bidding_category_level1) @product_sold_bidding_category_level2 = args[:product_sold_bidding_category_level2] if args.key?(:product_sold_bidding_category_level2) @product_sold_bidding_category_level3 = args[:product_sold_bidding_category_level3] if args.key?(:product_sold_bidding_category_level3) @product_sold_bidding_category_level4 = args[:product_sold_bidding_category_level4] if args.key?(:product_sold_bidding_category_level4) @product_sold_bidding_category_level5 = args[:product_sold_bidding_category_level5] if args.key?(:product_sold_bidding_category_level5) @product_sold_brand = args[:product_sold_brand] if args.key?(:product_sold_brand) @product_sold_condition = args[:product_sold_condition] if args.key?(:product_sold_condition) @product_sold_custom_attribute0 = args[:product_sold_custom_attribute0] if args.key?(:product_sold_custom_attribute0) @product_sold_custom_attribute1 = args[:product_sold_custom_attribute1] if args.key?(:product_sold_custom_attribute1) @product_sold_custom_attribute2 = args[:product_sold_custom_attribute2] if args.key?(:product_sold_custom_attribute2) @product_sold_custom_attribute3 = args[:product_sold_custom_attribute3] if args.key?(:product_sold_custom_attribute3) @product_sold_custom_attribute4 = args[:product_sold_custom_attribute4] if args.key?(:product_sold_custom_attribute4) @product_sold_item_id = args[:product_sold_item_id] if args.key?(:product_sold_item_id) @product_sold_title = args[:product_sold_title] if args.key?(:product_sold_title) @product_sold_type_l1 = args[:product_sold_type_l1] if args.key?(:product_sold_type_l1) @product_sold_type_l2 = args[:product_sold_type_l2] if args.key?(:product_sold_type_l2) @product_sold_type_l3 = args[:product_sold_type_l3] if args.key?(:product_sold_type_l3) @product_sold_type_l4 = args[:product_sold_type_l4] if args.key?(:product_sold_type_l4) @product_sold_type_l5 = args[:product_sold_type_l5] if args.key?(:product_sold_type_l5) @product_store_id = args[:product_store_id] if args.key?(:product_store_id) @product_title = args[:product_title] if args.key?(:product_title) @product_type_l1 = args[:product_type_l1] if args.key?(:product_type_l1) @product_type_l2 = args[:product_type_l2] if args.key?(:product_type_l2) @product_type_l3 = args[:product_type_l3] if args.key?(:product_type_l3) @product_type_l4 = args[:product_type_l4] if args.key?(:product_type_l4) @product_type_l5 = args[:product_type_l5] if args.key?(:product_type_l5) @quarter = args[:quarter] if args.key?(:quarter) @raw_event_conversion_dimensions = args[:raw_event_conversion_dimensions] if args.key?(:raw_event_conversion_dimensions) @vertical_ads_event_participant_display_names = args[:vertical_ads_event_participant_display_names] if args.key?(:vertical_ads_event_participant_display_names) @vertical_ads_hotel_class = args[:vertical_ads_hotel_class] if args.key?(:vertical_ads_hotel_class) @vertical_ads_listing = args[:vertical_ads_listing] if args.key?(:vertical_ads_listing) @vertical_ads_listing_brand = args[:vertical_ads_listing_brand] if args.key?(:vertical_ads_listing_brand) @vertical_ads_listing_city = args[:vertical_ads_listing_city] if args.key?(:vertical_ads_listing_city) @vertical_ads_listing_country = args[:vertical_ads_listing_country] if args.key?(:vertical_ads_listing_country) @vertical_ads_listing_region = args[:vertical_ads_listing_region] if args.key?(:vertical_ads_listing_region) @vertical_ads_partner_account = args[:vertical_ads_partner_account] if args.key?(:vertical_ads_partner_account) @vertical_ads_vertical = args[:vertical_ads_vertical] if args.key?(:vertical_ads_vertical) @week = args[:week] if args.key?(:week) @year = args[:year] if args.key?(:year) end |