Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonShoppingLoyalty

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The shopping loyalty related data. Shopping utilizes this data to provide users with a better experience. Accessible only to merchants on the allow-list.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonShoppingLoyalty

Returns a new instance of GoogleAdsSearchads360V23CommonShoppingLoyalty.



10794
10795
10796
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10794

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#loyalty_tierString

The membership tier. It is a free-form string as each merchant may have their own loyalty system. For example, it could be a number from 1 to 10, or a string such as "Golden" or "Silver", or even empty string "". Corresponds to the JSON property loyaltyTier

Returns:

  • (String)


10792
10793
10794
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10792

def loyalty_tier
  @loyalty_tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10799
10800
10801
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10799

def update!(**args)
  @loyalty_tier = args[:loyalty_tier] if args.key?(:loyalty_tier)
end