Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSitelinkFeedItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a sitelink.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSitelinkFeedItem

Returns a new instance of GoogleAdsSearchads360V23CommonSitelinkFeedItem.



10971
10972
10973
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10971

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#final_mobile_urlsArray<String>

A list of possible final mobile URLs after all cross domain redirects. Corresponds to the JSON property finalMobileUrls

Returns:

  • (Array<String>)


10927
10928
10929
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10927

def final_mobile_urls
  @final_mobile_urls
end

#final_url_suffixString

Final URL suffix to be appended to landing page URLs served with parallel tracking. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


10933
10934
10935
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10933

def final_url_suffix
  @final_url_suffix
end

#final_urlsArray<String>

A list of possible final URLs after all cross domain redirects. Corresponds to the JSON property finalUrls

Returns:

  • (Array<String>)


10938
10939
10940
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10938

def final_urls
  @final_urls
end

#line1String

First line of the description for the sitelink. If this value is set, line2 must also be set. The length of this string should be between 0 and 35, inclusive. Corresponds to the JSON property line1

Returns:

  • (String)


10945
10946
10947
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10945

def line1
  @line1
end

#line2String

Second line of the description for the sitelink. If this value is set, line1 must also be set. The length of this string should be between 0 and 35, inclusive. Corresponds to the JSON property line2

Returns:

  • (String)


10952
10953
10954
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10952

def line2
  @line2
end

URL display text for the sitelink. The length of this string should be between 1 and 25, inclusive. Corresponds to the JSON property linkText

Returns:

  • (String)


10958
10959
10960
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10958

def link_text
  @link_text
end

#tracking_url_templateString

URL template for constructing a tracking URL. Corresponds to the JSON property trackingUrlTemplate

Returns:

  • (String)


10963
10964
10965
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10963

def tracking_url_template
  @tracking_url_template
end

#url_custom_parametersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>

A list of mappings to be used for substituting URL custom parameter tags in the tracking_url_template, final_urls, and/or final_mobile_urls. Corresponds to the JSON property urlCustomParameters



10969
10970
10971
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10969

def url_custom_parameters
  @url_custom_parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10976
10977
10978
10979
10980
10981
10982
10983
10984
10985
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10976

def update!(**args)
  @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @final_urls = args[:final_urls] if args.key?(:final_urls)
  @line1 = args[:line1] if args.key?(:line1)
  @line2 = args[:line2] if args.key?(:line2)
  @link_text = args[:link_text] if args.key?(:link_text)
  @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template)
  @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters)
end