Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStoreSalesThirdPartyMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Metadata for a third party Store Sales. This product is only for customers on the allow-list. Contact your Google business development representative for details on the upload configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonStoreSalesThirdPartyMetadata

Returns a new instance of GoogleAdsSearchads360V23CommonStoreSalesThirdPartyMetadata.



11182
11183
11184
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11182

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_upload_date_timeString

Time the advertiser uploaded the data to the partner. Required. The format is " YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34:30" Corresponds to the JSON property advertiserUploadDateTime

Returns:

  • (String)


11150
11151
11152
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11150

def advertiser_upload_date_time
  @advertiser_upload_date_time
end

#bridge_map_version_idString

Version of partner IDs to be used for uploads. Required. Corresponds to the JSON property bridgeMapVersionId

Returns:

  • (String)


11155
11156
11157
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11155

def bridge_map_version_id
  @bridge_map_version_id
end

#partner_idFixnum

ID of the third party partner updating the transaction feed. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


11160
11161
11162
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11160

def partner_id
  @partner_id
end

#partner_match_fractionFloat

The fraction of valid transactions that are matched to a third party assigned user ID on the partner side. Required. The fraction needs to be between 0 and 1 (excluding 0). Corresponds to the JSON property partnerMatchFraction

Returns:

  • (Float)


11167
11168
11169
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11167

def partner_match_fraction
  @partner_match_fraction
end

#partner_upload_fractionFloat

The fraction of valid transactions that are uploaded by the partner to Google. Required. The fraction needs to be between 0 and 1 (excluding 0). Corresponds to the JSON property partnerUploadFraction

Returns:

  • (Float)


11173
11174
11175
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11173

def partner_upload_fraction
  @partner_upload_fraction
end

#valid_transaction_fractionFloat

The fraction of transactions that are valid. Invalid transactions may include invalid formats or values. Required. The fraction needs to be between 0 and 1 ( excluding 0). Corresponds to the JSON property validTransactionFraction

Returns:

  • (Float)


11180
11181
11182
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11180

def valid_transaction_fraction
  @valid_transaction_fraction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11187
11188
11189
11190
11191
11192
11193
11194
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11187

def update!(**args)
  @advertiser_upload_date_time = args[:advertiser_upload_date_time] if args.key?(:advertiser_upload_date_time)
  @bridge_map_version_id = args[:bridge_map_version_id] if args.key?(:bridge_map_version_id)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @partner_match_fraction = args[:partner_match_fraction] if args.key?(:partner_match_fraction)
  @partner_upload_fraction = args[:partner_upload_fraction] if args.key?(:partner_upload_fraction)
  @valid_transaction_fraction = args[:valid_transaction_fraction] if args.key?(:valid_transaction_fraction)
end