Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStructuredSnippetAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Structured Snippet asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonStructuredSnippetAsset

Returns a new instance of GoogleAdsSearchads360V23CommonStructuredSnippetAsset.



11215
11216
11217
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11215

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#headerString

Required. The header of the snippet. This string should be one of the predefined values at https://developers.google.com/google-ads/api/reference/ data/structured-snippet-headers Corresponds to the JSON property header

Returns:

  • (String)


11206
11207
11208
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11206

def header
  @header
end

#valuesArray<String>

Required. The values in the snippet. The size of this collection should be between 3 and 10, inclusive. The length of each value should be between 1 and 25 characters, inclusive. Corresponds to the JSON property values

Returns:

  • (Array<String>)


11213
11214
11215
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11213

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11220
11221
11222
11223
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11220

def update!(**args)
  @header = args[:header] if args.key?(:header)
  @values = args[:values] if args.key?(:values)
end