Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSyntheticContentAttestation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents an attestation about synthetic content from a single source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSyntheticContentAttestation

Returns a new instance of GoogleAdsSearchads360V23CommonSyntheticContentAttestation.



11240
11241
11242
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sourceString

The source of the synthetic content attestation. Corresponds to the JSON property source

Returns:

  • (String)


11233
11234
11235
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11233

def source
  @source
end

#statusString

Indicates whether the content is considered synthetic by this source. Corresponds to the JSON property status

Returns:

  • (String)


11238
11239
11240
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11238

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11245
11246
11247
11248
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11245

def update!(**args)
  @source = args[:source] if args.key?(:source)
  @status = args[:status] if args.key?(:status)
end