Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSyntheticContentInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSyntheticContentInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Container for synthetic content attestations from different sources, such as the advertiser and Google systems.
Instance Attribute Summary collapse
-
#advertiser_attestation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSyntheticContentAttestation
Represents an attestation about synthetic content from a single source.
-
#system_attestation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSyntheticContentAttestation
Represents an attestation about synthetic content from a single source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSyntheticContentInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonSyntheticContentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSyntheticContentInfo
Returns a new instance of GoogleAdsSearchads360V23CommonSyntheticContentInfo.
11266 11267 11268 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11266 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_attestation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSyntheticContentAttestation
Represents an attestation about synthetic content from a single source.
Corresponds to the JSON property advertiserAttestation
11259 11260 11261 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11259 def advertiser_attestation @advertiser_attestation end |
#system_attestation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSyntheticContentAttestation
Represents an attestation about synthetic content from a single source.
Corresponds to the JSON property systemAttestation
11264 11265 11266 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11264 def system_attestation @system_attestation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11271 11272 11273 11274 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11271 def update!(**args) @advertiser_attestation = args[:advertiser_attestation] if args.key?(:advertiser_attestation) @system_attestation = args[:system_attestation] if args.key?(:system_attestation) end |