Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpaSimulationPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Projected metrics for a specific target CPA amount.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetCpaSimulationPoint

Returns a new instance of GoogleAdsSearchads360V23CommonTargetCpaSimulationPoint.



11422
11423
11424
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11422

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_installsFloat

Projected number of app installs. Corresponds to the JSON property appInstalls

Returns:

  • (Float)


11361
11362
11363
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11361

def app_installs
  @app_installs
end

#biddable_conversionsFloat

Projected number of biddable conversions. Corresponds to the JSON property biddableConversions

Returns:

  • (Float)


11366
11367
11368
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11366

def biddable_conversions
  @biddable_conversions
end

#biddable_conversions_valueFloat

Projected total value of biddable conversions. Corresponds to the JSON property biddableConversionsValue

Returns:

  • (Float)


11371
11372
11373
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11371

def biddable_conversions_value
  @biddable_conversions_value
end

#clicksFixnum

Projected number of clicks. Corresponds to the JSON property clicks

Returns:

  • (Fixnum)


11376
11377
11378
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11376

def clicks
  @clicks
end

#cost_microsFixnum

Projected cost in micros. Corresponds to the JSON property costMicros

Returns:

  • (Fixnum)


11381
11382
11383
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11381

def cost_micros
  @cost_micros
end

#impressionsFixnum

Projected number of impressions. Corresponds to the JSON property impressions

Returns:

  • (Fixnum)


11386
11387
11388
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11386

def impressions
  @impressions
end

#in_app_actionsFloat

Projected number of in-app actions. Corresponds to the JSON property inAppActions

Returns:

  • (Float)


11391
11392
11393
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11391

def in_app_actions
  @in_app_actions
end

#interactionsFixnum

Projected number of interactions. Only discovery advertising channel type supports this field. Corresponds to the JSON property interactions

Returns:

  • (Fixnum)


11397
11398
11399
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11397

def interactions
  @interactions
end

#required_budget_amount_microsFixnum

Projected required daily budget that the advertiser must set in order to receive the estimated traffic, in micros of advertiser currency. Corresponds to the JSON property requiredBudgetAmountMicros

Returns:

  • (Fixnum)


11403
11404
11405
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11403

def required_budget_amount_micros
  @required_budget_amount_micros
end

#target_cpa_microsFixnum

The simulated target CPA upon which projected metrics are based. Corresponds to the JSON property targetCpaMicros

Returns:

  • (Fixnum)


11408
11409
11410
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11408

def target_cpa_micros
  @target_cpa_micros
end

#target_cpa_scaling_modifierFloat

The simulated scaling modifier upon which projected metrics are based. All CPA targets relevant to the simulated entity are scaled by this modifier. Corresponds to the JSON property targetCpaScalingModifier

Returns:

  • (Float)


11414
11415
11416
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11414

def target_cpa_scaling_modifier
  @target_cpa_scaling_modifier
end

#top_slot_impressionsFixnum

Projected number of top slot impressions. Only search advertising channel type supports this field. Corresponds to the JSON property topSlotImpressions

Returns:

  • (Fixnum)


11420
11421
11422
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11420

def top_slot_impressions
  @top_slot_impressions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11427

def update!(**args)
  @app_installs = args[:app_installs] if args.key?(:app_installs)
  @biddable_conversions = args[:biddable_conversions] if args.key?(:biddable_conversions)
  @biddable_conversions_value = args[:biddable_conversions_value] if args.key?(:biddable_conversions_value)
  @clicks = args[:clicks] if args.key?(:clicks)
  @cost_micros = args[:cost_micros] if args.key?(:cost_micros)
  @impressions = args[:impressions] if args.key?(:impressions)
  @in_app_actions = args[:in_app_actions] if args.key?(:in_app_actions)
  @interactions = args[:interactions] if args.key?(:interactions)
  @required_budget_amount_micros = args[:required_budget_amount_micros] if args.key?(:required_budget_amount_micros)
  @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros)
  @target_cpa_scaling_modifier = args[:target_cpa_scaling_modifier] if args.key?(:target_cpa_scaling_modifier)
  @top_slot_impressions = args[:top_slot_impressions] if args.key?(:top_slot_impressions)
end