Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPointList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A container for simulation points for simulations of type TARGET_IMPRESSION_SHARE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPointList

Returns a new instance of GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPointList.



11621
11622
11623
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pointsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPoint>

Projected metrics for a specific target impression share value. Corresponds to the JSON property points



11619
11620
11621
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11619

def points
  @points
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11626
11627
11628
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11626

def update!(**args)
  @points = args[:points] if args.key?(:points)
end