Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoas

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetRoas

Returns a new instance of GoogleAdsSearchads360V23CommonTargetRoas.



11721
11722
11723
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpc_bid_ceiling_microsFixnum

Maximum bid limit that can be set by the bid strategy. The limit applies to all keywords managed by the strategy. This should only be set for portfolio bid strategies. Corresponds to the JSON property cpcBidCeilingMicros

Returns:

  • (Fixnum)


11697
11698
11699
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11697

def cpc_bid_ceiling_micros
  @cpc_bid_ceiling_micros
end

#cpc_bid_floor_microsFixnum

Minimum bid limit that can be set by the bid strategy. The limit applies to all keywords managed by the strategy. This should only be set for portfolio bid strategies. Corresponds to the JSON property cpcBidFloorMicros

Returns:

  • (Fixnum)


11704
11705
11706
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11704

def cpc_bid_floor_micros
  @cpc_bid_floor_micros
end

#target_roasFloat

Required. The chosen revenue (based on conversion data) per unit of spend. Value must be between 0.01 and 1000.0, inclusive. Corresponds to the JSON property targetRoas

Returns:

  • (Float)


11710
11711
11712
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11710

def target_roas
  @target_roas
end

#target_roas_tolerance_percent_millisFixnum

The percent of ROAS(return on advertising spend) degradation tolerance allowed to increase traffic diversity and conversion volume, specified in millis (for example, 10,000 = 10%). A value of 10,000 means that the advertiser can expect ROAS degradation of up to 10% of the specified target ROAS. This field is only mutable for portfolio bidding strategies. Corresponds to the JSON property targetRoasTolerancePercentMillis

Returns:

  • (Fixnum)


11719
11720
11721
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11719

def target_roas_tolerance_percent_millis
  @target_roas_tolerance_percent_millis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11726
11727
11728
11729
11730
11731
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11726

def update!(**args)
  @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros)
  @cpc_bid_floor_micros = args[:cpc_bid_floor_micros] if args.key?(:cpc_bid_floor_micros)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
  @target_roas_tolerance_percent_millis = args[:target_roas_tolerance_percent_millis] if args.key?(:target_roas_tolerance_percent_millis)
end