Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonThirdPartyIntegrationPartnerData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Contains third party measurement partner related data for video campaigns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonThirdPartyIntegrationPartnerData

Returns a new instance of GoogleAdsSearchads360V23CommonThirdPartyIntegrationPartnerData.



11912
11913
11914
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11912

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

The client ID that allows the measurement partner to join multiple campaigns for a particular advertiser. Corresponds to the JSON property clientId

Returns:

  • (String)


11904
11905
11906
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11904

def client_id
  @client_id
end

#third_party_placement_idString

The third party placement ID that maps the measurement partner data with a campaign (or a group of related campaigns) specific data. Corresponds to the JSON property thirdPartyPlacementId

Returns:

  • (String)


11910
11911
11912
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11910

def third_party_placement_id
  @third_party_placement_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11917
11918
11919
11920
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11917

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @third_party_placement_id = args[:third_party_placement_id] if args.key?(:third_party_placement_id)
end