Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedCallAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedCallAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A unified call asset.
Instance Attribute Summary collapse
-
#ad_schedule_targets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>
List of non-overlapping schedules specifying all time intervals for which the asset may serve.
-
#call_conversion_action ⇒ String
The conversion action to attribute a call conversion to.
-
#call_conversion_reporting_state ⇒ String
Output only.
-
#call_only ⇒ Boolean
(also: #call_only?)
Whether the call only shows the phone number without a link to the website.
-
#call_tracking_enabled ⇒ Boolean
(also: #call_tracking_enabled?)
Whether the call should be enabled on call tracking.
-
#country_code ⇒ String
Two-letter country code of the phone number.
-
#end_date ⇒ String
Last date of when this asset is effective and still serving, in yyyy-MM-dd format.
-
#phone_number ⇒ String
The advertiser's raw phone number.
-
#start_date ⇒ String
Start date of when this asset is effective and can begin serving, in yyyy-MM- dd format.
-
#use_searcher_time_zone ⇒ Boolean
(also: #use_searcher_time_zone?)
Whether to show the call extension in search user's time zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUnifiedCallAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonUnifiedCallAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUnifiedCallAsset
Returns a new instance of GoogleAdsSearchads360V23CommonUnifiedCallAsset.
12161 12162 12163 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12161 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_schedule_targets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>
List of non-overlapping schedules specifying all time intervals for which the
asset may serve. There can be a maximum of 6 schedules per day, 42 in total.
Corresponds to the JSON property adScheduleTargets
12102 12103 12104 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12102 def ad_schedule_targets @ad_schedule_targets end |
#call_conversion_action ⇒ String
The conversion action to attribute a call conversion to. If not set, the
default conversion action is used. This field only has effect if
call_conversion_reporting_state is set to
USE_RESOURCE_LEVEL_CALL_CONVERSION_ACTION.
Corresponds to the JSON property callConversionAction
12110 12111 12112 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12110 def call_conversion_action @call_conversion_action end |
#call_conversion_reporting_state ⇒ String
Output only. Indicates whether this CallAsset should use its own call
conversion setting, follow the account level setting, or disable call
conversion.
Corresponds to the JSON property callConversionReportingState
12117 12118 12119 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12117 def call_conversion_reporting_state @call_conversion_reporting_state end |
#call_only ⇒ Boolean Also known as: call_only?
Whether the call only shows the phone number without a link to the website.
Applies to Microsoft Ads.
Corresponds to the JSON property callOnly
12123 12124 12125 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12123 def call_only @call_only end |
#call_tracking_enabled ⇒ Boolean Also known as: call_tracking_enabled?
Whether the call should be enabled on call tracking. Applies to Microsoft Ads.
Corresponds to the JSON property callTrackingEnabled
12129 12130 12131 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12129 def call_tracking_enabled @call_tracking_enabled end |
#country_code ⇒ String
Two-letter country code of the phone number. Examples: 'US', 'us'.
Corresponds to the JSON property countryCode
12135 12136 12137 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12135 def country_code @country_code end |
#end_date ⇒ String
Last date of when this asset is effective and still serving, in yyyy-MM-dd
format.
Corresponds to the JSON property endDate
12141 12142 12143 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12141 def end_date @end_date end |
#phone_number ⇒ String
The advertiser's raw phone number. Examples: '1234567890', '(123)456-7890'
Corresponds to the JSON property phoneNumber
12146 12147 12148 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12146 def phone_number @phone_number end |
#start_date ⇒ String
Start date of when this asset is effective and can begin serving, in yyyy-MM-
dd format.
Corresponds to the JSON property startDate
12152 12153 12154 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12152 def start_date @start_date end |
#use_searcher_time_zone ⇒ Boolean Also known as: use_searcher_time_zone?
Whether to show the call extension in search user's time zone. Applies to
Microsoft Ads.
Corresponds to the JSON property useSearcherTimeZone
12158 12159 12160 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12158 def use_searcher_time_zone @use_searcher_time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12166 12167 12168 12169 12170 12171 12172 12173 12174 12175 12176 12177 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12166 def update!(**args) @ad_schedule_targets = args[:ad_schedule_targets] if args.key?(:ad_schedule_targets) @call_conversion_action = args[:call_conversion_action] if args.key?(:call_conversion_action) @call_conversion_reporting_state = args[:call_conversion_reporting_state] if args.key?(:call_conversion_reporting_state) @call_only = args[:call_only] if args.key?(:call_only) @call_tracking_enabled = args[:call_tracking_enabled] if args.key?(:call_tracking_enabled) @country_code = args[:country_code] if args.key?(:country_code) @end_date = args[:end_date] if args.key?(:end_date) @phone_number = args[:phone_number] if args.key?(:phone_number) @start_date = args[:start_date] if args.key?(:start_date) @use_searcher_time_zone = args[:use_searcher_time_zone] if args.key?(:use_searcher_time_zone) end |