Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedCalloutAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedCalloutAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A unified callout asset.
Instance Attribute Summary collapse
-
#ad_schedule_targets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>
List of non-overlapping schedules specifying all time intervals for which the asset may serve.
-
#callout_text ⇒ String
The callout text.
-
#end_date ⇒ String
Last date of when this asset is effective and still serving, in yyyy-MM-dd format.
-
#start_date ⇒ String
Start date of when this asset is effective and can begin serving, in yyyy-MM- dd format.
-
#use_searcher_time_zone ⇒ Boolean
(also: #use_searcher_time_zone?)
Whether to show the asset in search user's time zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUnifiedCalloutAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonUnifiedCalloutAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUnifiedCalloutAsset
Returns a new instance of GoogleAdsSearchads360V23CommonUnifiedCalloutAsset.
12214 12215 12216 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12214 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_schedule_targets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>
List of non-overlapping schedules specifying all time intervals for which the
asset may serve. There can be a maximum of 6 schedules per day, 42 in total.
Corresponds to the JSON property adScheduleTargets
12188 12189 12190 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12188 def ad_schedule_targets @ad_schedule_targets end |
#callout_text ⇒ String
The callout text. The length of this string should be between 1 and 25,
inclusive.
Corresponds to the JSON property calloutText
12194 12195 12196 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12194 def callout_text @callout_text end |
#end_date ⇒ String
Last date of when this asset is effective and still serving, in yyyy-MM-dd
format.
Corresponds to the JSON property endDate
12200 12201 12202 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12200 def end_date @end_date end |
#start_date ⇒ String
Start date of when this asset is effective and can begin serving, in yyyy-MM-
dd format.
Corresponds to the JSON property startDate
12206 12207 12208 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12206 def start_date @start_date end |
#use_searcher_time_zone ⇒ Boolean Also known as: use_searcher_time_zone?
Whether to show the asset in search user's time zone. Applies to Microsoft Ads.
Corresponds to the JSON property useSearcherTimeZone
12211 12212 12213 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12211 def use_searcher_time_zone @use_searcher_time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12219 12220 12221 12222 12223 12224 12225 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12219 def update!(**args) @ad_schedule_targets = args[:ad_schedule_targets] if args.key?(:ad_schedule_targets) @callout_text = args[:callout_text] if args.key?(:callout_text) @end_date = args[:end_date] if args.key?(:end_date) @start_date = args[:start_date] if args.key?(:start_date) @use_searcher_time_zone = args[:use_searcher_time_zone] if args.key?(:use_searcher_time_zone) end |