Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserIdentifier
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserIdentifier
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
identifying information.
Instance Attribute Summary collapse
-
#address_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonOfflineUserAddressInfo
Address identifier of offline data.
-
#hashed_email ⇒ String
Hashed email address using SHA-256 hash function after normalization.
-
#hashed_phone_number ⇒ String
Hashed phone number using SHA-256 hash function after normalization (E164 standard).
-
#mobile_id ⇒ String
Mobile device ID (advertising ID/IDFA).
-
#third_party_user_id ⇒ String
Advertiser-assigned user ID for Customer Match upload, or third-party-assigned user ID for Corresponds to the JSON property
thirdPartyUserId. -
#user_identifier_source ⇒ String
Source of the user identifier when the upload is from Store Sales Corresponds to the JSON property
userIdentifierSource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserIdentifier
constructor
A new instance of GoogleAdsSearchads360V23CommonUserIdentifier.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserIdentifier
Returns a new instance of GoogleAdsSearchads360V23CommonUserIdentifier.
12579 12580 12581 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonOfflineUserAddressInfo
Address identifier of offline data.
Corresponds to the JSON property addressInfo
12550 12551 12552 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12550 def address_info @address_info end |
#hashed_email ⇒ String
Hashed email address using SHA-256 hash function after normalization.
Corresponds to the JSON property hashedEmail
12555 12556 12557 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12555 def hashed_email @hashed_email end |
#hashed_phone_number ⇒ String
Hashed phone number using SHA-256 hash function after normalization (E164
standard).
Corresponds to the JSON property hashedPhoneNumber
12561 12562 12563 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12561 def hashed_phone_number @hashed_phone_number end |
#mobile_id ⇒ String
Mobile device ID (advertising ID/IDFA).
Corresponds to the JSON property mobileId
12566 12567 12568 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12566 def mobile_id @mobile_id end |
#third_party_user_id ⇒ String
Advertiser-assigned user ID for Customer Match upload, or third-party-assigned
user ID for
Corresponds to the JSON property thirdPartyUserId
12572 12573 12574 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12572 def third_party_user_id @third_party_user_id end |
#user_identifier_source ⇒ String
Source of the user identifier when the upload is from Store Sales
Corresponds to the JSON property userIdentifierSource
12577 12578 12579 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12577 def user_identifier_source @user_identifier_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12584 12585 12586 12587 12588 12589 12590 12591 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12584 def update!(**args) @address_info = args[:address_info] if args.key?(:address_info) @hashed_email = args[:hashed_email] if args.key?(:hashed_email) @hashed_phone_number = args[:hashed_phone_number] if args.key?(:hashed_phone_number) @mobile_id = args[:mobile_id] if args.key?(:mobile_id) @third_party_user_id = args[:third_party_user_id] if args.key?(:third_party_user_id) @user_identifier_source = args[:user_identifier_source] if args.key?(:user_identifier_source) end |