Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserInterestAttributeMetadata
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserInterestAttributeMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Metadata associated with a User Interest attribute.
Instance Attribute Summary collapse
-
#user_interest_description ⇒ String
English language text description of the user interest category (200 characters max).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserInterestAttributeMetadata
constructor
A new instance of GoogleAdsSearchads360V23CommonUserInterestAttributeMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserInterestAttributeMetadata
Returns a new instance of GoogleAdsSearchads360V23CommonUserInterestAttributeMetadata.
12604 12605 12606 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12604 def initialize(**args) update!(**args) end |
Instance Attribute Details
#user_interest_description ⇒ String
English language text description of the user interest category (200
characters max).
Corresponds to the JSON property userInterestDescription
12602 12603 12604 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12602 def user_interest_description @user_interest_description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12609 12610 12611 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12609 def update!(**args) @user_interest_description = args[:user_interest_description] if args.key?(:user_interest_description) end |