Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListNumberRuleItemInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A rule item composed of a number operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListNumberRuleItemInfo

Returns a new instance of GoogleAdsSearchads360V23CommonUserListNumberRuleItemInfo.



12794
12795
12796
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12794

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operatorString

Number comparison operator. This field is required and must be populated when creating a new number rule item. Corresponds to the JSON property operator

Returns:

  • (String)


12786
12787
12788
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12786

def operator
  @operator
end

#valueFloat

Number value to be compared with the variable. This field is required and must be populated when creating a new number rule item. Corresponds to the JSON property value

Returns:

  • (Float)


12792
12793
12794
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12792

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12799
12800
12801
12802
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12799

def update!(**args)
  @operator = args[:operator] if args.key?(:operator)
  @value = args[:value] if args.key?(:value)
end