Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleItemGroupInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleItemGroupInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A group of rule items.
Instance Attribute Summary collapse
-
#rule_items ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleItemInfo>
Rule items that will be grouped together based on rule_type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListRuleItemGroupInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonUserListRuleItemGroupInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListRuleItemGroupInfo
Returns a new instance of GoogleAdsSearchads360V23CommonUserListRuleItemGroupInfo.
12784 12785 12786 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12784 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rule_items ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleItemInfo>
Rule items that will be grouped together based on rule_type.
Corresponds to the JSON property ruleItems
12782 12783 12784 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12782 def rule_items @rule_items end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12789 12790 12791 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12789 def update!(**args) @rule_items = args[:rule_items] if args.key?(:rule_items) end |