Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleItemInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An atomic rule item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListRuleItemInfo

Returns a new instance of GoogleAdsSearchads360V23CommonUserListRuleItemInfo.



12823
12824
12825
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12823

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_rule_itemGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListDateRuleItemInfo

A rule item composed of a date operation. Corresponds to the JSON property dateRuleItem



12801
12802
12803
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12801

def date_rule_item
  @date_rule_item
end

#nameString

Rule variable name. It should match the corresponding key name fired by the pixel. A name must begin with US-ascii letters or underscore or UTF8 code that is greater than 127 and consist of US-ascii letters or digits or underscore or UTF8 code that is greater than 127. For websites, there are two built-in variable URL (name = 'url_') and referrer URL (name = 'ref_url_'). This field must be populated when creating a new rule item. Corresponds to the JSON property name

Returns:

  • (String)


12811
12812
12813
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12811

def name
  @name
end

#number_rule_itemGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListNumberRuleItemInfo

A rule item composed of a number operation. Corresponds to the JSON property numberRuleItem



12816
12817
12818
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12816

def number_rule_item
  @number_rule_item
end

#string_rule_itemGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo

A rule item composed of a string operation. Corresponds to the JSON property stringRuleItem



12821
12822
12823
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12821

def string_rule_item
  @string_rule_item
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12828
12829
12830
12831
12832
12833
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12828

def update!(**args)
  @date_rule_item = args[:date_rule_item] if args.key?(:date_rule_item)
  @name = args[:name] if args.key?(:name)
  @number_rule_item = args[:number_rule_item] if args.key?(:number_rule_item)
  @string_rule_item = args[:string_rule_item] if args.key?(:string_rule_item)
end