Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A rule item composed of a string operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo

Returns a new instance of GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo.



12933
12934
12935
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12933

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operatorString

String comparison operator. This field is required and must be populated when creating a new string rule item. Corresponds to the JSON property operator

Returns:

  • (String)


12923
12924
12925
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12923

def operator
  @operator
end

#valueString

The right hand side of the string rule item. For URLs or referrer URLs, the value can not contain illegal URL chars such as newlines, quotes, tabs, or parentheses. This field is required and must be populated when creating a new string rule item. Corresponds to the JSON property value

Returns:

  • (String)


12931
12932
12933
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12931

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12938
12939
12940
12941
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12938

def update!(**args)
  @operator = args[:operator] if args.key?(:operator)
  @value = args[:value] if args.key?(:value)
end