Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A criterion to represent a single item group rule in Vertical Ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo

Returns a new instance of GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo.



13018
13019
13020
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13018

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#city_criterion_idString

The resource name of the Geo Target Constant for the city. Corresponds to the JSON property cityCriterionId

Returns:

  • (String)


12995
12996
12997
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12995

def city_criterion_id
  @city_criterion_id
end

#country_criterion_idString

The resource name of the Geo Target Constant for the country. Corresponds to the JSON property countryCriterionId

Returns:

  • (String)


13000
13001
13002
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13000

def country_criterion_id
  @country_criterion_id
end

#hotel_classFixnum

Integer value specifying the class rating for a hotel. Ranges from 1 to 5 stars. Corresponds to the JSON property hotelClass

Returns:

  • (Fixnum)


13006
13007
13008
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13006

def hotel_class
  @hotel_class
end

#item_codeString

The id specifying a particular Vertical Ad listing. Corresponds to the JSON property itemCode

Returns:

  • (String)


13011
13012
13013
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13011

def item_code
  @item_code
end

#region_criterion_idString

The resource name of the Geo Target Constant for the region. Corresponds to the JSON property regionCriterionId

Returns:

  • (String)


13016
13017
13018
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13016

def region_criterion_id
  @region_criterion_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13023
13024
13025
13026
13027
13028
13029
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13023

def update!(**args)
  @city_criterion_id = args[:city_criterion_id] if args.key?(:city_criterion_id)
  @country_criterion_id = args[:country_criterion_id] if args.key?(:country_criterion_id)
  @hotel_class = args[:hotel_class] if args.key?(:hotel_class)
  @item_code = args[:item_code] if args.key?(:item_code)
  @region_criterion_id = args[:region_criterion_id] if args.key?(:region_criterion_id)
end