Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A YouTube Channel criterion.
Instance Attribute Summary collapse
-
#channel_id ⇒ String
The YouTube uploader channel id or the channel code of a YouTube channel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonYouTubeChannelInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonYouTubeChannelInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonYouTubeChannelInfo
Returns a new instance of GoogleAdsSearchads360V23CommonYouTubeChannelInfo.
13200 13201 13202 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13200 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_id ⇒ String
The YouTube uploader channel id or the channel code of a YouTube channel.
Corresponds to the JSON property channelId
13198 13199 13200 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13198 def channel_id @channel_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13205 13206 13207 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13205 def update!(**args) @channel_id = args[:channel_id] if args.key?(:channel_id) end |