Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A YouTube Video criterion.
Instance Attribute Summary collapse
-
#video_id ⇒ String
YouTube video id as it appears on the YouTube watch page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonYouTubeVideoInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonYouTubeVideoInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonYouTubeVideoInfo
Returns a new instance of GoogleAdsSearchads360V23CommonYouTubeVideoInfo.
13274 13275 13276 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13274 def initialize(**args) update!(**args) end |
Instance Attribute Details
#video_id ⇒ String
YouTube video id as it appears on the YouTube watch page.
Corresponds to the JSON property videoId
13272 13273 13274 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13272 def video_id @video_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13279 13280 13281 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13279 def update!(**args) @video_id = args[:video_id] if args.key?(:video_id) end |