Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonZaloBusinessMessageInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonZaloBusinessMessageInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Zalo information to use for messaging.
Instance Attribute Summary collapse
-
#custom_name ⇒ String
Custom name generated by the advertiser for their Zalo Account.
-
#oa_id ⇒ Fixnum
Zalo Official Account ID of the advertiser.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonZaloBusinessMessageInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonZaloBusinessMessageInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonZaloBusinessMessageInfo
Returns a new instance of GoogleAdsSearchads360V23CommonZaloBusinessMessageInfo.
13391 13392 13393 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13391 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_name ⇒ String
Custom name generated by the advertiser for their Zalo Account. These names
will usually be registered brands or trademarks.
Corresponds to the JSON property customName
13384 13385 13386 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13384 def custom_name @custom_name end |
#oa_id ⇒ Fixnum
Zalo Official Account ID of the advertiser.
Corresponds to the JSON property oaId
13389 13390 13391 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13389 def oa_id @oa_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13396 13397 13398 13399 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13396 def update!(**args) @custom_name = args[:custom_name] if args.key?(:custom_name) @oa_id = args[:oa_id] if args.key?(:oa_id) end |