Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorLocation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Describes the part of the request proto that caused the error.
Instance Attribute Summary collapse
-
#field_path_elements ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement>
A field path that indicates which field was invalid in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsErrorLocation
constructor
A new instance of GoogleAdsSearchads360V23ErrorsErrorLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsErrorLocation
Returns a new instance of GoogleAdsSearchads360V23ErrorsErrorLocation.
14622 14623 14624 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14622 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_path_elements ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement>
A field path that indicates which field was invalid in the request.
Corresponds to the JSON property fieldPathElements
14620 14621 14622 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14620 def field_path_elements @field_path_elements end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14627 14628 14629 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14627 def update!(**args) @field_path_elements = args[:field_path_elements] if args.key?(:field_path_elements) end |