Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A part of a field path.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement

Returns a new instance of GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement.



13416
13417
13418
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_nameString

The name of a field or a oneof Corresponds to the JSON property fieldName

Returns:

  • (String)


13409
13410
13411
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13409

def field_name
  @field_name
end

#indexFixnum

If field_name is a repeated field, this is the element that failed Corresponds to the JSON property index

Returns:

  • (Fixnum)


13414
13415
13416
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13414

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13421
13422
13423
13424
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13421

def update!(**args)
  @field_name = args[:field_name] if args.key?(:field_name)
  @index = args[:index] if args.key?(:index)
end