Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsPolicyFindingDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Error returned as part of a mutate response. This error indicates one or more policy findings in the fields of a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsPolicyFindingDetails

Returns a new instance of GoogleAdsSearchads360V23ErrorsPolicyFindingDetails.



14518
14519
14520
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14518

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policy_topic_entriesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry>

The list of policy topics for the resource. Contains the PROHIBITED or FULLY_LIMITED policy topic entries that prevented the resource from being saved (among any other entries the resource may also have). Corresponds to the JSON property policyTopicEntries



14516
14517
14518
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14516

def policy_topic_entries
  @policy_topic_entries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14523
14524
14525
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14523

def update!(**args)
  @policy_topic_entries = args[:policy_topic_entries] if args.key?(:policy_topic_entries)
end