Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsPolicyViolationDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Error returned as part of a mutate response. This error indicates single policy violation by some text in one of the fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsPolicyViolationDetails

Returns a new instance of GoogleAdsSearchads360V23ErrorsPolicyViolationDetails.



14681
14682
14683
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_policy_descriptionString

Human readable description of policy violation. Corresponds to the JSON property externalPolicyDescription

Returns:

  • (String)


14662
14663
14664
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14662

def external_policy_description
  @external_policy_description
end

#external_policy_nameString

Human readable name of the policy. Corresponds to the JSON property externalPolicyName

Returns:

  • (String)


14667
14668
14669
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14667

def external_policy_name
  @external_policy_name
end

#is_exemptibleBoolean Also known as: is_exemptible?

Whether user can file an exemption request for this violation. Corresponds to the JSON property isExemptible

Returns:

  • (Boolean)


14672
14673
14674
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14672

def is_exemptible
  @is_exemptible
end

#keyGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyViolationKey

Key of the violation. The key is used for referring to a violation when filing an exemption request. Corresponds to the JSON property key



14679
14680
14681
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14679

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14686
14687
14688
14689
14690
14691
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14686

def update!(**args)
  @external_policy_description = args[:external_policy_description] if args.key?(:external_policy_description)
  @external_policy_name = args[:external_policy_name] if args.key?(:external_policy_name)
  @is_exemptible = args[:is_exemptible] if args.key?(:is_exemptible)
  @key = args[:key] if args.key?(:key)
end