Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsQuotaErrorDetails
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsQuotaErrorDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Additional quota error details when there is QuotaError.
Instance Attribute Summary collapse
-
#rate_name ⇒ String
The high level description of the quota bucket.
-
#rate_scope ⇒ String
The rate scope of the quota limit.
-
#retry_delay ⇒ String
Backoff period that customers should wait before sending next request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsQuotaErrorDetails
constructor
A new instance of GoogleAdsSearchads360V23ErrorsQuotaErrorDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsQuotaErrorDetails
Returns a new instance of GoogleAdsSearchads360V23ErrorsQuotaErrorDetails.
14588 14589 14590 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14588 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rate_name ⇒ String
The high level description of the quota bucket. Examples are "Get requests for
standard access" or "Requests per account".
Corresponds to the JSON property rateName
14576 14577 14578 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14576 def rate_name @rate_name end |
#rate_scope ⇒ String
The rate scope of the quota limit.
Corresponds to the JSON property rateScope
14581 14582 14583 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14581 def rate_scope @rate_scope end |
#retry_delay ⇒ String
Backoff period that customers should wait before sending next request.
Corresponds to the JSON property retryDelay
14586 14587 14588 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14586 def retry_delay @retry_delay end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14593 14594 14595 14596 14597 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14593 def update!(**args) @rate_name = args[:rate_name] if args.key?(:rate_name) @rate_scope = args[:rate_scope] if args.key?(:rate_scope) @retry_delay = args[:retry_delay] if args.key?(:retry_delay) end |