Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsSearchAds360Error
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsSearchAds360Error
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Search Ads 360-specific error.
Instance Attribute Summary collapse
-
#details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorDetails
Additional error details.
-
#error_code ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorCode
The error reason represented by type and enum.
-
#location ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorLocation
Describes the part of the request proto that caused the error.
-
#message ⇒ String
A human-readable description of the error.
-
#trigger ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonValue
A generic data container.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsSearchAds360Error
constructor
A new instance of GoogleAdsSearchads360V23ErrorsSearchAds360Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsSearchAds360Error
Returns a new instance of GoogleAdsSearchads360V23ErrorsSearchAds360Error.
14799 14800 14801 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorDetails
Additional error details.
Corresponds to the JSON property details
14777 14778 14779 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14777 def details @details end |
#error_code ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorCode
The error reason represented by type and enum.
Corresponds to the JSON property errorCode
14782 14783 14784 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14782 def error_code @error_code end |
#location ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorLocation
Describes the part of the request proto that caused the error.
Corresponds to the JSON property location
14787 14788 14789 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14787 def location @location end |
#message ⇒ String
A human-readable description of the error.
Corresponds to the JSON property message
14792 14793 14794 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14792 def @message end |
#trigger ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonValue
A generic data container.
Corresponds to the JSON property trigger
14797 14798 14799 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14797 def trigger @trigger end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14804 14805 14806 14807 14808 14809 14810 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14804 def update!(**args) @details = args[:details] if args.key?(:details) @error_code = args[:error_code] if args.key?(:error_code) @location = args[:location] if args.key?(:location) @message = args[:message] if args.key?(:message) @trigger = args[:trigger] if args.key?(:trigger) end |