Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsSearchAds360Failure
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsSearchAds360Failure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Describes how a Search Ads 360 API call failed. It's returned inside google. rpc.Status.details when a call fails.
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsSearchAds360Error>
The list of errors that occurred.
-
#request_id ⇒ String
The unique ID of the request that is used for debugging purposes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsSearchAds360Failure
constructor
A new instance of GoogleAdsSearchads360V23ErrorsSearchAds360Failure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsSearchAds360Failure
Returns a new instance of GoogleAdsSearchads360V23ErrorsSearchAds360Failure.
14702 14703 14704 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14702 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsSearchAds360Error>
The list of errors that occurred.
Corresponds to the JSON property errors
14695 14696 14697 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14695 def errors @errors end |
#request_id ⇒ String
The unique ID of the request that is used for debugging purposes.
Corresponds to the JSON property requestId
14700 14701 14702 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14700 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14707 14708 14709 14710 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14707 def update!(**args) @errors = args[:errors] if args.key?(:errors) @request_id = args[:request_id] if args.key?(:request_id) end |