Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a view of BiddingStrategies owned by and shared with the customer. In contrast to BiddingStrategy, this resource includes strategies owned by managers of the customer and shared with this customer - in addition to strategies owned by this customer. This resource does not provide metrics and only exposes a limited subset of the BiddingStrategy attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategy

Returns a new instance of GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategy.



19286
19287
19288
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. The ID of the bidding strategy. Corresponds to the JSON property id

Returns:

  • (Fixnum)


19221
19222
19223
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19221

def id
  @id
end

#maximize_conversion_valueGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversionValue

An automated bidding strategy to help get the most conversion value for your campaigns while spending your budget. Corresponds to the JSON property maximizeConversionValue



19227
19228
19229
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19227

def maximize_conversion_value
  @maximize_conversion_value
end

#maximize_conversionsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversions

An automated bidding strategy to help get the most conversions for your campaigns while spending your budget. Corresponds to the JSON property maximizeConversions



19233
19234
19235
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19233

def maximize_conversions
  @maximize_conversions
end

#nameString

Output only. The name of the bidding strategy. Corresponds to the JSON property name

Returns:

  • (String)


19238
19239
19240
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19238

def name
  @name
end

#owner_customer_idFixnum

Output only. The ID of the Customer which owns the bidding strategy. Corresponds to the JSON property ownerCustomerId

Returns:

  • (Fixnum)


19243
19244
19245
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19243

def owner_customer_id
  @owner_customer_id
end

#owner_descriptive_nameString

Output only. descriptive_name of the Customer which owns the bidding strategy. Corresponds to the JSON property ownerDescriptiveName

Returns:

  • (String)


19248
19249
19250
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19248

def owner_descriptive_name
  @owner_descriptive_name
end

#resource_nameString

Output only. The resource name of the accessible bidding strategy. AccessibleBiddingStrategy resource names have the form: customers/ customer_id/accessibleBiddingStrategies/bidding_strategy_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


19255
19256
19257
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19255

def resource_name
  @resource_name
end

#target_cpaGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetCpa

An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set. Corresponds to the JSON property targetCpa



19261
19262
19263
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19261

def target_cpa
  @target_cpa
end

#target_impression_shareGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetImpressionShare

An automated bidding strategy that sets bids so that a certain percentage of search ads are shown at the top of the first page (or other targeted location). Corresponds to the JSON property targetImpressionShare



19267
19268
19269
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19267

def target_impression_share
  @target_impression_share
end

#target_roasGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetRoas

An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS). Corresponds to the JSON property targetRoas



19273
19274
19275
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19273

def target_roas
  @target_roas
end

#target_spendGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetSpend

An automated bid strategy that sets your bids to help get as many clicks as possible within your budget. Corresponds to the JSON property targetSpend



19279
19280
19281
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19279

def target_spend
  @target_spend
end

#typeString

Output only. The type of the bidding strategy. Corresponds to the JSON property type

Returns:

  • (String)


19284
19285
19286
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19284

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19291
19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19291

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @maximize_conversion_value = args[:maximize_conversion_value] if args.key?(:maximize_conversion_value)
  @maximize_conversions = args[:maximize_conversions] if args.key?(:maximize_conversions)
  @name = args[:name] if args.key?(:name)
  @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id)
  @owner_descriptive_name = args[:owner_descriptive_name] if args.key?(:owner_descriptive_name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @target_cpa = args[:target_cpa] if args.key?(:target_cpa)
  @target_impression_share = args[:target_impression_share] if args.key?(:target_impression_share)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
  @target_spend = args[:target_spend] if args.key?(:target_spend)
  @type = args[:type] if args.key?(:type)
end