Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversionValue
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversionValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An automated bidding strategy to help get the most conversion value for your campaigns while spending your budget.
Instance Attribute Summary collapse
-
#target_roas ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversionValue
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversionValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversionValue
Returns a new instance of GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversionValue.
14853 14854 14855 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14853 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_roas ⇒ Float
Output only. The target return on ad spend (ROAS) option. If set, the bid
strategy will maximize revenue while averaging the target return on ad spend.
If the target ROAS is high, the bid strategy may not be able to spend the full
budget. If the target ROAS is not set, the bid strategy will aim to achieve
the highest possible ROAS for the budget.
Corresponds to the JSON property targetRoas
14851 14852 14853 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14851 def target_roas @target_roas end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14858 14859 14860 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14858 def update!(**args) @target_roas = args[:target_roas] if args.key?(:target_roas) end |