Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An automated bidding strategy to help get the most conversions for your campaigns while spending your budget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversions

Returns a new instance of GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversions.



14748
14749
14750
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14748

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_cpa_microsFixnum

Output only. The target cost per acquisition (CPA) option. This is the average amount that you would like to spend per acquisition. Corresponds to the JSON property targetCpaMicros

Returns:

  • (Fixnum)


14746
14747
14748
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14746

def target_cpa_micros
  @target_cpa_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14753
14754
14755
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14753

def update!(**args)
  @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros)
end