Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetImpressionShare

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An automated bidding strategy that sets bids so that a certain percentage of search ads are shown at the top of the first page (or other targeted location).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetImpressionShare

Returns a new instance of GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetImpressionShare.



14928
14929
14930
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14928

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpc_bid_ceiling_microsFixnum

Output only. The highest CPC bid the automated bidding system is permitted to specify. This is a required field entered by the advertiser that sets the ceiling and specified in local micros. Corresponds to the JSON property cpcBidCeilingMicros

Returns:

  • (Fixnum)


14915
14916
14917
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14915

def cpc_bid_ceiling_micros
  @cpc_bid_ceiling_micros
end

#locationString

Output only. The targeted location on the search results page. Corresponds to the JSON property location

Returns:

  • (String)


14920
14921
14922
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14920

def location
  @location
end

#location_fraction_microsFixnum

The chosen fraction of ads to be shown in the targeted location in micros. For example, 1% equals 10,000. Corresponds to the JSON property locationFractionMicros

Returns:

  • (Fixnum)


14926
14927
14928
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14926

def location_fraction_micros
  @location_fraction_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14933
14934
14935
14936
14937
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14933

def update!(**args)
  @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros)
  @location = args[:location] if args.key?(:location)
  @location_fraction_micros = args[:location_fraction_micros] if args.key?(:location_fraction_micros)
end