Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccountBudgetPendingAccountBudgetProposal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A pending proposal associated with the enclosing account-level budget, if applicable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccountBudgetPendingAccountBudgetProposal

Returns a new instance of GoogleAdsSearchads360V23ResourcesAccountBudgetPendingAccountBudgetProposal.



14998
14999
15000
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14998

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_budget_proposalString

Output only. The resource name of the proposal. AccountBudgetProposal resource names have the form: customers/customer_id/accountBudgetProposals/ account_budget_proposal_id` Corresponds to the JSON propertyaccountBudgetProposal`

Returns:

  • (String)


14942
14943
14944
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14942

def 
  @account_budget_proposal
end

#creation_date_timeString

Output only. The time when this account-level budget proposal was created. Formatted as yyyy-MM-dd HH:mm:ss. Corresponds to the JSON property creationDateTime

Returns:

  • (String)


14948
14949
14950
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14948

def creation_date_time
  @creation_date_time
end

#end_date_timeString

Output only. The end time in yyyy-MM-dd HH:mm:ss format. Corresponds to the JSON property endDateTime

Returns:

  • (String)


14953
14954
14955
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14953

def end_date_time
  @end_date_time
end

#end_time_typeString

Output only. The end time as a well-defined type, for example, FOREVER. Corresponds to the JSON property endTimeType

Returns:

  • (String)


14958
14959
14960
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14958

def end_time_type
  @end_time_type
end

#nameString

Output only. The name to assign to the account-level budget. Corresponds to the JSON property name

Returns:

  • (String)


14963
14964
14965
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14963

def name
  @name
end

#notesString

Output only. Notes associated with this budget. Corresponds to the JSON property notes

Returns:

  • (String)


14968
14969
14970
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14968

def notes
  @notes
end

#proposal_typeString

Output only. The type of this proposal, for example, END to end the budget associated with this proposal. Corresponds to the JSON property proposalType

Returns:

  • (String)


14974
14975
14976
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14974

def proposal_type
  @proposal_type
end

#purchase_order_numberString

Output only. A purchase order number is a value that helps users reference this budget in their monthly invoices. Corresponds to the JSON property purchaseOrderNumber

Returns:

  • (String)


14980
14981
14982
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14980

def purchase_order_number
  @purchase_order_number
end

#spending_limit_microsFixnum

Output only. The spending limit in micros. One million is equivalent to one unit. Corresponds to the JSON property spendingLimitMicros

Returns:

  • (Fixnum)


14986
14987
14988
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14986

def spending_limit_micros
  @spending_limit_micros
end

#spending_limit_typeString

Output only. The spending limit as a well-defined type, for example, INFINITE. Corresponds to the JSON property spendingLimitType

Returns:

  • (String)


14991
14992
14993
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14991

def spending_limit_type
  @spending_limit_type
end

#start_date_timeString

Output only. The start time in yyyy-MM-dd HH:mm:ss format. Corresponds to the JSON property startDateTime

Returns:

  • (String)


14996
14997
14998
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14996

def start_date_time
  @start_date_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15003
15004
15005
15006
15007
15008
15009
15010
15011
15012
15013
15014
15015
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15003

def update!(**args)
  @account_budget_proposal = args[:account_budget_proposal] if args.key?(:account_budget_proposal)
  @creation_date_time = args[:creation_date_time] if args.key?(:creation_date_time)
  @end_date_time = args[:end_date_time] if args.key?(:end_date_time)
  @end_time_type = args[:end_time_type] if args.key?(:end_time_type)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @proposal_type = args[:proposal_type] if args.key?(:proposal_type)
  @purchase_order_number = args[:purchase_order_number] if args.key?(:purchase_order_number)
  @spending_limit_micros = args[:spending_limit_micros] if args.key?(:spending_limit_micros)
  @spending_limit_type = args[:spending_limit_type] if args.key?(:spending_limit_type)
  @start_date_time = args[:start_date_time] if args.key?(:start_date_time)
end