Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccountLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents the data sharing connection between a Google Ads account and another account

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccountLink

Returns a new instance of GoogleAdsSearchads360V23ResourcesAccountLink.



19692
19693
19694
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19692

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Output only. The ID of the link. This field is read only. Corresponds to the JSON property accountLinkId

Returns:

  • (Fixnum)


19669
19670
19671
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19669

def 
  @account_link_id
end

#resource_nameString

Immutable. Resource name of the account link. AccountLink resource names have the form: customers/customer_id/accountLinks/account_link_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


19675
19676
19677
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19675

def resource_name
  @resource_name
end

#statusString

The status of the link. Corresponds to the JSON property status

Returns:

  • (String)


19680
19681
19682
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19680

def status
  @status
end

#third_party_app_analyticsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLinkIdentifier

The identifiers of a Third Party App Analytics Link. Corresponds to the JSON property thirdPartyAppAnalytics



19685
19686
19687
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19685

def third_party_app_analytics
  @third_party_app_analytics
end

#typeString

Output only. The type of the linked account. Corresponds to the JSON property type

Returns:

  • (String)


19690
19691
19692
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19690

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19697
19698
19699
19700
19701
19702
19703
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19697

def update!(**args)
  @account_link_id = args[:account_link_id] if args.key?(:account_link_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @third_party_app_analytics = args[:third_party_app_analytics] if args.key?(:third_party_app_analytics)
  @type = args[:type] if args.key?(:type)
end