Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAd

Returns a new instance of GoogleAdsSearchads360V23ResourcesAd.



19966
19967
19968
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#added_by_google_adsBoolean Also known as: added_by_google_ads?

Output only. Indicates if this ad was automatically added by Google Ads and not by a user. For example, this could happen when ads are automatically created as suggestions for new ads based on knowledge of how existing ads are performing. Corresponds to the JSON property addedByGoogleAds

Returns:

  • (Boolean)


19716
19717
19718
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19716

def added_by_google_ads
  @added_by_google_ads
end

#app_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppAdInfo

An app ad. Corresponds to the JSON property appAd



19722
19723
19724
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19722

def app_ad
  @app_ad
end

#app_engagement_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppEngagementAdInfo

App engagement ads allow you to write text encouraging a specific action in the app, like checking in, making a purchase, or booking a flight. They allow you to send users to a specific part of your app where they can find what they' re looking for easier and faster. Corresponds to the JSON property appEngagementAd



19730
19731
19732
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19730

def app_engagement_ad
  @app_engagement_ad
end

#app_pre_registration_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppPreRegistrationAdInfo

App pre-registration ads link to your app or game listing on Google Play, and can run on Google Play, on YouTube (in-stream only), and within other apps and mobile websites on the Display Network. It will help capture people's interest in your app or game and generate an early install base for your app or game before a launch. Corresponds to the JSON property appPreRegistrationAd



19739
19740
19741
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19739

def app_pre_registration_ad
  @app_pre_registration_ad
end

A Demand Gen carousel ad. Corresponds to the JSON property demandGenCarouselAd



19744
19745
19746
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19744

def demand_gen_carousel_ad
  @demand_gen_carousel_ad
end

#demand_gen_multi_asset_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenMultiAssetAdInfo

A Demand Gen multi asset ad. Corresponds to the JSON property demandGenMultiAssetAd



19749
19750
19751
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19749

def demand_gen_multi_asset_ad
  @demand_gen_multi_asset_ad
end

#demand_gen_product_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenProductAdInfo

A Demand Gen product ad. Corresponds to the JSON property demandGenProductAd



19754
19755
19756
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19754

def demand_gen_product_ad
  @demand_gen_product_ad
end

#demand_gen_video_responsive_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenVideoResponsiveAdInfo

A Demand Gen video responsive ad. Corresponds to the JSON property demandGenVideoResponsiveAd



19759
19760
19761
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19759

def demand_gen_video_responsive_ad
  @demand_gen_video_responsive_ad
end

#device_preferenceString

The device preference for the ad. You can only specify a preference for mobile devices. When this preference is set the ad will be preferred over other ads when being displayed on a mobile device. The ad can still be displayed on other device types, for example, if no other ads are available. If unspecified (no device preference), all devices are targeted. This is only supported by some ad types. Corresponds to the JSON property devicePreference

Returns:

  • (String)


19769
19770
19771
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19769

def device_preference
  @device_preference
end

#display_upload_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDisplayUploadAdInfo

A generic type of display ad. The exact ad format is controlled by the display_upload_product_type field, which determines what kinds of data need to be included with the ad. Corresponds to the JSON property displayUploadAd



19776
19777
19778
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19776

def display_upload_ad
  @display_upload_ad
end

#display_urlString

The URL that appears in the ad description for some ad formats. Corresponds to the JSON property displayUrl

Returns:

  • (String)


19781
19782
19783
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19781

def display_url
  @display_url
end

#expanded_dynamic_search_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonExpandedDynamicSearchAdInfo

An expanded dynamic search ad. Corresponds to the JSON property expandedDynamicSearchAd



19786
19787
19788
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19786

def expanded_dynamic_search_ad
  @expanded_dynamic_search_ad
end

#expanded_text_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonExpandedTextAdInfo

An expanded text ad. Expanded text ads are deprecated. Corresponds to the JSON property expandedTextAd



19791
19792
19793
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19791

def expanded_text_ad
  @expanded_text_ad
end

#final_app_urlsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFinalAppUrl>

A list of final app URLs that will be used on mobile if the user has the specific app installed. Corresponds to the JSON property finalAppUrls



19797
19798
19799
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19797

def final_app_urls
  @final_app_urls
end

#final_mobile_urlsArray<String>

The list of possible final mobile URLs after all cross-domain redirects for the ad. Corresponds to the JSON property finalMobileUrls

Returns:

  • (Array<String>)


19803
19804
19805
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19803

def final_mobile_urls
  @final_mobile_urls
end

#final_url_suffixString

The suffix to use when constructing a final URL. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


19808
19809
19810
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19808

def final_url_suffix
  @final_url_suffix
end

#final_urlsArray<String>

The list of possible final URLs after all cross-domain redirects for the ad. Corresponds to the JSON property finalUrls

Returns:

  • (Array<String>)


19813
19814
19815
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19813

def final_urls
  @final_urls
end

#hotel_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelAdInfo

A hotel ad. Corresponds to the JSON property hotelAd



19818
19819
19820
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19818

def hotel_ad
  @hotel_ad
end

#idFixnum

Output only. The ID of the ad. Corresponds to the JSON property id

Returns:

  • (Fixnum)


19823
19824
19825
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19823

def id
  @id
end

#image_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonImageAdInfo

An image ad. Corresponds to the JSON property imageAd



19828
19829
19830
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19828

def image_ad
  @image_ad
end

#legacy_app_install_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo

A legacy app install ad that only can be used by a few select customers. Corresponds to the JSON property legacyAppInstallAd



19833
19834
19835
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19833

def legacy_app_install_ad
  @legacy_app_install_ad
end

#legacy_responsive_display_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLegacyResponsiveDisplayAdInfo

A legacy responsive display ad. Ads of this type are labeled 'Responsive ads' in the Google Ads UI. Corresponds to the JSON property legacyResponsiveDisplayAd



19839
19840
19841
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19839

def legacy_responsive_display_ad
  @legacy_responsive_display_ad
end

#local_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalAdInfo

A local ad. Corresponds to the JSON property localAd



19844
19845
19846
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19844

def local_ad
  @local_ad
end

#nameString

Immutable. The name of the ad. This is only used to be able to identify the ad. It does not need to be unique and does not affect the served ad. Corresponds to the JSON property name

Returns:

  • (String)


19850
19851
19852
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19850

def name
  @name
end

#product_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360ProductAdInfo

A Search Ads 360 product ad. Corresponds to the JSON property productAd



19855
19856
19857
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19855

def product_ad
  @product_ad
end

#resource_nameString

Immutable. The resource name of the ad. Ad resource names have the form: customers/customer_id/ads/ad_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


19861
19862
19863
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19861

def resource_name
  @resource_name
end

#responsive_display_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveDisplayAdInfo

A responsive display ad. Corresponds to the JSON property responsiveDisplayAd



19866
19867
19868
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19866

def responsive_display_ad
  @responsive_display_ad
end

#responsive_search_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveSearchAdInfo

A responsive search ad. Responsive search ads let you create an ad that adapts to show more text, and more relevant messages, to your customers. Enter multiple headlines and descriptions when creating a responsive search ad, and over time, Google Ads will automatically test different combinations and learn which combinations perform best. By adapting your ad's content to more closely match potential customers' search terms, responsive search ads may improve your campaign's performance. More information at https://support.google.com/ google-ads/answer/7684791 Corresponds to the JSON property responsiveSearchAd



19878
19879
19880
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19878

def responsive_search_ad
  @responsive_search_ad
end

#search_ads360_expanded_dynamic_search_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360ExpandedDynamicSearchAdInfo

An expanded dynamic search ad. Corresponds to the JSON property searchAds360ExpandedDynamicSearchAd



19883
19884
19885
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19883

def search_ads360_expanded_dynamic_search_ad
  @search_ads360_expanded_dynamic_search_ad
end

#search_ads360_expanded_text_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360ExpandedTextAdInfo

A Search Ads 360 expanded text ad. Expanded text ads are deprecated. Use SearchAds360ResponsiveSearchAd instead. Corresponds to the JSON property searchAds360ExpandedTextAd



19889
19890
19891
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19889

def search_ads360_expanded_text_ad
  @search_ads360_expanded_text_ad
end

#search_ads360_responsive_search_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360ResponsiveSearchAdInfo

A Search Ads 360 responsive search ad. Corresponds to the JSON property searchAds360ResponsiveSearchAd



19894
19895
19896
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19894

def search_ads360_responsive_search_ad
  @search_ads360_responsive_search_ad
end

#search_ads360_text_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360TextAdInfo

A Search Ads 360 text ad. Corresponds to the JSON property searchAds360TextAd



19899
19900
19901
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19899

def search_ads360_text_ad
  @search_ads360_text_ad
end

#shopping_comparison_listing_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonShoppingComparisonListingAdInfo

A Shopping Comparison Listing ad. Corresponds to the JSON property shoppingComparisonListingAd



19904
19905
19906
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19904

def shopping_comparison_listing_ad
  @shopping_comparison_listing_ad
end

#shopping_product_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonShoppingProductAdInfo

A standard Shopping ad. Corresponds to the JSON property shoppingProductAd



19909
19910
19911
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19909

def shopping_product_ad
  @shopping_product_ad
end

#shopping_smart_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonShoppingSmartAdInfo

A Smart Shopping ad. Corresponds to the JSON property shoppingSmartAd



19914
19915
19916
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19914

def shopping_smart_ad
  @shopping_smart_ad
end

#smart_campaign_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSmartCampaignAdInfo

A Smart campaign ad. Corresponds to the JSON property smartCampaignAd



19919
19920
19921
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19919

def smart_campaign_ad
  @smart_campaign_ad
end

#synthetic_content_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSyntheticContentInfo

Container for synthetic content attestations from different sources, such as the advertiser and Google systems. Corresponds to the JSON property syntheticContentInfo



19925
19926
19927
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19925

def 
  @synthetic_content_info
end

#system_managed_resource_sourceString

Output only. If this ad is system managed, then this field will indicate the source. This field is read-only. Corresponds to the JSON property systemManagedResourceSource

Returns:

  • (String)


19931
19932
19933
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19931

def system_managed_resource_source
  @system_managed_resource_source
end

#text_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTextAdInfo

A text ad. Corresponds to the JSON property textAd



19936
19937
19938
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19936

def text_ad
  @text_ad
end

#tracking_url_templateString

The URL template for constructing a tracking URL. Corresponds to the JSON property trackingUrlTemplate

Returns:

  • (String)


19941
19942
19943
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19941

def tracking_url_template
  @tracking_url_template
end

#travel_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTravelAdInfo

A travel ad. Corresponds to the JSON property travelAd



19946
19947
19948
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19946

def travel_ad
  @travel_ad
end

#typeString

Output only. The type of ad. Corresponds to the JSON property type

Returns:

  • (String)


19951
19952
19953
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19951

def type
  @type
end

#url_collectionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUrlCollection>

Additional URLs for the ad that are tagged with a unique identifier that can be referenced from other fields in the ad. Corresponds to the JSON property urlCollections



19957
19958
19959
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19957

def url_collections
  @url_collections
end

#url_custom_parametersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>

The list of mappings that can be used to substitute custom parameter tags in a tracking_url_template, final_urls, or mobile_final_urls. For mutates, use url custom parameter operations. Corresponds to the JSON property urlCustomParameters



19964
19965
19966
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19964

def url_custom_parameters
  @url_custom_parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19971
19972
19973
19974
19975
19976
19977
19978
19979
19980
19981
19982
19983
19984
19985
19986
19987
19988
19989
19990
19991
19992
19993
19994
19995
19996
19997
19998
19999
20000
20001
20002
20003
20004
20005
20006
20007
20008
20009
20010
20011
20012
20013
20014
20015
20016
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19971

def update!(**args)
  @added_by_google_ads = args[:added_by_google_ads] if args.key?(:added_by_google_ads)
  @app_ad = args[:app_ad] if args.key?(:app_ad)
  @app_engagement_ad = args[:app_engagement_ad] if args.key?(:app_engagement_ad)
  @app_pre_registration_ad = args[:app_pre_registration_ad] if args.key?(:app_pre_registration_ad)
  @demand_gen_carousel_ad = args[:demand_gen_carousel_ad] if args.key?(:demand_gen_carousel_ad)
  @demand_gen_multi_asset_ad = args[:demand_gen_multi_asset_ad] if args.key?(:demand_gen_multi_asset_ad)
  @demand_gen_product_ad = args[:demand_gen_product_ad] if args.key?(:demand_gen_product_ad)
  @demand_gen_video_responsive_ad = args[:demand_gen_video_responsive_ad] if args.key?(:demand_gen_video_responsive_ad)
  @device_preference = args[:device_preference] if args.key?(:device_preference)
  @display_upload_ad = args[:display_upload_ad] if args.key?(:display_upload_ad)
  @display_url = args[:display_url] if args.key?(:display_url)
  @expanded_dynamic_search_ad = args[:expanded_dynamic_search_ad] if args.key?(:expanded_dynamic_search_ad)
  @expanded_text_ad = args[:expanded_text_ad] if args.key?(:expanded_text_ad)
  @final_app_urls = args[:final_app_urls] if args.key?(:final_app_urls)
  @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @final_urls = args[:final_urls] if args.key?(:final_urls)
  @hotel_ad = args[:hotel_ad] if args.key?(:hotel_ad)
  @id = args[:id] if args.key?(:id)
  @image_ad = args[:image_ad] if args.key?(:image_ad)
  @legacy_app_install_ad = args[:legacy_app_install_ad] if args.key?(:legacy_app_install_ad)
  @legacy_responsive_display_ad = args[:legacy_responsive_display_ad] if args.key?(:legacy_responsive_display_ad)
  @local_ad = args[:local_ad] if args.key?(:local_ad)
  @name = args[:name] if args.key?(:name)
  @product_ad = args[:product_ad] if args.key?(:product_ad)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @responsive_display_ad = args[:responsive_display_ad] if args.key?(:responsive_display_ad)
  @responsive_search_ad = args[:responsive_search_ad] if args.key?(:responsive_search_ad)
  @search_ads360_expanded_dynamic_search_ad = args[:search_ads360_expanded_dynamic_search_ad] if args.key?(:search_ads360_expanded_dynamic_search_ad)
  @search_ads360_expanded_text_ad = args[:search_ads360_expanded_text_ad] if args.key?(:search_ads360_expanded_text_ad)
  @search_ads360_responsive_search_ad = args[:search_ads360_responsive_search_ad] if args.key?(:search_ads360_responsive_search_ad)
  @search_ads360_text_ad = args[:search_ads360_text_ad] if args.key?(:search_ads360_text_ad)
  @shopping_comparison_listing_ad = args[:shopping_comparison_listing_ad] if args.key?(:shopping_comparison_listing_ad)
  @shopping_product_ad = args[:shopping_product_ad] if args.key?(:shopping_product_ad)
  @shopping_smart_ad = args[:shopping_smart_ad] if args.key?(:shopping_smart_ad)
  @smart_campaign_ad = args[:smart_campaign_ad] if args.key?(:smart_campaign_ad)
  @synthetic_content_info = args[:synthetic_content_info] if args.key?(:synthetic_content_info)
  @system_managed_resource_source = args[:system_managed_resource_source] if args.key?(:system_managed_resource_source)
  @text_ad = args[:text_ad] if args.key?(:text_ad)
  @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template)
  @travel_ad = args[:travel_ad] if args.key?(:travel_ad)
  @type = args[:type] if args.key?(:type)
  @url_collections = args[:url_collections] if args.key?(:url_collections)
  @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters)
end