Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An ad group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroup

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroup.



20340
20341
20342
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20340

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_rotation_modeString

The ad rotation mode of the ad group. Corresponds to the JSON property adRotationMode

Returns:

  • (String)


20026
20027
20028
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20026

def ad_rotation_mode
  @ad_rotation_mode
end

#ai_max_ad_group_settingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAiMaxAdGroupSetting

Settings for AI Max feature in standard search adgroups. Corresponds to the JSON property aiMaxAdGroupSetting



20031
20032
20033
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20031

def ai_max_ad_group_setting
  @ai_max_ad_group_setting
end

#audience_settingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAudienceSetting

Settings for the audience targeting. Corresponds to the JSON property audienceSetting



20036
20037
20038
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20036

def audience_setting
  @audience_setting
end

#base_ad_groupString

Output only. For draft or experiment ad groups, this field is the resource name of the base ad group from which this ad group was created. If a draft or experiment ad group does not have a base ad group, then this field is null. For base ad groups, this field equals the ad group resource name. This field is read-only. Corresponds to the JSON property baseAdGroup

Returns:

  • (String)


20045
20046
20047
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20045

def base_ad_group
  @base_ad_group
end

#campaignString

Immutable. The campaign to which the ad group belongs. Corresponds to the JSON property campaign

Returns:

  • (String)


20050
20051
20052
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20050

def campaign
  @campaign
end

#cpc_bid_microsFixnum

The maximum CPC (cost-per-click) bid. This field is used when the ad group's effective bidding strategy is Manual CPC. This field is not applicable and will be ignored if the ad group's campaign is using a portfolio bidding strategy. Corresponds to the JSON property cpcBidMicros

Returns:

  • (Fixnum)


20058
20059
20060
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20058

def cpc_bid_micros
  @cpc_bid_micros
end

#cpm_bid_microsFixnum

The maximum CPM (cost-per-thousand viewable impressions) bid. Corresponds to the JSON property cpmBidMicros

Returns:

  • (Fixnum)


20063
20064
20065
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20063

def cpm_bid_micros
  @cpm_bid_micros
end

#cpv_bid_microsFixnum

The CPV (cost-per-view) bid. Corresponds to the JSON property cpvBidMicros

Returns:

  • (Fixnum)


20068
20069
20070
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20068

def cpv_bid_micros
  @cpv_bid_micros
end

#creation_timeString

Output only. The timestamp when this ad_group was created. The timestamp is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. Corresponds to the JSON property creationTime

Returns:

  • (String)


20074
20075
20076
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20074

def creation_time
  @creation_time
end

#demand_gen_ad_group_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettings

Settings for Demand Gen ad groups. Corresponds to the JSON property demandGenAdGroupSettings



20079
20080
20081
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20079

def demand_gen_ad_group_settings
  @demand_gen_ad_group_settings
end

#display_custom_bid_dimensionString

Lets advertisers specify a targeting dimension on which to place absolute bids. This is only applicable for campaigns that target only the display network and not search. Corresponds to the JSON property displayCustomBidDimension

Returns:

  • (String)


20086
20087
20088
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20086

def display_custom_bid_dimension
  @display_custom_bid_dimension
end

#effective_cpc_bid_microsFixnum

Output only. Value will be same as that of the CPC (cost-per-click) bid value when the bidding strategy is one of manual cpc, enhanced cpc, page one promoted or target outrank share, otherwise the value will be null. Corresponds to the JSON property effectiveCpcBidMicros

Returns:

  • (Fixnum)


20093
20094
20095
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20093

def effective_cpc_bid_micros
  @effective_cpc_bid_micros
end

#effective_labelsArray<String>

Output only. The resource names of effective labels attached to this ad group. An effective label is a label inherited or directly assigned to this ad group. Corresponds to the JSON property effectiveLabels

Returns:

  • (Array<String>)


20099
20100
20101
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20099

def effective_labels
  @effective_labels
end

#effective_target_cpa_microsFixnum

Output only. The effective target CPA (cost-per-acquisition). This field is read-only. Corresponds to the JSON property effectiveTargetCpaMicros

Returns:

  • (Fixnum)


20105
20106
20107
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20105

def effective_target_cpa_micros
  @effective_target_cpa_micros
end

#effective_target_cpa_sourceString

Output only. Source of the effective target CPA. This field is read-only. Corresponds to the JSON property effectiveTargetCpaSource

Returns:

  • (String)


20110
20111
20112
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20110

def effective_target_cpa_source
  @effective_target_cpa_source
end

#effective_target_cpcFixnum

Output only. The effective target CPC (cost-per-click). This field is read- only. Corresponds to the JSON property effectiveTargetCpc

Returns:

  • (Fixnum)


20116
20117
20118
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20116

def effective_target_cpc
  @effective_target_cpc
end

#effective_target_cpc_sourceString

Output only. Source of the effective target CPC. This field is read-only. Corresponds to the JSON property effectiveTargetCpcSource

Returns:

  • (String)


20121
20122
20123
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20121

def effective_target_cpc_source
  @effective_target_cpc_source
end

#effective_target_roasFloat

Output only. The effective target ROAS (return-on-ad-spend). This field is read-only. Corresponds to the JSON property effectiveTargetRoas

Returns:

  • (Float)


20127
20128
20129
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20127

def effective_target_roas
  @effective_target_roas
end

#effective_target_roas_sourceString

Output only. Source of the effective target ROAS. This field is read-only. Corresponds to the JSON property effectiveTargetRoasSource

Returns:

  • (String)


20132
20133
20134
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20132

def effective_target_roas_source
  @effective_target_roas_source
end

#end_dateString

Output only. Date when the ad group ends serving ads. By default, the ad group ends on the ad group's end date. If this field is set, then the ad group ends at the end of the specified date in the customer's time zone. This field is only available for Microsoft Advertising and Facebook gateway accounts. Format: YYYY-MM-DD Example: 2019-03-14 Corresponds to the JSON property endDate

Returns:

  • (String)


20141
20142
20143
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20141

def end_date
  @end_date
end

#engine_idString

Output only. ID of the ad group in the external engine account. This field is for non-Google Ads account only, for example, Yahoo Japan, Microsoft, Baidu etc. For Google Ads entity, use "ad_group.id" instead. Corresponds to the JSON property engineId

Returns:

  • (String)


20148
20149
20150
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20148

def engine_id
  @engine_id
end

#engine_statusString

Output only. The Engine Status for ad group. Corresponds to the JSON property engineStatus

Returns:

  • (String)


20153
20154
20155
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20153

def engine_status
  @engine_status
end

#exclude_demographic_expansionBoolean Also known as: exclude_demographic_expansion?

When this value is true, demographics will be excluded from the types of targeting which are expanded when optimized_targeting_enabled is true. When optimized_targeting_enabled is false, this field is ignored. Default is false. Corresponds to the JSON property excludeDemographicExpansion

Returns:

  • (Boolean)


20160
20161
20162
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20160

def exclude_demographic_expansion
  @exclude_demographic_expansion
end

#excluded_parent_asset_field_typesArray<String>

The asset field types that should be excluded from this ad group. Asset links with these field types will not be inherited by this ad group from the upper levels. Corresponds to the JSON property excludedParentAssetFieldTypes

Returns:

  • (Array<String>)


20168
20169
20170
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20168

def excluded_parent_asset_field_types
  @excluded_parent_asset_field_types
end

#excluded_parent_asset_set_typesArray<String>

The asset set types that should be excluded from this ad group. Asset set links with these types will not be inherited by this ad group from the upper levels. Location group types (GMB_DYNAMIC_LOCATION_GROUP, CHAIN_DYNAMIC_LOCATION_GROUP, and STATIC_LOCATION_GROUP) are child types of LOCATION_SYNC. Therefore, if LOCATION_SYNC is set for this field, all location group asset sets are not allowed to be linked to this ad group, and all Location Extension (LE) and Affiliate Location Extensions (ALE) will not be served under this ad group. Only LOCATION_SYNC is currently supported. Corresponds to the JSON property excludedParentAssetSetTypes

Returns:

  • (Array<String>)


20180
20181
20182
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20180

def excluded_parent_asset_set_types
  @excluded_parent_asset_set_types
end

#final_url_suffixString

URL template for appending params to Final URL. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


20185
20186
20187
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20185

def final_url_suffix
  @final_url_suffix
end

#fixed_cpm_microsFixnum

The fixed amount in micros that the advertiser pays for every thousand impressions of the ad. Corresponds to the JSON property fixedCpmMicros

Returns:

  • (Fixnum)


20191
20192
20193
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20191

def fixed_cpm_micros
  @fixed_cpm_micros
end

#idFixnum

Output only. The ID of the ad group. Corresponds to the JSON property id

Returns:

  • (Fixnum)


20196
20197
20198
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20196

def id
  @id
end

#labelsArray<String>

Output only. The resource names of labels attached to this ad group. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


20201
20202
20203
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20201

def labels
  @labels
end

#language_codeString

Output only. The language of the ads and keywords in an ad group. This field is only available for Microsoft Advertising accounts. More details: https:// docs.microsoft.com/en-us/advertising/guides/ad-languages?view=bingads-13# adlanguage Corresponds to the JSON property languageCode

Returns:

  • (String)


20209
20210
20211
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20209

def language_code
  @language_code
end

#last_modified_timeString

Output only. The datetime when this ad group was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


20215
20216
20217
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20215

def last_modified_time
  @last_modified_time
end

#nameString

The name of the ad group. This field is required and should not be empty when creating new ad groups. It must contain fewer than 255 UTF-8 full-width characters. It must not contain any null (code point 0x0), NL line feed (code point 0xA) or carriage return (code point 0xD) characters. Corresponds to the JSON property name

Returns:

  • (String)


20223
20224
20225
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20223

def name
  @name
end

#optimized_targeting_enabledBoolean Also known as: optimized_targeting_enabled?

True if optimized targeting is enabled. Optimized Targeting is the replacement for Audience Expansion. Corresponds to the JSON property optimizedTargetingEnabled

Returns:

  • (Boolean)


20229
20230
20231
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20229

def optimized_targeting_enabled
  @optimized_targeting_enabled
end

#percent_cpc_bid_microsFixnum

The percent cpc bid amount, expressed as a fraction of the advertised price for some good or service. The valid range for the fraction is [0,1) and the value stored here is 1,000,000 * [fraction]. Corresponds to the JSON property percentCpcBidMicros

Returns:

  • (Fixnum)


20237
20238
20239
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20237

def percent_cpc_bid_micros
  @percent_cpc_bid_micros
end

#primary_statusString

Output only. Provides aggregated view into why an ad group is not serving or not serving optimally. Corresponds to the JSON property primaryStatus

Returns:

  • (String)


20243
20244
20245
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20243

def primary_status
  @primary_status
end

#primary_status_reasonsArray<String>

Output only. Provides reasons for why an ad group is not serving or not serving optimally. Corresponds to the JSON property primaryStatusReasons

Returns:

  • (Array<String>)


20249
20250
20251
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20249

def primary_status_reasons
  @primary_status_reasons
end

#resource_nameString

Immutable. The resource name of the ad group. Ad group resource names have the form: customers/customer_id/adGroups/ad_group_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


20255
20256
20257
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20255

def resource_name
  @resource_name
end

#start_dateString

Output only. Date when this ad group starts serving ads. By default, the ad group starts now or the ad group's start date, whichever is later. If this field is set, then the ad group starts at the beginning of the specified date in the customer's time zone. This field is only available for Microsoft Advertising and Facebook gateway accounts. Format: YYYY-MM-DD Example: 2019-03- 14 Corresponds to the JSON property startDate

Returns:

  • (String)


20265
20266
20267
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20265

def start_date
  @start_date
end

#statusString

The status of the ad group. Corresponds to the JSON property status

Returns:

  • (String)


20270
20271
20272
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20270

def status
  @status
end

#target_cpa_microsFixnum

The target CPA (cost-per-acquisition). If the ad group's campaign bidding strategy is TargetCpa or MaximizeConversions (with its target_cpa field set), then this field overrides the target CPA specified in the campaign's bidding strategy. Otherwise, this value is ignored. Corresponds to the JSON property targetCpaMicros

Returns:

  • (Fixnum)


20278
20279
20280
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20278

def target_cpa_micros
  @target_cpa_micros
end

#target_cpc_microsFixnum

Average amount in micros that the advertiser is willing to pay for every ad click. Overrides the target CPC configured at the campaign level. Corresponds to the JSON property targetCpcMicros

Returns:

  • (Fixnum)


20284
20285
20286
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20284

def target_cpc_micros
  @target_cpc_micros
end

#target_cpm_microsFixnum

Average amount in micros that the advertiser is willing to pay for every thousand times the ad is shown. Corresponds to the JSON property targetCpmMicros

Returns:

  • (Fixnum)


20290
20291
20292
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20290

def target_cpm_micros
  @target_cpm_micros
end

#target_cpv_microsFixnum

Average amount in micros that the advertiser is willing to pay for every ad view. Corresponds to the JSON property targetCpvMicros

Returns:

  • (Fixnum)


20296
20297
20298
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20296

def target_cpv_micros
  @target_cpv_micros
end

#target_roasFloat

The target ROAS (return-on-ad-spend) for this ad group. This field lets you override the target ROAS specified in the campaign's bidding strategy, but only if the campaign is using a standard (not portfolio) TargetRoas strategy or a standard MaximizeConversionValue strategy with its target_roas field set. If the campaign is using a portfolio bidding strategy, this field cannot be set and attempting to do so will result in an error. For any other bidding strategies, this value is ignored. To see the actual target ROAS being used by the ad group, considering potential overrides, query the effective_target_roas and effective_target_roas_source fields. Corresponds to the JSON property targetRoas

Returns:

  • (Float)


20309
20310
20311
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20309

def target_roas
  @target_roas
end

#targeting_settingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetingSetting

Settings for the targeting-related features, at the campaign and ad group levels. For more details about the targeting setting, visit https://support. google.com/google-ads/answer/7365594 Corresponds to the JSON property targetingSetting



20316
20317
20318
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20316

def targeting_setting
  @targeting_setting
end

#tracking_url_templateString

The URL template for constructing a tracking URL. Corresponds to the JSON property trackingUrlTemplate

Returns:

  • (String)


20321
20322
20323
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20321

def tracking_url_template
  @tracking_url_template
end

#typeString

Immutable. The type of the ad group. Corresponds to the JSON property type

Returns:

  • (String)


20326
20327
20328
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20326

def type
  @type
end

#url_custom_parametersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>

The list of mappings used to substitute custom parameter tags in a tracking_url_template, final_urls, or mobile_final_urls. Corresponds to the JSON property urlCustomParameters



20332
20333
20334
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20332

def url_custom_parameters
  @url_custom_parameters
end

#vertical_ads_format_settingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupVerticalAdsFormatSetting

Vertical ads setting feature to enable/disable ad group format controls in search campaigns. Corresponds to the JSON property verticalAdsFormatSetting



20338
20339
20340
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20338

def vertical_ads_format_setting
  @vertical_ads_format_setting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20345
20346
20347
20348
20349
20350
20351
20352
20353
20354
20355
20356
20357
20358
20359
20360
20361
20362
20363
20364
20365
20366
20367
20368
20369
20370
20371
20372
20373
20374
20375
20376
20377
20378
20379
20380
20381
20382
20383
20384
20385
20386
20387
20388
20389
20390
20391
20392
20393
20394
20395
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20345

def update!(**args)
  @ad_rotation_mode = args[:ad_rotation_mode] if args.key?(:ad_rotation_mode)
  @ai_max_ad_group_setting = args[:ai_max_ad_group_setting] if args.key?(:ai_max_ad_group_setting)
  @audience_setting = args[:audience_setting] if args.key?(:audience_setting)
  @base_ad_group = args[:base_ad_group] if args.key?(:base_ad_group)
  @campaign = args[:campaign] if args.key?(:campaign)
  @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros)
  @cpm_bid_micros = args[:cpm_bid_micros] if args.key?(:cpm_bid_micros)
  @cpv_bid_micros = args[:cpv_bid_micros] if args.key?(:cpv_bid_micros)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @demand_gen_ad_group_settings = args[:demand_gen_ad_group_settings] if args.key?(:demand_gen_ad_group_settings)
  @display_custom_bid_dimension = args[:display_custom_bid_dimension] if args.key?(:display_custom_bid_dimension)
  @effective_cpc_bid_micros = args[:effective_cpc_bid_micros] if args.key?(:effective_cpc_bid_micros)
  @effective_labels = args[:effective_labels] if args.key?(:effective_labels)
  @effective_target_cpa_micros = args[:effective_target_cpa_micros] if args.key?(:effective_target_cpa_micros)
  @effective_target_cpa_source = args[:effective_target_cpa_source] if args.key?(:effective_target_cpa_source)
  @effective_target_cpc = args[:effective_target_cpc] if args.key?(:effective_target_cpc)
  @effective_target_cpc_source = args[:effective_target_cpc_source] if args.key?(:effective_target_cpc_source)
  @effective_target_roas = args[:effective_target_roas] if args.key?(:effective_target_roas)
  @effective_target_roas_source = args[:effective_target_roas_source] if args.key?(:effective_target_roas_source)
  @end_date = args[:end_date] if args.key?(:end_date)
  @engine_id = args[:engine_id] if args.key?(:engine_id)
  @engine_status = args[:engine_status] if args.key?(:engine_status)
  @exclude_demographic_expansion = args[:exclude_demographic_expansion] if args.key?(:exclude_demographic_expansion)
  @excluded_parent_asset_field_types = args[:excluded_parent_asset_field_types] if args.key?(:excluded_parent_asset_field_types)
  @excluded_parent_asset_set_types = args[:excluded_parent_asset_set_types] if args.key?(:excluded_parent_asset_set_types)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @fixed_cpm_micros = args[:fixed_cpm_micros] if args.key?(:fixed_cpm_micros)
  @id = args[:id] if args.key?(:id)
  @labels = args[:labels] if args.key?(:labels)
  @language_code = args[:language_code] if args.key?(:language_code)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @name = args[:name] if args.key?(:name)
  @optimized_targeting_enabled = args[:optimized_targeting_enabled] if args.key?(:optimized_targeting_enabled)
  @percent_cpc_bid_micros = args[:percent_cpc_bid_micros] if args.key?(:percent_cpc_bid_micros)
  @primary_status = args[:primary_status] if args.key?(:primary_status)
  @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @status = args[:status] if args.key?(:status)
  @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros)
  @target_cpc_micros = args[:target_cpc_micros] if args.key?(:target_cpc_micros)
  @target_cpm_micros = args[:target_cpm_micros] if args.key?(:target_cpm_micros)
  @target_cpv_micros = args[:target_cpv_micros] if args.key?(:target_cpv_micros)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
  @targeting_setting = args[:targeting_setting] if args.key?(:targeting_setting)
  @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template)
  @type = args[:type] if args.key?(:type)
  @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters)
  @vertical_ads_format_setting = args[:vertical_ads_format_setting] if args.key?(:vertical_ads_format_setting)
end