Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An ad group ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAd

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAd.



20497
20498
20499
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_itemsArray<String>

Output only. A list of recommendations to improve the ad strength. For example, a recommendation could be "Try adding a few more unique headlines or unpinning some assets.". Corresponds to the JSON property actionItems

Returns:

  • (Array<String>)


20407
20408
20409
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20407

def action_items
  @action_items
end

#adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAd

An ad. Corresponds to the JSON property ad



20412
20413
20414
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20412

def ad
  @ad
end

#ad_groupString

Immutable. The ad group to which the ad belongs. Corresponds to the JSON property adGroup

Returns:

  • (String)


20417
20418
20419
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20417

def ad_group
  @ad_group
end

#ad_group_ad_asset_automation_settingsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdAssetAutomationSetting>

Settings that control the types of asset automation. See the AssetAutomationTypeEnum documentation for the default opt in/out behavior of each type. Corresponds to the JSON property adGroupAdAssetAutomationSettings



20424
20425
20426
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20424

def ad_group_ad_asset_automation_settings
  @ad_group_ad_asset_automation_settings
end

#ad_strengthString

Output only. Overall ad strength for this ad group ad. Corresponds to the JSON property adStrength

Returns:

  • (String)


20429
20430
20431
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20429

def ad_strength
  @ad_strength
end

#creation_timeString

Output only. The timestamp when this ad_group_ad was created. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property creationTime

Returns:

  • (String)


20435
20436
20437
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20435

def creation_time
  @creation_time
end

#effective_labelsArray<String>

Output only. The resource names of effective labels attached to this ad. An effective label is a label inherited or directly assigned to this ad. Corresponds to the JSON property effectiveLabels

Returns:

  • (Array<String>)


20441
20442
20443
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20441

def effective_labels
  @effective_labels
end

#engine_idString

Output only. ID of the ad in the external engine account. This field is for Search Ads 360 account only, for example, Yahoo Japan, Microsoft, Baidu etc. For non-Search Ads 360 entity, use "ad_group_ad.ad.id" instead. Corresponds to the JSON property engineId

Returns:

  • (String)


20448
20449
20450
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20448

def engine_id
  @engine_id
end

#engine_statusString

Output only. Additional status of the ad in the external engine account. Possible statuses (depending on the type of external account) include active, eligible, pending review, etc. Corresponds to the JSON property engineStatus

Returns:

  • (String)


20455
20456
20457
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20455

def engine_status
  @engine_status
end

#labelsArray<String>

Output only. The resource names of labels attached to this ad group ad. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


20460
20461
20462
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20460

def labels
  @labels
end

#last_modified_timeString

Output only. The datetime when this ad group ad was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


20467
20468
20469
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20467

def last_modified_time
  @last_modified_time
end

#policy_summaryGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdPolicySummary

Contains policy information for an ad. Corresponds to the JSON property policySummary



20472
20473
20474
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20472

def policy_summary
  @policy_summary
end

#primary_statusString

Output only. Provides aggregated view into why an ad group ad is not serving or not serving optimally. Corresponds to the JSON property primaryStatus

Returns:

  • (String)


20478
20479
20480
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20478

def primary_status
  @primary_status
end

#primary_status_reasonsArray<String>

Output only. Provides reasons for why an ad group ad is not serving or not serving optimally. Corresponds to the JSON property primaryStatusReasons

Returns:

  • (Array<String>)


20484
20485
20486
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20484

def primary_status_reasons
  @primary_status_reasons
end

#resource_nameString

Immutable. The resource name of the ad. Ad group ad resource names have the form: customers/customer_id/adGroupAds/ad_group_id~ad_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


20490
20491
20492
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20490

def resource_name
  @resource_name
end

#statusString

The status of the ad. Corresponds to the JSON property status

Returns:

  • (String)


20495
20496
20497
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20495

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20502
20503
20504
20505
20506
20507
20508
20509
20510
20511
20512
20513
20514
20515
20516
20517
20518
20519
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20502

def update!(**args)
  @action_items = args[:action_items] if args.key?(:action_items)
  @ad = args[:ad] if args.key?(:ad)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @ad_group_ad_asset_automation_settings = args[:ad_group_ad_asset_automation_settings] if args.key?(:ad_group_ad_asset_automation_settings)
  @ad_strength = args[:ad_strength] if args.key?(:ad_strength)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @effective_labels = args[:effective_labels] if args.key?(:effective_labels)
  @engine_id = args[:engine_id] if args.key?(:engine_id)
  @engine_status = args[:engine_status] if args.key?(:engine_status)
  @labels = args[:labels] if args.key?(:labels)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @policy_summary = args[:policy_summary] if args.key?(:policy_summary)
  @primary_status = args[:primary_status] if args.key?(:primary_status)
  @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end