Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdAssetCombinationView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A view on the usage of ad group ad asset combination. Now we only support AdGroupAdAssetCombinationView for Responsive Search Ads, with more ad types planned for the future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAdAssetCombinationView

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAdAssetCombinationView.



20578
20579
20580
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Output only. The status between the asset combination and the latest version of the ad. If true, the asset combination is linked to the latest version of the ad. If false, it means the link once existed but has been removed and is no longer present in the latest version of the ad. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


20559
20560
20561
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20559

def enabled
  @enabled
end

#resource_nameString

Output only. The resource name of the ad group ad asset combination view. The combination ID is 128 bits long, where the upper 64 bits are stored in asset_combination_id_high, and the lower 64 bits are stored in asset_combination_id_low. AdGroupAd Asset Combination view resource names have the form: customers/customer_id/adGroupAdAssetCombinationViews/AdGroupAd. ad_group_id~AdGroupAd.ad.ad_id~AssetCombination.asset_combination_id_low~ AssetCombination.asset_combination_id_high` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


20571
20572
20573
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20571

def resource_name
  @resource_name
end

#served_assetsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetUsage>

Output only. Served assets. Corresponds to the JSON property servedAssets



20576
20577
20578
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20576

def served_assets
  @served_assets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20583
20584
20585
20586
20587
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20583

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @served_assets = args[:served_assets] if args.key?(:served_assets)
end