Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdLabel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A relationship between an ad group ad and a label.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAdLabel

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAdLabel.



20768
20769
20770
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_adString

Immutable. The ad group ad to which the label is attached. Corresponds to the JSON property adGroupAd

Returns:

  • (String)


20749
20750
20751
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20749

def ad_group_ad
  @ad_group_ad
end

#labelString

Immutable. The label assigned to the ad group ad. Corresponds to the JSON property label

Returns:

  • (String)


20754
20755
20756
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20754

def label
  @label
end

#owner_customer_idFixnum

Output only. The ID of the Customer which owns the label. Corresponds to the JSON property ownerCustomerId

Returns:

  • (Fixnum)


20759
20760
20761
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20759

def owner_customer_id
  @owner_customer_id
end

#resource_nameString

Immutable. The resource name of the ad group ad label. Ad group ad label resource names have the form: customers/owner_customer_id/adGroupAdLabels/ ad_group_id~ad_id~label_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


20766
20767
20768
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20766

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20773
20774
20775
20776
20777
20778
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20773

def update!(**args)
  @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad)
  @label = args[:label] if args.key?(:label)
  @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end