Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdPolicySummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Contains policy information for an ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAdPolicySummary

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAdPolicySummary.



20801
20802
20803
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20801

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approval_statusString

Output only. The overall approval status of this ad, calculated based on the status of its individual policy topic entries. Corresponds to the JSON property approvalStatus

Returns:

  • (String)


20789
20790
20791
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20789

def approval_status
  @approval_status
end

#policy_topic_entriesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry>

Output only. The list of policy findings for this ad. Corresponds to the JSON property policyTopicEntries



20794
20795
20796
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20794

def policy_topic_entries
  @policy_topic_entries
end

#review_statusString

Output only. Where in the review process this ad is. Corresponds to the JSON property reviewStatus

Returns:

  • (String)


20799
20800
20801
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20799

def review_status
  @review_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20806
20807
20808
20809
20810
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20806

def update!(**args)
  @approval_status = args[:approval_status] if args.key?(:approval_status)
  @policy_topic_entries = args[:policy_topic_entries] if args.key?(:policy_topic_entries)
  @review_status = args[:review_status] if args.key?(:review_status)
end