Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAiMaxAdGroupSetting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAiMaxAdGroupSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Settings for AI Max feature in standard search adgroups.
Instance Attribute Summary collapse
-
#disable_search_term_matching ⇒ Boolean
(also: #disable_search_term_matching?)
Disable search term matching for this adgroup when AI Max is enabled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAiMaxAdGroupSetting
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupAiMaxAdGroupSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAiMaxAdGroupSetting
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAiMaxAdGroupSetting.
15137 15138 15139 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15137 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disable_search_term_matching ⇒ Boolean Also known as: disable_search_term_matching?
Disable search term matching for this adgroup when AI Max is enabled. Search
term matching uses broad match, asset-based, and landing page-based technology
to improve reach.
Corresponds to the JSON property disableSearchTermMatching
15134 15135 15136 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15134 def disable_search_term_matching @disable_search_term_matching end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15142 15143 15144 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15142 def update!(**args) @disable_search_term_matching = args[:disable_search_term_matching] if args.key?(:disable_search_term_matching) end |