Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAudienceSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Settings for the audience targeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAudienceSetting

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAudienceSetting.



15224
15225
15226
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#use_audience_groupedBoolean Also known as: use_audience_grouped?

Immutable. If true, this ad group uses an Audience resource for audience targeting. If false, this ad group may use audience segment criteria instead. Corresponds to the JSON property useAudienceGrouped

Returns:

  • (Boolean)


15221
15222
15223
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15221

def use_audience_grouped
  @use_audience_grouped
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15229
15230
15231
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15229

def update!(**args)
  @use_audience_grouped = args[:use_audience_grouped] if args.key?(:use_audience_grouped)
end