Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An ad group criterion. The ad_group_criterion report only returns criteria that were explicitly added to the ad group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterion

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterion.



21412
21413
21414
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21412

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Immutable. The ad group to which the criterion belongs. Corresponds to the JSON property adGroup

Returns:

  • (String)


21052
21053
21054
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21052

def ad_group
  @ad_group
end

#age_rangeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo

An age range criterion. Corresponds to the JSON property ageRange



21057
21058
21059
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21057

def age_range
  @age_range
end

#app_payment_modelGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppPaymentModelInfo

An app payment model criterion. Corresponds to the JSON property appPaymentModel



21062
21063
21064
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21062

def app_payment_model
  @app_payment_model
end

#approval_statusString

Output only. Approval status of the criterion. Corresponds to the JSON property approvalStatus

Returns:

  • (String)


21067
21068
21069
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21067

def approval_status
  @approval_status
end

#audienceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInfo

An audience criterion. Corresponds to the JSON property audience



21072
21073
21074
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21072

def audience
  @audience
end

#bid_modifierFloat

The modifier for the bid when the criterion matches. The modifier must be in the range: 0.1 - 10.0. Most targetable criteria types support modifiers. Corresponds to the JSON property bidModifier

Returns:

  • (Float)


21078
21079
21080
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21078

def bid_modifier
  @bid_modifier
end

#brand_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandListInfo

A Brand List Criterion is used to specify a list of brands. The list is represented as a SharedSet id type BRAND_HINT. A criterion of this type can be either targeted or excluded. Corresponds to the JSON property brandList



21085
21086
21087
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21085

def brand_list
  @brand_list
end

#combined_audienceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCombinedAudienceInfo

A combined audience criterion. Corresponds to the JSON property combinedAudience



21090
21091
21092
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21090

def combined_audience
  @combined_audience
end

#cpc_bid_microsFixnum

The CPC (cost-per-click) bid. Corresponds to the JSON property cpcBidMicros

Returns:

  • (Fixnum)


21095
21096
21097
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21095

def cpc_bid_micros
  @cpc_bid_micros
end

#cpm_bid_microsFixnum

The CPM (cost-per-thousand viewable impressions) bid. Corresponds to the JSON property cpmBidMicros

Returns:

  • (Fixnum)


21100
21101
21102
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21100

def cpm_bid_micros
  @cpm_bid_micros
end

#cpv_bid_microsFixnum

The CPV (cost-per-view) bid. Corresponds to the JSON property cpvBidMicros

Returns:

  • (Fixnum)


21105
21106
21107
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21105

def cpv_bid_micros
  @cpv_bid_micros
end

#creation_timeString

Output only. The timestamp when this ad group criterion was created. The timestamp is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. Corresponds to the JSON property creationTime

Returns:

  • (String)


21111
21112
21113
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21111

def creation_time
  @creation_time
end

#criterion_idFixnum

Output only. The ID of the criterion. Corresponds to the JSON property criterionId

Returns:

  • (Fixnum)


21116
21117
21118
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21116

def criterion_id
  @criterion_id
end

#custom_affinityGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomAffinityInfo

A custom affinity criterion. A criterion of this type is only targetable. Corresponds to the JSON property customAffinity



21121
21122
21123
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21121

def custom_affinity
  @custom_affinity
end

#custom_audienceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomAudienceInfo

A custom audience criterion. Corresponds to the JSON property customAudience



21126
21127
21128
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21126

def custom_audience
  @custom_audience
end

#custom_intentGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomIntentInfo

A custom intent criterion. A criterion of this type is only targetable. Corresponds to the JSON property customIntent



21131
21132
21133
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21131

def custom_intent
  @custom_intent
end

#disapproval_reasonsArray<String>

Output only. List of disapproval reasons of the criterion. The different reasons for disapproving a criterion can be found here: https://support.google. com/adspolicy/answer/6008942 This field is read-only. Corresponds to the JSON property disapprovalReasons

Returns:

  • (Array<String>)


21138
21139
21140
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21138

def disapproval_reasons
  @disapproval_reasons
end

#display_nameString

Output only. The display name of the criterion. Corresponds to the JSON property displayName

Returns:

  • (String)


21143
21144
21145
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21143

def display_name
  @display_name
end

#effective_cpc_bid_microsFixnum

Output only. The effective CPC (cost-per-click) bid. Corresponds to the JSON property effectiveCpcBidMicros

Returns:

  • (Fixnum)


21148
21149
21150
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21148

def effective_cpc_bid_micros
  @effective_cpc_bid_micros
end

#effective_cpc_bid_sourceString

Output only. Source of the effective CPC bid. Corresponds to the JSON property effectiveCpcBidSource

Returns:

  • (String)


21153
21154
21155
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21153

def effective_cpc_bid_source
  @effective_cpc_bid_source
end

#effective_cpm_bid_microsFixnum

Output only. The effective CPM (cost-per-thousand viewable impressions) bid. Corresponds to the JSON property effectiveCpmBidMicros

Returns:

  • (Fixnum)


21158
21159
21160
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21158

def effective_cpm_bid_micros
  @effective_cpm_bid_micros
end

#effective_cpm_bid_sourceString

Output only. Source of the effective CPM bid. Corresponds to the JSON property effectiveCpmBidSource

Returns:

  • (String)


21163
21164
21165
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21163

def effective_cpm_bid_source
  @effective_cpm_bid_source
end

#effective_cpv_bid_microsFixnum

Output only. The effective CPV (cost-per-view) bid. Corresponds to the JSON property effectiveCpvBidMicros

Returns:

  • (Fixnum)


21168
21169
21170
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21168

def effective_cpv_bid_micros
  @effective_cpv_bid_micros
end

#effective_cpv_bid_sourceString

Output only. Source of the effective CPV bid. Corresponds to the JSON property effectiveCpvBidSource

Returns:

  • (String)


21173
21174
21175
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21173

def effective_cpv_bid_source
  @effective_cpv_bid_source
end

#effective_labelsArray<String>

Output only. The resource names of effective labels attached to this ad group criterion. An effective label is a label inherited or directly assigned to this ad group criterion. Corresponds to the JSON property effectiveLabels

Returns:

  • (Array<String>)


21180
21181
21182
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21180

def effective_labels
  @effective_labels
end

#effective_percent_cpc_bid_microsFixnum

Output only. The effective Percent CPC bid amount. Corresponds to the JSON property effectivePercentCpcBidMicros

Returns:

  • (Fixnum)


21185
21186
21187
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21185

def effective_percent_cpc_bid_micros
  @effective_percent_cpc_bid_micros
end

#effective_percent_cpc_bid_sourceString

Output only. Source of the effective Percent CPC bid. Corresponds to the JSON property effectivePercentCpcBidSource

Returns:

  • (String)


21190
21191
21192
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21190

def effective_percent_cpc_bid_source
  @effective_percent_cpc_bid_source
end

#engine_idString

Output only. ID of the ad group criterion in the external engine account. This field is for non-Google Ads account only, for example, Yahoo Japan, Microsoft, Baidu etc. For Google Ads entity, use "ad_group_criterion.criterion_id" instead. Corresponds to the JSON property engineId

Returns:

  • (String)


21198
21199
21200
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21198

def engine_id
  @engine_id
end

#engine_statusString

Output only. The Engine Status for ad group criterion. Corresponds to the JSON property engineStatus

Returns:

  • (String)


21203
21204
21205
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21203

def engine_status
  @engine_status
end

#extended_demographicGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonExtendedDemographicInfo

Represents an extended demographic criterion. Corresponds to the JSON property extendedDemographic



21208
21209
21210
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21208

def extended_demographic
  @extended_demographic
end

#final_mobile_urlsArray<String>

The list of possible final mobile URLs after all cross-domain redirects. Corresponds to the JSON property finalMobileUrls

Returns:

  • (Array<String>)


21213
21214
21215
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21213

def final_mobile_urls
  @final_mobile_urls
end

#final_url_suffixString

URL template for appending params to final URL. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


21218
21219
21220
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21218

def final_url_suffix
  @final_url_suffix
end

#final_urlsArray<String>

The list of possible final URLs after all cross-domain redirects for the ad. Corresponds to the JSON property finalUrls

Returns:

  • (Array<String>)


21223
21224
21225
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21223

def final_urls
  @final_urls
end

#genderGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo

A gender criterion. Corresponds to the JSON property gender



21228
21229
21230
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21228

def gender
  @gender
end

#income_rangeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIncomeRangeInfo

An income range criterion. Corresponds to the JSON property incomeRange



21233
21234
21235
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21233

def income_range
  @income_range
end

#keywordGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo

A keyword criterion. Corresponds to the JSON property keyword



21238
21239
21240
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21238

def keyword
  @keyword
end

#labelsArray<String>

Output only. The resource names of labels attached to this ad group criterion. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


21243
21244
21245
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21243

def labels
  @labels
end

#languageGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLanguageInfo

A language criterion. Corresponds to the JSON property language



21248
21249
21250
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21248

def language
  @language
end

#last_modified_timeString

Output only. The datetime when this ad group criterion was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


21255
21256
21257
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21255

def last_modified_time
  @last_modified_time
end

#life_eventGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLifeEventInfo

Represents a life event criterion. Corresponds to the JSON property lifeEvent



21260
21261
21262
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21260

def life_event
  @life_event
end

#listing_groupGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingGroupInfo

A listing group criterion. Corresponds to the JSON property listingGroup



21265
21266
21267
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21265

def listing_group
  @listing_group
end

#locationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo

A location criterion. Corresponds to the JSON property location



21270
21271
21272
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21270

def location
  @location
end

#mobile_app_categoryGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo

A mobile app category criterion. Corresponds to the JSON property mobileAppCategory



21275
21276
21277
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21275

def mobile_app_category
  @mobile_app_category
end

#mobile_applicationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo

A mobile application criterion. Corresponds to the JSON property mobileApplication



21280
21281
21282
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21280

def mobile_application
  @mobile_application
end

#negativeBoolean Also known as: negative?

Immutable. Whether to target (false) or exclude (true) the criterion. This field is immutable. To switch a criterion from positive to negative, remove then re-add it. Corresponds to the JSON property negative

Returns:

  • (Boolean)


21287
21288
21289
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21287

def negative
  @negative
end

#parental_statusGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo

A parental status criterion. Corresponds to the JSON property parentalStatus



21293
21294
21295
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21293

def parental_status
  @parental_status
end

#percent_cpc_bid_microsFixnum

The CPC bid amount, expressed as a fraction of the advertised price for some good or service. The valid range for the fraction is [0,1) and the value stored here is 1,000,000 * [fraction]. Corresponds to the JSON property percentCpcBidMicros

Returns:

  • (Fixnum)


21300
21301
21302
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21300

def percent_cpc_bid_micros
  @percent_cpc_bid_micros
end

#placementGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo

A placement criterion. This can be used to modify bids for sites when targeting the content network. Corresponds to the JSON property placement



21306
21307
21308
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21306

def placement
  @placement
end

#position_estimatesGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates

Estimates for criterion bids at various positions. Corresponds to the JSON property positionEstimates



21311
21312
21313
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21311

def position_estimates
  @position_estimates
end

#primary_statusString

Output only. The primary status for the ad group criterion. Corresponds to the JSON property primaryStatus

Returns:

  • (String)


21316
21317
21318
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21316

def primary_status
  @primary_status
end

#primary_status_reasonsArray<String>

Output only. The primary status reasons for the ad group criterion. Corresponds to the JSON property primaryStatusReasons

Returns:

  • (Array<String>)


21321
21322
21323
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21321

def primary_status_reasons
  @primary_status_reasons
end

#quality_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionQualityInfo

A container for ad group criterion quality information. Corresponds to the JSON property qualityInfo



21326
21327
21328
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21326

def quality_info
  @quality_info
end

#resource_nameString

Immutable. The resource name of the ad group criterion. Ad group criterion resource names have the form: customers/customer_id/adGroupCriteria/ ad_group_id~criterion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


21333
21334
21335
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21333

def resource_name
  @resource_name
end

#statusString

The status of the criterion. This is the status of the ad group criterion entity, set by the client. Note: UI reports may incorporate additional information that affects whether a criterion is eligible to run. In some cases a criterion that's REMOVED in the API can still show as enabled in the UI. For example, campaigns by default show to users of all age ranges unless excluded. The UI will show each age range as "enabled", since they're eligible to see the ads; but AdGroupCriterion.status will show "removed", since no positive criterion was added. Corresponds to the JSON property status

Returns:

  • (String)


21345
21346
21347
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21345

def status
  @status
end

#system_serving_statusString

Output only. Serving status of the criterion. Corresponds to the JSON property systemServingStatus

Returns:

  • (String)


21350
21351
21352
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21350

def system_serving_status
  @system_serving_status
end

#topicGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTopicInfo

A topic criterion. Use topics to target or exclude placements in the Google Display Network based on the category into which the placement falls (for example, "Pets & Animals/Pets/Dogs"). Corresponds to the JSON property topic



21357
21358
21359
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21357

def topic
  @topic
end

#tracking_url_templateString

The URL template for constructing a tracking URL. Corresponds to the JSON property trackingUrlTemplate

Returns:

  • (String)


21362
21363
21364
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21362

def tracking_url_template
  @tracking_url_template
end

#typeString

Output only. The type of the criterion. Corresponds to the JSON property type

Returns:

  • (String)


21367
21368
21369
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21367

def type
  @type
end

#url_custom_parametersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>

The list of mappings used to substitute custom parameter tags in a tracking_url_template, final_urls, or mobile_final_urls. Corresponds to the JSON property urlCustomParameters



21373
21374
21375
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21373

def url_custom_parameters
  @url_custom_parameters
end

#user_interestGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserInterestInfo

Represents a particular interest-based topic to be targeted. Corresponds to the JSON property userInterest



21378
21379
21380
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21378

def user_interest
  @user_interest
end

#user_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListInfo

A User List criterion. Represents a user list that is defined by the advertiser to be targeted. Corresponds to the JSON property userList



21384
21385
21386
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21384

def user_list
  @user_list
end

#vertical_ads_item_group_rule_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleListInfo

A criterion for targeting a shared set of rules for item groups in Vertical Ads (e.g., for hotel ads). Corresponds to the JSON property verticalAdsItemGroupRuleList



21390
21391
21392
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21390

def vertical_ads_item_group_rule_list
  @vertical_ads_item_group_rule_list
end

#video_lineupGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVideoLineupInfo

A Video lineup criterion. Corresponds to the JSON property videoLineup



21395
21396
21397
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21395

def video_lineup
  @video_lineup
end

#webpageGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageInfo

Represents a criterion for targeting webpages of an advertiser's website. Corresponds to the JSON property webpage



21400
21401
21402
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21400

def webpage
  @webpage
end

#youtube_channelGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo

A YouTube Channel criterion. Corresponds to the JSON property youtubeChannel



21405
21406
21407
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21405

def youtube_channel
  @youtube_channel
end

#youtube_videoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo

A YouTube Video criterion. Corresponds to the JSON property youtubeVideo



21410
21411
21412
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21410

def youtube_video
  @youtube_video
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21417
21418
21419
21420
21421
21422
21423
21424
21425
21426
21427
21428
21429
21430
21431
21432
21433
21434
21435
21436
21437
21438
21439
21440
21441
21442
21443
21444
21445
21446
21447
21448
21449
21450
21451
21452
21453
21454
21455
21456
21457
21458
21459
21460
21461
21462
21463
21464
21465
21466
21467
21468
21469
21470
21471
21472
21473
21474
21475
21476
21477
21478
21479
21480
21481
21482
21483
21484
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21417

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @age_range = args[:age_range] if args.key?(:age_range)
  @app_payment_model = args[:app_payment_model] if args.key?(:app_payment_model)
  @approval_status = args[:approval_status] if args.key?(:approval_status)
  @audience = args[:audience] if args.key?(:audience)
  @bid_modifier = args[:bid_modifier] if args.key?(:bid_modifier)
  @brand_list = args[:brand_list] if args.key?(:brand_list)
  @combined_audience = args[:combined_audience] if args.key?(:combined_audience)
  @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros)
  @cpm_bid_micros = args[:cpm_bid_micros] if args.key?(:cpm_bid_micros)
  @cpv_bid_micros = args[:cpv_bid_micros] if args.key?(:cpv_bid_micros)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @criterion_id = args[:criterion_id] if args.key?(:criterion_id)
  @custom_affinity = args[:custom_affinity] if args.key?(:custom_affinity)
  @custom_audience = args[:custom_audience] if args.key?(:custom_audience)
  @custom_intent = args[:custom_intent] if args.key?(:custom_intent)
  @disapproval_reasons = args[:disapproval_reasons] if args.key?(:disapproval_reasons)
  @display_name = args[:display_name] if args.key?(:display_name)
  @effective_cpc_bid_micros = args[:effective_cpc_bid_micros] if args.key?(:effective_cpc_bid_micros)
  @effective_cpc_bid_source = args[:effective_cpc_bid_source] if args.key?(:effective_cpc_bid_source)
  @effective_cpm_bid_micros = args[:effective_cpm_bid_micros] if args.key?(:effective_cpm_bid_micros)
  @effective_cpm_bid_source = args[:effective_cpm_bid_source] if args.key?(:effective_cpm_bid_source)
  @effective_cpv_bid_micros = args[:effective_cpv_bid_micros] if args.key?(:effective_cpv_bid_micros)
  @effective_cpv_bid_source = args[:effective_cpv_bid_source] if args.key?(:effective_cpv_bid_source)
  @effective_labels = args[:effective_labels] if args.key?(:effective_labels)
  @effective_percent_cpc_bid_micros = args[:effective_percent_cpc_bid_micros] if args.key?(:effective_percent_cpc_bid_micros)
  @effective_percent_cpc_bid_source = args[:effective_percent_cpc_bid_source] if args.key?(:effective_percent_cpc_bid_source)
  @engine_id = args[:engine_id] if args.key?(:engine_id)
  @engine_status = args[:engine_status] if args.key?(:engine_status)
  @extended_demographic = args[:extended_demographic] if args.key?(:extended_demographic)
  @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @final_urls = args[:final_urls] if args.key?(:final_urls)
  @gender = args[:gender] if args.key?(:gender)
  @income_range = args[:income_range] if args.key?(:income_range)
  @keyword = args[:keyword] if args.key?(:keyword)
  @labels = args[:labels] if args.key?(:labels)
  @language = args[:language] if args.key?(:language)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @life_event = args[:life_event] if args.key?(:life_event)
  @listing_group = args[:listing_group] if args.key?(:listing_group)
  @location = args[:location] if args.key?(:location)
  @mobile_app_category = args[:mobile_app_category] if args.key?(:mobile_app_category)
  @mobile_application = args[:mobile_application] if args.key?(:mobile_application)
  @negative = args[:negative] if args.key?(:negative)
  @parental_status = args[:parental_status] if args.key?(:parental_status)
  @percent_cpc_bid_micros = args[:percent_cpc_bid_micros] if args.key?(:percent_cpc_bid_micros)
  @placement = args[:placement] if args.key?(:placement)
  @position_estimates = args[:position_estimates] if args.key?(:position_estimates)
  @primary_status = args[:primary_status] if args.key?(:primary_status)
  @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons)
  @quality_info = args[:quality_info] if args.key?(:quality_info)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @system_serving_status = args[:system_serving_status] if args.key?(:system_serving_status)
  @topic = args[:topic] if args.key?(:topic)
  @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template)
  @type = args[:type] if args.key?(:type)
  @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters)
  @user_interest = args[:user_interest] if args.key?(:user_interest)
  @user_list = args[:user_list] if args.key?(:user_list)
  @vertical_ads_item_group_rule_list = args[:vertical_ads_item_group_rule_list] if args.key?(:vertical_ads_item_group_rule_list)
  @video_lineup = args[:video_lineup] if args.key?(:video_lineup)
  @webpage = args[:webpage] if args.key?(:webpage)
  @youtube_channel = args[:youtube_channel] if args.key?(:youtube_channel)
  @youtube_video = args[:youtube_video] if args.key?(:youtube_video)
end