Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionLabel
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionLabel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A relationship between an ad group criterion and a label.
Instance Attribute Summary collapse
-
#ad_group_criterion ⇒ String
Immutable.
-
#label ⇒ String
Immutable.
-
#owner_customer_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionLabel
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionLabel
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionLabel.
21605 21606 21607 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_criterion ⇒ String
Immutable. The ad group criterion to which the label is attached.
Corresponds to the JSON property adGroupCriterion
21586 21587 21588 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21586 def ad_group_criterion @ad_group_criterion end |
#label ⇒ String
Immutable. The label assigned to the ad group criterion.
Corresponds to the JSON property label
21591 21592 21593 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21591 def label @label end |
#owner_customer_id ⇒ Fixnum
Output only. The ID of the Customer which owns the label.
Corresponds to the JSON property ownerCustomerId
21596 21597 21598 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21596 def owner_customer_id @owner_customer_id end |
#resource_name ⇒ String
Immutable. The resource name of the ad group criterion label. Ad group
criterion label resource names have the form: customers/owner_customer_id/
adGroupCriterionLabels/ad_group_id~criterion_id~label_id`
Corresponds to the JSON propertyresourceName`
21603 21604 21605 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21603 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21610 21611 21612 21613 21614 21615 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21610 def update!(**args) @ad_group_criterion = args[:ad_group_criterion] if args.key?(:ad_group_criterion) @label = args[:label] if args.key?(:label) @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id) @resource_name = args[:resource_name] if args.key?(:resource_name) end |