Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCustomizer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A customizer value for the associated CustomizerAttribute at the AdGroup level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCustomizer

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCustomizer.



21666
21667
21668
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21666

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Immutable. The ad group to which the customizer attribute is linked. Corresponds to the JSON property adGroup

Returns:

  • (String)


21641
21642
21643
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21641

def ad_group
  @ad_group
end

#customizer_attributeString

Required. Immutable. The customizer attribute which is linked to the ad group. Corresponds to the JSON property customizerAttribute

Returns:

  • (String)


21646
21647
21648
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21646

def customizer_attribute
  @customizer_attribute
end

#resource_nameString

Immutable. The resource name of the ad group customizer. Ad group customizer resource names have the form: customers/customer_id/adGroupCustomizers/ ad_group_id~customizer_attribute_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


21653
21654
21655
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21653

def resource_name
  @resource_name
end

#statusString

Output only. The status of the ad group customizer. Corresponds to the JSON property status

Returns:

  • (String)


21658
21659
21660
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21658

def status
  @status
end

#valueGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue

A customizer value that is referenced in customizer linkage entities like CustomerCustomizer, CampaignCustomizer, etc. Corresponds to the JSON property value



21664
21665
21666
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21664

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21671
21672
21673
21674
21675
21676
21677
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21671

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @customizer_attribute = args[:customizer_attribute] if args.key?(:customizer_attribute)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @value = args[:value] if args.key?(:value)
end