Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupEffectiveLabel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A relationship between an ad group and an effective label. An effective label is a label inherited or directly assigned to this ad group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupEffectiveLabel

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupEffectiveLabel.



21767
21768
21769
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Immutable. The ad group to which the effective label is attached. Corresponds to the JSON property adGroup

Returns:

  • (String)


21748
21749
21750
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21748

def ad_group
  @ad_group
end

#labelString

Immutable. The effective label assigned to the ad group. Corresponds to the JSON property label

Returns:

  • (String)


21753
21754
21755
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21753

def label
  @label
end

#owner_customer_idFixnum

Output only. The ID of the Customer which owns the effective label. Corresponds to the JSON property ownerCustomerId

Returns:

  • (Fixnum)


21758
21759
21760
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21758

def owner_customer_id
  @owner_customer_id
end

#resource_nameString

Immutable. The resource name of the ad group effective label. Ad group effective label resource names have the form: customers/owner_customer_id/ adGroupEffectiveLabels/ad_group_id~label_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


21765
21766
21767
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21765

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21772
21773
21774
21775
21776
21777
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21772

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @label = args[:label] if args.key?(:label)
  @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end