Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupSimulation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An ad group simulation. Supported combinations of advertising channel type, simulation type and simulation modification method is detailed below respectively. 1. SEARCH - CPC_BID - DEFAULT 2. SEARCH - CPC_BID - UNIFORM 3. SEARCH - TARGET_CPA - UNIFORM 4. SEARCH - TARGET_ROAS - UNIFORM 5. DISPLAY - CPC_BID - DEFAULT 6. DISPLAY - CPC_BID - UNIFORM 7. DISPLAY - TARGET_CPA - UNIFORM

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupSimulation

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupSimulation.



21880
21881
21882
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21880

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_idFixnum

Output only. Ad group id of the simulation. Corresponds to the JSON property adGroupId

Returns:

  • (Fixnum)


21831
21832
21833
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21831

def ad_group_id
  @ad_group_id
end

#cpc_bid_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpcBidSimulationPointList

A container for simulation points for simulations of type CPC_BID. Corresponds to the JSON property cpcBidPointList



21836
21837
21838
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21836

def cpc_bid_point_list
  @cpc_bid_point_list
end

#cpv_bid_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpvBidSimulationPointList

A container for simulation points for simulations of type CPV_BID. Corresponds to the JSON property cpvBidPointList



21841
21842
21843
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21841

def cpv_bid_point_list
  @cpv_bid_point_list
end

#end_dateString

Output only. Last day on which the simulation is based, in YYYY-MM-DD format Corresponds to the JSON property endDate

Returns:

  • (String)


21846
21847
21848
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21846

def end_date
  @end_date
end

#modification_methodString

Output only. How the simulation modifies the field. Corresponds to the JSON property modificationMethod

Returns:

  • (String)


21851
21852
21853
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21851

def modification_method
  @modification_method
end

#resource_nameString

Output only. The resource name of the ad group simulation. Ad group simulation resource names have the form: customers/customer_id/adGroupSimulations/ ad_group_id~type~modification_method~start_date~end_date` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


21858
21859
21860
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21858

def resource_name
  @resource_name
end

#start_dateString

Output only. First day on which the simulation is based, in YYYY-MM-DD format. Corresponds to the JSON property startDate

Returns:

  • (String)


21863
21864
21865
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21863

def start_date
  @start_date
end

#target_cpa_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpaSimulationPointList

A container for simulation points for simulations of type TARGET_CPA. Corresponds to the JSON property targetCpaPointList



21868
21869
21870
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21868

def target_cpa_point_list
  @target_cpa_point_list
end

#target_roas_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoasSimulationPointList

A container for simulation points for simulations of type TARGET_ROAS. Corresponds to the JSON property targetRoasPointList



21873
21874
21875
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21873

def target_roas_point_list
  @target_roas_point_list
end

#typeString

Output only. The field that the simulation modifies. Corresponds to the JSON property type

Returns:

  • (String)


21878
21879
21880
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21878

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21885
21886
21887
21888
21889
21890
21891
21892
21893
21894
21895
21896
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21885

def update!(**args)
  @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id)
  @cpc_bid_point_list = args[:cpc_bid_point_list] if args.key?(:cpc_bid_point_list)
  @cpv_bid_point_list = args[:cpv_bid_point_list] if args.key?(:cpv_bid_point_list)
  @end_date = args[:end_date] if args.key?(:end_date)
  @modification_method = args[:modification_method] if args.key?(:modification_method)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @target_cpa_point_list = args[:target_cpa_point_list] if args.key?(:target_cpa_point_list)
  @target_roas_point_list = args[:target_roas_point_list] if args.key?(:target_roas_point_list)
  @type = args[:type] if args.key?(:type)
end