Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupVerticalAdsFormatSetting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupVerticalAdsFormatSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Vertical ads setting feature to enable/disable ad group format controls in search campaigns.
Instance Attribute Summary collapse
-
#disable_text_ads ⇒ Boolean
(also: #disable_text_ads?)
If true, text ads will be disabled for this ad group.
-
#enable_booking_links ⇒ Boolean
(also: #enable_booking_links?)
If true, booking links will be enabled for this ad group.
-
#enable_vertical_promotion_ads ⇒ Boolean
(also: #enable_vertical_promotion_ads?)
If true, vertical promotion ads will be enabled for this ad group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupVerticalAdsFormatSetting
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupVerticalAdsFormatSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupVerticalAdsFormatSetting
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupVerticalAdsFormatSetting.
15336 15337 15338 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disable_text_ads ⇒ Boolean Also known as: disable_text_ads?
If true, text ads will be disabled for this ad group.
Corresponds to the JSON property disableTextAds
15321 15322 15323 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15321 def disable_text_ads @disable_text_ads end |
#enable_booking_links ⇒ Boolean Also known as: enable_booking_links?
If true, booking links will be enabled for this ad group.
Corresponds to the JSON property enableBookingLinks
15327 15328 15329 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15327 def enable_booking_links @enable_booking_links end |
#enable_vertical_promotion_ads ⇒ Boolean Also known as: enable_vertical_promotion_ads?
If true, vertical promotion ads will be enabled for this ad group.
Corresponds to the JSON property enableVerticalPromotionAds
15333 15334 15335 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15333 def enable_vertical_promotion_ads @enable_vertical_promotion_ads end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15341 15342 15343 15344 15345 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15341 def update!(**args) @disable_text_ads = args[:disable_text_ads] if args.key?(:disable_text_ads) @enable_booking_links = args[:enable_booking_links] if args.key?(:enable_booking_links) @enable_vertical_promotion_ads = args[:enable_vertical_promotion_ads] if args.key?(:enable_vertical_promotion_ads) end |