Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdParameter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An ad parameter that is used to update numeric values (such as prices or inventory levels) in any text line of an ad (including URLs). There can be a maximum of two AdParameters per ad group criterion. (One with parameter_index = 1 and one with parameter_index = 2.) In the ad the parameters are referenced by a placeholder of the form "param#:value". For example, "param1:$17"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdParameter

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdParameter.



21803
21804
21805
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_criterionString

Immutable. The ad group criterion that this ad parameter belongs to. Corresponds to the JSON property adGroupCriterion

Returns:

  • (String)


21776
21777
21778
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21776

def ad_group_criterion
  @ad_group_criterion
end

#insertion_textString

Numeric value to insert into the ad text. The following restrictions apply: - Can use comma or period as a separator, with an optional period or comma ( respectively) for fractional values. For example, 1,000,000.00 and 2.000.000, 10 are valid. - Can be prepended or appended with a currency symbol. For example, $99.99 is valid. - Can be prepended or appended with a currency code. For example, 99.99USD and EUR200 are valid. - Can use '%'. For example, 1.0% and 1,0% are valid. - Can use plus or minus. For example, -10.99 and 25+ are valid. - Can use '/' between two numbers. For example 4/1 and 0.95/0.45 are valid. Corresponds to the JSON property insertionText

Returns:

  • (String)


21789
21790
21791
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21789

def insertion_text
  @insertion_text
end

#parameter_indexFixnum

Immutable. The unique index of this ad parameter. Must be either 1 or 2. Corresponds to the JSON property parameterIndex

Returns:

  • (Fixnum)


21794
21795
21796
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21794

def parameter_index
  @parameter_index
end

#resource_nameString

Immutable. The resource name of the ad parameter. Ad parameter resource names have the form: customers/customer_id/adParameters/ad_group_id~ criterion_id~parameter_index` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


21801
21802
21803
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21801

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21808
21809
21810
21811
21812
21813
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21808

def update!(**args)
  @ad_group_criterion = args[:ad_group_criterion] if args.key?(:ad_group_criterion)
  @insertion_text = args[:insertion_text] if args.key?(:insertion_text)
  @parameter_index = args[:parameter_index] if args.key?(:parameter_index)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end