Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdStrengthActionItemAddAssetDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The details of the asset to add.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdStrengthActionItemAddAssetDetails

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdStrengthActionItemAddAssetDetails.



15369
15370
15371
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15369

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_countFixnum

Output only. The number of assets to add. Corresponds to the JSON property assetCount

Returns:

  • (Fixnum)


15355
15356
15357
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15355

def asset_count
  @asset_count
end

#asset_field_typeString

Output only. The asset field type of the asset(s) to add. Corresponds to the JSON property assetFieldType

Returns:

  • (String)


15360
15361
15362
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15360

def asset_field_type
  @asset_field_type
end

#video_aspect_ratio_requirementString

Output only. For video field types, the required aspect ratio of the video. When unset and asset_field_type is YOUTUBE_VIDEO, the system recommends the advertiser upload any YouTube video, regardless of aspect ratio. Corresponds to the JSON property videoAspectRatioRequirement

Returns:

  • (String)


15367
15368
15369
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15367

def video_aspect_ratio_requirement
  @video_aspect_ratio_requirement
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15374
15375
15376
15377
15378
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15374

def update!(**args)
  @asset_count = args[:asset_count] if args.key?(:asset_count)
  @asset_field_type = args[:asset_field_type] if args.key?(:asset_field_type)
  @video_aspect_ratio_requirement = args[:video_aspect_ratio_requirement] if args.key?(:video_aspect_ratio_requirement)
end