Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdvertisingPartnerIdentifier

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The identifier for the Advertising Partner Google Ads account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdvertisingPartnerIdentifier

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdvertisingPartnerIdentifier.



21874
21875
21876
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21874

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customerString

Output only. The resource name of the advertising partner Google Ads account. This field is required and should not be empty when creating a new Advertising Partner link. It is unable to be modified after the creation of the link. Corresponds to the JSON property customer

Returns:

  • (String)


21872
21873
21874
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21872

def customer
  @customer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21879
21880
21881
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21879

def update!(**args)
  @customer = args[:customer] if args.key?(:customer)
end