Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdvertisingPartnerLinkInvitationIdentifier

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The identifier for the Advertising Partner Google Ads account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdvertisingPartnerLinkInvitationIdentifier

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdvertisingPartnerLinkInvitationIdentifier.



21968
21969
21970
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customerString

Immutable. The resource name of the advertising partner Google Ads account. This field is read only. Corresponds to the JSON property customer

Returns:

  • (String)


21966
21967
21968
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21966

def customer
  @customer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21973
21974
21975
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21973

def update!(**args)
  @customer = args[:customer] if args.key?(:customer)
end