Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
AiMaxSearchTermAdCombinationView Resource.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Output only.
-
#headline ⇒ String
Output only.
-
#landing_page ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#search_term ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView
Returns a new instance of GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView.
22100 22101 22102 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22100 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Output only. Ad group where the search term served.
Corresponds to the JSON property adGroup
22072 22073 22074 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22072 def ad_group @ad_group end |
#headline ⇒ String
Output only. The concatenated string containing headline assets for the ad. Up
to three headline assets are concatenated, separated by " | ". This field is
read-only.
Corresponds to the JSON property headline
22079 22080 22081 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22079 def headline @headline end |
#landing_page ⇒ String
Output only. The destination URL, which was dynamically generated. This field
is read-only.
Corresponds to the JSON property landingPage
22085 22086 22087 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22085 def landing_page @landing_page end |
#resource_name ⇒ String
Output only. The resource name of the AI Max Search Term Ad Combination view
AI Max Search Term Ad Combination view resource names have the form:
customers/customer_id/aiMaxSearchTermAdCombinationViews/ad_group_id~URL-
base64_search_term~URL-base64_landing_page~URL-base64_headline`
Corresponds to the JSON propertyresourceName`
22093 22094 22095 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22093 def resource_name @resource_name end |
#search_term ⇒ String
Output only. The search term that triggered the ad. This field is read-only.
Corresponds to the JSON property searchTerm
22098 22099 22100 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22098 def search_term @search_term end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22105 22106 22107 22108 22109 22110 22111 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22105 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @headline = args[:headline] if args.key?(:headline) @landing_page = args[:landing_page] if args.key?(:landing_page) @resource_name = args[:resource_name] if args.key?(:resource_name) @search_term = args[:search_term] if args.key?(:search_term) end |