Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Asset is a part of an ad which can be shared across multiple ads. It can be an image (ImageAsset), a video (YoutubeVideoAsset), etc. Assets are immutable and cannot be removed. To stop an asset from serving, remove the asset from the entity that is using it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAsset

Returns a new instance of GoogleAdsSearchads360V23ResourcesAsset.



22560
22561
22562
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

An app deep link asset Corresponds to the JSON property appDeepLinkAsset



22295
22296
22297
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22295

def app_deep_link_asset
  @app_deep_link_asset
end

#book_on_google_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBookOnGoogleAsset

A Book on Google asset. Used to redirect user to book through Google. Book on Google will change the redirect url to book directly through Google. Corresponds to the JSON property bookOnGoogleAsset



22301
22302
22303
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22301

def book_on_google_asset
  @book_on_google_asset
end

#business_message_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessMessageAsset

A business message asset. Corresponds to the JSON property businessMessageAsset



22306
22307
22308
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22306

def business_message_asset
  @business_message_asset
end

#call_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCallAsset

A Call asset. Corresponds to the JSON property callAsset



22311
22312
22313
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22311

def call_asset
  @call_asset
end

#call_to_action_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCallToActionAsset

A call to action asset. Corresponds to the JSON property callToActionAsset



22316
22317
22318
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22316

def call_to_action_asset
  @call_to_action_asset
end

#callout_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCalloutAsset

A Callout asset. Corresponds to the JSON property calloutAsset



22321
22322
22323
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22321

def callout_asset
  @callout_asset
end

#creation_timeString

Output only. The timestamp when this asset was created. The timestamp is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. Corresponds to the JSON property creationTime

Returns:

  • (String)


22327
22328
22329
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22327

def creation_time
  @creation_time
end

A Demand Gen Carousel Card asset. Corresponds to the JSON property demandGenCarouselCardAsset



22332
22333
22334
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22332

def demand_gen_carousel_card_asset
  @demand_gen_carousel_card_asset
end

#dynamic_custom_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicCustomAsset

A dynamic custom asset. Corresponds to the JSON property dynamicCustomAsset



22337
22338
22339
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22337

def dynamic_custom_asset
  @dynamic_custom_asset
end

#dynamic_education_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicEducationAsset

A Dynamic Education asset. Corresponds to the JSON property dynamicEducationAsset



22342
22343
22344
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22342

def dynamic_education_asset
  @dynamic_education_asset
end

#dynamic_flights_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicFlightsAsset

A dynamic flights asset. Corresponds to the JSON property dynamicFlightsAsset



22347
22348
22349
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22347

def dynamic_flights_asset
  @dynamic_flights_asset
end

#dynamic_hotels_and_rentals_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicHotelsAndRentalsAsset

A dynamic hotels and rentals asset. Corresponds to the JSON property dynamicHotelsAndRentalsAsset



22352
22353
22354
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22352

def dynamic_hotels_and_rentals_asset
  @dynamic_hotels_and_rentals_asset
end

#dynamic_jobs_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicJobsAsset

A dynamic jobs asset. Corresponds to the JSON property dynamicJobsAsset



22357
22358
22359
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22357

def dynamic_jobs_asset
  @dynamic_jobs_asset
end

#dynamic_local_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicLocalAsset

A dynamic local asset. Corresponds to the JSON property dynamicLocalAsset



22362
22363
22364
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22362

def dynamic_local_asset
  @dynamic_local_asset
end

#dynamic_real_estate_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicRealEstateAsset

A dynamic real estate asset. Corresponds to the JSON property dynamicRealEstateAsset



22367
22368
22369
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22367

def dynamic_real_estate_asset
  @dynamic_real_estate_asset
end

#dynamic_travel_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicTravelAsset

A dynamic travel asset. Corresponds to the JSON property dynamicTravelAsset



22372
22373
22374
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22372

def dynamic_travel_asset
  @dynamic_travel_asset
end

#engine_statusString

Output only. The Engine Status for an asset. Corresponds to the JSON property engineStatus

Returns:

  • (String)


22377
22378
22379
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22377

def engine_status
  @engine_status
end

#field_type_policy_summariesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetFieldTypePolicySummary>

Output only. Policy information for the asset for each FieldType. Corresponds to the JSON property fieldTypePolicySummaries



22382
22383
22384
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22382

def field_type_policy_summaries
  @field_type_policy_summaries
end

#final_mobile_urlsArray<String>

A list of possible final mobile URLs after all cross domain redirects. Corresponds to the JSON property finalMobileUrls

Returns:

  • (Array<String>)


22387
22388
22389
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22387

def final_mobile_urls
  @final_mobile_urls
end

#final_url_suffixString

URL template for appending params to landing page URLs served with parallel tracking. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


22393
22394
22395
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22393

def final_url_suffix
  @final_url_suffix
end

#final_urlsArray<String>

A list of possible final URLs after all cross domain redirects. Corresponds to the JSON property finalUrls

Returns:

  • (Array<String>)


22398
22399
22400
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22398

def final_urls
  @final_urls
end

#hotel_callout_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCalloutAsset

An asset representing a hotel callout. Corresponds to the JSON property hotelCalloutAsset



22403
22404
22405
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22403

def hotel_callout_asset
  @hotel_callout_asset
end

#hotel_property_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelPropertyAsset

A hotel property asset. Corresponds to the JSON property hotelPropertyAsset



22408
22409
22410
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22408

def hotel_property_asset
  @hotel_property_asset
end

#idFixnum

Output only. The ID of the asset. Corresponds to the JSON property id

Returns:

  • (Fixnum)


22413
22414
22415
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22413

def id
  @id
end

#image_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonImageAsset

An Image asset. Corresponds to the JSON property imageAsset



22418
22419
22420
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22418

def image_asset
  @image_asset
end

#last_modified_timeString

Output only. The datetime when this asset was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


22424
22425
22426
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22424

def last_modified_time
  @last_modified_time
end

#lead_form_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLeadFormAsset

A Lead Form asset. Corresponds to the JSON property leadFormAsset



22429
22430
22431
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22429

def lead_form_asset
  @lead_form_asset
end

#location_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationAsset

A location asset. Corresponds to the JSON property locationAsset



22434
22435
22436
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22434

def location_asset
  @location_asset
end

#media_bundle_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMediaBundleAsset

A MediaBundle asset. Corresponds to the JSON property mediaBundleAsset



22439
22440
22441
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22439

def media_bundle_asset
  @media_bundle_asset
end

#mobile_app_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppAsset

An asset representing a mobile app. Corresponds to the JSON property mobileAppAsset



22444
22445
22446
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22444

def mobile_app_asset
  @mobile_app_asset
end

#nameString

Optional name of the asset. Corresponds to the JSON property name

Returns:

  • (String)


22449
22450
22451
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22449

def name
  @name
end

#orientationString

Output only. Orientation of the asset. This is only supported for image and video assets. Corresponds to the JSON property orientation

Returns:

  • (String)


22455
22456
22457
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22455

def orientation
  @orientation
end

#page_feed_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPageFeedAsset

A Page Feed asset. Corresponds to the JSON property pageFeedAsset



22460
22461
22462
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22460

def page_feed_asset
  @page_feed_asset
end

#policy_summaryGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetPolicySummary

Contains policy information for an asset. Corresponds to the JSON property policySummary



22465
22466
22467
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22465

def policy_summary
  @policy_summary
end

#price_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPriceAsset

An asset representing a list of price offers. Corresponds to the JSON property priceAsset



22470
22471
22472
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22470

def price_asset
  @price_asset
end

#promotion_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPromotionAsset

A Promotion asset. Corresponds to the JSON property promotionAsset



22475
22476
22477
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22475

def promotion_asset
  @promotion_asset
end

#resource_nameString

Immutable. The resource name of the asset. Asset resource names have the form: customers/customer_id/assets/asset_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


22481
22482
22483
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22481

def resource_name
  @resource_name
end

#search_ads360_call_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedCallAsset

A unified call asset. Corresponds to the JSON property searchAds360CallAsset



22486
22487
22488
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22486

def search_ads360_call_asset
  @search_ads360_call_asset
end

#search_ads360_callout_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedCalloutAsset

A unified callout asset. Corresponds to the JSON property searchAds360CalloutAsset



22491
22492
22493
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22491

def search_ads360_callout_asset
  @search_ads360_callout_asset
end

#search_ads360_location_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedLocationAsset

A unified location asset. Corresponds to the JSON property searchAds360LocationAsset



22496
22497
22498
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22496

def search_ads360_location_asset
  @search_ads360_location_asset
end

#search_ads360_page_feed_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedPageFeedAsset

A Unified Page Feed asset. Corresponds to the JSON property searchAds360PageFeedAsset



22501
22502
22503
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22501

def search_ads360_page_feed_asset
  @search_ads360_page_feed_asset
end

A unified sitelink asset. Corresponds to the JSON property searchAds360SitelinkAsset



22506
22507
22508
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22506

def search_ads360_sitelink_asset
  @search_ads360_sitelink_asset
end

A Sitelink asset. Corresponds to the JSON property sitelinkAsset



22511
22512
22513
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22511

def sitelink_asset
  @sitelink_asset
end

#sourceString

Output only. Source of the asset. Corresponds to the JSON property source

Returns:

  • (String)


22516
22517
22518
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22516

def source
  @source
end

#statusString

Output only. The status of the asset. Corresponds to the JSON property status

Returns:

  • (String)


22521
22522
22523
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22521

def status
  @status
end

#structured_snippet_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStructuredSnippetAsset

A Structured Snippet asset. Corresponds to the JSON property structuredSnippetAsset



22526
22527
22528
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22526

def structured_snippet_asset
  @structured_snippet_asset
end

#synthetic_content_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSyntheticContentInfo

Container for synthetic content attestations from different sources, such as the advertiser and Google systems. Corresponds to the JSON property syntheticContentInfo



22532
22533
22534
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22532

def 
  @synthetic_content_info
end

#text_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTextAsset

A Text asset. Corresponds to the JSON property textAsset



22537
22538
22539
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22537

def text_asset
  @text_asset
end

#tracking_url_templateString

URL template for constructing a tracking URL. Corresponds to the JSON property trackingUrlTemplate

Returns:

  • (String)


22542
22543
22544
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22542

def tracking_url_template
  @tracking_url_template
end

#typeString

Output only. Type of the asset. Corresponds to the JSON property type

Returns:

  • (String)


22547
22548
22549
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22547

def type
  @type
end

#url_custom_parametersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>

A list of mappings to be used for substituting URL custom parameter tags in the tracking_url_template, final_urls, and/or final_mobile_urls. Corresponds to the JSON property urlCustomParameters



22553
22554
22555
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22553

def url_custom_parameters
  @url_custom_parameters
end

#youtube_video_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYoutubeVideoAsset

A YouTube asset. Corresponds to the JSON property youtubeVideoAsset



22558
22559
22560
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22558

def youtube_video_asset
  @youtube_video_asset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22565
22566
22567
22568
22569
22570
22571
22572
22573
22574
22575
22576
22577
22578
22579
22580
22581
22582
22583
22584
22585
22586
22587
22588
22589
22590
22591
22592
22593
22594
22595
22596
22597
22598
22599
22600
22601
22602
22603
22604
22605
22606
22607
22608
22609
22610
22611
22612
22613
22614
22615
22616
22617
22618
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22565

def update!(**args)
  @app_deep_link_asset = args[:app_deep_link_asset] if args.key?(:app_deep_link_asset)
  @book_on_google_asset = args[:book_on_google_asset] if args.key?(:book_on_google_asset)
  @business_message_asset = args[:business_message_asset] if args.key?(:business_message_asset)
  @call_asset = args[:call_asset] if args.key?(:call_asset)
  @call_to_action_asset = args[:call_to_action_asset] if args.key?(:call_to_action_asset)
  @callout_asset = args[:callout_asset] if args.key?(:callout_asset)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @demand_gen_carousel_card_asset = args[:demand_gen_carousel_card_asset] if args.key?(:demand_gen_carousel_card_asset)
  @dynamic_custom_asset = args[:dynamic_custom_asset] if args.key?(:dynamic_custom_asset)
  @dynamic_education_asset = args[:dynamic_education_asset] if args.key?(:dynamic_education_asset)
  @dynamic_flights_asset = args[:dynamic_flights_asset] if args.key?(:dynamic_flights_asset)
  @dynamic_hotels_and_rentals_asset = args[:dynamic_hotels_and_rentals_asset] if args.key?(:dynamic_hotels_and_rentals_asset)
  @dynamic_jobs_asset = args[:dynamic_jobs_asset] if args.key?(:dynamic_jobs_asset)
  @dynamic_local_asset = args[:dynamic_local_asset] if args.key?(:dynamic_local_asset)
  @dynamic_real_estate_asset = args[:dynamic_real_estate_asset] if args.key?(:dynamic_real_estate_asset)
  @dynamic_travel_asset = args[:dynamic_travel_asset] if args.key?(:dynamic_travel_asset)
  @engine_status = args[:engine_status] if args.key?(:engine_status)
  @field_type_policy_summaries = args[:field_type_policy_summaries] if args.key?(:field_type_policy_summaries)
  @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @final_urls = args[:final_urls] if args.key?(:final_urls)
  @hotel_callout_asset = args[:hotel_callout_asset] if args.key?(:hotel_callout_asset)
  @hotel_property_asset = args[:hotel_property_asset] if args.key?(:hotel_property_asset)
  @id = args[:id] if args.key?(:id)
  @image_asset = args[:image_asset] if args.key?(:image_asset)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @lead_form_asset = args[:lead_form_asset] if args.key?(:lead_form_asset)
  @location_asset = args[:location_asset] if args.key?(:location_asset)
  @media_bundle_asset = args[:media_bundle_asset] if args.key?(:media_bundle_asset)
  @mobile_app_asset = args[:mobile_app_asset] if args.key?(:mobile_app_asset)
  @name = args[:name] if args.key?(:name)
  @orientation = args[:orientation] if args.key?(:orientation)
  @page_feed_asset = args[:page_feed_asset] if args.key?(:page_feed_asset)
  @policy_summary = args[:policy_summary] if args.key?(:policy_summary)
  @price_asset = args[:price_asset] if args.key?(:price_asset)
  @promotion_asset = args[:promotion_asset] if args.key?(:promotion_asset)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @search_ads360_call_asset = args[:search_ads360_call_asset] if args.key?(:search_ads360_call_asset)
  @search_ads360_callout_asset = args[:search_ads360_callout_asset] if args.key?(:search_ads360_callout_asset)
  @search_ads360_location_asset = args[:search_ads360_location_asset] if args.key?(:search_ads360_location_asset)
  @search_ads360_page_feed_asset = args[:search_ads360_page_feed_asset] if args.key?(:search_ads360_page_feed_asset)
  @search_ads360_sitelink_asset = args[:search_ads360_sitelink_asset] if args.key?(:search_ads360_sitelink_asset)
  @sitelink_asset = args[:sitelink_asset] if args.key?(:sitelink_asset)
  @source = args[:source] if args.key?(:source)
  @status = args[:status] if args.key?(:status)
  @structured_snippet_asset = args[:structured_snippet_asset] if args.key?(:structured_snippet_asset)
  @synthetic_content_info = args[:synthetic_content_info] if args.key?(:synthetic_content_info)
  @text_asset = args[:text_asset] if args.key?(:text_asset)
  @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template)
  @type = args[:type] if args.key?(:type)
  @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters)
  @youtube_video_asset = args[:youtube_video_asset] if args.key?(:youtube_video_asset)
end