Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetCoverage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Information about the asset coverage of an asset group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetCoverage

Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetCoverage.



22631
22632
22633
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22631

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_strength_action_itemsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdStrengthActionItem>

Output only. A list of action items to improve the ad strength of an asset group. Corresponds to the JSON property adStrengthActionItems



22629
22630
22631
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22629

def ad_strength_action_items
  @ad_strength_action_items
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22636
22637
22638
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22636

def update!(**args)
  @ad_strength_action_items = args[:ad_strength_action_items] if args.key?(:ad_strength_action_items)
end