Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetFieldTypeView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An asset field type view. This view reports non-overcounted metrics for each asset field type when the asset is used as extension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetFieldTypeView

Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetFieldTypeView.



22689
22690
22691
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22689

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_typeString

Output only. The asset field type of the asset field type view. Corresponds to the JSON property fieldType

Returns:

  • (String)


22680
22681
22682
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22680

def field_type
  @field_type
end

#resource_nameString

Output only. The resource name of the asset field type view. Asset field type view resource names have the form: customers/customer_id/ assetFieldTypeViews/field_type` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


22687
22688
22689
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22687

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22694
22695
22696
22697
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22694

def update!(**args)
  @field_type = args[:field_type] if args.key?(:field_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end