Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

AssetGroupAsset is the link between an asset and an asset group. Adding an AssetGroupAsset links an asset with an asset group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetGroupAsset

Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetGroupAsset.



22865
22866
22867
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetString

Immutable. The asset which this asset group asset is linking. Corresponds to the JSON property asset

Returns:

  • (String)


22809
22810
22811
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22809

def asset
  @asset
end

#asset_groupString

Immutable. The asset group which this asset group asset is linking. Corresponds to the JSON property assetGroup

Returns:

  • (String)


22814
22815
22816
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22814

def asset_group
  @asset_group
end

#field_typeString

The description of the placement of the asset within the asset group. For example: HEADLINE, YOUTUBE_VIDEO etc Corresponds to the JSON property fieldType

Returns:

  • (String)


22820
22821
22822
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22820

def field_type
  @field_type
end

#policy_summaryGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicySummary

Contains policy summary information. Corresponds to the JSON property policySummary



22825
22826
22827
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22825

def policy_summary
  @policy_summary
end

#primary_statusString

Output only. Provides the PrimaryStatus of this asset link. Primary status is meant essentially to differentiate between the plain "status" field, which has advertiser set values of enabled, paused, or removed. The primary status takes into account other signals (for assets its mainly policy and quality approvals) to come up with a more comprehensive status to indicate its serving state. Corresponds to the JSON property primaryStatus

Returns:

  • (String)


22834
22835
22836
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22834

def primary_status
  @primary_status
end

#primary_status_detailsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetLinkPrimaryStatusDetails>

Output only. Provides the details of the primary status and its associated reasons. Corresponds to the JSON property primaryStatusDetails



22840
22841
22842
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22840

def primary_status_details
  @primary_status_details
end

#primary_status_reasonsArray<String>

Output only. Provides a list of reasons for why an asset is not serving or not serving at full capacity. Corresponds to the JSON property primaryStatusReasons

Returns:

  • (Array<String>)


22846
22847
22848
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22846

def primary_status_reasons
  @primary_status_reasons
end

#resource_nameString

Immutable. The resource name of the asset group asset. Asset group asset resource name have the form: customers/customer_id/assetGroupAssets/ asset_group_id~asset_id~field_type` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


22853
22854
22855
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22853

def resource_name
  @resource_name
end

#sourceString

Output only. Source of the asset group asset. Corresponds to the JSON property source

Returns:

  • (String)


22858
22859
22860
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22858

def source
  @source
end

#statusString

The status of the link between an asset and asset group. Corresponds to the JSON property status

Returns:

  • (String)


22863
22864
22865
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22863

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22870
22871
22872
22873
22874
22875
22876
22877
22878
22879
22880
22881
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22870

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @asset_group = args[:asset_group] if args.key?(:asset_group)
  @field_type = args[:field_type] if args.key?(:field_type)
  @policy_summary = args[:policy_summary] if args.key?(:policy_summary)
  @primary_status = args[:primary_status] if args.key?(:primary_status)
  @primary_status_details = args[:primary_status_details] if args.key?(:primary_status_details)
  @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @source = args[:source] if args.key?(:source)
  @status = args[:status] if args.key?(:status)
end