Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupProductGroupView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An asset group product group view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetGroupProductGroupView

Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetGroupProductGroupView.



22991
22992
22993
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22991

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_groupString

Output only. The asset group associated with the listing group filter. Corresponds to the JSON property assetGroup

Returns:

  • (String)


22977
22978
22979
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22977

def asset_group
  @asset_group
end

#asset_group_listing_group_filterString

Output only. The resource name of the asset group listing group filter. Corresponds to the JSON property assetGroupListingGroupFilter

Returns:

  • (String)


22982
22983
22984
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22982

def asset_group_listing_group_filter
  @asset_group_listing_group_filter
end

#resource_nameString

Output only. The resource name of the asset group product group view. Asset group product group view resource names have the form: customers/customer_id /assetGroupProductGroupViews/asset_group_id~listing_group_filter_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


22989
22990
22991
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22989

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22996
22997
22998
22999
23000
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22996

def update!(**args)
  @asset_group = args[:asset_group] if args.key?(:asset_group)
  @asset_group_listing_group_filter = args[:asset_group_listing_group_filter] if args.key?(:asset_group_listing_group_filter)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end