Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupTopCombinationView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupTopCombinationView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A view on the usage of asset group asset top combinations.
Instance Attribute Summary collapse
-
#asset_group_top_combinations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupAssetCombinationData>
Output only.
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetGroupTopCombinationView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAssetGroupTopCombinationView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetGroupTopCombinationView
Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetGroupTopCombinationView.
23078 23079 23080 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23078 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_group_top_combinations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupAssetCombinationData>
Output only. The top combinations of assets that served together.
Corresponds to the JSON property assetGroupTopCombinations
23068 23069 23070 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23068 def asset_group_top_combinations @asset_group_top_combinations end |
#resource_name ⇒ String
Output only. The resource name of the asset group top combination view.
AssetGroup Top Combination view resource names have the form: "customers/
customer_id/assetGroupTopCombinationViews/asset_group_id~
asset_combination_category"
Corresponds to the JSON propertyresourceName`
23076 23077 23078 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23076 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23083 23084 23085 23086 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23083 def update!(**args) @asset_group_top_combinations = args[:asset_group_top_combinations] if args.key?(:asset_group_top_combinations) @resource_name = args[:resource_name] if args.key?(:resource_name) end |