Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetPolicySummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Contains policy information for an asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetPolicySummary

Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetPolicySummary.



22962
22963
22964
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approval_statusString

Output only. The overall approval status of this asset, calculated based on the status of its individual policy topic entries. Corresponds to the JSON property approvalStatus

Returns:

  • (String)


22950
22951
22952
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22950

def approval_status
  @approval_status
end

#policy_topic_entriesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry>

Output only. The list of policy findings for this asset. Corresponds to the JSON property policyTopicEntries



22955
22956
22957
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22955

def policy_topic_entries
  @policy_topic_entries
end

#review_statusString

Output only. Where in the review process this asset is. Corresponds to the JSON property reviewStatus

Returns:

  • (String)


22960
22961
22962
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22960

def review_status
  @review_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22967
22968
22969
22970
22971
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22967

def update!(**args)
  @approval_status = args[:approval_status] if args.key?(:approval_status)
  @policy_topic_entries = args[:policy_topic_entries] if args.key?(:policy_topic_entries)
  @review_status = args[:review_status] if args.key?(:review_status)
end