Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingDataExclusion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a bidding data exclusion. Bidding data exclusions can be set in client accounts only, and cannot be used in manager accounts. See "About data exclusions" at https://support.google.com/google-ads/answer/10370710. Note: A customer account can have a maximum of 500 active bidding data exclusions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBiddingDataExclusion

Returns a new instance of GoogleAdsSearchads360V23ResourcesBiddingDataExclusion.



23520
23521
23522
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23520

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertising_channel_typesArray<String>

The data_exclusion will apply to all the campaigns under the listed channels retroactively as well as going forward when the scope of this exclusion is CHANNEL. The supported advertising channel types are DISPLAY, SEARCH and SHOPPING. Note: a data exclusion with both advertising_channel_types and campaign_ids is not supported. Corresponds to the JSON property advertisingChannelTypes

Returns:

  • (Array<String>)


23457
23458
23459
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23457

def advertising_channel_types
  @advertising_channel_types
end

#campaignsArray<String>

The data exclusion will apply to the campaigns listed when the scope of this exclusion is CAMPAIGN. The maximum number of campaigns per event is 2000. Note: a data exclusion with both advertising_channel_types and campaign_ids is not supported. Corresponds to the JSON property campaigns

Returns:

  • (Array<String>)


23465
23466
23467
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23465

def campaigns
  @campaigns
end

#data_exclusion_idFixnum

Output only. The ID of the data exclusion. Corresponds to the JSON property dataExclusionId

Returns:

  • (Fixnum)


23470
23471
23472
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23470

def data_exclusion_id
  @data_exclusion_id
end

#descriptionString

The description of the data exclusion. The description can be at most 2048 characters. Corresponds to the JSON property description

Returns:

  • (String)


23476
23477
23478
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23476

def description
  @description
end

#devicesArray<String>

If not specified, all devices will be included in this exclusion. Otherwise, only the specified targeted devices will be included in this exclusion. Corresponds to the JSON property devices

Returns:

  • (Array<String>)


23482
23483
23484
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23482

def devices
  @devices
end

#end_date_timeString

Required. The exclusive end time of the data exclusion in yyyy-MM-dd HH:mm:ss format. The length of [start_date_time, end_date_time) interval must be within (0, 14 days]. Corresponds to the JSON property endDateTime

Returns:

  • (String)


23489
23490
23491
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23489

def end_date_time
  @end_date_time
end

#nameString

The name of the data exclusion. The name can be at most 255 characters. Corresponds to the JSON property name

Returns:

  • (String)


23494
23495
23496
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23494

def name
  @name
end

#resource_nameString

Immutable. The resource name of the data exclusion. Data exclusion resource names have the form: customers/customer_id/biddingDataExclusions/ data_exclusion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


23501
23502
23503
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23501

def resource_name
  @resource_name
end

#scopeString

The scope of the data exclusion. Corresponds to the JSON property scope

Returns:

  • (String)


23506
23507
23508
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23506

def scope
  @scope
end

#start_date_timeString

Required. The inclusive start time of the data exclusion in yyyy-MM-dd HH:mm: ss format. A data exclusion is backward looking and should be used for events that start in the past and end either in the past or future. Corresponds to the JSON property startDateTime

Returns:

  • (String)


23513
23514
23515
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23513

def start_date_time
  @start_date_time
end

#statusString

Output only. The status of the data exclusion. Corresponds to the JSON property status

Returns:

  • (String)


23518
23519
23520
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23518

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23525
23526
23527
23528
23529
23530
23531
23532
23533
23534
23535
23536
23537
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23525

def update!(**args)
  @advertising_channel_types = args[:advertising_channel_types] if args.key?(:advertising_channel_types)
  @campaigns = args[:campaigns] if args.key?(:campaigns)
  @data_exclusion_id = args[:data_exclusion_id] if args.key?(:data_exclusion_id)
  @description = args[:description] if args.key?(:description)
  @devices = args[:devices] if args.key?(:devices)
  @end_date_time = args[:end_date_time] if args.key?(:end_date_time)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @scope = args[:scope] if args.key?(:scope)
  @start_date_time = args[:start_date_time] if args.key?(:start_date_time)
  @status = args[:status] if args.key?(:status)
end