Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A bidding strategy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBiddingStrategy

Returns a new instance of GoogleAdsSearchads360V23ResourcesBiddingStrategy.



23762
23763
23764
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aligned_campaign_budget_idFixnum

ID of the campaign budget that this portfolio bidding strategy is aligned with. When a portfolio and a campaign budget are aligned, that means that they are attached to the same set of campaigns. After a bidding strategy is aligned with a campaign budget, campaigns that are added to the bidding strategy must also use the aligned campaign budget. Corresponds to the JSON property alignedCampaignBudgetId

Returns:

  • (Fixnum)


23655
23656
23657
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23655

def aligned_campaign_budget_id
  @aligned_campaign_budget_id
end

#campaign_countFixnum

Output only. The number of campaigns attached to this bidding strategy. This field is read-only. Corresponds to the JSON property campaignCount

Returns:

  • (Fixnum)


23661
23662
23663
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23661

def campaign_count
  @campaign_count
end

#currency_codeString

Immutable. The currency used by the bidding strategy (ISO 4217 three-letter code). For bidding strategies in manager customers, this currency can be set on creation and defaults to the manager customer's currency. For serving customers, this field cannot be set; all strategies in a serving customer implicitly use the serving customer's currency. In all cases the effective_currency_code field returns the currency used by the strategy. Corresponds to the JSON property currencyCode

Returns:

  • (String)


23671
23672
23673
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23671

def currency_code
  @currency_code
end

#effective_currency_codeString

Output only. The currency used by the bidding strategy (ISO 4217 three-letter code). For bidding strategies in manager customers, this is the currency set by the advertiser when creating the strategy. For serving customers, this is the customer's currency_code. Bidding strategy metrics are reported in this currency. This field is read-only. Corresponds to the JSON property effectiveCurrencyCode

Returns:

  • (String)


23680
23681
23682
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23680

def effective_currency_code
  @effective_currency_code
end

#enhanced_cpcGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonEnhancedCpc

An automated bidding strategy that raises bids for clicks that seem more likely to lead to a conversion and lowers them for clicks where they seem less likely. This bidding strategy is deprecated and cannot be created anymore. Use ManualCpc with enhanced_cpc_enabled set to true for equivalent functionality. Corresponds to the JSON property enhancedCpc



23688
23689
23690
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23688

def enhanced_cpc
  @enhanced_cpc
end

#idFixnum

Output only. The ID of the bidding strategy. Corresponds to the JSON property id

Returns:

  • (Fixnum)


23693
23694
23695
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23693

def id
  @id
end

#maximize_conversion_valueGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMaximizeConversionValue

An automated bidding strategy to help get the most conversion value for your campaigns while spending your budget. Corresponds to the JSON property maximizeConversionValue



23699
23700
23701
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23699

def maximize_conversion_value
  @maximize_conversion_value
end

#maximize_conversionsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMaximizeConversions

An automated bidding strategy to help get the most conversions for your campaigns while spending your budget. Corresponds to the JSON property maximizeConversions



23705
23706
23707
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23705

def maximize_conversions
  @maximize_conversions
end

#nameString

The name of the bidding strategy. All bidding strategies within an account must be named distinctly. The length of this string should be between 1 and 255, inclusive, in UTF-8 bytes, (trimmed). Corresponds to the JSON property name

Returns:

  • (String)


23712
23713
23714
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23712

def name
  @name
end

#non_removed_campaign_countFixnum

Output only. The number of non-removed campaigns attached to this bidding strategy. This field is read-only. Corresponds to the JSON property nonRemovedCampaignCount

Returns:

  • (Fixnum)


23718
23719
23720
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23718

def non_removed_campaign_count
  @non_removed_campaign_count
end

#resource_nameString

Immutable. The resource name of the bidding strategy. Bidding strategy resource names have the form: customers/customer_id/biddingStrategies/ bidding_strategy_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


23725
23726
23727
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23725

def resource_name
  @resource_name
end

#statusString

Output only. The status of the bidding strategy. This field is read-only. Corresponds to the JSON property status

Returns:

  • (String)


23730
23731
23732
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23730

def status
  @status
end

#target_cpaGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpa

An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set. Corresponds to the JSON property targetCpa



23736
23737
23738
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23736

def target_cpa
  @target_cpa
end

#target_impression_shareGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetImpressionShare

An automated bidding strategy that sets bids so that a certain percentage of search ads are shown at the top of the first page (or other targeted location). Corresponds to the JSON property targetImpressionShare



23742
23743
23744
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23742

def target_impression_share
  @target_impression_share
end

#target_roasGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoas

An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS). Corresponds to the JSON property targetRoas



23748
23749
23750
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23748

def target_roas
  @target_roas
end

#target_spendGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetSpend

An automated bid strategy that sets your bids to help get as many clicks as possible within your budget. Corresponds to the JSON property targetSpend



23754
23755
23756
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23754

def target_spend
  @target_spend
end

#typeString

Output only. The type of the bidding strategy. Create a bidding strategy by setting the bidding scheme. This field is read-only. Corresponds to the JSON property type

Returns:

  • (String)


23760
23761
23762
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23760

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23767
23768
23769
23770
23771
23772
23773
23774
23775
23776
23777
23778
23779
23780
23781
23782
23783
23784
23785
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23767

def update!(**args)
  @aligned_campaign_budget_id = args[:aligned_campaign_budget_id] if args.key?(:aligned_campaign_budget_id)
  @campaign_count = args[:campaign_count] if args.key?(:campaign_count)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @effective_currency_code = args[:effective_currency_code] if args.key?(:effective_currency_code)
  @enhanced_cpc = args[:enhanced_cpc] if args.key?(:enhanced_cpc)
  @id = args[:id] if args.key?(:id)
  @maximize_conversion_value = args[:maximize_conversion_value] if args.key?(:maximize_conversion_value)
  @maximize_conversions = args[:maximize_conversions] if args.key?(:maximize_conversions)
  @name = args[:name] if args.key?(:name)
  @non_removed_campaign_count = args[:non_removed_campaign_count] if args.key?(:non_removed_campaign_count)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @target_cpa = args[:target_cpa] if args.key?(:target_cpa)
  @target_impression_share = args[:target_impression_share] if args.key?(:target_impression_share)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
  @target_spend = args[:target_spend] if args.key?(:target_spend)
  @type = args[:type] if args.key?(:type)
end