Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A bidding strategy simulation. Supported combinations of simulation type and simulation modification method are detailed below respectively. 1. TARGET_CPA - UNIFORM 2. TARGET_ROAS - UNIFORM
Instance Attribute Summary collapse
-
#bidding_strategy_id ⇒ Fixnum
Output only.
-
#end_date ⇒ String
Output only.
-
#modification_method ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#start_date ⇒ String
Output only.
-
#target_cpa_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpaSimulationPointList
A container for simulation points for simulations of type TARGET_CPA.
-
#target_roas_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoasSimulationPointList
A container for simulation points for simulations of type TARGET_ROAS.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation
Returns a new instance of GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation.
23837 23838 23839 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23837 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bidding_strategy_id ⇒ Fixnum
Output only. Bidding strategy shared set id of the simulation.
Corresponds to the JSON property biddingStrategyId
23797 23798 23799 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23797 def bidding_strategy_id @bidding_strategy_id end |
#end_date ⇒ String
Output only. Last day on which the simulation is based, in YYYY-MM-DD format
Corresponds to the JSON property endDate
23802 23803 23804 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23802 def end_date @end_date end |
#modification_method ⇒ String
Output only. How the simulation modifies the field.
Corresponds to the JSON property modificationMethod
23807 23808 23809 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23807 def modification_method @modification_method end |
#resource_name ⇒ String
Output only. The resource name of the bidding strategy simulation. Bidding
strategy simulation resource names have the form: customers/customer_id/
biddingStrategySimulations/bidding_strategy_id~type~modification_method~
start_date~end_date`
Corresponds to the JSON propertyresourceName`
23815 23816 23817 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23815 def resource_name @resource_name end |
#start_date ⇒ String
Output only. First day on which the simulation is based, in YYYY-MM-DD format.
Corresponds to the JSON property startDate
23820 23821 23822 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23820 def start_date @start_date end |
#target_cpa_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpaSimulationPointList
A container for simulation points for simulations of type TARGET_CPA.
Corresponds to the JSON property targetCpaPointList
23825 23826 23827 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23825 def target_cpa_point_list @target_cpa_point_list end |
#target_roas_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoasSimulationPointList
A container for simulation points for simulations of type TARGET_ROAS.
Corresponds to the JSON property targetRoasPointList
23830 23831 23832 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23830 def target_roas_point_list @target_roas_point_list end |
#type ⇒ String
Output only. The field that the simulation modifies.
Corresponds to the JSON property type
23835 23836 23837 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23835 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23842 23843 23844 23845 23846 23847 23848 23849 23850 23851 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23842 def update!(**args) @bidding_strategy_id = args[:bidding_strategy_id] if args.key?(:bidding_strategy_id) @end_date = args[:end_date] if args.key?(:end_date) @modification_method = args[:modification_method] if args.key?(:modification_method) @resource_name = args[:resource_name] if args.key?(:resource_name) @start_date = args[:start_date] if args.key?(:start_date) @target_cpa_point_list = args[:target_cpa_point_list] if args.key?(:target_cpa_point_list) @target_roas_point_list = args[:target_roas_point_list] if args.key?(:target_roas_point_list) @type = args[:type] if args.key?(:type) end |