Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBillingSetupPaymentsAccountInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Container of payments account information for this billing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBillingSetupPaymentsAccountInfo

Returns a new instance of GoogleAdsSearchads360V23ResourcesBillingSetupPaymentsAccountInfo.



15533
15534
15535
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#payments_account_idString

Output only. A 16 digit id used to identify the payments account associated with the billing setup. This must be passed as a string with dashes, for example, "1234-5678-9012-3456". Corresponds to the JSON property paymentsAccountId

Returns:

  • (String)


15504
15505
15506
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15504

def 
  @payments_account_id
end

#payments_account_nameString

Immutable. The name of the payments account associated with the billing setup. This enables the user to specify a meaningful name for a payments account to aid in reconciling monthly invoices. This name will be printed in the monthly invoices. Corresponds to the JSON property paymentsAccountName

Returns:

  • (String)


15512
15513
15514
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15512

def 
  @payments_account_name
end

#payments_profile_idString

Immutable. A 12 digit id used to identify the payments profile associated with the billing setup. This must be passed in as a string with dashes, for example, "1234-5678-9012". Corresponds to the JSON property paymentsProfileId

Returns:

  • (String)


15519
15520
15521
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15519

def payments_profile_id
  @payments_profile_id
end

#payments_profile_nameString

Output only. The name of the payments profile associated with the billing setup. Corresponds to the JSON property paymentsProfileName

Returns:

  • (String)


15525
15526
15527
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15525

def payments_profile_name
  @payments_profile_name
end

#secondary_payments_profile_idString

Output only. A secondary payments profile id present in uncommon situations, for example, when a sequential liability agreement has been arranged. Corresponds to the JSON property secondaryPaymentsProfileId

Returns:

  • (String)


15531
15532
15533
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15531

def secondary_payments_profile_id
  @secondary_payments_profile_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15538
15539
15540
15541
15542
15543
15544
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15538

def update!(**args)
  @payments_account_id = args[:payments_account_id] if args.key?(:payments_account_id)
  @payments_account_name = args[:payments_account_name] if args.key?(:payments_account_name)
  @payments_profile_id = args[:payments_profile_id] if args.key?(:payments_profile_id)
  @payments_profile_name = args[:payments_profile_name] if args.key?(:payments_profile_name)
  @secondary_payments_profile_id = args[:secondary_payments_profile_id] if args.key?(:secondary_payments_profile_id)
end