Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBusinessRegistrationDocument
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBusinessRegistrationDocument
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
specific to a local services business registration document.
Instance Attribute Summary collapse
-
#document_readonly ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalServicesDocumentReadOnly
A Local Services Document with read only accessible data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBusinessRegistrationDocument
constructor
A new instance of GoogleAdsSearchads360V23ResourcesBusinessRegistrationDocument.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBusinessRegistrationDocument
Returns a new instance of GoogleAdsSearchads360V23ResourcesBusinessRegistrationDocument.
23835 23836 23837 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23835 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_readonly ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalServicesDocumentReadOnly
A Local Services Document with read only accessible data.
Corresponds to the JSON property documentReadonly
23833 23834 23835 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23833 def document_readonly @document_readonly end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23840 23841 23842 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23840 def update!(**args) @document_readonly = args[:document_readonly] if args.key?(:document_readonly) end |