Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCallReportingSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Call reporting setting for a customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCallReportingSetting

Returns a new instance of GoogleAdsSearchads360V23ResourcesCallReportingSetting.



24035
24036
24037
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24035

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_conversion_actionString

Customer-level call conversion action to attribute a call conversion to. If not set a default conversion action is used. Only in effect when call_conversion_reporting_enabled is set to true. Corresponds to the JSON property callConversionAction

Returns:

  • (String)


24020
24021
24022
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24020

def call_conversion_action
  @call_conversion_action
end

#call_conversion_reporting_enabledBoolean Also known as: call_conversion_reporting_enabled?

Whether to enable call conversion reporting. Corresponds to the JSON property callConversionReportingEnabled

Returns:

  • (Boolean)


24025
24026
24027
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24025

def call_conversion_reporting_enabled
  @call_conversion_reporting_enabled
end

#call_reporting_enabledBoolean Also known as: call_reporting_enabled?

Enable reporting of phone call events by redirecting them through Google System. Corresponds to the JSON property callReportingEnabled

Returns:

  • (Boolean)


24032
24033
24034
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24032

def call_reporting_enabled
  @call_reporting_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24040
24041
24042
24043
24044
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24040

def update!(**args)
  @call_conversion_action = args[:call_conversion_action] if args.key?(:call_conversion_action)
  @call_conversion_reporting_enabled = args[:call_conversion_reporting_enabled] if args.key?(:call_conversion_reporting_enabled)
  @call_reporting_enabled = args[:call_reporting_enabled] if args.key?(:call_reporting_enabled)
end