Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCallView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A call view that includes data for call tracking of call-only ads or call extensions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCallView

Returns a new instance of GoogleAdsSearchads360V23ResourcesCallView.



24099
24100
24101
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_duration_secondsFixnum

Output only. The advertiser-provided call duration in seconds. Corresponds to the JSON property callDurationSeconds

Returns:

  • (Fixnum)


24055
24056
24057
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24055

def call_duration_seconds
  @call_duration_seconds
end

#call_statusString

Output only. The status of the call. Corresponds to the JSON property callStatus

Returns:

  • (String)


24060
24061
24062
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24060

def call_status
  @call_status
end

#call_tracking_display_locationString

Output only. The call tracking display location. Corresponds to the JSON property callTrackingDisplayLocation

Returns:

  • (String)


24065
24066
24067
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24065

def call_tracking_display_location
  @call_tracking_display_location
end

#caller_area_codeString

Output only. Area code of the caller. Null if the call duration is shorter than 15 seconds. Corresponds to the JSON property callerAreaCode

Returns:

  • (String)


24071
24072
24073
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24071

def caller_area_code
  @caller_area_code
end

#caller_country_codeString

Output only. code of the caller. Corresponds to the JSON property callerCountryCode

Returns:

  • (String)


24076
24077
24078
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24076

def caller_country_code
  @caller_country_code
end

#end_call_date_timeString

Output only. The advertiser-provided call end date time. Corresponds to the JSON property endCallDateTime

Returns:

  • (String)


24081
24082
24083
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24081

def end_call_date_time
  @end_call_date_time
end

#resource_nameString

Output only. The resource name of the call view. Call view resource names have the form: customers/customer_id/callViews/call_detail_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


24087
24088
24089
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24087

def resource_name
  @resource_name
end

#start_call_date_timeString

Output only. The advertiser-provided call start date time. Corresponds to the JSON property startCallDateTime

Returns:

  • (String)


24092
24093
24094
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24092

def start_call_date_time
  @start_call_date_time
end

#typeString

Output only. The type of the call. Corresponds to the JSON property type

Returns:

  • (String)


24097
24098
24099
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24097

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24104
24105
24106
24107
24108
24109
24110
24111
24112
24113
24114
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24104

def update!(**args)
  @call_duration_seconds = args[:call_duration_seconds] if args.key?(:call_duration_seconds)
  @call_status = args[:call_status] if args.key?(:call_status)
  @call_tracking_display_location = args[:call_tracking_display_location] if args.key?(:call_tracking_display_location)
  @caller_area_code = args[:caller_area_code] if args.key?(:caller_area_code)
  @caller_country_code = args[:caller_country_code] if args.key?(:caller_country_code)
  @end_call_date_time = args[:end_call_date_time] if args.key?(:end_call_date_time)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @start_call_date_time = args[:start_call_date_time] if args.key?(:start_call_date_time)
  @type = args[:type] if args.key?(:type)
end