Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaign
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaign
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A campaign.
Instance Attribute Summary collapse
-
#accessible_bidding_strategy ⇒ String
Output only.
-
#ad_serving_optimization_status ⇒ String
The ad serving optimization status of the campaign.
-
#advertising_channel_sub_type ⇒ String
Immutable.
-
#advertising_channel_type ⇒ String
Immutable.
-
#ai_max_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAiMaxSetting
Settings for AI Max in search campaigns.
-
#app_campaign_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAppCampaignSetting
Campaign-level settings for App Campaigns.
-
#asset_automation_settings ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAssetAutomationSetting>
Contains the opt-in/out status of each AssetAutomationType.
-
#audience_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAudienceSetting
Settings for the audience targeting.
-
#base_campaign ⇒ String
Output only.
-
#bidding_strategy ⇒ String
The resource name of the portfolio bidding strategy used by the campaign.
-
#bidding_strategy_system_status ⇒ String
Output only.
-
#bidding_strategy_type ⇒ String
Output only.
-
#brand_guidelines ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBrandGuidelines
Settings that control the visual appearance of your brand in a campaign's automatically generated assets and formats.
-
#brand_guidelines_enabled ⇒ Boolean
(also: #brand_guidelines_enabled?)
Immutable.
-
#campaign_budget ⇒ String
The resource name of the campaign budget of the campaign.
-
#campaign_group ⇒ String
The resource name of the campaign group that this campaign belongs to.
-
#commission ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCommission
Commission is an automatic bidding strategy in which the advertiser pays a certain portion of the conversion value.
-
#contains_eu_political_advertising ⇒ String
The advertiser should self-declare whether this campaign contains political advertising content targeted towards the European Union.
-
#demand_gen_campaign_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDemandGenCampaignSettings
Settings for Demand Gen campaign.
-
#dynamic_search_ads_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDynamicSearchAdsSetting
The setting for controlling Dynamic Search Ads (DSA).
-
#effective_labels ⇒ Array<String>
Output only.
-
#end_date_time ⇒ String
The last day and time of the campaign in serving customer's timezone in "yyyy- MM-dd HH:mm:ss" format.
-
#engine_id ⇒ String
Output only.
-
#excluded_parent_asset_field_types ⇒ Array<String>
The asset field types that should be excluded from this campaign.
-
#excluded_parent_asset_set_types ⇒ Array<String>
The asset set types that should be excluded from this campaign.
-
#experiment_type ⇒ String
Output only.
-
#feed_types ⇒ Array<String>
Output only.
-
#final_url_suffix ⇒ String
Suffix used to append query parameters to landing pages that are served with parallel tracking.
-
#frequency_caps ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFrequencyCapEntry>
A list that limits how often each user will see this campaign's ads.
-
#geo_target_type_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGeoTargetTypeSetting
Represents a collection of settings related to ads geotargeting.
-
#hotel_property_asset_set ⇒ String
Immutable.
-
#hotel_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignHotelSettingInfo
Campaign-level settings for hotel ads.
-
#id ⇒ Fixnum
Output only.
-
#keyword_match_type ⇒ String
Keyword match type of Campaign.
-
#labels ⇒ Array<String>
Output only.
-
#last_modified_time ⇒ String
Output only.
-
#listing_type ⇒ String
Immutable.
-
#local_campaign_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignLocalCampaignSetting
Campaign setting for local campaigns.
-
#local_services_campaign_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignLocalServicesCampaignSettings
Settings for LocalServicesCampaign subresource.
-
#manual_cpa ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonManualCpa
Manual bidding strategy that allows advertiser to set the bid per advertiser- specified action.
-
#manual_cpc ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonManualCpc
Manual click-based bidding where user pays per click.
-
#manual_cpm ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonManualCpm
Manual impression-based bidding where user pays per thousand impressions.
-
#manual_cpv ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonManualCpv
View based bidding where user pays per video view.
-
#maximize_conversion_value ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMaximizeConversionValue
An automated bidding strategy to help get the most conversion value for your campaigns while spending your budget.
-
#maximize_conversions ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMaximizeConversions
An automated bidding strategy to help get the most conversions for your campaigns while spending your budget.
-
#missing_eu_political_advertising_declaration ⇒ Boolean
(also: #missing_eu_political_advertising_declaration?)
Output only.
-
#name ⇒ String
The name of the campaign.
-
#network_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignNetworkSettings
The network settings for the campaign.
-
#optimization_goal_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignOptimizationGoalSetting
Optimization goal setting for this campaign, which includes a set of optimization goal types.
-
#optimization_score ⇒ Float
Output only.
-
#payment_mode ⇒ String
Payment mode for the campaign.
-
#percent_cpc ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPercentCpc
A bidding strategy where bids are a fraction of the advertised price for some good or service.
-
#performance_max_upgrade ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignPerformanceMaxUpgrade
Information about a campaign being upgraded to Performance Max.
-
#pmax_campaign_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignPmaxCampaignSettings
Settings for Performance Max campaigns.
-
#primary_status ⇒ String
Output only.
-
#primary_status_reasons ⇒ Array<String>
Output only.
-
#real_time_bidding_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonRealTimeBiddingSetting
Settings for Real-Time Bidding, a feature only available for campaigns targeting the Ad Exchange network.
-
#resource_name ⇒ String
Immutable.
-
#selective_optimization ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSelectiveOptimization
Selective optimization setting for this campaign, which includes a set of conversion actions to optimize this campaign towards.
-
#selective_optimization_mode ⇒ String
Selective optimization mode for this campaign.
-
#serving_status ⇒ String
Output only.
-
#shopping_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting
The setting for Shopping campaigns.
-
#start_date_time ⇒ String
The date and time when campaign started in serving.
-
#status ⇒ String
The status of the campaign.
-
#target_cpa ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpa
An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set.
-
#target_cpc ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpc
An automated bidding strategy that sets bids to help get as many clicks as possible at the target cost-per-click (CPC) you set.
-
#target_cpm ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpm
Target CPM (cost per thousand impressions) is an automated bidding strategy that sets bids to optimize performance given the target CPM you set.
-
#target_impression_share ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetImpressionShare
An automated bidding strategy that sets bids so that a certain percentage of search ads are shown at the top of the first page (or other targeted location).
-
#target_roas ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoas
An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS).
-
#target_spend ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetSpend
An automated bid strategy that sets your bids to help get as many clicks as possible within your budget.
-
#targeting_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetingSetting
Settings for the targeting-related features, at the campaign and ad group levels.
-
#third_party_integration_partners ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCampaignThirdPartyIntegrationPartners
Container for Campaign level third party integration partners.
-
#tracking_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignTrackingSetting
Campaign-level settings for tracking information.
-
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
-
#travel_campaign_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignTravelCampaignSettings
Settings for Travel campaign.
-
#url_custom_parameters ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>
The list of mappings used to substitute custom parameter tags in a
tracking_url_template,final_urls, ormobile_final_urls. -
#vanity_pharma ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignVanityPharma
Describes how unbranded pharma ads will be displayed.
-
#video_brand_safety_suitability ⇒ String
Brand Safety setting at the individual campaign level.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaign
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaign.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaign
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaign.
24601 24602 24603 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24601 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accessible_bidding_strategy ⇒ String
Output only. Resource name of AccessibleBiddingStrategy, a read-only view of
the unrestricted attributes of the attached portfolio bidding strategy
identified by 'bidding_strategy'. Empty, if the campaign does not use a
portfolio strategy. Unrestricted strategy attributes are available to all
customers with whom the strategy is shared and are read from the
AccessibleBiddingStrategy resource. In contrast, restricted attributes are
only available to the owner customer of the strategy and their managers.
Restricted attributes can only be read from the BiddingStrategy resource.
Corresponds to the JSON property accessibleBiddingStrategy
24131 24132 24133 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24131 def accessible_bidding_strategy @accessible_bidding_strategy end |
#ad_serving_optimization_status ⇒ String
The ad serving optimization status of the campaign.
Corresponds to the JSON property adServingOptimizationStatus
24136 24137 24138 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24136 def ad_serving_optimization_status @ad_serving_optimization_status end |
#advertising_channel_sub_type ⇒ String
Immutable. Optional refinement to advertising_channel_type. Must be a valid
sub-type of the parent channel type. Can be set only when creating campaigns.
After campaign is created, the field can not be changed.
Corresponds to the JSON property advertisingChannelSubType
24143 24144 24145 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24143 def advertising_channel_sub_type @advertising_channel_sub_type end |
#advertising_channel_type ⇒ String
Immutable. The primary serving target for ads within the campaign. The
targeting options can be refined in network_settings. This field is required
and should not be empty when creating new campaigns. Can be set only when
creating campaigns. After the campaign is created, the field can not be
changed.
Corresponds to the JSON property advertisingChannelType
24152 24153 24154 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24152 def advertising_channel_type @advertising_channel_type end |
#ai_max_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAiMaxSetting
Settings for AI Max in search campaigns.
Corresponds to the JSON property aiMaxSetting
24157 24158 24159 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24157 def ai_max_setting @ai_max_setting end |
#app_campaign_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAppCampaignSetting
Campaign-level settings for App Campaigns.
Corresponds to the JSON property appCampaignSetting
24162 24163 24164 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24162 def app_campaign_setting @app_campaign_setting end |
#asset_automation_settings ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAssetAutomationSetting>
Contains the opt-in/out status of each AssetAutomationType. See documentation
of each asset automation type enum for default opt in/out behavior.
Corresponds to the JSON property assetAutomationSettings
24168 24169 24170 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24168 def asset_automation_settings @asset_automation_settings end |
#audience_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAudienceSetting
Settings for the audience targeting.
Corresponds to the JSON property audienceSetting
24173 24174 24175 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24173 def audience_setting @audience_setting end |
#base_campaign ⇒ String
Output only. The resource name of the base campaign of a draft or experiment
campaign. For base campaigns, this is equal to resource_name. This field is
read-only.
Corresponds to the JSON property baseCampaign
24180 24181 24182 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24180 def base_campaign @base_campaign end |
#bidding_strategy ⇒ String
The resource name of the portfolio bidding strategy used by the campaign.
Corresponds to the JSON property biddingStrategy
24185 24186 24187 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24185 def bidding_strategy @bidding_strategy end |
#bidding_strategy_system_status ⇒ String
Output only. The system status of the campaign's bidding strategy.
Corresponds to the JSON property biddingStrategySystemStatus
24190 24191 24192 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24190 def bidding_strategy_system_status @bidding_strategy_system_status end |
#bidding_strategy_type ⇒ String
Output only. The type of bidding strategy. A bidding strategy can be created
by setting either the bidding scheme to create a standard bidding strategy or
the bidding_strategy field to create a portfolio bidding strategy. This
field is read-only.
Corresponds to the JSON property biddingStrategyType
24198 24199 24200 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24198 def bidding_strategy_type @bidding_strategy_type end |
#brand_guidelines ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBrandGuidelines
Settings that control the visual appearance of your brand in a campaign's
automatically generated assets and formats. Only applicable to Performance Max
campaigns.
Corresponds to the JSON property brandGuidelines
24205 24206 24207 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24205 def brand_guidelines @brand_guidelines end |
#brand_guidelines_enabled ⇒ Boolean Also known as: brand_guidelines_enabled?
Immutable. Whether Brand Guidelines are enabled for this Campaign. Only
applicable to Performance Max campaigns. If enabled, business name and logo
assets must be linked as CampaignAssets instead of AssetGroupAssets.
Corresponds to the JSON property brandGuidelinesEnabled
24212 24213 24214 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24212 def brand_guidelines_enabled @brand_guidelines_enabled end |
#campaign_budget ⇒ String
The resource name of the campaign budget of the campaign.
Corresponds to the JSON property campaignBudget
24218 24219 24220 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24218 def campaign_budget @campaign_budget end |
#campaign_group ⇒ String
The resource name of the campaign group that this campaign belongs to.
Corresponds to the JSON property campaignGroup
24223 24224 24225 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24223 def campaign_group @campaign_group end |
#commission ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCommission
Commission is an automatic bidding strategy in which the advertiser pays a
certain portion of the conversion value.
Corresponds to the JSON property commission
24229 24230 24231 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24229 def commission @commission end |
#contains_eu_political_advertising ⇒ String
The advertiser should self-declare whether this campaign contains political
advertising content targeted towards the European Union.
Corresponds to the JSON property containsEuPoliticalAdvertising
24235 24236 24237 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24235 def contains_eu_political_advertising @contains_eu_political_advertising end |
#demand_gen_campaign_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDemandGenCampaignSettings
Settings for Demand Gen campaign.
Corresponds to the JSON property demandGenCampaignSettings
24240 24241 24242 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24240 def demand_gen_campaign_settings @demand_gen_campaign_settings end |
#dynamic_search_ads_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDynamicSearchAdsSetting
The setting for controlling Dynamic Search Ads (DSA).
Corresponds to the JSON property dynamicSearchAdsSetting
24245 24246 24247 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24245 def dynamic_search_ads_setting @dynamic_search_ads_setting end |
#effective_labels ⇒ Array<String>
Output only. The resource names of effective labels attached to this campaign.
An effective label is a label inherited or directly assigned to this campaign.
Corresponds to the JSON property effectiveLabels
24251 24252 24253 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24251 def effective_labels @effective_labels end |
#end_date_time ⇒ String
The last day and time of the campaign in serving customer's timezone in "yyyy-
MM-dd HH:mm:ss" format. Set the time component to 23:59:59 for daily
granularity, time granularity is only supported for some campaign types. On
create, defaults to running indefinitely. To set an existing campaign to run
indefinitely, clear this field.
Corresponds to the JSON property endDateTime
24260 24261 24262 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24260 def end_date_time @end_date_time end |
#engine_id ⇒ String
Output only. ID of the campaign in the external engine account. This field is
for non-Google Ads account only, for example, Yahoo Japan, Microsoft, Baidu
etc. For Google Ads entity, use "campaign.id" instead.
Corresponds to the JSON property engineId
24267 24268 24269 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24267 def engine_id @engine_id end |
#excluded_parent_asset_field_types ⇒ Array<String>
The asset field types that should be excluded from this campaign. Asset links
with these field types will not be inherited by this campaign from the upper
level.
Corresponds to the JSON property excludedParentAssetFieldTypes
24274 24275 24276 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24274 def excluded_parent_asset_field_types @excluded_parent_asset_field_types end |
#excluded_parent_asset_set_types ⇒ Array<String>
The asset set types that should be excluded from this campaign. Asset set
links with these types will not be inherited by this campaign from the upper
level. Location group types (GMB_DYNAMIC_LOCATION_GROUP,
CHAIN_DYNAMIC_LOCATION_GROUP, and STATIC_LOCATION_GROUP) are child types of
LOCATION_SYNC. Therefore, if LOCATION_SYNC is set for this field, all location
group asset sets are not allowed to be linked to this campaign, and all
Location Extension (LE) and Affiliate Location Extensions (ALE) will not be
served under this campaign. Only LOCATION_SYNC is currently supported.
Corresponds to the JSON property excludedParentAssetSetTypes
24286 24287 24288 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24286 def excluded_parent_asset_set_types @excluded_parent_asset_set_types end |
#experiment_type ⇒ String
Output only. The type of campaign: normal, draft, or experiment.
Corresponds to the JSON property experimentType
24291 24292 24293 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24291 def experiment_type @experiment_type end |
#feed_types ⇒ Array<String>
Output only. Types of feeds that are attached directly to this campaign.
Corresponds to the JSON property feedTypes
24296 24297 24298 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24296 def feed_types @feed_types end |
#final_url_suffix ⇒ String
Suffix used to append query parameters to landing pages that are served with
parallel tracking.
Corresponds to the JSON property finalUrlSuffix
24302 24303 24304 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24302 def final_url_suffix @final_url_suffix end |
#frequency_caps ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFrequencyCapEntry>
A list that limits how often each user will see this campaign's ads.
Corresponds to the JSON property frequencyCaps
24307 24308 24309 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24307 def frequency_caps @frequency_caps end |
#geo_target_type_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGeoTargetTypeSetting
Represents a collection of settings related to ads geotargeting.
Corresponds to the JSON property geoTargetTypeSetting
24312 24313 24314 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24312 def geo_target_type_setting @geo_target_type_setting end |
#hotel_property_asset_set ⇒ String
Immutable. The resource name for a set of hotel properties for Performance Max
for travel goals campaigns.
Corresponds to the JSON property hotelPropertyAssetSet
24318 24319 24320 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24318 def hotel_property_asset_set @hotel_property_asset_set end |
#hotel_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignHotelSettingInfo
Campaign-level settings for hotel ads.
Corresponds to the JSON property hotelSetting
24323 24324 24325 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24323 def hotel_setting @hotel_setting end |
#id ⇒ Fixnum
Output only. The ID of the campaign.
Corresponds to the JSON property id
24328 24329 24330 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24328 def id @id end |
#keyword_match_type ⇒ String
Keyword match type of Campaign. Set to BROAD to set broad matching for all
keywords in a campaign.
Corresponds to the JSON property keywordMatchType
24334 24335 24336 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24334 def keyword_match_type @keyword_match_type end |
#labels ⇒ Array<String>
Output only. The resource names of labels attached to this campaign.
Corresponds to the JSON property labels
24339 24340 24341 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24339 def labels @labels end |
#last_modified_time ⇒ String
Output only. The datetime when this campaign was last modified. The datetime
is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format.
Corresponds to the JSON property lastModifiedTime
24345 24346 24347 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24345 def last_modified_time @last_modified_time end |
#listing_type ⇒ String
Immutable. Listing type of ads served for this campaign. Field is restricted
for usage with Performance Max campaigns.
Corresponds to the JSON property listingType
24351 24352 24353 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24351 def listing_type @listing_type end |
#local_campaign_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignLocalCampaignSetting
Campaign setting for local campaigns.
Corresponds to the JSON property localCampaignSetting
24356 24357 24358 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24356 def local_campaign_setting @local_campaign_setting end |
#local_services_campaign_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignLocalServicesCampaignSettings
Settings for LocalServicesCampaign subresource.
Corresponds to the JSON property localServicesCampaignSettings
24361 24362 24363 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24361 def local_services_campaign_settings @local_services_campaign_settings end |
#manual_cpa ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonManualCpa
Manual bidding strategy that allows advertiser to set the bid per advertiser-
specified action.
Corresponds to the JSON property manualCpa
24367 24368 24369 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24367 def manual_cpa @manual_cpa end |
#manual_cpc ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonManualCpc
Manual click-based bidding where user pays per click.
Corresponds to the JSON property manualCpc
24372 24373 24374 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24372 def manual_cpc @manual_cpc end |
#manual_cpm ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonManualCpm
Manual impression-based bidding where user pays per thousand impressions.
Corresponds to the JSON property manualCpm
24377 24378 24379 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24377 def manual_cpm @manual_cpm end |
#manual_cpv ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonManualCpv
View based bidding where user pays per video view.
Corresponds to the JSON property manualCpv
24382 24383 24384 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24382 def manual_cpv @manual_cpv end |
#maximize_conversion_value ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMaximizeConversionValue
An automated bidding strategy to help get the most conversion value for your
campaigns while spending your budget.
Corresponds to the JSON property maximizeConversionValue
24388 24389 24390 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24388 def maximize_conversion_value @maximize_conversion_value end |
#maximize_conversions ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMaximizeConversions
An automated bidding strategy to help get the most conversions for your
campaigns while spending your budget.
Corresponds to the JSON property maximizeConversions
24394 24395 24396 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24394 def maximize_conversions @maximize_conversions end |
#missing_eu_political_advertising_declaration ⇒ Boolean Also known as: missing_eu_political_advertising_declaration?
Output only. Indicates whether this campaign is missing a declaration about
whether it contains political advertising targeted towards the EU and is
ineligible for any exemptions. If this field is true, use the
contains_eu_political_advertising field to add the required declaration. This
field is read-only.
Corresponds to the JSON property missingEuPoliticalAdvertisingDeclaration
24403 24404 24405 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24403 def missing_eu_political_advertising_declaration @missing_eu_political_advertising_declaration end |
#name ⇒ String
The name of the campaign. This field is required and should not be empty when
creating new campaigns. It must not contain any null (code point 0x0), NL line
feed (code point 0xA) or carriage return (code point 0xD) characters.
Corresponds to the JSON property name
24411 24412 24413 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24411 def name @name end |
#network_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignNetworkSettings
The network settings for the campaign.
Corresponds to the JSON property networkSettings
24416 24417 24418 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24416 def network_settings @network_settings end |
#optimization_goal_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignOptimizationGoalSetting
Optimization goal setting for this campaign, which includes a set of
optimization goal types.
Corresponds to the JSON property optimizationGoalSetting
24422 24423 24424 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24422 def optimization_goal_setting @optimization_goal_setting end |
#optimization_score ⇒ Float
Output only. Optimization score of the campaign. Optimization score is an
estimate of how well a campaign is set to perform. It ranges from 0% (0.0) to
100% (1.0), with 100% indicating that the campaign is performing at full
potential. This field is null for unscored campaigns. See "About optimization
score" at https://support.google.com/google-ads/answer/9061546. This field is
read-only.
Corresponds to the JSON property optimizationScore
24432 24433 24434 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24432 def optimization_score @optimization_score end |
#payment_mode ⇒ String
Payment mode for the campaign.
Corresponds to the JSON property paymentMode
24437 24438 24439 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24437 def payment_mode @payment_mode end |
#percent_cpc ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPercentCpc
A bidding strategy where bids are a fraction of the advertised price for some
good or service.
Corresponds to the JSON property percentCpc
24443 24444 24445 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24443 def percent_cpc @percent_cpc end |
#performance_max_upgrade ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignPerformanceMaxUpgrade
Information about a campaign being upgraded to Performance Max.
Corresponds to the JSON property performanceMaxUpgrade
24448 24449 24450 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24448 def performance_max_upgrade @performance_max_upgrade end |
#pmax_campaign_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignPmaxCampaignSettings
Settings for Performance Max campaigns.
Corresponds to the JSON property pmaxCampaignSettings
24453 24454 24455 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24453 def pmax_campaign_settings @pmax_campaign_settings end |
#primary_status ⇒ String
Output only. The primary status of the campaign. Provides insight into why a
campaign is not serving or not serving optimally. Modification to the campaign
and its related entities might take a while to be reflected in this status.
Corresponds to the JSON property primaryStatus
24460 24461 24462 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24460 def primary_status @primary_status end |
#primary_status_reasons ⇒ Array<String>
Output only. The primary status reasons of the campaign. Provides insight into
why a campaign is not serving or not serving optimally. These reasons are
aggregated to determine an overall CampaignPrimaryStatus.
Corresponds to the JSON property primaryStatusReasons
24467 24468 24469 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24467 def primary_status_reasons @primary_status_reasons end |
#real_time_bidding_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonRealTimeBiddingSetting
Settings for Real-Time Bidding, a feature only available for campaigns
targeting the Ad Exchange network.
Corresponds to the JSON property realTimeBiddingSetting
24473 24474 24475 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24473 def real_time_bidding_setting @real_time_bidding_setting end |
#resource_name ⇒ String
Immutable. The resource name of the campaign. Campaign resource names have the
form: customers/customer_id/campaigns/campaign_id`
Corresponds to the JSON propertyresourceName`
24479 24480 24481 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24479 def resource_name @resource_name end |
#selective_optimization ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSelectiveOptimization
Selective optimization setting for this campaign, which includes a set of
conversion actions to optimize this campaign towards. This feature only
applies to app campaigns that use MULTI_CHANNEL as AdvertisingChannelType and
APP_CAMPAIGN or APP_CAMPAIGN_FOR_ENGAGEMENT as AdvertisingChannelSubType.
Corresponds to the JSON property selectiveOptimization
24487 24488 24489 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24487 def selective_optimization @selective_optimization end |
#selective_optimization_mode ⇒ String
Selective optimization mode for this campaign.
Corresponds to the JSON property selectiveOptimizationMode
24492 24493 24494 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24492 def selective_optimization_mode @selective_optimization_mode end |
#serving_status ⇒ String
Output only. The ad serving status of the campaign.
Corresponds to the JSON property servingStatus
24497 24498 24499 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24497 def serving_status @serving_status end |
#shopping_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting
The setting for Shopping campaigns. Defines the universe of products that can
be advertised by the campaign, and how this campaign interacts with other
Shopping campaigns.
Corresponds to the JSON property shoppingSetting
24504 24505 24506 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24504 def shopping_setting @shopping_setting end |
#start_date_time ⇒ String
The date and time when campaign started in serving. The timestamp is in the
customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. Set the time
component to 00:00:00 for daily granularity, time granularity is only
supported for some campaign types.
Corresponds to the JSON property startDateTime
24512 24513 24514 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24512 def start_date_time @start_date_time end |
#status ⇒ String
The status of the campaign. When a new campaign is added, the status defaults
to ENABLED.
Corresponds to the JSON property status
24518 24519 24520 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24518 def status @status end |
#target_cpa ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpa
An automated bid strategy that sets bids to help get as many conversions as
possible at the target cost-per-acquisition (CPA) you set.
Corresponds to the JSON property targetCpa
24524 24525 24526 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24524 def target_cpa @target_cpa end |
#target_cpc ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpc
An automated bidding strategy that sets bids to help get as many clicks as
possible at the target cost-per-click (CPC) you set.
Corresponds to the JSON property targetCpc
24530 24531 24532 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24530 def target_cpc @target_cpc end |
#target_cpm ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpm
Target CPM (cost per thousand impressions) is an automated bidding strategy
that sets bids to optimize performance given the target CPM you set.
Corresponds to the JSON property targetCpm
24536 24537 24538 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24536 def target_cpm @target_cpm end |
#target_impression_share ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetImpressionShare
An automated bidding strategy that sets bids so that a certain percentage of
search ads are shown at the top of the first page (or other targeted location).
Corresponds to the JSON property targetImpressionShare
24542 24543 24544 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24542 def target_impression_share @target_impression_share end |
#target_roas ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoas
An automated bidding strategy that helps you maximize revenue while averaging
a specific target return on ad spend (ROAS).
Corresponds to the JSON property targetRoas
24548 24549 24550 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24548 def target_roas @target_roas end |
#target_spend ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetSpend
An automated bid strategy that sets your bids to help get as many clicks as
possible within your budget.
Corresponds to the JSON property targetSpend
24554 24555 24556 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24554 def target_spend @target_spend end |
#targeting_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetingSetting
Settings for the targeting-related features, at the campaign and ad group
levels. For more details about the targeting setting, visit https://support.
google.com/google-ads/answer/7365594
Corresponds to the JSON property targetingSetting
24561 24562 24563 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24561 def targeting_setting @targeting_setting end |
#third_party_integration_partners ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCampaignThirdPartyIntegrationPartners
Container for Campaign level third party integration partners.
Corresponds to the JSON property thirdPartyIntegrationPartners
24566 24567 24568 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24566 def third_party_integration_partners @third_party_integration_partners end |
#tracking_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignTrackingSetting
Campaign-level settings for tracking information.
Corresponds to the JSON property trackingSetting
24571 24572 24573 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24571 def tracking_setting @tracking_setting end |
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
Corresponds to the JSON property trackingUrlTemplate
24576 24577 24578 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24576 def tracking_url_template @tracking_url_template end |
#travel_campaign_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignTravelCampaignSettings
Settings for Travel campaign.
Corresponds to the JSON property travelCampaignSettings
24581 24582 24583 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24581 def travel_campaign_settings @travel_campaign_settings end |
#url_custom_parameters ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>
The list of mappings used to substitute custom parameter tags in a
tracking_url_template, final_urls, or mobile_final_urls.
Corresponds to the JSON property urlCustomParameters
24587 24588 24589 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24587 def url_custom_parameters @url_custom_parameters end |
#vanity_pharma ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignVanityPharma
Describes how unbranded pharma ads will be displayed.
Corresponds to the JSON property vanityPharma
24592 24593 24594 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24592 def vanity_pharma @vanity_pharma end |
#video_brand_safety_suitability ⇒ String
Brand Safety setting at the individual campaign level. Allows for selecting an
inventory type to show your ads on content that is the right fit for your
brand. See https://support.google.com/google-ads/answer/7515513.
Corresponds to the JSON property videoBrandSafetySuitability
24599 24600 24601 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24599 def video_brand_safety_suitability @video_brand_safety_suitability end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24606 24607 24608 24609 24610 24611 24612 24613 24614 24615 24616 24617 24618 24619 24620 24621 24622 24623 24624 24625 24626 24627 24628 24629 24630 24631 24632 24633 24634 24635 24636 24637 24638 24639 24640 24641 24642 24643 24644 24645 24646 24647 24648 24649 24650 24651 24652 24653 24654 24655 24656 24657 24658 24659 24660 24661 24662 24663 24664 24665 24666 24667 24668 24669 24670 24671 24672 24673 24674 24675 24676 24677 24678 24679 24680 24681 24682 24683 24684 24685 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24606 def update!(**args) @accessible_bidding_strategy = args[:accessible_bidding_strategy] if args.key?(:accessible_bidding_strategy) @ad_serving_optimization_status = args[:ad_serving_optimization_status] if args.key?(:ad_serving_optimization_status) @advertising_channel_sub_type = args[:advertising_channel_sub_type] if args.key?(:advertising_channel_sub_type) @advertising_channel_type = args[:advertising_channel_type] if args.key?(:advertising_channel_type) @ai_max_setting = args[:ai_max_setting] if args.key?(:ai_max_setting) @app_campaign_setting = args[:app_campaign_setting] if args.key?(:app_campaign_setting) @asset_automation_settings = args[:asset_automation_settings] if args.key?(:asset_automation_settings) @audience_setting = args[:audience_setting] if args.key?(:audience_setting) @base_campaign = args[:base_campaign] if args.key?(:base_campaign) @bidding_strategy = args[:bidding_strategy] if args.key?(:bidding_strategy) @bidding_strategy_system_status = args[:bidding_strategy_system_status] if args.key?(:bidding_strategy_system_status) @bidding_strategy_type = args[:bidding_strategy_type] if args.key?(:bidding_strategy_type) @brand_guidelines = args[:brand_guidelines] if args.key?(:brand_guidelines) @brand_guidelines_enabled = args[:brand_guidelines_enabled] if args.key?(:brand_guidelines_enabled) @campaign_budget = args[:campaign_budget] if args.key?(:campaign_budget) @campaign_group = args[:campaign_group] if args.key?(:campaign_group) @commission = args[:commission] if args.key?(:commission) @contains_eu_political_advertising = args[:contains_eu_political_advertising] if args.key?(:contains_eu_political_advertising) @demand_gen_campaign_settings = args[:demand_gen_campaign_settings] if args.key?(:demand_gen_campaign_settings) @dynamic_search_ads_setting = args[:dynamic_search_ads_setting] if args.key?(:dynamic_search_ads_setting) @effective_labels = args[:effective_labels] if args.key?(:effective_labels) @end_date_time = args[:end_date_time] if args.key?(:end_date_time) @engine_id = args[:engine_id] if args.key?(:engine_id) @excluded_parent_asset_field_types = args[:excluded_parent_asset_field_types] if args.key?(:excluded_parent_asset_field_types) @excluded_parent_asset_set_types = args[:excluded_parent_asset_set_types] if args.key?(:excluded_parent_asset_set_types) @experiment_type = args[:experiment_type] if args.key?(:experiment_type) @feed_types = args[:feed_types] if args.key?(:feed_types) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @frequency_caps = args[:frequency_caps] if args.key?(:frequency_caps) @geo_target_type_setting = args[:geo_target_type_setting] if args.key?(:geo_target_type_setting) @hotel_property_asset_set = args[:hotel_property_asset_set] if args.key?(:hotel_property_asset_set) @hotel_setting = args[:hotel_setting] if args.key?(:hotel_setting) @id = args[:id] if args.key?(:id) @keyword_match_type = args[:keyword_match_type] if args.key?(:keyword_match_type) @labels = args[:labels] if args.key?(:labels) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @listing_type = args[:listing_type] if args.key?(:listing_type) @local_campaign_setting = args[:local_campaign_setting] if args.key?(:local_campaign_setting) @local_services_campaign_settings = args[:local_services_campaign_settings] if args.key?(:local_services_campaign_settings) @manual_cpa = args[:manual_cpa] if args.key?(:manual_cpa) @manual_cpc = args[:manual_cpc] if args.key?(:manual_cpc) @manual_cpm = args[:manual_cpm] if args.key?(:manual_cpm) @manual_cpv = args[:manual_cpv] if args.key?(:manual_cpv) @maximize_conversion_value = args[:maximize_conversion_value] if args.key?(:maximize_conversion_value) @maximize_conversions = args[:maximize_conversions] if args.key?(:maximize_conversions) @missing_eu_political_advertising_declaration = args[:missing_eu_political_advertising_declaration] if args.key?(:missing_eu_political_advertising_declaration) @name = args[:name] if args.key?(:name) @network_settings = args[:network_settings] if args.key?(:network_settings) @optimization_goal_setting = args[:optimization_goal_setting] if args.key?(:optimization_goal_setting) @optimization_score = args[:optimization_score] if args.key?(:optimization_score) @payment_mode = args[:payment_mode] if args.key?(:payment_mode) @percent_cpc = args[:percent_cpc] if args.key?(:percent_cpc) @performance_max_upgrade = args[:performance_max_upgrade] if args.key?(:performance_max_upgrade) @pmax_campaign_settings = args[:pmax_campaign_settings] if args.key?(:pmax_campaign_settings) @primary_status = args[:primary_status] if args.key?(:primary_status) @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons) @real_time_bidding_setting = args[:real_time_bidding_setting] if args.key?(:real_time_bidding_setting) @resource_name = args[:resource_name] if args.key?(:resource_name) @selective_optimization = args[:selective_optimization] if args.key?(:selective_optimization) @selective_optimization_mode = args[:selective_optimization_mode] if args.key?(:selective_optimization_mode) @serving_status = args[:serving_status] if args.key?(:serving_status) @shopping_setting = args[:shopping_setting] if args.key?(:shopping_setting) @start_date_time = args[:start_date_time] if args.key?(:start_date_time) @status = args[:status] if args.key?(:status) @target_cpa = args[:target_cpa] if args.key?(:target_cpa) @target_cpc = args[:target_cpc] if args.key?(:target_cpc) @target_cpm = args[:target_cpm] if args.key?(:target_cpm) @target_impression_share = args[:target_impression_share] if args.key?(:target_impression_share) @target_roas = args[:target_roas] if args.key?(:target_roas) @target_spend = args[:target_spend] if args.key?(:target_spend) @targeting_setting = args[:targeting_setting] if args.key?(:targeting_setting) @third_party_integration_partners = args[:third_party_integration_partners] if args.key?(:third_party_integration_partners) @tracking_setting = args[:tracking_setting] if args.key?(:tracking_setting) @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template) @travel_campaign_settings = args[:travel_campaign_settings] if args.key?(:travel_campaign_settings) @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters) @vanity_pharma = args[:vanity_pharma] if args.key?(:vanity_pharma) @video_brand_safety_suitability = args[:video_brand_safety_suitability] if args.key?(:video_brand_safety_suitability) end |