Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAiMaxSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Settings for AI Max in search campaigns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignAiMaxSetting

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignAiMaxSetting.



15529
15530
15531
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15529

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bundling_requiredString

Output only. Indicates whether a search campaign has adopted AI Max before, and is required to have AI Max enabled to adopt campaign-level text asset automation and brand list targeting in all API versions. Corresponds to the JSON property bundlingRequired

Returns:

  • (String)


15516
15517
15518
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15516

def bundling_required
  @bundling_required
end

#enable_ai_maxBoolean Also known as: enable_ai_max?

Controls whether or not AI Max features are served for this campaign. Individual AI Max features are enabled or disabled by their respective settings. But if enable_ai_max is set to false or cleared, then no AI Max features will serve for this campaign, regardless of the other settings. Search Term Matching is enabled by default when AI Max is enabled, and can be disabled at the ad group level. Corresponds to the JSON property enableAiMax

Returns:

  • (Boolean)


15526
15527
15528
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15526

def enable_ai_max
  @enable_ai_max
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15534
15535
15536
15537
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15534

def update!(**args)
  @bundling_required = args[:bundling_required] if args.key?(:bundling_required)
  @enable_ai_max = args[:enable_ai_max] if args.key?(:enable_ai_max)
end