Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAppCampaignSetting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAppCampaignSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Campaign-level settings for App Campaigns.
Instance Attribute Summary collapse
-
#app_id ⇒ String
Immutable.
-
#app_store ⇒ String
Immutable.
-
#bidding_strategy_goal_type ⇒ String
Represents the goal which the bidding strategy of this app campaign should optimize towards.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignAppCampaignSetting
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignAppCampaignSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignAppCampaignSetting
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignAppCampaignSetting.
15494 15495 15496 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15494 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ String
Immutable. A string that uniquely identifies a mobile application.
Corresponds to the JSON property appId
15481 15482 15483 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15481 def app_id @app_id end |
#app_store ⇒ String
Immutable. The application store that distributes this specific app.
Corresponds to the JSON property appStore
15486 15487 15488 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15486 def app_store @app_store end |
#bidding_strategy_goal_type ⇒ String
Represents the goal which the bidding strategy of this app campaign should
optimize towards.
Corresponds to the JSON property biddingStrategyGoalType
15492 15493 15494 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15492 def bidding_strategy_goal_type @bidding_strategy_goal_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15499 15500 15501 15502 15503 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15499 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @app_store = args[:app_store] if args.key?(:app_store) @bidding_strategy_goal_type = args[:bidding_strategy_goal_type] if args.key?(:bidding_strategy_goal_type) end |