Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAssetAutomationSetting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAssetAutomationSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Asset automation setting contains pair of AssetAutomationType and the asset automation opt-in/out status
Instance Attribute Summary collapse
-
#asset_automation_status ⇒ String
The opt-in/out status of asset automation type.
-
#asset_automation_type ⇒ String
The asset automation type advertiser would like to opt-in/out.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignAssetAutomationSetting
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignAssetAutomationSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignAssetAutomationSetting
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignAssetAutomationSetting.
15521 15522 15523 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15521 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_automation_status ⇒ String
The opt-in/out status of asset automation type.
Corresponds to the JSON property assetAutomationStatus
15514 15515 15516 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15514 def asset_automation_status @asset_automation_status end |
#asset_automation_type ⇒ String
The asset automation type advertiser would like to opt-in/out.
Corresponds to the JSON property assetAutomationType
15519 15520 15521 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15519 def asset_automation_type @asset_automation_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15526 15527 15528 15529 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15526 def update!(**args) @asset_automation_status = args[:asset_automation_status] if args.key?(:asset_automation_status) @asset_automation_type = args[:asset_automation_type] if args.key?(:asset_automation_type) end |