Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAudienceView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A campaign audience view. Includes performance data from interests and remarketing lists for Display Network and YouTube Network ads, and remarketing lists for search ads (RLSA), aggregated by campaign and audience criterion. This view only includes audiences attached at the campaign level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignAudienceView

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignAudienceView.



24817
24818
24819
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_nameString

Output only. The resource name of the campaign audience view. Campaign audience view resource names have the form: customers/customer_id/ campaignAudienceViews/campaign_id~criterion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


24815
24816
24817
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24815

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24822
24823
24824
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24822

def update!(**args)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end