Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBidModifier
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBidModifier
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents a bid-modifiable only criterion at the campaign level.
Instance Attribute Summary collapse
-
#bid_modifier ⇒ Float
The modifier for the bid when the criterion matches.
-
#campaign ⇒ String
Output only.
-
#criterion_id ⇒ Fixnum
Output only.
-
#interaction_type ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonInteractionTypeInfo
Criterion for Interaction Type.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignBidModifier
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignBidModifier.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignBidModifier
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignBidModifier.
24859 24860 24861 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24859 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bid_modifier ⇒ Float
The modifier for the bid when the criterion matches.
Corresponds to the JSON property bidModifier
24834 24835 24836 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24834 def bid_modifier @bid_modifier end |
#campaign ⇒ String
Output only. The campaign to which this criterion belongs.
Corresponds to the JSON property campaign
24839 24840 24841 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24839 def campaign @campaign end |
#criterion_id ⇒ Fixnum
Output only. The ID of the criterion to bid modify. This field is ignored for
mutates.
Corresponds to the JSON property criterionId
24845 24846 24847 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24845 def criterion_id @criterion_id end |
#interaction_type ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonInteractionTypeInfo
Criterion for Interaction Type.
Corresponds to the JSON property interactionType
24850 24851 24852 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24850 def interaction_type @interaction_type end |
#resource_name ⇒ String
Immutable. The resource name of the campaign bid modifier. Campaign bid
modifier resource names have the form: customers/customer_id/
campaignBidModifiers/campaign_id~criterion_id`
Corresponds to the JSON propertyresourceName`
24857 24858 24859 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24857 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24864 24865 24866 24867 24868 24869 24870 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24864 def update!(**args) @bid_modifier = args[:bid_modifier] if args.key?(:bid_modifier) @campaign = args[:campaign] if args.key?(:campaign) @criterion_id = args[:criterion_id] if args.key?(:criterion_id) @interaction_type = args[:interaction_type] if args.key?(:interaction_type) @resource_name = args[:resource_name] if args.key?(:resource_name) end |