Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignConversionGoal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The biddability setting for the specified campaign only for all conversion actions with a matching category and origin.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignConversionGoal

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignConversionGoal.



25019
25020
25021
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#biddableBoolean Also known as: biddable?

The biddability of the campaign conversion goal. Corresponds to the JSON property biddable

Returns:

  • (Boolean)


24988
24989
24990
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24988

def biddable
  @biddable
end

#campaignString

Immutable. The campaign with which this campaign conversion goal is associated. Corresponds to the JSON property campaign

Returns:

  • (String)


24994
24995
24996
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24994

def campaign
  @campaign
end

#categoryString

The conversion category of this campaign conversion goal. Corresponds to the JSON property category

Returns:

  • (String)


24999
25000
25001
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24999

def category
  @category
end

#originString

The conversion origin of this campaign conversion goal. Corresponds to the JSON property origin

Returns:

  • (String)


25004
25005
25006
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25004

def origin
  @origin
end

#resource_nameString

Immutable. The resource name of the campaign conversion goal. Campaign conversion goal resource names have the form: customers/customer_id/ campaignConversionGoals/campaign_id~category~origin` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25011
25012
25013
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25011

def resource_name
  @resource_name
end

#search_ads360_biddableBoolean Also known as: search_ads360_biddable?

Search Ads 360 biddability of the campaign conversion goal. Corresponds to the JSON property searchAds360Biddable

Returns:

  • (Boolean)


25016
25017
25018
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25016

def search_ads360_biddable
  @search_ads360_biddable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25024
25025
25026
25027
25028
25029
25030
25031
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25024

def update!(**args)
  @biddable = args[:biddable] if args.key?(:biddable)
  @campaign = args[:campaign] if args.key?(:campaign)
  @category = args[:category] if args.key?(:category)
  @origin = args[:origin] if args.key?(:origin)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @search_ads360_biddable = args[:search_ads360_biddable] if args.key?(:search_ads360_biddable)
end