Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A campaign criterion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignCriterion

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignCriterion.



25343
25344
25345
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_scheduleGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo

Represents an AdSchedule criterion. AdSchedule is specified as the day of the week and a time interval within which ads will be shown. No more than six AdSchedules can be added for the same day. Corresponds to the JSON property adSchedule



25103
25104
25105
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25103

def ad_schedule
  @ad_schedule
end

#age_rangeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo

An age range criterion. Corresponds to the JSON property ageRange



25108
25109
25110
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25108

def age_range
  @age_range
end

#bid_modifierFloat

The modifier for the bids when the criterion matches. The modifier must be in the range: 0.1 - 10.0. Most targetable criteria types support modifiers. Use 0 to opt out of a Device type. Corresponds to the JSON property bidModifier

Returns:

  • (Float)


25115
25116
25117
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25115

def bid_modifier
  @bid_modifier
end

#brand_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandListInfo

A Brand List Criterion is used to specify a list of brands. The list is represented as a SharedSet id type BRAND_HINT. A criterion of this type can be either targeted or excluded. Corresponds to the JSON property brandList



25122
25123
25124
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25122

def brand_list
  @brand_list
end

#campaignString

Immutable. The campaign to which the criterion belongs. Corresponds to the JSON property campaign

Returns:

  • (String)


25127
25128
25129
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25127

def campaign
  @campaign
end

#carrierGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCarrierInfo

Represents a Carrier Criterion. Corresponds to the JSON property carrier



25132
25133
25134
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25132

def carrier
  @carrier
end

#combined_audienceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCombinedAudienceInfo

A combined audience criterion. Corresponds to the JSON property combinedAudience



25137
25138
25139
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25137

def combined_audience
  @combined_audience
end

#content_labelGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonContentLabelInfo

Content Label for category exclusion. Corresponds to the JSON property contentLabel



25142
25143
25144
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25142

def 
  @content_label
end

#criterion_idFixnum

Output only. The ID of the criterion. This field is ignored during mutate. Corresponds to the JSON property criterionId

Returns:

  • (Fixnum)


25147
25148
25149
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25147

def criterion_id
  @criterion_id
end

#deviceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo

A device criterion. Corresponds to the JSON property device



25152
25153
25154
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25152

def device
  @device
end

#display_nameString

Output only. The display name of the criterion. This field is ignored for mutates. Corresponds to the JSON property displayName

Returns:

  • (String)


25158
25159
25160
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25158

def display_name
  @display_name
end

#extended_demographicGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonExtendedDemographicInfo

Represents an extended demographic criterion. Corresponds to the JSON property extendedDemographic



25163
25164
25165
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25163

def extended_demographic
  @extended_demographic
end

#genderGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo

A gender criterion. Corresponds to the JSON property gender



25168
25169
25170
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25168

def gender
  @gender
end

#income_rangeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIncomeRangeInfo

An income range criterion. Corresponds to the JSON property incomeRange



25173
25174
25175
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25173

def income_range
  @income_range
end

#ip_blockGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIpBlockInfo

An IpBlock criterion used for excluding IP addresses. We support excluding individual IP addresses or CIDR blocks. Create one IpBlockInfo criterion for each individual IP address or CIDR block you want to exclude. You can exclude up to 500 IP addresses per campaign. For more details, see Exclude IP addresses. IPv4 examples: * Individual address: 192.168.0.1 * Individual address as CIDR block: 192.168.0. 1/32 * CIDR block: 192.168.0.0/24 IPv6 examples: * Individual address: 2001: db8:a0b:12f0::1 * Individual address as CIDR block: 2001:db8:a0b:12f0::1/128 * CIDR block: 2001:db8::/48 Corresponds to the JSON property ipBlock



25186
25187
25188
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25186

def ip_block
  @ip_block
end

#keywordGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo

A keyword criterion. Corresponds to the JSON property keyword



25191
25192
25193
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25191

def keyword
  @keyword
end

#keyword_themeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordThemeInfo

A Smart Campaign keyword theme. Corresponds to the JSON property keywordTheme



25196
25197
25198
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25196

def keyword_theme
  @keyword_theme
end

#languageGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLanguageInfo

A language criterion. Corresponds to the JSON property language



25201
25202
25203
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25201

def language
  @language
end

#last_modified_timeString

Output only. The datetime when this campaign criterion was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


25208
25209
25210
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25208

def last_modified_time
  @last_modified_time
end

#life_eventGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLifeEventInfo

Represents a life event criterion. Corresponds to the JSON property lifeEvent



25213
25214
25215
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25213

def life_event
  @life_event
end

#listing_scopeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingScopeInfo

A listing scope criterion. Corresponds to the JSON property listingScope



25218
25219
25220
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25218

def listing_scope
  @listing_scope
end

#local_service_idGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalServiceIdInfo

A Local Services Ads service ID. Represents a service type (such as install_faucet) that a Local Services Campaign can target. Corresponds to the JSON property localServiceId



25224
25225
25226
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25224

def local_service_id
  @local_service_id
end

#locationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo

A location criterion. Corresponds to the JSON property location



25229
25230
25231
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25229

def location
  @location
end

#location_groupGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationGroupInfo

A radius around a list of locations specified through a feed. Corresponds to the JSON property locationGroup



25234
25235
25236
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25234

def location_group
  @location_group
end

#mobile_app_categoryGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo

A mobile app category criterion. Corresponds to the JSON property mobileAppCategory



25239
25240
25241
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25239

def mobile_app_category
  @mobile_app_category
end

#mobile_applicationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo

A mobile application criterion. Corresponds to the JSON property mobileApplication



25244
25245
25246
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25244

def mobile_application
  @mobile_application
end

#mobile_deviceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileDeviceInfo

A mobile device criterion. Corresponds to the JSON property mobileDevice



25249
25250
25251
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25249

def mobile_device
  @mobile_device
end

#negativeBoolean Also known as: negative?

Immutable. Whether to target (false) or exclude (true) the criterion. Corresponds to the JSON property negative

Returns:

  • (Boolean)


25254
25255
25256
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25254

def negative
  @negative
end

#operating_system_versionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonOperatingSystemVersionInfo

Represents an operating system version to be targeted. Corresponds to the JSON property operatingSystemVersion



25260
25261
25262
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25260

def operating_system_version
  @operating_system_version
end

#parental_statusGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo

A parental status criterion. Corresponds to the JSON property parentalStatus



25265
25266
25267
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25265

def parental_status
  @parental_status
end

#placementGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo

A placement criterion. This can be used to modify bids for sites when targeting the content network. Corresponds to the JSON property placement



25271
25272
25273
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25271

def placement
  @placement
end

#proximityGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProximityInfo

A Proximity criterion. The geo point and radius determine what geographical area is included. The address is a description of the geo point that does not affect ad serving. There are two ways to create a proximity. First, by setting an address and radius. The geo point will be automatically computed. Second, by setting a geo point and radius. The address is an optional label that won't be validated. Corresponds to the JSON property proximity



25281
25282
25283
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25281

def proximity
  @proximity
end

#resource_nameString

Immutable. The resource name of the campaign criterion. Campaign criterion resource names have the form: customers/customer_id/campaignCriteria/ campaign_id~criterion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25288
25289
25290
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25288

def resource_name
  @resource_name
end

#statusString

The status of the criterion. Corresponds to the JSON property status

Returns:

  • (String)


25293
25294
25295
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25293

def status
  @status
end

#topicGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTopicInfo

A topic criterion. Use topics to target or exclude placements in the Google Display Network based on the category into which the placement falls (for example, "Pets & Animals/Pets/Dogs"). Corresponds to the JSON property topic



25300
25301
25302
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25300

def topic
  @topic
end

#typeString

Output only. The type of the criterion. Corresponds to the JSON property type

Returns:

  • (String)


25305
25306
25307
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25305

def type
  @type
end

#user_interestGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserInterestInfo

Represents a particular interest-based topic to be targeted. Corresponds to the JSON property userInterest



25310
25311
25312
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25310

def user_interest
  @user_interest
end

#user_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListInfo

A User List criterion. Represents a user list that is defined by the advertiser to be targeted. Corresponds to the JSON property userList



25316
25317
25318
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25316

def user_list
  @user_list
end

#video_lineupGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVideoLineupInfo

A Video lineup criterion. Corresponds to the JSON property videoLineup



25321
25322
25323
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25321

def video_lineup
  @video_lineup
end

#webpageGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageInfo

Represents a criterion for targeting webpages of an advertiser's website. Corresponds to the JSON property webpage



25326
25327
25328
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25326

def webpage
  @webpage
end

#webpage_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageListInfo

Represents a list of webpage criteria. Corresponds to the JSON property webpageList



25331
25332
25333
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25331

def webpage_list
  @webpage_list
end

#youtube_channelGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo

A YouTube Channel criterion. Corresponds to the JSON property youtubeChannel



25336
25337
25338
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25336

def youtube_channel
  @youtube_channel
end

#youtube_videoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo

A YouTube Video criterion. Corresponds to the JSON property youtubeVideo



25341
25342
25343
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25341

def youtube_video
  @youtube_video
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25348
25349
25350
25351
25352
25353
25354
25355
25356
25357
25358
25359
25360
25361
25362
25363
25364
25365
25366
25367
25368
25369
25370
25371
25372
25373
25374
25375
25376
25377
25378
25379
25380
25381
25382
25383
25384
25385
25386
25387
25388
25389
25390
25391
25392
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25348

def update!(**args)
  @ad_schedule = args[:ad_schedule] if args.key?(:ad_schedule)
  @age_range = args[:age_range] if args.key?(:age_range)
  @bid_modifier = args[:bid_modifier] if args.key?(:bid_modifier)
  @brand_list = args[:brand_list] if args.key?(:brand_list)
  @campaign = args[:campaign] if args.key?(:campaign)
  @carrier = args[:carrier] if args.key?(:carrier)
  @combined_audience = args[:combined_audience] if args.key?(:combined_audience)
  @content_label = args[:content_label] if args.key?(:content_label)
  @criterion_id = args[:criterion_id] if args.key?(:criterion_id)
  @device = args[:device] if args.key?(:device)
  @display_name = args[:display_name] if args.key?(:display_name)
  @extended_demographic = args[:extended_demographic] if args.key?(:extended_demographic)
  @gender = args[:gender] if args.key?(:gender)
  @income_range = args[:income_range] if args.key?(:income_range)
  @ip_block = args[:ip_block] if args.key?(:ip_block)
  @keyword = args[:keyword] if args.key?(:keyword)
  @keyword_theme = args[:keyword_theme] if args.key?(:keyword_theme)
  @language = args[:language] if args.key?(:language)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @life_event = args[:life_event] if args.key?(:life_event)
  @listing_scope = args[:listing_scope] if args.key?(:listing_scope)
  @local_service_id = args[:local_service_id] if args.key?(:local_service_id)
  @location = args[:location] if args.key?(:location)
  @location_group = args[:location_group] if args.key?(:location_group)
  @mobile_app_category = args[:mobile_app_category] if args.key?(:mobile_app_category)
  @mobile_application = args[:mobile_application] if args.key?(:mobile_application)
  @mobile_device = args[:mobile_device] if args.key?(:mobile_device)
  @negative = args[:negative] if args.key?(:negative)
  @operating_system_version = args[:operating_system_version] if args.key?(:operating_system_version)
  @parental_status = args[:parental_status] if args.key?(:parental_status)
  @placement = args[:placement] if args.key?(:placement)
  @proximity = args[:proximity] if args.key?(:proximity)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @topic = args[:topic] if args.key?(:topic)
  @type = args[:type] if args.key?(:type)
  @user_interest = args[:user_interest] if args.key?(:user_interest)
  @user_list = args[:user_list] if args.key?(:user_list)
  @video_lineup = args[:video_lineup] if args.key?(:video_lineup)
  @webpage = args[:webpage] if args.key?(:webpage)
  @webpage_list = args[:webpage_list] if args.key?(:webpage_list)
  @youtube_channel = args[:youtube_channel] if args.key?(:youtube_channel)
  @youtube_video = args[:youtube_video] if args.key?(:youtube_video)
end