Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCustomizer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A customizer value for the associated CustomizerAttribute at the Campaign level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignCustomizer

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignCustomizer.



25428
25429
25430
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaignString

Immutable. The campaign to which the customizer attribute is linked. Corresponds to the JSON property campaign

Returns:

  • (String)


25403
25404
25405
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25403

def campaign
  @campaign
end

#customizer_attributeString

Required. Immutable. The customizer attribute which is linked to the campaign. Corresponds to the JSON property customizerAttribute

Returns:

  • (String)


25408
25409
25410
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25408

def customizer_attribute
  @customizer_attribute
end

#resource_nameString

Immutable. The resource name of the campaign customizer. Campaign customizer resource names have the form: customers/customer_id/campaignCustomizers/ campaign_id~customizer_attribute_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25415
25416
25417
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25415

def resource_name
  @resource_name
end

#statusString

Output only. The status of the campaign customizer. Corresponds to the JSON property status

Returns:

  • (String)


25420
25421
25422
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25420

def status
  @status
end

#valueGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue

A customizer value that is referenced in customizer linkage entities like CustomerCustomizer, CampaignCustomizer, etc. Corresponds to the JSON property value



25426
25427
25428
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25426

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25433
25434
25435
25436
25437
25438
25439
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25433

def update!(**args)
  @campaign = args[:campaign] if args.key?(:campaign)
  @customizer_attribute = args[:customizer_attribute] if args.key?(:customizer_attribute)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @value = args[:value] if args.key?(:value)
end