Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDynamicSearchAdsSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The setting for controlling Dynamic Search Ads (DSA).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignDynamicSearchAdsSetting

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignDynamicSearchAdsSetting.



15795
15796
15797
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domain_nameString

Required. The Internet domain name that this setting represents, for example, " google.com" or "www.google.com". Corresponds to the JSON property domainName

Returns:

  • (String)


15781
15782
15783
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15781

def domain_name
  @domain_name
end

#language_codeString

Required. The language code specifying the language of the domain, for example, "en". Corresponds to the JSON property languageCode

Returns:

  • (String)


15787
15788
15789
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15787

def language_code
  @language_code
end

#use_supplied_urls_onlyBoolean Also known as: use_supplied_urls_only?

Whether the campaign uses advertiser supplied URLs exclusively. Corresponds to the JSON property useSuppliedUrlsOnly

Returns:

  • (Boolean)


15792
15793
15794
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15792

def use_supplied_urls_only
  @use_supplied_urls_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15800
15801
15802
15803
15804
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15800

def update!(**args)
  @domain_name = args[:domain_name] if args.key?(:domain_name)
  @language_code = args[:language_code] if args.key?(:language_code)
  @use_supplied_urls_only = args[:use_supplied_urls_only] if args.key?(:use_supplied_urls_only)
end