Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignEffectiveLabel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a relationship between a campaign and an effective label. An effective label is a label inherited or directly assigned to this campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignEffectiveLabel

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignEffectiveLabel.



25481
25482
25483
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25481

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaignString

Immutable. The campaign to which the effective label is attached. Corresponds to the JSON property campaign

Returns:

  • (String)


25462
25463
25464
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25462

def campaign
  @campaign
end

#labelString

Immutable. The effective label assigned to the campaign. Corresponds to the JSON property label

Returns:

  • (String)


25467
25468
25469
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25467

def label
  @label
end

#owner_customer_idFixnum

Output only. The ID of the Customer which owns the effective label. Corresponds to the JSON property ownerCustomerId

Returns:

  • (Fixnum)


25472
25473
25474
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25472

def owner_customer_id
  @owner_customer_id
end

#resource_nameString

Immutable. Name of the resource. CampaignEffectivelabel resource names have the form: customers/owner_customer_id/campaignEffectiveLabels/campaign_id~ label_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25479
25480
25481
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25479

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25486
25487
25488
25489
25490
25491
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25486

def update!(**args)
  @campaign = args[:campaign] if args.key?(:campaign)
  @label = args[:label] if args.key?(:label)
  @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end