Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGeoTargetTypeSetting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGeoTargetTypeSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents a collection of settings related to ads geotargeting.
Instance Attribute Summary collapse
-
#negative_geo_target_type ⇒ String
The setting used for negative geotargeting in this particular campaign.
-
#positive_geo_target_type ⇒ String
The setting used for positive geotargeting in this particular campaign.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignGeoTargetTypeSetting
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignGeoTargetTypeSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignGeoTargetTypeSetting
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignGeoTargetTypeSetting.
15761 15762 15763 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15761 def initialize(**args) update!(**args) end |
Instance Attribute Details
#negative_geo_target_type ⇒ String
The setting used for negative geotargeting in this particular campaign.
Corresponds to the JSON property negativeGeoTargetType
15754 15755 15756 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15754 def negative_geo_target_type @negative_geo_target_type end |
#positive_geo_target_type ⇒ String
The setting used for positive geotargeting in this particular campaign.
Corresponds to the JSON property positiveGeoTargetType
15759 15760 15761 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15759 def positive_geo_target_type @positive_geo_target_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15766 15767 15768 15769 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15766 def update!(**args) @negative_geo_target_type = args[:negative_geo_target_type] if args.key?(:negative_geo_target_type) @positive_geo_target_type = args[:positive_geo_target_type] if args.key?(:positive_geo_target_type) end |