Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGoalConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A link between a campaign and a goal enabling campaign-specific optimization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignGoalConfig

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignGoalConfig.



25595
25596
25597
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaignString

Immutable. The resource name of the campaign for this link. Corresponds to the JSON property campaign

Returns:

  • (String)


25561
25562
25563
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25561

def campaign
  @campaign
end

#campaign_loyalty_retention_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCampaignGoalSettingsCampaignLoyaltyRetentionGoalSettings

Loyalty retention campaign goal settings. Corresponds to the JSON property campaignLoyaltyRetentionSettings



25566
25567
25568
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25566

def campaign_loyalty_retention_settings
  @campaign_loyalty_retention_settings
end

#campaign_new_customer_acquisition_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCampaignGoalSettingsCampaignNewCustomerAcquisitionGoalSettings

New Customer Acquisition campaign goal settings. Corresponds to the JSON property campaignNewCustomerAcquisitionSettings



25571
25572
25573
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25571

def campaign_new_customer_acquisition_settings
  @campaign_new_customer_acquisition_settings
end

#campaign_retention_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCampaignGoalSettingsCampaignRetentionGoalSettings

Retention campaign goal settings. Corresponds to the JSON property campaignRetentionSettings



25576
25577
25578
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25576

def campaign_retention_settings
  @campaign_retention_settings
end

#goalString

Immutable. The resource name of the goal this link is attached to. Corresponds to the JSON property goal

Returns:

  • (String)


25581
25582
25583
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25581

def goal
  @goal
end

#goal_typeString

Output only. The goal type this link is attached to. Corresponds to the JSON property goalType

Returns:

  • (String)


25586
25587
25588
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25586

def goal_type
  @goal_type
end

#resource_nameString

Immutable. The resource name of the campaign goal config. campaign goal config resource names have the form: customers/customer_id/campaignGoalConfigs/ campaign_id~goal_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25593
25594
25595
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25593

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25600
25601
25602
25603
25604
25605
25606
25607
25608
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25600

def update!(**args)
  @campaign = args[:campaign] if args.key?(:campaign)
  @campaign_loyalty_retention_settings = args[:campaign_loyalty_retention_settings] if args.key?(:campaign_loyalty_retention_settings)
  @campaign_new_customer_acquisition_settings = args[:campaign_new_customer_acquisition_settings] if args.key?(:campaign_new_customer_acquisition_settings)
  @campaign_retention_settings = args[:campaign_retention_settings] if args.key?(:campaign_retention_settings)
  @goal = args[:goal] if args.key?(:goal)
  @goal_type = args[:goal_type] if args.key?(:goal_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end