Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A campaign group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignGroup

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignGroup.



25641
25642
25643
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25641

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. The ID of the campaign group. Corresponds to the JSON property id

Returns:

  • (Fixnum)


25618
25619
25620
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25618

def id
  @id
end

#nameString

The name of the campaign group. This field is required and should not be empty when creating new campaign groups. It must not contain any null (code point 0x0), NL line feed (code point 0xA) or carriage return (code point 0xD) characters. Corresponds to the JSON property name

Returns:

  • (String)


25626
25627
25628
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25626

def name
  @name
end

#resource_nameString

Immutable. The resource name of the campaign group. Campaign group resource names have the form: customers/customer_id/campaignGroups/ campaign_group_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25633
25634
25635
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25633

def resource_name
  @resource_name
end

#statusString

The status of the campaign group. When a new campaign group is added, the status defaults to ENABLED. Corresponds to the JSON property status

Returns:

  • (String)


25639
25640
25641
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25639

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25646
25647
25648
25649
25650
25651
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25646

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end