Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignPerformanceMaxUpgrade

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Information about a campaign being upgraded to Performance Max.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignPerformanceMaxUpgrade

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignPerformanceMaxUpgrade.



15866
15867
15868
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15866

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#performance_max_campaignString

Output only. The resource name of the Performance Max campaign the campaign is upgraded to. Corresponds to the JSON property performanceMaxCampaign

Returns:

  • (String)


15852
15853
15854
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15852

def performance_max_campaign
  @performance_max_campaign
end

#pre_upgrade_campaignString

Output only. The resource name of the legacy campaign upgraded to Performance Max. Corresponds to the JSON property preUpgradeCampaign

Returns:

  • (String)


15858
15859
15860
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15858

def pre_upgrade_campaign
  @pre_upgrade_campaign
end

#statusString

Output only. The upgrade status of a campaign requested to be upgraded to Performance Max. Corresponds to the JSON property status

Returns:

  • (String)


15864
15865
15866
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15864

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15871
15872
15873
15874
15875
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15871

def update!(**args)
  @performance_max_campaign = args[:performance_max_campaign] if args.key?(:performance_max_campaign)
  @pre_upgrade_campaign = args[:pre_upgrade_campaign] if args.key?(:pre_upgrade_campaign)
  @status = args[:status] if args.key?(:status)
end