Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSelectiveOptimization
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSelectiveOptimization
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Selective optimization setting for this campaign, which includes a set of conversion actions to optimize this campaign towards. This feature only applies to app campaigns that use MULTI_CHANNEL as AdvertisingChannelType and APP_CAMPAIGN or APP_CAMPAIGN_FOR_ENGAGEMENT as AdvertisingChannelSubType.
Instance Attribute Summary collapse
-
#conversion_actions ⇒ Array<String>
The selected set of resource names for conversion actions for optimizing this campaign.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignSelectiveOptimization
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignSelectiveOptimization.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignSelectiveOptimization
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignSelectiveOptimization.
15910 15911 15912 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15910 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_actions ⇒ Array<String>
The selected set of resource names for conversion actions for optimizing this
campaign.
Corresponds to the JSON property conversionActions
15908 15909 15910 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15908 def conversion_actions @conversion_actions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15915 15916 15917 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15915 def update!(**args) @conversion_actions = args[:conversion_actions] if args.key?(:conversion_actions) end |