Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCarrierConstant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A carrier criterion that can be used in campaign targeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCarrierConstant

Returns a new instance of GoogleAdsSearchads360V23ResourcesCarrierConstant.



25963
25964
25965
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Output only. The country code of the country where the carrier is located, for example, "AR", "FR", etc. Corresponds to the JSON property countryCode

Returns:

  • (String)


25945
25946
25947
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25945

def country_code
  @country_code
end

#idFixnum

Output only. The ID of the carrier criterion. Corresponds to the JSON property id

Returns:

  • (Fixnum)


25950
25951
25952
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25950

def id
  @id
end

#nameString

Output only. The full name of the carrier in English. Corresponds to the JSON property name

Returns:

  • (String)


25955
25956
25957
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25955

def name
  @name
end

#resource_nameString

Output only. The resource name of the carrier criterion. Carrier criterion resource names have the form: carrierConstants/criterion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25961
25962
25963
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25961

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25968
25969
25970
25971
25972
25973
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25968

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end