Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Describes the granular change of returned resources of certain resource types. Changes made through the UI or API in the past 30 days are included. Previous and new values of the changed fields are shown. ChangeEvent could have up to 3 minutes delay to reflect a new change.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesChangeEvent

Returns a new instance of GoogleAdsSearchads360V23ResourcesChangeEvent.



26079
26080
26081
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Output only. The AdGroup affected by this change. Corresponds to the JSON property adGroup

Returns:

  • (String)


26012
26013
26014
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26012

def ad_group
  @ad_group
end

#assetString

Output only. The Asset affected by this change. Corresponds to the JSON property asset

Returns:

  • (String)


26017
26018
26019
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26017

def asset
  @asset
end

#campaignString

Output only. The Campaign affected by this change. Corresponds to the JSON property campaign

Returns:

  • (String)


26022
26023
26024
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26022

def campaign
  @campaign
end

#change_date_timeString

Output only. Time at which the change was committed on this resource. Corresponds to the JSON property changeDateTime

Returns:

  • (String)


26027
26028
26029
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26027

def change_date_time
  @change_date_time
end

#change_resource_nameString

Output only. The Simply resource this change occurred on. Corresponds to the JSON property changeResourceName

Returns:

  • (String)


26032
26033
26034
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26032

def change_resource_name
  @change_resource_name
end

#change_resource_typeString

Output only. The type of the changed resource. This dictates what resource will be set in old_resource and new_resource. Corresponds to the JSON property changeResourceType

Returns:

  • (String)


26038
26039
26040
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26038

def change_resource_type
  @change_resource_type
end

#changed_fieldsString

Output only. A list of fields that are changed in the returned resource. Corresponds to the JSON property changedFields

Returns:

  • (String)


26043
26044
26045
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26043

def changed_fields
  @changed_fields
end

#client_typeString

Output only. Where the change was made through. Corresponds to the JSON property clientType

Returns:

  • (String)


26048
26049
26050
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26048

def client_type
  @client_type
end

#new_resourceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEventChangedResource

A wrapper proto presenting all supported resources. Only the resource of the change_resource_type will be set. Corresponds to the JSON property newResource



26054
26055
26056
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26054

def new_resource
  @new_resource
end

#old_resourceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEventChangedResource

A wrapper proto presenting all supported resources. Only the resource of the change_resource_type will be set. Corresponds to the JSON property oldResource



26060
26061
26062
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26060

def old_resource
  @old_resource
end

#resource_change_operationString

Output only. The operation on the changed resource. Corresponds to the JSON property resourceChangeOperation

Returns:

  • (String)


26065
26066
26067
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26065

def resource_change_operation
  @resource_change_operation
end

#resource_nameString

Output only. The resource name of the change event. Change event resource names have the form: customers/customer_id/changeEvents/timestamp_micros~ command_index~mutate_index` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


26072
26073
26074
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26072

def resource_name
  @resource_name
end

#user_emailString

Output only. The email of the user who made this change. Corresponds to the JSON property userEmail

Returns:

  • (String)


26077
26078
26079
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26077

def user_email
  @user_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26084
26085
26086
26087
26088
26089
26090
26091
26092
26093
26094
26095
26096
26097
26098
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26084

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @asset = args[:asset] if args.key?(:asset)
  @campaign = args[:campaign] if args.key?(:campaign)
  @change_date_time = args[:change_date_time] if args.key?(:change_date_time)
  @change_resource_name = args[:change_resource_name] if args.key?(:change_resource_name)
  @change_resource_type = args[:change_resource_type] if args.key?(:change_resource_type)
  @changed_fields = args[:changed_fields] if args.key?(:changed_fields)
  @client_type = args[:client_type] if args.key?(:client_type)
  @new_resource = args[:new_resource] if args.key?(:new_resource)
  @old_resource = args[:old_resource] if args.key?(:old_resource)
  @resource_change_operation = args[:resource_change_operation] if args.key?(:resource_change_operation)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @user_email = args[:user_email] if args.key?(:user_email)
end