Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCombinedAudience

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Describe a resource for combined audiences which includes different audiences.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCombinedAudience

Returns a new instance of GoogleAdsSearchads360V23ResourcesCombinedAudience.



26359
26360
26361
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26359

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Output only. Description of this combined audience. Corresponds to the JSON property description

Returns:

  • (String)


26333
26334
26335
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26333

def description
  @description
end

#idFixnum

Output only. ID of the combined audience. Corresponds to the JSON property id

Returns:

  • (Fixnum)


26338
26339
26340
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26338

def id
  @id
end

#nameString

Output only. Name of the combined audience. It should be unique across all combined audiences. Corresponds to the JSON property name

Returns:

  • (String)


26344
26345
26346
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26344

def name
  @name
end

#resource_nameString

Immutable. The resource name of the combined audience. Combined audience names have the form: customers/customer_id/combinedAudience/combined_audience_id Corresponds to the JSON property resourceName

Returns:

  • (String)


26351
26352
26353
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26351

def resource_name
  @resource_name
end

#statusString

Output only. Status of this combined audience. Indicates whether the combined audience is enabled or removed. Corresponds to the JSON property status

Returns:

  • (String)


26357
26358
26359
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26357

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26364
26365
26366
26367
26368
26369
26370
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26364

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end