Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionCustomVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A conversion custom variable. See "About custom Floodlight metrics and dimensions in the new Search Ads 360" at https://support.google.com/sa360/ answer/13567857

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionCustomVariable

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionCustomVariable.



26855
26856
26857
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

Output only. Cardinality of the conversion custom variable. Corresponds to the JSON property cardinality

Returns:

  • (String)


26800
26801
26802
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26800

def cardinality
  @cardinality
end

#custom_column_idsArray<Fixnum>

Output only. The IDs of custom columns that use this conversion custom variable. Corresponds to the JSON property customColumnIds

Returns:

  • (Array<Fixnum>)


26806
26807
26808
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26806

def custom_column_ids
  @custom_column_ids
end

#familyString

Output only. Family of the conversion custom variable. Corresponds to the JSON property family

Returns:

  • (String)


26811
26812
26813
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26811

def family
  @family
end

#floodlight_conversion_custom_variable_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionCustomVariableFloodlightConversionCustomVariableInfo

Information for Search Ads 360 Floodlight Conversion Custom Variables. Corresponds to the JSON property floodlightConversionCustomVariableInfo



26816
26817
26818
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26816

def floodlight_conversion_custom_variable_info
  @floodlight_conversion_custom_variable_info
end

#idFixnum

Output only. The ID of the conversion custom variable. Corresponds to the JSON property id

Returns:

  • (Fixnum)


26821
26822
26823
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26821

def id
  @id
end

#nameString

Required. The name of the conversion custom variable. Name should be unique. The maximum length of name is 100 characters. There should not be any extra spaces before and after. Corresponds to the JSON property name

Returns:

  • (String)


26828
26829
26830
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26828

def name
  @name
end

#owner_customerString

Output only. The resource name of the customer that owns the conversion custom variable. Corresponds to the JSON property ownerCustomer

Returns:

  • (String)


26834
26835
26836
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26834

def owner_customer
  @owner_customer
end

#resource_nameString

Immutable. The resource name of the conversion custom variable. Conversion custom variable resource names have the form: customers/customer_id/ conversionCustomVariables/conversion_custom_variable_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


26841
26842
26843
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26841

def resource_name
  @resource_name
end

#statusString

The status of the conversion custom variable for conversion event accrual. Corresponds to the JSON property status

Returns:

  • (String)


26846
26847
26848
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26846

def status
  @status
end

#tagString

Required. Immutable. The tag of the conversion custom variable. Tag should be unique and consist of a "u" character directly followed with a number less than ormequal to 100. For example: "u4". Corresponds to the JSON property tag

Returns:

  • (String)


26853
26854
26855
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26853

def tag
  @tag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26860
26861
26862
26863
26864
26865
26866
26867
26868
26869
26870
26871
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26860

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @custom_column_ids = args[:custom_column_ids] if args.key?(:custom_column_ids)
  @family = args[:family] if args.key?(:family)
  @floodlight_conversion_custom_variable_info = args[:floodlight_conversion_custom_variable_info] if args.key?(:floodlight_conversion_custom_variable_info)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @owner_customer = args[:owner_customer] if args.key?(:owner_customer)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @tag = args[:tag] if args.key?(:tag)
end