Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionGoalCampaignConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Conversion goal settings for a Campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionGoalCampaignConfig

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionGoalCampaignConfig.



26912
26913
26914
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26912

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaignString

Immutable. The campaign with which this conversion goal campaign config is associated. Corresponds to the JSON property campaign

Returns:

  • (String)


26882
26883
26884
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26882

def campaign
  @campaign
end

#custom_conversion_goalString

The custom conversion goal the campaign is using for optimization. Corresponds to the JSON property customConversionGoal

Returns:

  • (String)


26887
26888
26889
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26887

def custom_conversion_goal
  @custom_conversion_goal
end

#goal_config_levelString

The level of goal config the campaign is using. Corresponds to the JSON property goalConfigLevel

Returns:

  • (String)


26892
26893
26894
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26892

def goal_config_level
  @goal_config_level
end

#resource_nameString

Immutable. The resource name of the conversion goal campaign config. Conversion goal campaign config resource names have the form: customers/ customer_id/conversionGoalCampaignConfigs/campaign_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


26899
26900
26901
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26899

def resource_name
  @resource_name
end

#search_ads360_custom_conversion_goalString

The Search Ads 360 custom conversion goal the campaign is using for optimization. Corresponds to the JSON property searchAds360CustomConversionGoal

Returns:

  • (String)


26905
26906
26907
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26905

def search_ads360_custom_conversion_goal
  @search_ads360_custom_conversion_goal
end

#search_ads360_goal_config_levelString

The level of Search Ads 360 goal config the campaign is using. Corresponds to the JSON property searchAds360GoalConfigLevel

Returns:

  • (String)


26910
26911
26912
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26910

def search_ads360_goal_config_level
  @search_ads360_goal_config_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26917
26918
26919
26920
26921
26922
26923
26924
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26917

def update!(**args)
  @campaign = args[:campaign] if args.key?(:campaign)
  @custom_conversion_goal = args[:custom_conversion_goal] if args.key?(:custom_conversion_goal)
  @goal_config_level = args[:goal_config_level] if args.key?(:goal_config_level)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @search_ads360_custom_conversion_goal = args[:search_ads360_custom_conversion_goal] if args.key?(:search_ads360_custom_conversion_goal)
  @search_ads360_goal_config_level = args[:search_ads360_goal_config_level] if args.key?(:search_ads360_goal_config_level)
end