Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryAdvanceBookingWindow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Range for the number of days between the date of the booking and the start of the itinerary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryAdvanceBookingWindow

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryAdvanceBookingWindow.



16573
16574
16575
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_daysFixnum

Maximum number of days between the date of the booking the start date. Corresponds to the JSON property maxDays

Returns:

  • (Fixnum)


16566
16567
16568
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16566

def max_days
  @max_days
end

#min_daysFixnum

Minimum number of days between the date of the booking the start date. Corresponds to the JSON property minDays

Returns:

  • (Fixnum)


16571
16572
16573
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16571

def min_days
  @min_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16578
16579
16580
16581
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16578

def update!(**args)
  @max_days = args[:max_days] if args.key?(:max_days)
  @min_days = args[:min_days] if args.key?(:min_days)
end