Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Condition on Itinerary dimension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryCondition

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryCondition.



16604
16605
16606
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16604

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advance_booking_windowGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryAdvanceBookingWindow

Range for the number of days between the date of the booking and the start of the itinerary. Corresponds to the JSON property advanceBookingWindow



16592
16593
16594
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16592

def advance_booking_window
  @advance_booking_window
end

#travel_lengthGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryTravelLength

Range for the itinerary length in number of nights. Corresponds to the JSON property travelLength



16597
16598
16599
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16597

def travel_length
  @travel_length
end

#travel_start_dayGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryTravelStartDay

The days of the week on which an itinerary's travel can start. Corresponds to the JSON property travelStartDay



16602
16603
16604
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16602

def travel_start_day
  @travel_start_day
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16609
16610
16611
16612
16613
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16609

def update!(**args)
  @advance_booking_window = args[:advance_booking_window] if args.key?(:advance_booking_window)
  @travel_length = args[:travel_length] if args.key?(:travel_length)
  @travel_start_day = args[:travel_start_day] if args.key?(:travel_start_day)
end