Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A custom column. See Search Ads 360 custom column at https://support.google. com/sa360/answer/9633916

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomColumn

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomColumn.



27402
27403
27404
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Output only. User-defined description of the custom column. Corresponds to the JSON property description

Returns:

  • (String)


27347
27348
27349
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27347

def description
  @description
end

#idFixnum

Output only. ID of the custom column. Corresponds to the JSON property id

Returns:

  • (Fixnum)


27352
27353
27354
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27352

def id
  @id
end

#nameString

Output only. User-defined name of the custom column. Corresponds to the JSON property name

Returns:

  • (String)


27357
27358
27359
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27357

def name
  @name
end

#queryableBoolean Also known as: queryable?

Output only. True when the custom column is available to be used in the query of SearchAds360Service.Search and SearchAds360Service.SearchStream. Corresponds to the JSON property queryable

Returns:

  • (Boolean)


27363
27364
27365
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27363

def queryable
  @queryable
end

#referenced_system_columnsArray<String>

Output only. The list of the referenced system columns of this custom column. For example, A custom column "sum of impressions and clicks" has referenced system columns of "metrics.clicks", "metrics.impressions". Corresponds to the JSON property referencedSystemColumns

Returns:

  • (Array<String>)


27371
27372
27373
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27371

def referenced_system_columns
  @referenced_system_columns
end

#references_attributesBoolean Also known as: references_attributes?

Output only. True when the custom column is referring to one or more attributes. Corresponds to the JSON property referencesAttributes

Returns:

  • (Boolean)


27377
27378
27379
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27377

def references_attributes
  @references_attributes
end

#references_metricsBoolean Also known as: references_metrics?

Output only. True when the custom column is referring to one or more metrics. Corresponds to the JSON property referencesMetrics

Returns:

  • (Boolean)


27383
27384
27385
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27383

def references_metrics
  @references_metrics
end

#render_typeString

Output only. How the result value of the custom column should be interpreted. Corresponds to the JSON property renderType

Returns:

  • (String)


27389
27390
27391
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27389

def render_type
  @render_type
end

#resource_nameString

Immutable. The resource name of the custom column. Custom column resource names have the form: customers/customer_id/customColumns/custom_column_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


27395
27396
27397
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27395

def resource_name
  @resource_name
end

#value_typeString

Output only. The type of the result value of the custom column. Corresponds to the JSON property valueType

Returns:

  • (String)


27400
27401
27402
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27400

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27407
27408
27409
27410
27411
27412
27413
27414
27415
27416
27417
27418
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27407

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @queryable = args[:queryable] if args.key?(:queryable)
  @referenced_system_columns = args[:referenced_system_columns] if args.key?(:referenced_system_columns)
  @references_attributes = args[:references_attributes] if args.key?(:references_attributes)
  @references_metrics = args[:references_metrics] if args.key?(:references_metrics)
  @render_type = args[:render_type] if args.key?(:render_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @value_type = args[:value_type] if args.key?(:value_type)
end