Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomConversionGoal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Custom conversion goal that can make arbitrary conversion actions biddable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomConversionGoal

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomConversionGoal.



27452
27453
27454
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27452

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversion_actionsArray<String>

Conversion actions that the custom conversion goal makes biddable. Corresponds to the JSON property conversionActions

Returns:

  • (Array<String>)


27428
27429
27430
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27428

def conversion_actions
  @conversion_actions
end

#idFixnum

Immutable. The ID for this custom conversion goal. Corresponds to the JSON property id

Returns:

  • (Fixnum)


27433
27434
27435
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27433

def id
  @id
end

#nameString

The name for this custom conversion goal. Corresponds to the JSON property name

Returns:

  • (String)


27438
27439
27440
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27438

def name
  @name
end

#resource_nameString

Immutable. The resource name of the custom conversion goal. Custom conversion goal resource names have the form: customers/customer_id/ customConversionGoals/goal_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


27445
27446
27447
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27445

def resource_name
  @resource_name
end

#statusString

The status of the custom conversion goal. Corresponds to the JSON property status

Returns:

  • (String)


27450
27451
27452
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27450

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27457
27458
27459
27460
27461
27462
27463
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27457

def update!(**args)
  @conversion_actions = args[:conversion_actions] if args.key?(:conversion_actions)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end