Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomLeadFormSubmissionField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Fields in the submitted custom question

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomLeadFormSubmissionField

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomLeadFormSubmissionField.



27498
27499
27500
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27498

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_valueString

Output only. Field value for custom question response, maximum number of characters is 70. Corresponds to the JSON property fieldValue

Returns:

  • (String)


27490
27491
27492
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27490

def field_value
  @field_value
end

#question_textString

Output only. Question text for custom question, maximum number of characters is 300. Corresponds to the JSON property questionText

Returns:

  • (String)


27496
27497
27498
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27496

def question_text
  @question_text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27503
27504
27505
27506
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27503

def update!(**args)
  @field_value = args[:field_value] if args.key?(:field_value)
  @question_text = args[:question_text] if args.key?(:question_text)
end