Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAssetSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

CustomerAssetSet is the linkage between a customer and an asset set. Adding a CustomerAssetSet links an asset set with a customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerAssetSet

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerAssetSet.



27854
27855
27856
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_setString

Immutable. The asset set which is linked to the customer. Corresponds to the JSON property assetSet

Returns:

  • (String)


27835
27836
27837
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27835

def asset_set
  @asset_set
end

#customerString

Immutable. The customer to which this asset set is linked. Corresponds to the JSON property customer

Returns:

  • (String)


27840
27841
27842
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27840

def customer
  @customer
end

#resource_nameString

Immutable. The resource name of the customer asset set. Asset set asset resource names have the form: customers/customer_id/customerAssetSets/ asset_set_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


27847
27848
27849
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27847

def resource_name
  @resource_name
end

#statusString

Output only. The status of the customer asset set asset. Read-only. Corresponds to the JSON property status

Returns:

  • (String)


27852
27853
27854
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27852

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27859
27860
27861
27862
27863
27864
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27859

def update!(**args)
  @asset_set = args[:asset_set] if args.key?(:asset_set)
  @customer = args[:customer] if args.key?(:customer)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end