Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClientLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents customer client link relationship.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerClientLink

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerClientLink.



28157
28158
28159
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28157

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_customerString

Immutable. The client customer linked to this customer. Corresponds to the JSON property clientCustomer

Returns:

  • (String)


28131
28132
28133
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28131

def client_customer
  @client_customer
end

#hiddenBoolean Also known as: hidden?

The visibility of the link. Users can choose whether or not to see hidden links in the Google Ads UI. Default value is false Corresponds to the JSON property hidden

Returns:

  • (Boolean)


28137
28138
28139
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28137

def hidden
  @hidden
end

Output only. This is uniquely identifies a customer client link. Read only. Corresponds to the JSON property managerLinkId

Returns:

  • (Fixnum)


28143
28144
28145
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28143

def manager_link_id
  @manager_link_id
end

#resource_nameString

Immutable. Name of the resource. CustomerClientLink resource names have the form: customers/customer_id/customerClientLinks/client_customer_id~ manager_link_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28150
28151
28152
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28150

def resource_name
  @resource_name
end

#statusString

This is the status of the link between client and manager. Corresponds to the JSON property status

Returns:

  • (String)


28155
28156
28157
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28155

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28162
28163
28164
28165
28166
28167
28168
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28162

def update!(**args)
  @client_customer = args[:client_customer] if args.key?(:client_customer)
  @hidden = args[:hidden] if args.key?(:hidden)
  @manager_link_id = args[:manager_link_id] if args.key?(:manager_link_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end