Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerConversionGoal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Biddability control for conversion actions with a matching category and origin.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerConversionGoal

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerConversionGoal.



28200
28201
28202
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#biddableBoolean Also known as: biddable?

The biddability of the customer conversion goal. Corresponds to the JSON property biddable

Returns:

  • (Boolean)


28178
28179
28180
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28178

def biddable
  @biddable
end

#categoryString

The conversion category of this customer conversion goal. Only conversion actions that have this category will be included in this goal. Corresponds to the JSON property category

Returns:

  • (String)


28185
28186
28187
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28185

def category
  @category
end

#originString

The conversion origin of this customer conversion goal. Only conversion actions that have this conversion origin will be included in this goal. Corresponds to the JSON property origin

Returns:

  • (String)


28191
28192
28193
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28191

def origin
  @origin
end

#resource_nameString

Immutable. The resource name of the customer conversion goal. Customer conversion goal resource names have the form: customers/customer_id/ customerConversionGoals/category~origin` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28198
28199
28200
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28198

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28205
28206
28207
28208
28209
28210
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28205

def update!(**args)
  @biddable = args[:biddable] if args.key?(:biddable)
  @category = args[:category] if args.key?(:category)
  @origin = args[:origin] if args.key?(:origin)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end