Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerCustomizer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A customizer value for the associated CustomizerAttribute at the Customer level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerCustomizer

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerCustomizer.



28241
28242
28243
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28241

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customizer_attributeString

Required. Immutable. The customizer attribute which is linked to the customer. Corresponds to the JSON property customizerAttribute

Returns:

  • (String)


28221
28222
28223
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28221

def customizer_attribute
  @customizer_attribute
end

#resource_nameString

Immutable. The resource name of the customer customizer. Customer customizer resource names have the form: customers/customer_id/customerCustomizers/ customizer_attribute_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28228
28229
28230
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28228

def resource_name
  @resource_name
end

#statusString

Output only. The status of the customer customizer attribute. Corresponds to the JSON property status

Returns:

  • (String)


28233
28234
28235
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28233

def status
  @status
end

#valueGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue

A customizer value that is referenced in customizer linkage entities like CustomerCustomizer, CampaignCustomizer, etc. Corresponds to the JSON property value



28239
28240
28241
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28239

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28246
28247
28248
28249
28250
28251
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28246

def update!(**args)
  @customizer_attribute = args[:customizer_attribute] if args.key?(:customizer_attribute)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @value = args[:value] if args.key?(:value)
end