Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerManagerLink
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerManagerLink
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents customer-manager link relationship.
Instance Attribute Summary collapse
-
#manager_customer ⇒ String
Output only.
-
#manager_link_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
-
#start_time ⇒ String
Output only.
-
#status ⇒ String
Status of the link between the customer and the manager.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerManagerLink
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomerManagerLink.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerManagerLink
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerManagerLink.
28357 28358 28359 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#manager_customer ⇒ String
Output only. The manager customer linked to the customer.
Corresponds to the JSON property managerCustomer
28332 28333 28334 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28332 def manager_customer @manager_customer end |
#manager_link_id ⇒ Fixnum
Output only. ID of the customer-manager link. This field is read only.
Corresponds to the JSON property managerLinkId
28337 28338 28339 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28337 def manager_link_id @manager_link_id end |
#resource_name ⇒ String
Immutable. Name of the resource. CustomerManagerLink resource names have the
form: customers/customer_id/customerManagerLinks/manager_customer_id~
manager_link_id`
Corresponds to the JSON propertyresourceName`
28344 28345 28346 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28344 def resource_name @resource_name end |
#start_time ⇒ String
Output only. The timestamp when the CustomerManagerLink was created. The
timestamp is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format.
Corresponds to the JSON property startTime
28350 28351 28352 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28350 def start_time @start_time end |
#status ⇒ String
Status of the link between the customer and the manager.
Corresponds to the JSON property status
28355 28356 28357 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28355 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28362 28363 28364 28365 28366 28367 28368 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28362 def update!(**args) @manager_customer = args[:manager_customer] if args.key?(:manager_customer) @manager_link_id = args[:manager_link_id] if args.key?(:manager_link_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) end |