Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A negative criterion for exclusions at the customer level.
Instance Attribute Summary collapse
-
#content_label ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonContentLabelInfo
Content Label for category exclusion.
-
#id ⇒ Fixnum
Output only.
-
#ip_block ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIpBlockInfo
An IpBlock criterion used for excluding IP addresses.
-
#mobile_app_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo
A mobile app category criterion.
-
#mobile_application ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo
A mobile application criterion.
-
#negative_keyword_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonNegativeKeywordListInfo
A Negative Keyword List criterion.
-
#placement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo
A placement criterion.
-
#placement_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementListInfo
A Placement List criterion.
-
#resource_name ⇒ String
Immutable.
-
#type ⇒ String
Output only.
-
#youtube_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
A YouTube Channel criterion.
-
#youtube_video ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
A YouTube Video criterion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion.
28449 28450 28451 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28449 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_label ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonContentLabelInfo
Content Label for category exclusion.
Corresponds to the JSON property contentLabel
28378 28379 28380 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28378 def content_label @content_label end |
#id ⇒ Fixnum
Output only. The ID of the criterion.
Corresponds to the JSON property id
28383 28384 28385 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28383 def id @id end |
#ip_block ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIpBlockInfo
An IpBlock criterion used for excluding IP addresses. We support excluding
individual IP addresses or CIDR blocks. Create one IpBlockInfo criterion for
each individual IP address or CIDR block you want to exclude. You can exclude
up to 500 IP addresses per campaign. For more details, see Exclude IP
addresses. IPv4 examples: *
Individual address: 192.168.0.1 * Individual address as CIDR block: 192.168.0.
1/32 * CIDR block: 192.168.0.0/24 IPv6 examples: * Individual address: 2001:
db8:a0b:12f0::1 * Individual address as CIDR block: 2001:db8:a0b:12f0::1/128 *
CIDR block: 2001:db8::/48
Corresponds to the JSON property ipBlock
28396 28397 28398 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28396 def ip_block @ip_block end |
#mobile_app_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo
A mobile app category criterion.
Corresponds to the JSON property mobileAppCategory
28401 28402 28403 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28401 def mobile_app_category @mobile_app_category end |
#mobile_application ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo
A mobile application criterion.
Corresponds to the JSON property mobileApplication
28406 28407 28408 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28406 def mobile_application @mobile_application end |
#negative_keyword_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonNegativeKeywordListInfo
A Negative Keyword List criterion. Represents a shared set of negative
keywords that can be excluded at the account-level. Only one negative keyword
list criterion can be attached per account.
Corresponds to the JSON property negativeKeywordList
28413 28414 28415 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28413 def negative_keyword_list @negative_keyword_list end |
#placement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo
A placement criterion. This can be used to modify bids for sites when
targeting the content network.
Corresponds to the JSON property placement
28419 28420 28421 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28419 def placement @placement end |
#placement_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementListInfo
A Placement List criterion. Represents a shared set of placements that can be
excluded at the account-level.
Corresponds to the JSON property placementList
28425 28426 28427 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28425 def placement_list @placement_list end |
#resource_name ⇒ String
Immutable. The resource name of the customer negative criterion. Customer
negative criterion resource names have the form: customers/customer_id/
customerNegativeCriteria/criterion_id`
Corresponds to the JSON propertyresourceName`
28432 28433 28434 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28432 def resource_name @resource_name end |
#type ⇒ String
Output only. The type of the criterion.
Corresponds to the JSON property type
28437 28438 28439 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28437 def type @type end |
#youtube_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
A YouTube Channel criterion.
Corresponds to the JSON property youtubeChannel
28442 28443 28444 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28442 def youtube_channel @youtube_channel end |
#youtube_video ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
A YouTube Video criterion.
Corresponds to the JSON property youtubeVideo
28447 28448 28449 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28447 def youtube_video @youtube_video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28454 28455 28456 28457 28458 28459 28460 28461 28462 28463 28464 28465 28466 28467 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28454 def update!(**args) @content_label = args[:content_label] if args.key?(:content_label) @id = args[:id] if args.key?(:id) @ip_block = args[:ip_block] if args.key?(:ip_block) @mobile_app_category = args[:mobile_app_category] if args.key?(:mobile_app_category) @mobile_application = args[:mobile_application] if args.key?(:mobile_application) @negative_keyword_list = args[:negative_keyword_list] if args.key?(:negative_keyword_list) @placement = args[:placement] if args.key?(:placement) @placement_list = args[:placement_list] if args.key?(:placement_list) @resource_name = args[:resource_name] if args.key?(:resource_name) @type = args[:type] if args.key?(:type) @youtube_channel = args[:youtube_channel] if args.key?(:youtube_channel) @youtube_video = args[:youtube_video] if args.key?(:youtube_video) end |