Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSearchTermInsight

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

This report provides a high-level view of search demand at the customer level by grouping similar search terms into categories and showing their search volume. Historical data is available starting March 2023.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerSearchTermInsight

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerSearchTermInsight.



28494
28495
28496
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_labelString

Output only. The label for the search category. An empty string denotes the catch-all category for search terms that didn't fit into another category. Corresponds to the JSON property categoryLabel

Returns:

  • (String)


28480
28481
28482
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28480

def category_label
  @category_label
end

#idFixnum

Output only. The ID of the insight. Corresponds to the JSON property id

Returns:

  • (Fixnum)


28485
28486
28487
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28485

def id
  @id
end

#resource_nameString

Output only. The resource name of the customer level search term insight. Customer level search term insight resource names have the form: customers/ customer_id/customerSearchTermInsights/category_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28492
28493
28494
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28492

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28499
28500
28501
28502
28503
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28499

def update!(**args)
  @category_label = args[:category_label] if args.key?(:category_label)
  @id = args[:id] if args.key?(:id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end