Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaPostbackMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Mappings for each postback in multiple conversion windows.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaPostbackMapping

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaPostbackMapping.



16932
16933
16934
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16932

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#coarse_grained_conversion_value_mappingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaCoarseGrainedConversionValueMappings

Mappings for coarse grained conversion values. Corresponds to the JSON property coarseGrainedConversionValueMappings



16907
16908
16909
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16907

def coarse_grained_conversion_value_mappings
  @coarse_grained_conversion_value_mappings
end

#lock_window_coarse_conversion_valueString

Output only. Coarse grained conversion value that triggers conversion window lock. Corresponds to the JSON property lockWindowCoarseConversionValue

Returns:

  • (String)


16913
16914
16915
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16913

def lock_window_coarse_conversion_value
  @lock_window_coarse_conversion_value
end

#lock_window_eventString

Output only. Event name that triggers conversion window lock. Corresponds to the JSON property lockWindowEvent

Returns:

  • (String)


16918
16919
16920
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16918

def lock_window_event
  @lock_window_event
end

#lock_window_fine_conversion_valueFixnum

Output only. Fine grained conversion value that triggers conversion window lock. Corresponds to the JSON property lockWindowFineConversionValue

Returns:

  • (Fixnum)


16924
16925
16926
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16924

def lock_window_fine_conversion_value
  @lock_window_fine_conversion_value
end

#postback_sequence_indexFixnum

Output only. 0-based index that indicates the order of postback. Valid values are in the inclusive range [0,2]. Corresponds to the JSON property postbackSequenceIndex

Returns:

  • (Fixnum)


16930
16931
16932
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16930

def postback_sequence_index
  @postback_sequence_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16937
16938
16939
16940
16941
16942
16943
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16937

def update!(**args)
  @coarse_grained_conversion_value_mappings = args[:coarse_grained_conversion_value_mappings] if args.key?(:coarse_grained_conversion_value_mappings)
  @lock_window_coarse_conversion_value = args[:lock_window_coarse_conversion_value] if args.key?(:lock_window_coarse_conversion_value)
  @lock_window_event = args[:lock_window_event] if args.key?(:lock_window_event)
  @lock_window_fine_conversion_value = args[:lock_window_fine_conversion_value] if args.key?(:lock_window_fine_conversion_value)
  @postback_sequence_index = args[:postback_sequence_index] if args.key?(:postback_sequence_index)
end