Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccess

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents the permission of a single user onto a single customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerUserAccess

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerUserAccess.



28571
28572
28573
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28571

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_creation_date_timeString

Output only. The customer user access creation time. Read only field The format is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05 09:15:00" or "2018-02- 01 14:34:30" Corresponds to the JSON property accessCreationDateTime

Returns:

  • (String)


28543
28544
28545
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28543

def access_creation_date_time
  @access_creation_date_time
end

#access_roleString

Access role of the user. Corresponds to the JSON property accessRole

Returns:

  • (String)


28548
28549
28550
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28548

def access_role
  @access_role
end

#email_addressString

Output only. Email address of the user. Read only field Corresponds to the JSON property emailAddress

Returns:

  • (String)


28553
28554
28555
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28553

def email_address
  @email_address
end

#inviter_user_email_addressString

Output only. The email address of the inviter user. Read only field Corresponds to the JSON property inviterUserEmailAddress

Returns:

  • (String)


28558
28559
28560
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28558

def inviter_user_email_address
  @inviter_user_email_address
end

#resource_nameString

Immutable. Name of the resource. Resource names have the form: customers/ customer_id/customerUserAccesses/user_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28564
28565
28566
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28564

def resource_name
  @resource_name
end

#user_idFixnum

Output only. User id of the user with the customer access. Read only field Corresponds to the JSON property userId

Returns:

  • (Fixnum)


28569
28570
28571
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28569

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28576
28577
28578
28579
28580
28581
28582
28583
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28576

def update!(**args)
  @access_creation_date_time = args[:access_creation_date_time] if args.key?(:access_creation_date_time)
  @access_role = args[:access_role] if args.key?(:access_role)
  @email_address = args[:email_address] if args.key?(:email_address)
  @inviter_user_email_address = args[:inviter_user_email_address] if args.key?(:inviter_user_email_address)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @user_id = args[:user_id] if args.key?(:user_id)
end