Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represent an invitation to a new user on this customer account.
Instance Attribute Summary collapse
-
#access_role ⇒ String
Immutable.
-
#creation_date_time ⇒ String
Output only.
-
#email_address ⇒ String
Immutable.
-
#invitation_id ⇒ Fixnum
Output only.
-
#invitation_status ⇒ String
Output only.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation.
28624 28625 28626 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28624 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_role ⇒ String
Immutable. Access role of the user.
Corresponds to the JSON property accessRole
28593 28594 28595 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28593 def access_role @access_role end |
#creation_date_time ⇒ String
Output only. Time invitation was created. This field is read-only. The format
is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34:
30"
Corresponds to the JSON property creationDateTime
28600 28601 28602 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28600 def creation_date_time @creation_date_time end |
#email_address ⇒ String
Immutable. Email address the invitation was sent to. This can differ from the
email address of the account that accepts the invite.
Corresponds to the JSON property emailAddress
28606 28607 28608 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28606 def email_address @email_address end |
#invitation_id ⇒ Fixnum
Output only. The ID of the invitation. This field is read-only.
Corresponds to the JSON property invitationId
28611 28612 28613 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28611 def invitation_id @invitation_id end |
#invitation_status ⇒ String
Output only. Invitation status of the user.
Corresponds to the JSON property invitationStatus
28616 28617 28618 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28616 def invitation_status @invitation_status end |
#resource_name ⇒ String
Immutable. Name of the resource. Resource names have the form: customers/
customer_id/customerUserAccessInvitations/invitation_id`
Corresponds to the JSON propertyresourceName`
28622 28623 28624 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28622 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28629 28630 28631 28632 28633 28634 28635 28636 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28629 def update!(**args) @access_role = args[:access_role] if args.key?(:access_role) @creation_date_time = args[:creation_date_time] if args.key?(:creation_date_time) @email_address = args[:email_address] if args.key?(:email_address) @invitation_id = args[:invitation_id] if args.key?(:invitation_id) @invitation_status = args[:invitation_status] if args.key?(:invitation_status) @resource_name = args[:resource_name] if args.key?(:resource_name) end |