Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomizerAttribute
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomizerAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A customizer attribute. Use CustomerCustomizer, CampaignCustomizer, AdGroupCustomizer, or AdGroupCriterionCustomizer to associate a customizer attribute and set its value at the customer, campaign, ad group, or ad group criterion level, respectively.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Required.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#type ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomizerAttribute
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomizerAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomizerAttribute
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomizerAttribute.
28675 28676 28677 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28675 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. The ID of the customizer attribute.
Corresponds to the JSON property id
28649 28650 28651 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28649 def id @id end |
#name ⇒ String
Required. Immutable. Name of the customizer attribute. Required. It must have
a minimum length of 1 and maximum length of 40. Name of an enabled customizer
attribute must be unique (case insensitive).
Corresponds to the JSON property name
28656 28657 28658 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28656 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the customizer attribute. Customizer Attribute
resource names have the form: customers/customer_id/customizerAttributes/
customizer_attribute_id`
Corresponds to the JSON propertyresourceName`
28663 28664 28665 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28663 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the customizer attribute.
Corresponds to the JSON property status
28668 28669 28670 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28668 def status @status end |
#type ⇒ String
Immutable. The type of the customizer attribute.
Corresponds to the JSON property type
28673 28674 28675 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28673 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28680 28681 28682 28683 28684 28685 28686 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28680 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) end |