Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDataPartnerIdentifier

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The identifier for Data Partner account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDataPartnerIdentifier

Returns a new instance of GoogleAdsSearchads360V23ResourcesDataPartnerIdentifier.



28590
28591
28592
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28590

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_partner_idFixnum

Immutable. The customer ID of the Data partner account. This field is required and should not be empty when creating a new data partner link. It is unable to be modified after the creation of the link. Corresponds to the JSON property dataPartnerId

Returns:

  • (Fixnum)


28588
28589
28590
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28588

def data_partner_id
  @data_partner_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28595
28596
28597
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28595

def update!(**args)
  @data_partner_id = args[:data_partner_id] if args.key?(:data_partner_id)
end