Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDetailContentSuitabilityPlacementView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A detail content suitability placement view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDetailContentSuitabilityPlacementView

Returns a new instance of GoogleAdsSearchads360V23ResourcesDetailContentSuitabilityPlacementView.



28796
28797
28798
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28796

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name is URL for websites, YouTube video name for YouTube videos, and translated mobile app name for mobile apps. Corresponds to the JSON property displayName

Returns:

  • (String)


28768
28769
28770
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28768

def display_name
  @display_name
end

#placementString

Output only. The automatic placement string at detail level, for example. website url, mobile application id, or a YouTube video id. Corresponds to the JSON property placement

Returns:

  • (String)


28774
28775
28776
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28774

def placement
  @placement
end

#placement_typeString

Output only. Represents the type of the placement, for example, Website, YouTubeVideo and MobileApplication. Corresponds to the JSON property placementType

Returns:

  • (String)


28780
28781
28782
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28780

def placement_type
  @placement_type
end

#resource_nameString

Output only. The resource name of the detail content suitability placement view. Detail content suitability placement view resource names have the form: customers/customer_id/detailContentSuitabilityPlacementViews/ placement_fingerprint` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28788
28789
28790
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28788

def resource_name
  @resource_name
end

#target_urlString

Output only. URL of the placement, for example, website, link to the mobile application in app store, or a YouTube video URL. Corresponds to the JSON property targetUrl

Returns:

  • (String)


28794
28795
28796
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28794

def target_url
  @target_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28801
28802
28803
28804
28805
28806
28807
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28801

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @placement = args[:placement] if args.key?(:placement)
  @placement_type = args[:placement_type] if args.key?(:placement_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @target_url = args[:target_url] if args.key?(:target_url)
end