Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDetailPlacementView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A view with metrics aggregated by ad group and URL or YouTube video. Provides granular performance data about specific URLs, YouTube videos, and apps where your ads showed. This offers a more detailed breakdown compared to the group_placement_view. This view primarily surfaces placement data from the Google Display Network. While you can select segments like segments. ad_network_type, this view generally does not include placement data from other networks, such as the Search Partners network. To understand performance on Search Partners, consider other reports and segmentations. Data for low- traffic placements may be aggregated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDetailPlacementView

Returns a new instance of GoogleAdsSearchads360V23ResourcesDetailPlacementView.



28859
28860
28861
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28859

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name is URL name for websites, YouTube video name for YouTube videos, and translated mobile app name for mobile apps. Corresponds to the JSON property displayName

Returns:

  • (String)


28826
28827
28828
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28826

def display_name
  @display_name
end

#group_placement_target_urlString

Output only. URL of the group placement, for example, domain, link to the mobile application in app store, or a YouTube channel URL. Corresponds to the JSON property groupPlacementTargetUrl

Returns:

  • (String)


28832
28833
28834
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28832

def group_placement_target_url
  @group_placement_target_url
end

#placementString

Output only. The automatic placement string at detail level, e. g. website URL, mobile application ID, or a YouTube video ID. Corresponds to the JSON property placement

Returns:

  • (String)


28838
28839
28840
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28838

def placement
  @placement
end

#placement_typeString

Output only. Type of the placement, for example, Website, YouTube Video, and Mobile Application. Corresponds to the JSON property placementType

Returns:

  • (String)


28844
28845
28846
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28844

def placement_type
  @placement_type
end

#resource_nameString

Output only. The resource name of the detail placement view. Detail placement view resource names have the form: customers/customer_id/ detailPlacementViews/ad_group_id~base64_placement` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28851
28852
28853
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28851

def resource_name
  @resource_name
end

#target_urlString

Output only. URL of the placement, for example, website, link to the mobile application in app store, or a YouTube video URL. Corresponds to the JSON property targetUrl

Returns:

  • (String)


28857
28858
28859
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28857

def target_url
  @target_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28864
28865
28866
28867
28868
28869
28870
28871
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28864

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @group_placement_target_url = args[:group_placement_target_url] if args.key?(:group_placement_target_url)
  @placement = args[:placement] if args.key?(:placement)
  @placement_type = args[:placement_type] if args.key?(:placement_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @target_url = args[:target_url] if args.key?(:target_url)
end