Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDetailedDemographic

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A detailed demographic: a particular interest-based vertical to be targeted to reach users based on long-term life facts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDetailedDemographic

Returns a new instance of GoogleAdsSearchads360V23ResourcesDetailedDemographic.



28914
28915
28916
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28914

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availabilitiesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryAvailability>

Output only. Availability information of the detailed demographic. Corresponds to the JSON property availabilities



28882
28883
28884
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28882

def availabilities
  @availabilities
end

#idFixnum

Output only. The ID of the detailed demographic. Corresponds to the JSON property id

Returns:

  • (Fixnum)


28887
28888
28889
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28887

def id
  @id
end

#launched_to_allBoolean Also known as: launched_to_all?

Output only. True if the detailed demographic is launched to all channels and locales. Corresponds to the JSON property launchedToAll

Returns:

  • (Boolean)


28893
28894
28895
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28893

def launched_to_all
  @launched_to_all
end

#nameString

Output only. The name of the detailed demographic. For example,"Highest Level of Educational Attainment" Corresponds to the JSON property name

Returns:

  • (String)


28900
28901
28902
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28900

def name
  @name
end

#parentString

Output only. The parent of the detailed_demographic. Corresponds to the JSON property parent

Returns:

  • (String)


28905
28906
28907
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28905

def parent
  @parent
end

#resource_nameString

Output only. The resource name of the detailed demographic. Detailed demographic resource names have the form: customers/customer_id/ detailedDemographics/detailed_demographic_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28912
28913
28914
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28912

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28919
28920
28921
28922
28923
28924
28925
28926
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28919

def update!(**args)
  @availabilities = args[:availabilities] if args.key?(:availabilities)
  @id = args[:id] if args.key?(:id)
  @launched_to_all = args[:launched_to_all] if args.key?(:launched_to_all)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end