Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDistanceView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A distance view with metrics aggregated by the user's distance from an advertiser's location extensions. Each DistanceBucket includes all impressions that fall within its distance and a single impression will contribute to the metrics for all DistanceBuckets that include the user's distance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDistanceView

Returns a new instance of GoogleAdsSearchads360V23ResourcesDistanceView.



28985
28986
28987
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28985

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#distance_bucketString

Output only. Grouping of user distance from location extensions. Corresponds to the JSON property distanceBucket

Returns:

  • (String)


28969
28970
28971
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28969

def distance_bucket
  @distance_bucket
end

#metric_systemBoolean Also known as: metric_system?

Output only. True if the DistanceBucket is using the metric system, false otherwise. Corresponds to the JSON property metricSystem

Returns:

  • (Boolean)


28975
28976
28977
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28975

def metric_system
  @metric_system
end

#resource_nameString

Output only. The resource name of the distance view. Distance view resource names have the form: customers/customer_id/distanceViews/1~distance_bucket Corresponds to the JSON property resourceName

Returns:

  • (String)


28983
28984
28985
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28983

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28990
28991
28992
28993
28994
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28990

def update!(**args)
  @distance_bucket = args[:distance_bucket] if args.key?(:distance_bucket)
  @metric_system = args[:metric_system] if args.key?(:metric_system)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end