Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

DoubleClick Campaign Manager (DCM) setting for a manager customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting

Returns a new instance of GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting.



29018
29019
29020
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29018

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. ID of the Campaign Manager advertiser associated with this customer. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


29005
29006
29007
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29005

def advertiser_id
  @advertiser_id
end

#network_idFixnum

Output only. ID of the Campaign Manager network associated with this customer. Corresponds to the JSON property networkId

Returns:

  • (Fixnum)


29010
29011
29012
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29010

def network_id
  @network_id
end

#time_zoneString

Output only. Time zone of the Campaign Manager network associated with this customer in IANA Time Zone Database format, such as America/New_York. Corresponds to the JSON property timeZone

Returns:

  • (String)


29016
29017
29018
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29016

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29023
29024
29025
29026
29027
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29023

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @network_id = args[:network_id] if args.key?(:network_id)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end