Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArm

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Google ads experiment for users to experiment changes on multiple campaigns, compare the performance, and apply the effective changes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesExperimentArm

Returns a new instance of GoogleAdsSearchads360V23ResourcesExperimentArm.



29291
29292
29293
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29291

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_groupsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArmAssetGroupInfo>

List of asset groups in the experiment arm. The max length is one. In the Optimize Assets experiment construction, the control arm and treatment arm should both contain the same asset group ID. Corresponds to the JSON property assetGroups



29248
29249
29250
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29248

def asset_groups
  @asset_groups
end

#campaignsArray<String>

List of campaigns in the trial arm. The max length is one. Corresponds to the JSON property campaigns

Returns:

  • (Array<String>)


29253
29254
29255
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29253

def campaigns
  @campaigns
end

#controlBoolean Also known as: control?

Whether this arm is a control arm. A control arm is the arm against which the other arms are compared. Corresponds to the JSON property control

Returns:

  • (Boolean)


29259
29260
29261
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29259

def control
  @control
end

#experimentString

Immutable. The experiment to which the ExperimentArm belongs. Corresponds to the JSON property experiment

Returns:

  • (String)


29265
29266
29267
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29265

def experiment
  @experiment
end

#in_design_campaignsArray<String>

Output only. The in design campaigns in the treatment experiment arm. Corresponds to the JSON property inDesignCampaigns

Returns:

  • (Array<String>)


29270
29271
29272
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29270

def in_design_campaigns
  @in_design_campaigns
end

#nameString

Required. The name of the experiment arm. It must have a minimum length of 1 and maximum length of 1024. It must be unique under an experiment. Corresponds to the JSON property name

Returns:

  • (String)


29276
29277
29278
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29276

def name
  @name
end

#resource_nameString

Immutable. The resource name of the experiment arm. Experiment arm resource names have the form: customers/customer_id/experimentArms/TrialArm. trial_id~TrialArm.trial_arm_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


29283
29284
29285
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29283

def resource_name
  @resource_name
end

#traffic_splitFixnum

Traffic split of the trial arm. The value should be between 1 and 100 and must total 100 between the two trial arms. Corresponds to the JSON property trafficSplit

Returns:

  • (Fixnum)


29289
29290
29291
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29289

def traffic_split
  @traffic_split
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29296
29297
29298
29299
29300
29301
29302
29303
29304
29305
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29296

def update!(**args)
  @asset_groups = args[:asset_groups] if args.key?(:asset_groups)
  @campaigns = args[:campaigns] if args.key?(:campaigns)
  @control = args[:control] if args.key?(:control)
  @experiment = args[:experiment] if args.key?(:experiment)
  @in_design_campaigns = args[:in_design_campaigns] if args.key?(:in_design_campaigns)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @traffic_split = args[:traffic_split] if args.key?(:traffic_split)
end