Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGenderView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A gender view resource. Represents the view of a customer's performance metrics aggregated by gender. All statistics are aggregated at the ad group level. Note: While you can segment metrics by age range using age_range_view or by gender using gender_view, the Search Ads 360 API does not support segmenting metrics by both age range and gender simultaneously in a single query. Analyzing performance across both dimensions combined is not supported in the Search Ads 360 API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGenderView

Returns a new instance of GoogleAdsSearchads360V23ResourcesGenderView.



29413
29414
29415
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_nameString

Output only. The resource name of the gender view. Gender view resource names have the form: customers/customer_id/genderViews/ad_group_id~ criterion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


29411
29412
29413
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29411

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29418
29419
29420
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29418

def update!(**args)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end