Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInsuranceVerificationArtifact
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInsuranceVerificationArtifact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
specific to a local services insurance.
Instance Attribute Summary collapse
-
#amount_micros ⇒ Fixnum
Output only.
-
#expiration_date_time ⇒ String
Output only.
-
#insurance_document_readonly ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalServicesDocumentReadOnly
A Local Services Document with read only accessible data.
-
#rejection_reason ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesInsuranceVerificationArtifact
constructor
A new instance of GoogleAdsSearchads360V23ResourcesInsuranceVerificationArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesInsuranceVerificationArtifact
Returns a new instance of GoogleAdsSearchads360V23ResourcesInsuranceVerificationArtifact.
29912 29913 29914 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amount_micros ⇒ Fixnum
Output only. Insurance amount. This is measured in "micros" of the currency
mentioned in the insurance document.
Corresponds to the JSON property amountMicros
29893 29894 29895 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29893 def amount_micros @amount_micros end |
#expiration_date_time ⇒ String
Output only. The timestamp when this insurance expires. The format is "YYYY-MM-
DD HH:MM:SS" in the Google Ads account's timezone. Examples: "2018-03-05 09:15:
00" or "2018-02-01 14:34:30"
Corresponds to the JSON property expirationDateTime
29900 29901 29902 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29900 def expiration_date_time @expiration_date_time end |
#insurance_document_readonly ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalServicesDocumentReadOnly
A Local Services Document with read only accessible data.
Corresponds to the JSON property insuranceDocumentReadonly
29905 29906 29907 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29905 def insurance_document_readonly @insurance_document_readonly end |
#rejection_reason ⇒ String
Output only. Insurance document's rejection reason.
Corresponds to the JSON property rejectionReason
29910 29911 29912 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29910 def rejection_reason @rejection_reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29917 29918 29919 29920 29921 29922 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29917 def update!(**args) @amount_micros = args[:amount_micros] if args.key?(:amount_micros) @expiration_date_time = args[:expiration_date_time] if args.key?(:expiration_date_time) @insurance_document_readonly = args[:insurance_document_readonly] if args.key?(:insurance_document_readonly) @rejection_reason = args[:rejection_reason] if args.key?(:rejection_reason) end |