Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoice

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An invoice. All invoice information is snapshotted to match the PDF invoice. For invoices older than the launch of InvoiceService, the snapshotted information may not match the PDF invoice.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesInvoice

Returns a new instance of GoogleAdsSearchads360V23ResourcesInvoice.



30171
30172
30173
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30171

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_budget_summariesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceAccountBudgetSummary>

Output only. The list of summarized account budget information associated with this invoice. Corresponds to the JSON property accountBudgetSummaries



30007
30008
30009
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30007

def 
  @account_budget_summaries
end

#account_summariesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceAccountSummary>

Output only. The list of summarized account information associated with this invoice. Corresponds to the JSON property accountSummaries



30013
30014
30015
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30013

def 
  @account_summaries
end

#adjustments_subtotal_amount_microsFixnum

Output only. The pretax subtotal amount of invoice level adjustments, in micros. Corresponds to the JSON property adjustmentsSubtotalAmountMicros

Returns:

  • (Fixnum)


30019
30020
30021
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30019

def adjustments_subtotal_amount_micros
  @adjustments_subtotal_amount_micros
end

#adjustments_tax_amount_microsFixnum

Output only. The sum of taxes on the invoice level adjustments, in micros. Corresponds to the JSON property adjustmentsTaxAmountMicros

Returns:

  • (Fixnum)


30024
30025
30026
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30024

def adjustments_tax_amount_micros
  @adjustments_tax_amount_micros
end

#adjustments_total_amount_microsFixnum

Output only. The total amount of invoice level adjustments, in micros. Corresponds to the JSON property adjustmentsTotalAmountMicros

Returns:

  • (Fixnum)


30029
30030
30031
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30029

def adjustments_total_amount_micros
  @adjustments_total_amount_micros
end

#billing_setupString

Output only. The resource name of this invoice's billing setup. customers/ customer_id/billingSetups/billing_setup_id` Corresponds to the JSON propertybillingSetup`

Returns:

  • (String)


30035
30036
30037
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30035

def billing_setup
  @billing_setup
end

#corrected_invoiceString

Output only. The resource name of the original invoice corrected, wrote off, or canceled by this invoice, if applicable. If corrected_invoice is set, replaced_invoices will not be set. Invoice resource names have the form: customers/customer_id/invoices/invoice_id` Corresponds to the JSON propertycorrectedInvoice`

Returns:

  • (String)


30043
30044
30045
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30043

def corrected_invoice
  @corrected_invoice
end

#currency_codeString

Output only. The currency code. All costs are returned in this currency. A subset of the currency codes derived from the ISO 4217 standard is supported. Corresponds to the JSON property currencyCode

Returns:

  • (String)


30049
30050
30051
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30049

def currency_code
  @currency_code
end

#due_dateString

Output only. The due date in yyyy-mm-dd format. Corresponds to the JSON property dueDate

Returns:

  • (String)


30054
30055
30056
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30054

def due_date
  @due_date
end

#export_charge_subtotal_amount_microsFixnum

Output only. The pretax subtotal amount of invoice level export charges, in micros. Corresponds to the JSON property exportChargeSubtotalAmountMicros

Returns:

  • (Fixnum)


30060
30061
30062
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30060

def export_charge_subtotal_amount_micros
  @export_charge_subtotal_amount_micros
end

#export_charge_tax_amount_microsFixnum

Output only. The sum of taxes on the invoice level export charges, in micros. Corresponds to the JSON property exportChargeTaxAmountMicros

Returns:

  • (Fixnum)


30065
30066
30067
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30065

def export_charge_tax_amount_micros
  @export_charge_tax_amount_micros
end

#export_charge_total_amount_microsFixnum

Output only. The total amount of invoice level export charges, in micros. Corresponds to the JSON property exportChargeTotalAmountMicros

Returns:

  • (Fixnum)


30070
30071
30072
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30070

def export_charge_total_amount_micros
  @export_charge_total_amount_micros
end

#idString

Output only. The ID of the invoice. It appears on the invoice PDF as "Invoice number". Corresponds to the JSON property id

Returns:

  • (String)


30076
30077
30078
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30076

def id
  @id
end

#issue_dateString

Output only. The issue date in yyyy-mm-dd format. It appears on the invoice PDF as either "Issue date" or "Invoice date". Corresponds to the JSON property issueDate

Returns:

  • (String)


30082
30083
30084
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30082

def issue_date
  @issue_date
end

#payments_account_idString

Output only. A 16 digit ID used to identify the payments account associated with the billing setup, for example, "1234-5678-9012-3456". It appears on the invoice PDF as "Billing Account Number". Corresponds to the JSON property paymentsAccountId

Returns:

  • (String)


30089
30090
30091
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30089

def 
  @payments_account_id
end

#payments_profile_idString

Output only. A 12 digit ID used to identify the payments profile associated with the billing setup, for example, "1234-5678-9012". It appears on the invoice PDF as "Billing ID". Corresponds to the JSON property paymentsProfileId

Returns:

  • (String)


30096
30097
30098
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30096

def payments_profile_id
  @payments_profile_id
end

#pdf_urlString

Output only. The URL to a PDF copy of the invoice. Users need to pass in their OAuth token to request the PDF with this URL. Corresponds to the JSON property pdfUrl

Returns:

  • (String)


30102
30103
30104
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30102

def pdf_url
  @pdf_url
end

#regulatory_costs_subtotal_amount_microsFixnum

Output only. The pretax subtotal amount of invoice level regulatory costs, in micros. Corresponds to the JSON property regulatoryCostsSubtotalAmountMicros

Returns:

  • (Fixnum)


30108
30109
30110
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30108

def regulatory_costs_subtotal_amount_micros
  @regulatory_costs_subtotal_amount_micros
end

#regulatory_costs_tax_amount_microsFixnum

Output only. The sum of taxes on the invoice level regulatory costs, in micros. Corresponds to the JSON property regulatoryCostsTaxAmountMicros

Returns:

  • (Fixnum)


30113
30114
30115
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30113

def regulatory_costs_tax_amount_micros
  @regulatory_costs_tax_amount_micros
end

#regulatory_costs_total_amount_microsFixnum

Output only. The total amount of invoice level regulatory costs, in micros. Corresponds to the JSON property regulatoryCostsTotalAmountMicros

Returns:

  • (Fixnum)


30118
30119
30120
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30118

def regulatory_costs_total_amount_micros
  @regulatory_costs_total_amount_micros
end

#replaced_invoicesArray<String>

Output only. The resource name of the original invoice(s) being rebilled or replaced by this invoice, if applicable. There might be multiple replaced invoices due to invoice consolidation. The replaced invoices may not belong to the same payments account. If replaced_invoices is set, corrected_invoice will not be set. Invoice resource names have the form: customers/customer_id /invoices/invoice_id` Corresponds to the JSON propertyreplacedInvoices`

Returns:

  • (Array<String>)


30128
30129
30130
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30128

def replaced_invoices
  @replaced_invoices
end

#resource_nameString

Output only. The resource name of the invoice. Multiple customers can share a given invoice, so multiple resource names may point to the same invoice. Invoice resource names have the form: customers/customer_id/invoices/ invoice_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


30136
30137
30138
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30136

def resource_name
  @resource_name
end

#service_date_rangeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDateRange

A date range. Corresponds to the JSON property serviceDateRange



30141
30142
30143
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30141

def service_date_range
  @service_date_range
end

#subtotal_amount_microsFixnum

Output only. The pretax subtotal amount, in micros. This is equal to the sum of the AccountBudgetSummary subtotal amounts and Invoice. adjustments_subtotal_amount_micros. Corresponds to the JSON property subtotalAmountMicros

Returns:

  • (Fixnum)


30148
30149
30150
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30148

def subtotal_amount_micros
  @subtotal_amount_micros
end

#tax_amount_microsFixnum

Output only. The sum of all taxes on the invoice, in micros. This equals the sum of the AccountBudgetSummary tax amounts, plus taxes not associated with a specific account budget. Corresponds to the JSON property taxAmountMicros

Returns:

  • (Fixnum)


30155
30156
30157
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30155

def tax_amount_micros
  @tax_amount_micros
end

#total_amount_microsFixnum

Output only. The total amount, in micros. This equals the sum of Invoice. subtotal_amount_micros, Invoice.tax_amount_micros, Invoice. regulatory_costs_subtotal_amount_micros, and Invoice. export_charge_subtotal_amount_micros (which is separated into a separate line item starting with V14.1). Corresponds to the JSON property totalAmountMicros

Returns:

  • (Fixnum)


30164
30165
30166
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30164

def total_amount_micros
  @total_amount_micros
end

#typeString

Output only. The type of invoice. Corresponds to the JSON property type

Returns:

  • (String)


30169
30170
30171
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30169

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30176
30177
30178
30179
30180
30181
30182
30183
30184
30185
30186
30187
30188
30189
30190
30191
30192
30193
30194
30195
30196
30197
30198
30199
30200
30201
30202
30203
30204
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30176

def update!(**args)
  @account_budget_summaries = args[:account_budget_summaries] if args.key?(:account_budget_summaries)
  @account_summaries = args[:account_summaries] if args.key?(:account_summaries)
  @adjustments_subtotal_amount_micros = args[:adjustments_subtotal_amount_micros] if args.key?(:adjustments_subtotal_amount_micros)
  @adjustments_tax_amount_micros = args[:adjustments_tax_amount_micros] if args.key?(:adjustments_tax_amount_micros)
  @adjustments_total_amount_micros = args[:adjustments_total_amount_micros] if args.key?(:adjustments_total_amount_micros)
  @billing_setup = args[:billing_setup] if args.key?(:billing_setup)
  @corrected_invoice = args[:corrected_invoice] if args.key?(:corrected_invoice)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @due_date = args[:due_date] if args.key?(:due_date)
  @export_charge_subtotal_amount_micros = args[:export_charge_subtotal_amount_micros] if args.key?(:export_charge_subtotal_amount_micros)
  @export_charge_tax_amount_micros = args[:export_charge_tax_amount_micros] if args.key?(:export_charge_tax_amount_micros)
  @export_charge_total_amount_micros = args[:export_charge_total_amount_micros] if args.key?(:export_charge_total_amount_micros)
  @id = args[:id] if args.key?(:id)
  @issue_date = args[:issue_date] if args.key?(:issue_date)
  @payments_account_id = args[:payments_account_id] if args.key?(:payments_account_id)
  @payments_profile_id = args[:payments_profile_id] if args.key?(:payments_profile_id)
  @pdf_url = args[:pdf_url] if args.key?(:pdf_url)
  @regulatory_costs_subtotal_amount_micros = args[:regulatory_costs_subtotal_amount_micros] if args.key?(:regulatory_costs_subtotal_amount_micros)
  @regulatory_costs_tax_amount_micros = args[:regulatory_costs_tax_amount_micros] if args.key?(:regulatory_costs_tax_amount_micros)
  @regulatory_costs_total_amount_micros = args[:regulatory_costs_total_amount_micros] if args.key?(:regulatory_costs_total_amount_micros)
  @replaced_invoices = args[:replaced_invoices] if args.key?(:replaced_invoices)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @service_date_range = args[:service_date_range] if args.key?(:service_date_range)
  @subtotal_amount_micros = args[:subtotal_amount_micros] if args.key?(:subtotal_amount_micros)
  @tax_amount_micros = args[:tax_amount_micros] if args.key?(:tax_amount_micros)
  @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros)
  @type = args[:type] if args.key?(:type)
end