Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceCampaignSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents campaign level billable cost information associated with an account budget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesInvoiceCampaignSummary

Returns a new instance of GoogleAdsSearchads360V23ResourcesInvoiceCampaignSummary.



17418
17419
17420
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amount_microsFixnum

Output only. The amount attributable to this campaign for the given unit of measure during the service period, in micros. The currency code for this amount is the same as the Invoice.currency_code. Corresponds to the JSON property amountMicros

Returns:

  • (Fixnum)


17400
17401
17402
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17400

def amount_micros
  @amount_micros
end

#campaign_descriptionString

Output only. The description of the campaign. This is generally the same as the campaign name, but may differ. Corresponds to the JSON property campaignDescription

Returns:

  • (String)


17406
17407
17408
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17406

def campaign_description
  @campaign_description
end

#quantityFixnum

Output only. The quantity served for the given unit of measure. Corresponds to the JSON property quantity

Returns:

  • (Fixnum)


17411
17412
17413
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17411

def quantity
  @quantity
end

#unit_of_measureString

Output only. The unit of measure for the quantity served. Corresponds to the JSON property unitOfMeasure

Returns:

  • (String)


17416
17417
17418
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17416

def unit_of_measure
  @unit_of_measure
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17423
17424
17425
17426
17427
17428
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17423

def update!(**args)
  @amount_micros = args[:amount_micros] if args.key?(:amount_micros)
  @campaign_description = args[:campaign_description] if args.key?(:campaign_description)
  @quantity = args[:quantity] if args.key?(:quantity)
  @unit_of_measure = args[:unit_of_measure] if args.key?(:unit_of_measure)
end