Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Keyword Planner ad group. Max number of keyword plan ad groups per plan: 200.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup

Returns a new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup.



30281
30282
30283
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpc_bid_microsFixnum

A default ad group max cpc bid in micros in account currency for all biddable keywords under the keyword plan ad group. If not set, will inherit from parent campaign. Corresponds to the JSON property cpcBidMicros

Returns:

  • (Fixnum)


30256
30257
30258
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30256

def cpc_bid_micros
  @cpc_bid_micros
end

#idFixnum

Output only. The ID of the keyword plan ad group. Corresponds to the JSON property id

Returns:

  • (Fixnum)


30261
30262
30263
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30261

def id
  @id
end

#keyword_plan_campaignString

The keyword plan campaign to which this ad group belongs. Corresponds to the JSON property keywordPlanCampaign

Returns:

  • (String)


30266
30267
30268
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30266

def keyword_plan_campaign
  @keyword_plan_campaign
end

#nameString

The name of the keyword plan ad group. This field is required and should not be empty when creating keyword plan ad group. Corresponds to the JSON property name

Returns:

  • (String)


30272
30273
30274
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30272

def name
  @name
end

#resource_nameString

Immutable. The resource name of the Keyword Planner ad group. KeywordPlanAdGroup resource names have the form: customers/customer_id/ keywordPlanAdGroups/kp_ad_group_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


30279
30280
30281
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30279

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30286
30287
30288
30289
30290
30291
30292
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30286

def update!(**args)
  @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros)
  @id = args[:id] if args.key?(:id)
  @keyword_plan_campaign = args[:keyword_plan_campaign] if args.key?(:keyword_plan_campaign)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end