Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaign

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Keyword Plan campaign. Max number of keyword plan campaigns per plan allowed: 1.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanCampaign

Returns a new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanCampaign.



30408
30409
30410
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpc_bid_microsFixnum

A default max cpc bid in micros, and in the account currency, for all ad groups under the campaign. This field is required and should not be empty when creating Keyword Plan campaigns. Corresponds to the JSON property cpcBidMicros

Returns:

  • (Fixnum)


30367
30368
30369
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30367

def cpc_bid_micros
  @cpc_bid_micros
end

#geo_targetsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanGeoTarget>

The geo targets. Max number allowed: 20. Corresponds to the JSON property geoTargets



30372
30373
30374
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30372

def geo_targets
  @geo_targets
end

#idFixnum

Output only. The ID of the Keyword Plan campaign. Corresponds to the JSON property id

Returns:

  • (Fixnum)


30377
30378
30379
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30377

def id
  @id
end

#keyword_planString

The keyword plan this campaign belongs to. Corresponds to the JSON property keywordPlan

Returns:

  • (String)


30382
30383
30384
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30382

def keyword_plan
  @keyword_plan
end

#keyword_plan_networkString

Targeting network. This field is required and should not be empty when creating Keyword Plan campaigns. Corresponds to the JSON property keywordPlanNetwork

Returns:

  • (String)


30388
30389
30390
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30388

def keyword_plan_network
  @keyword_plan_network
end

#language_constantsArray<String>

The languages targeted for the Keyword Plan campaign. Max allowed: 1. Corresponds to the JSON property languageConstants

Returns:

  • (Array<String>)


30393
30394
30395
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30393

def language_constants
  @language_constants
end

#nameString

The name of the Keyword Plan campaign. This field is required and should not be empty when creating Keyword Plan campaigns. Corresponds to the JSON property name

Returns:

  • (String)


30399
30400
30401
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30399

def name
  @name
end

#resource_nameString

Immutable. The resource name of the Keyword Plan campaign. KeywordPlanCampaign resource names have the form: customers/customer_id/keywordPlanCampaigns/ kp_campaign_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


30406
30407
30408
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30406

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30413
30414
30415
30416
30417
30418
30419
30420
30421
30422
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30413

def update!(**args)
  @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros)
  @geo_targets = args[:geo_targets] if args.key?(:geo_targets)
  @id = args[:id] if args.key?(:id)
  @keyword_plan = args[:keyword_plan] if args.key?(:keyword_plan)
  @keyword_plan_network = args[:keyword_plan_network] if args.key?(:keyword_plan_network)
  @language_constants = args[:language_constants] if args.key?(:language_constants)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end