Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaignKeyword

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Keyword Plan Campaign keyword. Only negative keywords are supported for Campaign Keyword.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanCampaignKeyword

Returns a new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanCampaignKeyword.



30464
30465
30466
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. The ID of the Keyword Plan negative keyword. Corresponds to the JSON property id

Returns:

  • (Fixnum)


30433
30434
30435
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30433

def id
  @id
end

#keyword_plan_campaignString

The Keyword Plan campaign to which this negative keyword belongs. Corresponds to the JSON property keywordPlanCampaign

Returns:

  • (String)


30438
30439
30440
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30438

def keyword_plan_campaign
  @keyword_plan_campaign
end

#match_typeString

The keyword match type. Corresponds to the JSON property matchType

Returns:

  • (String)


30443
30444
30445
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30443

def match_type
  @match_type
end

#negativeBoolean Also known as: negative?

Immutable. If true, the keyword is negative. Must be set to true. Only negative campaign keywords are supported. Corresponds to the JSON property negative

Returns:

  • (Boolean)


30449
30450
30451
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30449

def negative
  @negative
end

#resource_nameString

Immutable. The resource name of the Keyword Plan Campaign keyword. KeywordPlanCampaignKeyword resource names have the form: customers/ customer_id/keywordPlanCampaignKeywords/kp_campaign_keyword_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


30457
30458
30459
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30457

def resource_name
  @resource_name
end

#textString

The keyword text. Corresponds to the JSON property text

Returns:

  • (String)


30462
30463
30464
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30462

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30469
30470
30471
30472
30473
30474
30475
30476
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30469

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @keyword_plan_campaign = args[:keyword_plan_campaign] if args.key?(:keyword_plan_campaign)
  @match_type = args[:match_type] if args.key?(:match_type)
  @negative = args[:negative] if args.key?(:negative)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @text = args[:text] if args.key?(:text)
end