Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordThemeConstant
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordThemeConstant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Smart Campaign keyword theme constant.
Instance Attribute Summary collapse
-
#country_code ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#language_code ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordThemeConstant
constructor
A new instance of GoogleAdsSearchads360V23ResourcesKeywordThemeConstant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordThemeConstant
Returns a new instance of GoogleAdsSearchads360V23ResourcesKeywordThemeConstant.
30552 30553 30554 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30552 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_code ⇒ String
Output only. The ISO-3166 Alpha-2 country code of the constant, eg. "US". To
display and query matching purpose, the keyword theme needs to be localized.
Corresponds to the JSON property countryCode
30531 30532 30533 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30531 def country_code @country_code end |
#display_name ⇒ String
Output only. The display name of the keyword theme or sub keyword theme.
Corresponds to the JSON property displayName
30536 30537 30538 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30536 def display_name @display_name end |
#language_code ⇒ String
Output only. The ISO-639-1 language code with 2 letters of the constant, eg. "
en". To display and query matching purpose, the keyword theme needs to be
localized.
Corresponds to the JSON property languageCode
30543 30544 30545 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30543 def language_code @language_code end |
#resource_name ⇒ String
Output only. The resource name of the keyword theme constant. Keyword theme
constant resource names have the form: keywordThemeConstants/
keyword_theme_id~sub_keyword_theme_id`
Corresponds to the JSON propertyresourceName`
30550 30551 30552 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30550 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30557 30558 30559 30560 30561 30562 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30557 def update!(**args) @country_code = args[:country_code] if args.key?(:country_code) @display_name = args[:display_name] if args.key?(:display_name) @language_code = args[:language_code] if args.key?(:language_code) @resource_name = args[:resource_name] if args.key?(:resource_name) end |