Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLabel
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLabel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A label.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
The name of the label.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#text_label ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTextLabel
A type of label displaying text on a colored background.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLabel
constructor
A new instance of GoogleAdsSearchads360V23ResourcesLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLabel
Returns a new instance of GoogleAdsSearchads360V23ResourcesLabel.
30618 30619 30620 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30618 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. ID of the label. Read only.
Corresponds to the JSON property id
30593 30594 30595 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30593 def id @id end |
#name ⇒ String
The name of the label. This field is required and should not be empty when
creating a new label. The length of this string should be between 1 and 80,
inclusive.
Corresponds to the JSON property name
30600 30601 30602 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30600 def name @name end |
#resource_name ⇒ String
Immutable. Name of the resource. Label resource names have the form:
customers/owner_customer_id/labels/label_id`
Corresponds to the JSON propertyresourceName`
30606 30607 30608 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30606 def resource_name @resource_name end |
#status ⇒ String
Output only. Status of the label. Read only.
Corresponds to the JSON property status
30611 30612 30613 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30611 def status @status end |
#text_label ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTextLabel
A type of label displaying text on a colored background.
Corresponds to the JSON property textLabel
30616 30617 30618 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30616 def text_label @text_label end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30623 30624 30625 30626 30627 30628 30629 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30623 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @text_label = args[:text_label] if args.key?(:text_label) end |