Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLicenseVerificationArtifact
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLicenseVerificationArtifact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
specific to a local services license.
Instance Attribute Summary collapse
-
#expiration_date_time ⇒ String
Output only.
-
#license_document_readonly ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalServicesDocumentReadOnly
A Local Services Document with read only accessible data.
-
#license_number ⇒ String
Output only.
-
#license_type ⇒ String
Output only.
-
#licensee_first_name ⇒ String
Output only.
-
#licensee_last_name ⇒ String
Output only.
-
#rejection_reason ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLicenseVerificationArtifact
constructor
A new instance of GoogleAdsSearchads360V23ResourcesLicenseVerificationArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLicenseVerificationArtifact
Returns a new instance of GoogleAdsSearchads360V23ResourcesLicenseVerificationArtifact.
30776 30777 30778 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30776 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expiration_date_time ⇒ String
Output only. The timestamp when this license expires. The format is "YYYY-MM-
DD HH:MM:SS" in the Google Ads account's timezone. Examples: "2018-03-05 09:15:
00" or "2018-02-01 14:34:30"
Corresponds to the JSON property expirationDateTime
30744 30745 30746 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30744 def expiration_date_time @expiration_date_time end |
#license_document_readonly ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalServicesDocumentReadOnly
A Local Services Document with read only accessible data.
Corresponds to the JSON property licenseDocumentReadonly
30749 30750 30751 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30749 def license_document_readonly @license_document_readonly end |
#license_number ⇒ String
Output only. License number.
Corresponds to the JSON property licenseNumber
30754 30755 30756 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30754 def license_number @license_number end |
#license_type ⇒ String
Output only. License type / name.
Corresponds to the JSON property licenseType
30759 30760 30761 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30759 def license_type @license_type end |
#licensee_first_name ⇒ String
Output only. First name of the licensee.
Corresponds to the JSON property licenseeFirstName
30764 30765 30766 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30764 def licensee_first_name @licensee_first_name end |
#licensee_last_name ⇒ String
Output only. Last name of the licensee.
Corresponds to the JSON property licenseeLastName
30769 30770 30771 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30769 def licensee_last_name @licensee_last_name end |
#rejection_reason ⇒ String
Output only. License rejection reason.
Corresponds to the JSON property rejectionReason
30774 30775 30776 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30774 def rejection_reason @rejection_reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30781 30782 30783 30784 30785 30786 30787 30788 30789 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30781 def update!(**args) @expiration_date_time = args[:expiration_date_time] if args.key?(:expiration_date_time) @license_document_readonly = args[:license_document_readonly] if args.key?(:license_document_readonly) @license_number = args[:license_number] if args.key?(:license_number) @license_type = args[:license_type] if args.key?(:license_type) @licensee_first_name = args[:licensee_first_name] if args.key?(:licensee_first_name) @licensee_last_name = args[:licensee_last_name] if args.key?(:licensee_last_name) @rejection_reason = args[:rejection_reason] if args.key?(:rejection_reason) end |