Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLifeEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A life event: a particular interest-based vertical to be targeted to reach users when they are in the midst of important life milestones.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLifeEvent

Returns a new instance of GoogleAdsSearchads360V23ResourcesLifeEvent.



30901
30902
30903
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30901

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availabilitiesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryAvailability>

Output only. Availability information of the life event. Corresponds to the JSON property availabilities



30872
30873
30874
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30872

def availabilities
  @availabilities
end

#idFixnum

Output only. The ID of the life event. Corresponds to the JSON property id

Returns:

  • (Fixnum)


30877
30878
30879
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30877

def id
  @id
end

#launched_to_allBoolean Also known as: launched_to_all?

Output only. True if the life event is launched to all channels and locales. Corresponds to the JSON property launchedToAll

Returns:

  • (Boolean)


30882
30883
30884
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30882

def launched_to_all
  @launched_to_all
end

#nameString

Output only. The name of the life event, for example,"Recently Moved" Corresponds to the JSON property name

Returns:

  • (String)


30888
30889
30890
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30888

def name
  @name
end

#parentString

Output only. The parent of the life_event. Corresponds to the JSON property parent

Returns:

  • (String)


30893
30894
30895
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30893

def parent
  @parent
end

#resource_nameString

Output only. The resource name of the life event. Life event resource names have the form: customers/customer_id/lifeEvents/life_event_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


30899
30900
30901
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30899

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30906
30907
30908
30909
30910
30911
30912
30913
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30906

def update!(**args)
  @availabilities = args[:availabilities] if args.key?(:availabilities)
  @id = args[:id] if args.key?(:id)
  @launched_to_all = args[:launched_to_all] if args.key?(:launched_to_all)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end