Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLocalServicesEmployee

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A local services employee resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLocalServicesEmployee

Returns a new instance of GoogleAdsSearchads360V23ResourcesLocalServicesEmployee.



31030
31031
31032
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31030

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_idsArray<String>

Output only. Category of the employee. A list of Local Services category IDs can be found at https://developers.google.com/google-ads/api/data/codes- formats#local_services_ids. Corresponds to the JSON property categoryIds

Returns:

  • (Array<String>)


30940
30941
30942
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30940

def category_ids
  @category_ids
end

#creation_date_timeString

Output only. Timestamp of employee creation. The format is "YYYY-MM-DD HH:MM: SS" in the Google Ads account's timezone. Examples: "2018-03-05 09:15:00" or " 2018-02-01 14:34:30" Corresponds to the JSON property creationDateTime

Returns:

  • (String)


30947
30948
30949
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30947

def creation_date_time
  @creation_date_time
end

#email_addressString

Output only. Email address of the employee. Corresponds to the JSON property emailAddress

Returns:

  • (String)


30952
30953
30954
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30952

def email_address
  @email_address
end

#fellowshipsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesFellowship>

Output only. The institutions where the employee has completed their fellowship. Corresponds to the JSON property fellowships



30958
30959
30960
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30958

def fellowships
  @fellowships
end

#first_nameString

Output only. First name of the employee. Corresponds to the JSON property firstName

Returns:

  • (String)


30963
30964
30965
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30963

def first_name
  @first_name
end

#idFixnum

Output only. The ID of the employee. Corresponds to the JSON property id

Returns:

  • (Fixnum)


30968
30969
30970
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30968

def id
  @id
end

#job_titleString

Output only. Job title for this employee, such as "Senior partner" in legal verticals. Corresponds to the JSON property jobTitle

Returns:

  • (String)


30974
30975
30976
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30974

def job_title
  @job_title
end

#languages_spokenArray<String>

Output only. Languages that the employee speaks, represented as language tags from https://developers.google.com/admin-sdk/directory/v1/languages Corresponds to the JSON property languagesSpoken

Returns:

  • (Array<String>)


30980
30981
30982
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30980

def languages_spoken
  @languages_spoken
end

#last_nameString

Output only. Last name of the employee. Corresponds to the JSON property lastName

Returns:

  • (String)


30985
30986
30987
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30985

def last_name
  @last_name
end

#middle_nameString

Output only. Middle name of the employee. Corresponds to the JSON property middleName

Returns:

  • (String)


30990
30991
30992
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30990

def middle_name
  @middle_name
end

#national_provider_id_numberString

Output only. NPI id associated with the employee. Corresponds to the JSON property nationalProviderIdNumber

Returns:

  • (String)


30995
30996
30997
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30995

def national_provider_id_number
  @national_provider_id_number
end

#residenciesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesResidency>

Output only. The institutions where the employee has completed their residency. Corresponds to the JSON property residencies



31000
31001
31002
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31000

def residencies
  @residencies
end

#resource_nameString

Immutable. The resource name of the Local Services Verification. Local Services Verification resource names have the form: customers/customer_id/ localServicesEmployees/gls_employee_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


31007
31008
31009
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31007

def resource_name
  @resource_name
end

#statusString

Output only. Employee status, such as DELETED or ENABLED. Corresponds to the JSON property status

Returns:

  • (String)


31012
31013
31014
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31012

def status
  @status
end

#typeString

Output only. Employee type. Corresponds to the JSON property type

Returns:

  • (String)


31017
31018
31019
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31017

def type
  @type
end

#university_degreesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUniversityDegree>

Output only. A list of degrees this employee has obtained, and wants to feature. Corresponds to the JSON property universityDegrees



31023
31024
31025
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31023

def university_degrees
  @university_degrees
end

#year_started_practicingFixnum

Output only. The year that this employee started practicing in this field. Corresponds to the JSON property yearStartedPracticing

Returns:

  • (Fixnum)


31028
31029
31030
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31028

def year_started_practicing
  @year_started_practicing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31035
31036
31037
31038
31039
31040
31041
31042
31043
31044
31045
31046
31047
31048
31049
31050
31051
31052
31053
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31035

def update!(**args)
  @category_ids = args[:category_ids] if args.key?(:category_ids)
  @creation_date_time = args[:creation_date_time] if args.key?(:creation_date_time)
  @email_address = args[:email_address] if args.key?(:email_address)
  @fellowships = args[:fellowships] if args.key?(:fellowships)
  @first_name = args[:first_name] if args.key?(:first_name)
  @id = args[:id] if args.key?(:id)
  @job_title = args[:job_title] if args.key?(:job_title)
  @languages_spoken = args[:languages_spoken] if args.key?(:languages_spoken)
  @last_name = args[:last_name] if args.key?(:last_name)
  @middle_name = args[:middle_name] if args.key?(:middle_name)
  @national_provider_id_number = args[:national_provider_id_number] if args.key?(:national_provider_id_number)
  @residencies = args[:residencies] if args.key?(:residencies)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
  @university_degrees = args[:university_degrees] if args.key?(:university_degrees)
  @year_started_practicing = args[:year_started_practicing] if args.key?(:year_started_practicing)
end