Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLocalServicesLeadConversation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Data from Local Services Lead Conversation. Contains details of Lead Conversation which is generated when user calls, messages or books service from advertiser. These are appended to a Lead. More info: https://ads.google. com/local-services-ads

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLocalServicesLeadConversation

Returns a new instance of GoogleAdsSearchads360V23ResourcesLocalServicesLeadConversation.



31216
31217
31218
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_channelString

Output only. Type of GLS lead conversation, EMAIL, MESSAGE, PHONE_CALL, SMS, etc. Corresponds to the JSON property conversationChannel

Returns:

  • (String)


31173
31174
31175
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31173

def conversation_channel
  @conversation_channel
end

#event_date_timeString

Output only. The date time at which lead conversation was created by Local Services Ads. The format is "YYYY-MM-DD HH:MM:SS" in the Google Ads account's timezone. Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34:30" Corresponds to the JSON property eventDateTime

Returns:

  • (String)


31180
31181
31182
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31180

def event_date_time
  @event_date_time
end

#idFixnum

Output only. ID of this Lead Conversation. Corresponds to the JSON property id

Returns:

  • (Fixnum)


31185
31186
31187
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31185

def id
  @id
end

#leadString

Output only. Resource name of Lead associated to the Lead Conversation. Corresponds to the JSON property lead

Returns:

  • (String)


31190
31191
31192
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31190

def lead
  @lead
end

#message_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMessageDetails

Represents details of text message in case of email, message or SMS. Corresponds to the JSON property messageDetails



31195
31196
31197
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31195

def message_details
  @message_details
end

#participant_typeString

Output only. Type of participant in the lead conversation, ADVERTISER or CONSUMER. Corresponds to the JSON property participantType

Returns:

  • (String)


31201
31202
31203
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31201

def participant_type
  @participant_type
end

#phone_call_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesPhoneCallDetails

Represents details of a phone call conversation. Corresponds to the JSON property phoneCallDetails



31206
31207
31208
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31206

def phone_call_details
  @phone_call_details
end

#resource_nameString

Output only. The resource name of the local services lead conversation data. Local Services Lead Conversation resource name have the form customers/ customer_id/localServicesLeadConversation/ local_services_lead_conversation_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


31214
31215
31216
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31214

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31221
31222
31223
31224
31225
31226
31227
31228
31229
31230
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31221

def update!(**args)
  @conversation_channel = args[:conversation_channel] if args.key?(:conversation_channel)
  @event_date_time = args[:event_date_time] if args.key?(:event_date_time)
  @id = args[:id] if args.key?(:id)
  @lead = args[:lead] if args.key?(:lead)
  @message_details = args[:message_details] if args.key?(:message_details)
  @participant_type = args[:participant_type] if args.key?(:participant_type)
  @phone_call_details = args[:phone_call_details] if args.key?(:phone_call_details)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end