Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMediaImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Encapsulates an Image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMediaImage

Returns a new instance of GoogleAdsSearchads360V23ResourcesMediaImage.



31639
31640
31641
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31639

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataString

Immutable. Raw image data. Corresponds to the JSON property data NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


31627
31628
31629
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31627

def data
  @data
end

#full_size_image_urlString

Output only. The url to the full size version of the image. Corresponds to the JSON property fullSizeImageUrl

Returns:

  • (String)


31632
31633
31634
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31632

def full_size_image_url
  @full_size_image_url
end

#preview_size_image_urlString

Output only. The url to the preview size version of the image. Corresponds to the JSON property previewSizeImageUrl

Returns:

  • (String)


31637
31638
31639
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31637

def preview_size_image_url
  @preview_size_image_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31644
31645
31646
31647
31648
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31644

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @full_size_image_url = args[:full_size_image_url] if args.key?(:full_size_image_url)
  @preview_size_image_url = args[:preview_size_image_url] if args.key?(:preview_size_image_url)
end