Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMerchantCenterIdentifier

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The identifier for Google Merchant Center account

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMerchantCenterIdentifier

Returns a new instance of GoogleAdsSearchads360V23ResourcesMerchantCenterIdentifier.



31632
31633
31634
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#merchant_center_idFixnum

Immutable. The customer ID of the Google Merchant Center account. This field is required and should not be empty when creating a new Merchant Center link. It is unable to be modified after the creation of the link. Corresponds to the JSON property merchantCenterId

Returns:

  • (Fixnum)


31630
31631
31632
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31630

def merchant_center_id
  @merchant_center_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31637
31638
31639
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31637

def update!(**args)
  @merchant_center_id = args[:merchant_center_id] if args.key?(:merchant_center_id)
end