Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionUploadClientSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Offline conversion upload summary at customer level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOfflineConversionUploadClientSummary

Returns a new instance of GoogleAdsSearchads360V23ResourcesOfflineConversionUploadClientSummary.



32083
32084
32085
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alertsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionAlert>

Output only. Details for each error code. Alerts are generated from most recent calendar day with upload stats. Corresponds to the JSON property alerts



32021
32022
32023
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32021

def alerts
  @alerts
end

#clientString

Output only. Client type of the upload event. Corresponds to the JSON property client

Returns:

  • (String)


32026
32027
32028
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32026

def client
  @client
end

#daily_summariesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionSummary>

Output only. Summary of history stats by last N days. Corresponds to the JSON property dailySummaries



32031
32032
32033
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32031

def daily_summaries
  @daily_summaries
end

#job_summariesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionSummary>

Output only. Summary of history stats by last N jobs. Corresponds to the JSON property jobSummaries



32036
32037
32038
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32036

def job_summaries
  @job_summaries
end

#last_upload_date_timeString

Output only. Date for the latest upload batch. The format is "yyyy-mm-dd hh:mm: ss", and it's in the time zone of the Google Ads account. Corresponds to the JSON property lastUploadDateTime

Returns:

  • (String)


32042
32043
32044
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32042

def last_upload_date_time
  @last_upload_date_time
end

#pending_event_countFixnum

Output only. Total count of pending uploaded events. Corresponds to the JSON property pendingEventCount

Returns:

  • (Fixnum)


32047
32048
32049
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32047

def pending_event_count
  @pending_event_count
end

#pending_rateFloat

Output only. The ratio of total pending events to total events. Corresponds to the JSON property pendingRate

Returns:

  • (Float)


32052
32053
32054
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32052

def pending_rate
  @pending_rate
end

#resource_nameString

Output only. The resource name of the offline conversion upload summary at customer level. Offline conversion upload client summary resource names have the form: customers/customer_id/offlineConversionUploadClientSummaries/ client` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


32060
32061
32062
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32060

def resource_name
  @resource_name
end

#statusString

Output only. Overall status for offline conversion client summary. Status is generated from most recent calendar day with upload stats. Corresponds to the JSON property status

Returns:

  • (String)


32066
32067
32068
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32066

def status
  @status
end

#success_rateFloat

Output only. Successful rate. Corresponds to the JSON property successRate

Returns:

  • (Float)


32071
32072
32073
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32071

def success_rate
  @success_rate
end

#successful_event_countFixnum

Output only. Total count of successful uploaded events. Corresponds to the JSON property successfulEventCount

Returns:

  • (Fixnum)


32076
32077
32078
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32076

def successful_event_count
  @successful_event_count
end

#total_event_countFixnum

Output only. Total count of uploaded events. Corresponds to the JSON property totalEventCount

Returns:

  • (Fixnum)


32081
32082
32083
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32081

def total_event_count
  @total_event_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32088
32089
32090
32091
32092
32093
32094
32095
32096
32097
32098
32099
32100
32101
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32088

def update!(**args)
  @alerts = args[:alerts] if args.key?(:alerts)
  @client = args[:client] if args.key?(:client)
  @daily_summaries = args[:daily_summaries] if args.key?(:daily_summaries)
  @job_summaries = args[:job_summaries] if args.key?(:job_summaries)
  @last_upload_date_time = args[:last_upload_date_time] if args.key?(:last_upload_date_time)
  @pending_event_count = args[:pending_event_count] if args.key?(:pending_event_count)
  @pending_rate = args[:pending_rate] if args.key?(:pending_rate)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @success_rate = args[:success_rate] if args.key?(:success_rate)
  @successful_event_count = args[:successful_event_count] if args.key?(:successful_event_count)
  @total_event_count = args[:total_event_count] if args.key?(:total_event_count)
end