Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineUserDataJobMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Metadata of offline user data job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOfflineUserDataJobMetadata

Returns a new instance of GoogleAdsSearchads360V23ResourcesOfflineUserDataJobMetadata.



32207
32208
32209
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32207

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#match_rate_rangeString

Output only. Match rate of the Customer Match user list upload. Describes the estimated match rate when the status of the job is "RUNNING" and final match rate when the final match rate is available after the status of the job is " SUCCESS/FAILED". Corresponds to the JSON property matchRateRange

Returns:

  • (String)


32205
32206
32207
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32205

def match_rate_range
  @match_rate_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32212
32213
32214
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32212

def update!(**args)
  @match_rate_range = args[:match_rate_range] if args.key?(:match_rate_range)
end