Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesProductLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents the data sharing connection between

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesProductLink

Returns a new instance of GoogleAdsSearchads360V23ResourcesProductLink.



32716
32717
32718
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32716

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertising_partnerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdvertisingPartnerIdentifier

The identifier for the Advertising Partner Google Ads account. Corresponds to the JSON property advertisingPartner



32683
32684
32685
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32683

def advertising_partner
  @advertising_partner
end

#data_partnerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDataPartnerIdentifier

The identifier for Data Partner account. Corresponds to the JSON property dataPartner



32688
32689
32690
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32688

def data_partner
  @data_partner
end

The identifier for Google Ads account. Corresponds to the JSON property googleAds



32693
32694
32695
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32693

def google_ads
  @google_ads
end

#merchant_centerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMerchantCenterIdentifier

The identifier for Google Merchant Center account Corresponds to the JSON property merchantCenter



32698
32699
32700
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32698

def merchant_center
  @merchant_center
end

Output only. The ID of the link. This field is read only. Corresponds to the JSON property productLinkId

Returns:

  • (Fixnum)


32703
32704
32705
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32703

def product_link_id
  @product_link_id
end

#resource_nameString

Immutable. Resource name of the product link. ProductLink resource names have the form: Corresponds to the JSON property resourceName

Returns:

  • (String)


32709
32710
32711
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32709

def resource_name
  @resource_name
end

#typeString

Output only. The type of the linked product. Corresponds to the JSON property type

Returns:

  • (String)


32714
32715
32716
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32714

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32721
32722
32723
32724
32725
32726
32727
32728
32729
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32721

def update!(**args)
  @advertising_partner = args[:advertising_partner] if args.key?(:advertising_partner)
  @data_partner = args[:data_partner] if args.key?(:data_partner)
  @google_ads = args[:google_ads] if args.key?(:google_ads)
  @merchant_center = args[:merchant_center] if args.key?(:merchant_center)
  @product_link_id = args[:product_link_id] if args.key?(:product_link_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @type = args[:type] if args.key?(:type)
end