Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesProductLinkInvitation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents an invitation for data sharing connection between a Google Ads account and another account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesProductLinkInvitation

Returns a new instance of GoogleAdsSearchads360V23ResourcesProductLinkInvitation.



32777
32778
32779
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32777

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertising_partnerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdvertisingPartnerLinkInvitationIdentifier

The identifier for the Advertising Partner Google Ads account. Corresponds to the JSON property advertisingPartner



32740
32741
32742
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32740

def advertising_partner
  @advertising_partner
end

#hotel_centerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesHotelCenterLinkInvitationIdentifier

The identifier for Hotel account. Corresponds to the JSON property hotelCenter



32745
32746
32747
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32745

def hotel_center
  @hotel_center
end

#merchant_centerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMerchantCenterLinkInvitationIdentifier

The identifier for Merchant Center Account. Corresponds to the JSON property merchantCenter



32750
32751
32752
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32750

def merchant_center
  @merchant_center
end

Output only. The ID of the product link invitation. This field is read only. Corresponds to the JSON property productLinkInvitationId

Returns:

  • (Fixnum)


32755
32756
32757
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32755

def product_link_invitation_id
  @product_link_invitation_id
end

#resource_nameString

Immutable. The resource name of a product link invitation. Product link invitation resource names have the form: customers/customer_id/ productLinkInvitations/product_link_invitation_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


32762
32763
32764
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32762

def resource_name
  @resource_name
end

#statusString

Output only. The status of the product link invitation. This field is read only. Corresponds to the JSON property status

Returns:

  • (String)


32768
32769
32770
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32768

def status
  @status
end

#typeString

Output only. The type of the invited account. This field is read only and can be used for filtering invitations with @code GoogleAdsService. SearchGoogleAdsRequest. Corresponds to the JSON property type

Returns:

  • (String)


32775
32776
32777
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32775

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32782
32783
32784
32785
32786
32787
32788
32789
32790
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32782

def update!(**args)
  @advertising_partner = args[:advertising_partner] if args.key?(:advertising_partner)
  @hotel_center = args[:hotel_center] if args.key?(:hotel_center)
  @merchant_center = args[:merchant_center] if args.key?(:merchant_center)
  @product_link_invitation_id = args[:product_link_invitation_id] if args.key?(:product_link_invitation_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end