Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A recommendation.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Output only.
-
#call_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCallAssetRecommendation
The call asset recommendation.
-
#callout_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCalloutAssetRecommendation
The callout asset recommendation.
-
#campaign ⇒ String
Output only.
-
#campaign_budget ⇒ String
Output only.
-
#campaign_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendation
The budget recommendation for budget constrained campaigns.
-
#campaigns ⇒ Array<String>
Output only.
-
#custom_audience_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCustomAudienceOptInRecommendation
The Custom Audience Opt In recommendation.
-
#dismissed ⇒ Boolean
(also: #dismissed?)
Output only.
-
#display_expansion_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationDisplayExpansionOptInRecommendation
The Display Expansion opt-in recommendation.
-
#dynamic_image_extension_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationDynamicImageExtensionOptInRecommendation
Recommendation to enable dynamic image extensions on the account, allowing Google to find the best images from ad landing pages and complement text ads.
-
#enhanced_cpc_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationEnhancedCpcOptInRecommendation
The Enhanced Cost-Per-Click Opt-In recommendation.
-
#forecasting_campaign_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendation
The budget recommendation for budget constrained campaigns.
-
#forecasting_set_target_cpa_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetCpaRecommendation
The set target CPA recommendations.
-
#forecasting_set_target_roas_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetRoasRecommendation
The forecasting set target ROAS recommendation.
-
#impact ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationImpact
The impact of making the change as described in the recommendation.
-
#improve_demand_gen_ad_strength_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImproveDemandGenAdStrengthRecommendation
The improve Demand Gen ad strength recommendation.
-
#improve_google_tag_coverage_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImproveGoogleTagCoverageRecommendation
Recommendation to deploy Google Tag on more pages.
-
#improve_performance_max_ad_strength_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImprovePerformanceMaxAdStrengthRecommendation
Recommendation to improve the asset group strength of a Performance Max campaign to an "Excellent" rating.
-
#keyword_match_type_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationKeywordMatchTypeRecommendation
The keyword match type recommendation.
-
#keyword_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationKeywordRecommendation
The keyword recommendation.
-
#lead_form_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationLeadFormAssetRecommendation
The lead form asset recommendation.
-
#lower_target_roas_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationLowerTargetRoasRecommendation
Recommendation to lower Target ROAS.
-
#marginal_roi_campaign_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendation
The budget recommendation for budget constrained campaigns.
-
#maximize_clicks_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMaximizeClicksOptInRecommendation
The Maximize Clicks opt-in recommendation.
-
#maximize_conversion_value_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMaximizeConversionValueOptInRecommendation
Recommendation to opt into Maximize Conversion Value bidding strategy.
-
#maximize_conversions_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMaximizeConversionsOptInRecommendation
The Maximize Conversions Opt-In recommendation.
-
#migrate_dynamic_search_ads_campaign_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMigrateDynamicSearchAdsCampaignToPerformanceMaxRecommendation
The Dynamic Search Ads to Performance Max migration recommendation.
-
#move_unused_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMoveUnusedBudgetRecommendation
The move unused budget recommendation.
-
#optimize_ad_rotation_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationOptimizeAdRotationRecommendation
The Optimize Ad Rotation recommendation.
-
#performance_max_final_url_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationPerformanceMaxFinalUrlOptInRecommendation
Recommendation to turn on Final URL expansion for your Performance Max campaigns.
-
#performance_max_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationPerformanceMaxOptInRecommendation
The Performance Max Opt In recommendation.
-
#raise_target_cpa_bid_too_low_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRaiseTargetCpaBidTooLowRecommendation
The raise target CPA bid too low recommendation.
-
#raise_target_cpa_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRaiseTargetCpaRecommendation
Recommendation to raise Target CPA.
-
#refresh_customer_match_list_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRefreshCustomerMatchListRecommendation
The recommendation to update a customer list that hasn't been updated in the last 90 days.
-
#resource_name ⇒ String
Immutable.
-
#responsive_search_ad_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationResponsiveSearchAdAssetRecommendation
The add responsive search ad asset recommendation.
-
#responsive_search_ad_improve_ad_strength_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationResponsiveSearchAdImproveAdStrengthRecommendation
The responsive search ad improve ad strength recommendation.
-
#responsive_search_ad_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationResponsiveSearchAdRecommendation
The add responsive search ad recommendation.
-
#search_partners_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationSearchPartnersOptInRecommendation
The Search Partners Opt-In recommendation.
-
#set_target_cpa_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetCpaRecommendation
The set target CPA recommendations.
-
#set_target_roas_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetRoasRecommendation
The forecasting set target ROAS recommendation.
-
#shopping_add_age_group_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted because it is missing.
-
#shopping_add_color_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted because it is missing.
-
#shopping_add_gender_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted because it is missing.
-
#shopping_add_gtin_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted because it is missing.
-
#shopping_add_more_identifiers_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted because it is missing.
-
#shopping_add_products_to_campaign_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingAddProductsToCampaignRecommendation
The shopping recommendation to add products to a Shopping Campaign Inventory.
-
#shopping_add_size_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted because it is missing.
-
#shopping_fix_disapproved_products_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingFixDisapprovedProductsRecommendation
The shopping recommendation to fix disapproved products in a Shopping Campaign Inventory.
-
#shopping_fix_merchant_center_account_suspension_warning_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMerchantCenterAccountSuspensionRecommendation
The shopping recommendation to fix Merchant Center account suspension issues.
-
#shopping_fix_suspended_merchant_center_account_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMerchantCenterAccountSuspensionRecommendation
The shopping recommendation to fix Merchant Center account suspension issues.
-
#shopping_migrate_regular_shopping_campaign_offers_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation
The shopping recommendation to migrate Regular Shopping Campaign targeted offers to Performance Max campaigns.
-
#shopping_target_all_offers_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingTargetAllOffersRecommendation
The shopping recommendation to create a catch-all campaign that targets all offers.
-
#sitelink_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationSitelinkAssetRecommendation
The sitelink asset recommendation.
-
#target_cpa_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendation
The Target CPA opt-in recommendation.
-
#target_roas_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetRoasOptInRecommendation
The Target ROAS opt-in recommendation.
-
#text_ad_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTextAdRecommendation
The text ad recommendation.
-
#type ⇒ String
Output only.
-
#upgrade_local_campaign_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationUpgradeLocalCampaignToPerformanceMaxRecommendation
The Upgrade Local campaign to Performance Max campaign recommendation.
-
#upgrade_smart_shopping_campaign_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationUpgradeSmartShoppingCampaignToPerformanceMaxRecommendation
The upgrade a Smart Shopping campaign to a Performance Max campaign recommendation.
-
#use_broad_match_keyword_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationUseBroadMatchKeywordRecommendation
The use broad match keyword recommendation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendation
Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendation.
33175 33176 33177 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Output only. The ad group targeted by this recommendation. This will be set
only when the recommendation affects a single ad group. This field will be set
for the following recommendation types: KEYWORD, OPTIMIZE_AD_ROTATION, TEXT_AD
Corresponds to the JSON property adGroup
32840 32841 32842 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32840 def ad_group @ad_group end |
#call_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCallAssetRecommendation
The call asset recommendation.
Corresponds to the JSON property callAssetRecommendation
32845 32846 32847 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32845 def call_asset_recommendation @call_asset_recommendation end |
#callout_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCalloutAssetRecommendation
The callout asset recommendation.
Corresponds to the JSON property calloutAssetRecommendation
32850 32851 32852 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32850 def callout_asset_recommendation @callout_asset_recommendation end |
#campaign ⇒ String
Output only. The campaign targeted by this recommendation. This field will be
set for the following recommendation types: CALL_EXTENSION, CALLOUT_EXTENSION,
ENHANCED_CPC_OPT_IN, KEYWORD, KEYWORD_MATCH_TYPE, MAXIMIZE_CLICKS_OPT_IN,
MAXIMIZE_CONVERSIONS_OPT_IN, OPTIMIZE_AD_ROTATION, SEARCH_PARTNERS_OPT_IN,
SITELINK_EXTENSION, TARGET_CPA_OPT_IN, TARGET_ROAS_OPT_IN, TEXT_AD,
Corresponds to the JSON property campaign
32859 32860 32861 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32859 def campaign @campaign end |
#campaign_budget ⇒ String
Output only. The budget targeted by this recommendation. This will be set only
when the recommendation affects a single campaign budget. This field will be
set for the following recommendation types: CAMPAIGN_BUDGET,
FORECASTING_CAMPAIGN_BUDGET, MOVE_UNUSED_BUDGET
Corresponds to the JSON property campaignBudget
32867 32868 32869 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32867 def campaign_budget @campaign_budget end |
#campaign_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendation
The budget recommendation for budget constrained campaigns.
Corresponds to the JSON property campaignBudgetRecommendation
32872 32873 32874 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32872 def campaign_budget_recommendation @campaign_budget_recommendation end |
#campaigns ⇒ Array<String>
Output only. The campaigns targeted by this recommendation. This field will be
set for the following recommendation types: CAMPAIGN_BUDGET,
FORECASTING_CAMPAIGN_BUDGET, MARGINAL_ROI_CAMPAIGN_BUDGET and
MOVE_UNUSED_BUDGET
Corresponds to the JSON property campaigns
32880 32881 32882 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32880 def campaigns @campaigns end |
#custom_audience_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCustomAudienceOptInRecommendation
The Custom Audience Opt In recommendation.
Corresponds to the JSON property customAudienceOptInRecommendation
32885 32886 32887 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32885 def custom_audience_opt_in_recommendation @custom_audience_opt_in_recommendation end |
#dismissed ⇒ Boolean Also known as: dismissed?
Output only. Whether the recommendation is dismissed or not.
Corresponds to the JSON property dismissed
32890 32891 32892 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32890 def dismissed @dismissed end |
#display_expansion_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationDisplayExpansionOptInRecommendation
The Display Expansion opt-in recommendation.
Corresponds to the JSON property displayExpansionOptInRecommendation
32896 32897 32898 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32896 def display_expansion_opt_in_recommendation @display_expansion_opt_in_recommendation end |
#dynamic_image_extension_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationDynamicImageExtensionOptInRecommendation
Recommendation to enable dynamic image extensions on the account, allowing
Google to find the best images from ad landing pages and complement text ads.
Corresponds to the JSON property dynamicImageExtensionOptInRecommendation
32902 32903 32904 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32902 def dynamic_image_extension_opt_in_recommendation @dynamic_image_extension_opt_in_recommendation end |
#enhanced_cpc_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationEnhancedCpcOptInRecommendation
The Enhanced Cost-Per-Click Opt-In recommendation.
Corresponds to the JSON property enhancedCpcOptInRecommendation
32907 32908 32909 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32907 def enhanced_cpc_opt_in_recommendation @enhanced_cpc_opt_in_recommendation end |
#forecasting_campaign_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendation
The budget recommendation for budget constrained campaigns.
Corresponds to the JSON property forecastingCampaignBudgetRecommendation
32912 32913 32914 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32912 def forecasting_campaign_budget_recommendation @forecasting_campaign_budget_recommendation end |
#forecasting_set_target_cpa_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetCpaRecommendation
The set target CPA recommendations.
Corresponds to the JSON property forecastingSetTargetCpaRecommendation
32917 32918 32919 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32917 def forecasting_set_target_cpa_recommendation @forecasting_set_target_cpa_recommendation end |
#forecasting_set_target_roas_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetRoasRecommendation
The forecasting set target ROAS recommendation.
Corresponds to the JSON property forecastingSetTargetRoasRecommendation
32922 32923 32924 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32922 def forecasting_set_target_roas_recommendation @forecasting_set_target_roas_recommendation end |
#impact ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationImpact
The impact of making the change as described in the recommendation. Some types
of recommendations may not have impact information.
Corresponds to the JSON property impact
32928 32929 32930 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32928 def impact @impact end |
#improve_demand_gen_ad_strength_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImproveDemandGenAdStrengthRecommendation
The improve Demand Gen ad strength recommendation.
Corresponds to the JSON property improveDemandGenAdStrengthRecommendation
32933 32934 32935 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32933 def improve_demand_gen_ad_strength_recommendation @improve_demand_gen_ad_strength_recommendation end |
#improve_google_tag_coverage_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImproveGoogleTagCoverageRecommendation
Recommendation to deploy Google Tag on more pages.
Corresponds to the JSON property improveGoogleTagCoverageRecommendation
32938 32939 32940 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32938 def improve_google_tag_coverage_recommendation @improve_google_tag_coverage_recommendation end |
#improve_performance_max_ad_strength_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImprovePerformanceMaxAdStrengthRecommendation
Recommendation to improve the asset group strength of a Performance Max
campaign to an "Excellent" rating.
Corresponds to the JSON property improvePerformanceMaxAdStrengthRecommendation
32944 32945 32946 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32944 def improve_performance_max_ad_strength_recommendation @improve_performance_max_ad_strength_recommendation end |
#keyword_match_type_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationKeywordMatchTypeRecommendation
The keyword match type recommendation.
Corresponds to the JSON property keywordMatchTypeRecommendation
32949 32950 32951 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32949 def keyword_match_type_recommendation @keyword_match_type_recommendation end |
#keyword_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationKeywordRecommendation
The keyword recommendation.
Corresponds to the JSON property keywordRecommendation
32954 32955 32956 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32954 def keyword_recommendation @keyword_recommendation end |
#lead_form_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationLeadFormAssetRecommendation
The lead form asset recommendation.
Corresponds to the JSON property leadFormAssetRecommendation
32959 32960 32961 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32959 def lead_form_asset_recommendation @lead_form_asset_recommendation end |
#lower_target_roas_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationLowerTargetRoasRecommendation
Recommendation to lower Target ROAS.
Corresponds to the JSON property lowerTargetRoasRecommendation
32964 32965 32966 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32964 def lower_target_roas_recommendation @lower_target_roas_recommendation end |
#marginal_roi_campaign_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendation
The budget recommendation for budget constrained campaigns.
Corresponds to the JSON property marginalRoiCampaignBudgetRecommendation
32969 32970 32971 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32969 def marginal_roi_campaign_budget_recommendation @marginal_roi_campaign_budget_recommendation end |
#maximize_clicks_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMaximizeClicksOptInRecommendation
The Maximize Clicks opt-in recommendation.
Corresponds to the JSON property maximizeClicksOptInRecommendation
32974 32975 32976 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32974 def maximize_clicks_opt_in_recommendation @maximize_clicks_opt_in_recommendation end |
#maximize_conversion_value_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMaximizeConversionValueOptInRecommendation
Recommendation to opt into Maximize Conversion Value bidding strategy.
Corresponds to the JSON property maximizeConversionValueOptInRecommendation
32979 32980 32981 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32979 def maximize_conversion_value_opt_in_recommendation @maximize_conversion_value_opt_in_recommendation end |
#maximize_conversions_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMaximizeConversionsOptInRecommendation
The Maximize Conversions Opt-In recommendation.
Corresponds to the JSON property maximizeConversionsOptInRecommendation
32984 32985 32986 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32984 def maximize_conversions_opt_in_recommendation @maximize_conversions_opt_in_recommendation end |
#migrate_dynamic_search_ads_campaign_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMigrateDynamicSearchAdsCampaignToPerformanceMaxRecommendation
The Dynamic Search Ads to Performance Max migration recommendation.
Corresponds to the JSON property migrateDynamicSearchAdsCampaignToPerformanceMaxRecommendation
32989 32990 32991 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32989 def migrate_dynamic_search_ads_campaign_to_performance_max_recommendation @migrate_dynamic_search_ads_campaign_to_performance_max_recommendation end |
#move_unused_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMoveUnusedBudgetRecommendation
The move unused budget recommendation.
Corresponds to the JSON property moveUnusedBudgetRecommendation
32994 32995 32996 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32994 def move_unused_budget_recommendation @move_unused_budget_recommendation end |
#optimize_ad_rotation_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationOptimizeAdRotationRecommendation
The Optimize Ad Rotation recommendation.
Corresponds to the JSON property optimizeAdRotationRecommendation
32999 33000 33001 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32999 def optimize_ad_rotation_recommendation @optimize_ad_rotation_recommendation end |
#performance_max_final_url_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationPerformanceMaxFinalUrlOptInRecommendation
Recommendation to turn on Final URL expansion for your Performance Max
campaigns.
Corresponds to the JSON property performanceMaxFinalUrlOptInRecommendation
33005 33006 33007 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33005 def performance_max_final_url_opt_in_recommendation @performance_max_final_url_opt_in_recommendation end |
#performance_max_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationPerformanceMaxOptInRecommendation
The Performance Max Opt In recommendation.
Corresponds to the JSON property performanceMaxOptInRecommendation
33010 33011 33012 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33010 def performance_max_opt_in_recommendation @performance_max_opt_in_recommendation end |
#raise_target_cpa_bid_too_low_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRaiseTargetCpaBidTooLowRecommendation
The raise target CPA bid too low recommendation.
Corresponds to the JSON property raiseTargetCpaBidTooLowRecommendation
33015 33016 33017 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33015 def raise_target_cpa_bid_too_low_recommendation @raise_target_cpa_bid_too_low_recommendation end |
#raise_target_cpa_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRaiseTargetCpaRecommendation
Recommendation to raise Target CPA.
Corresponds to the JSON property raiseTargetCpaRecommendation
33020 33021 33022 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33020 def raise_target_cpa_recommendation @raise_target_cpa_recommendation end |
#refresh_customer_match_list_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRefreshCustomerMatchListRecommendation
The recommendation to update a customer list that hasn't been updated in the
last 90 days. The customer receiving the recommendation is not necessarily the
owner account. The owner account should update the customer list.
Corresponds to the JSON property refreshCustomerMatchListRecommendation
33027 33028 33029 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33027 def refresh_customer_match_list_recommendation @refresh_customer_match_list_recommendation end |
#resource_name ⇒ String
Immutable. The resource name of the recommendation. customers/customer_id/
recommendations/recommendation_id`
Corresponds to the JSON propertyresourceName`
33033 33034 33035 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33033 def resource_name @resource_name end |
#responsive_search_ad_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationResponsiveSearchAdAssetRecommendation
The add responsive search ad asset recommendation.
Corresponds to the JSON property responsiveSearchAdAssetRecommendation
33038 33039 33040 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33038 def responsive_search_ad_asset_recommendation @responsive_search_ad_asset_recommendation end |
#responsive_search_ad_improve_ad_strength_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationResponsiveSearchAdImproveAdStrengthRecommendation
The responsive search ad improve ad strength recommendation.
Corresponds to the JSON property responsiveSearchAdImproveAdStrengthRecommendation
33043 33044 33045 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33043 def responsive_search_ad_improve_ad_strength_recommendation @responsive_search_ad_improve_ad_strength_recommendation end |
#responsive_search_ad_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationResponsiveSearchAdRecommendation
The add responsive search ad recommendation.
Corresponds to the JSON property responsiveSearchAdRecommendation
33048 33049 33050 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33048 def responsive_search_ad_recommendation @responsive_search_ad_recommendation end |
#search_partners_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationSearchPartnersOptInRecommendation
The Search Partners Opt-In recommendation.
Corresponds to the JSON property searchPartnersOptInRecommendation
33053 33054 33055 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33053 def search_partners_opt_in_recommendation @search_partners_opt_in_recommendation end |
#set_target_cpa_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetCpaRecommendation
The set target CPA recommendations.
Corresponds to the JSON property setTargetCpaRecommendation
33058 33059 33060 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33058 def set_target_cpa_recommendation @set_target_cpa_recommendation end |
#set_target_roas_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetRoasRecommendation
The forecasting set target ROAS recommendation.
Corresponds to the JSON property setTargetRoasRecommendation
33063 33064 33065 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33063 def set_target_roas_recommendation @set_target_roas_recommendation end |
#shopping_add_age_group_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted
because it is missing.
Corresponds to the JSON property shoppingAddAgeGroupRecommendation
33069 33070 33071 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33069 def shopping_add_age_group_recommendation @shopping_add_age_group_recommendation end |
#shopping_add_color_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted
because it is missing.
Corresponds to the JSON property shoppingAddColorRecommendation
33075 33076 33077 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33075 def shopping_add_color_recommendation @shopping_add_color_recommendation end |
#shopping_add_gender_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted
because it is missing.
Corresponds to the JSON property shoppingAddGenderRecommendation
33081 33082 33083 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33081 def shopping_add_gender_recommendation @shopping_add_gender_recommendation end |
#shopping_add_gtin_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted
because it is missing.
Corresponds to the JSON property shoppingAddGtinRecommendation
33087 33088 33089 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33087 def shopping_add_gtin_recommendation @shopping_add_gtin_recommendation end |
#shopping_add_more_identifiers_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted
because it is missing.
Corresponds to the JSON property shoppingAddMoreIdentifiersRecommendation
33093 33094 33095 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33093 def shopping_add_more_identifiers_recommendation @shopping_add_more_identifiers_recommendation end |
#shopping_add_products_to_campaign_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingAddProductsToCampaignRecommendation
The shopping recommendation to add products to a Shopping Campaign Inventory.
Corresponds to the JSON property shoppingAddProductsToCampaignRecommendation
33098 33099 33100 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33098 def shopping_add_products_to_campaign_recommendation @shopping_add_products_to_campaign_recommendation end |
#shopping_add_size_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted
because it is missing.
Corresponds to the JSON property shoppingAddSizeRecommendation
33104 33105 33106 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33104 def shopping_add_size_recommendation @shopping_add_size_recommendation end |
#shopping_fix_disapproved_products_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingFixDisapprovedProductsRecommendation
The shopping recommendation to fix disapproved products in a Shopping Campaign
Inventory.
Corresponds to the JSON property shoppingFixDisapprovedProductsRecommendation
33110 33111 33112 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33110 def shopping_fix_disapproved_products_recommendation @shopping_fix_disapproved_products_recommendation end |
#shopping_fix_merchant_center_account_suspension_warning_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMerchantCenterAccountSuspensionRecommendation
The shopping recommendation to fix Merchant Center account suspension issues.
Corresponds to the JSON property shoppingFixMerchantCenterAccountSuspensionWarningRecommendation
33115 33116 33117 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33115 def shopping_fix_merchant_center_account_suspension_warning_recommendation @shopping_fix_merchant_center_account_suspension_warning_recommendation end |
#shopping_fix_suspended_merchant_center_account_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMerchantCenterAccountSuspensionRecommendation
The shopping recommendation to fix Merchant Center account suspension issues.
Corresponds to the JSON property shoppingFixSuspendedMerchantCenterAccountRecommendation
33120 33121 33122 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33120 def shopping_fix_suspended_merchant_center_account_recommendation @shopping_fix_suspended_merchant_center_account_recommendation end |
#shopping_migrate_regular_shopping_campaign_offers_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation
The shopping recommendation to migrate Regular Shopping Campaign targeted
offers to Performance Max campaigns.
Corresponds to the JSON property shoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation
33126 33127 33128 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33126 def shopping_migrate_regular_shopping_campaign_offers_to_performance_max_recommendation @shopping_migrate_regular_shopping_campaign_offers_to_performance_max_recommendation end |
#shopping_target_all_offers_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingTargetAllOffersRecommendation
The shopping recommendation to create a catch-all campaign that targets all
offers.
Corresponds to the JSON property shoppingTargetAllOffersRecommendation
33132 33133 33134 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33132 def shopping_target_all_offers_recommendation @shopping_target_all_offers_recommendation end |
#sitelink_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationSitelinkAssetRecommendation
The sitelink asset recommendation.
Corresponds to the JSON property sitelinkAssetRecommendation
33137 33138 33139 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33137 def sitelink_asset_recommendation @sitelink_asset_recommendation end |
#target_cpa_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendation
The Target CPA opt-in recommendation.
Corresponds to the JSON property targetCpaOptInRecommendation
33142 33143 33144 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33142 def target_cpa_opt_in_recommendation @target_cpa_opt_in_recommendation end |
#target_roas_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetRoasOptInRecommendation
The Target ROAS opt-in recommendation.
Corresponds to the JSON property targetRoasOptInRecommendation
33147 33148 33149 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33147 def target_roas_opt_in_recommendation @target_roas_opt_in_recommendation end |
#text_ad_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTextAdRecommendation
The text ad recommendation.
Corresponds to the JSON property textAdRecommendation
33152 33153 33154 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33152 def text_ad_recommendation @text_ad_recommendation end |
#type ⇒ String
Output only. The type of recommendation.
Corresponds to the JSON property type
33157 33158 33159 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33157 def type @type end |
#upgrade_local_campaign_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationUpgradeLocalCampaignToPerformanceMaxRecommendation
The Upgrade Local campaign to Performance Max campaign recommendation.
Corresponds to the JSON property upgradeLocalCampaignToPerformanceMaxRecommendation
33162 33163 33164 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33162 def upgrade_local_campaign_to_performance_max_recommendation @upgrade_local_campaign_to_performance_max_recommendation end |
#upgrade_smart_shopping_campaign_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationUpgradeSmartShoppingCampaignToPerformanceMaxRecommendation
The upgrade a Smart Shopping campaign to a Performance Max campaign
recommendation.
Corresponds to the JSON property upgradeSmartShoppingCampaignToPerformanceMaxRecommendation
33168 33169 33170 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33168 def upgrade_smart_shopping_campaign_to_performance_max_recommendation @upgrade_smart_shopping_campaign_to_performance_max_recommendation end |
#use_broad_match_keyword_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationUseBroadMatchKeywordRecommendation
The use broad match keyword recommendation.
Corresponds to the JSON property useBroadMatchKeywordRecommendation
33173 33174 33175 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33173 def use_broad_match_keyword_recommendation @use_broad_match_keyword_recommendation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33180 33181 33182 33183 33184 33185 33186 33187 33188 33189 33190 33191 33192 33193 33194 33195 33196 33197 33198 33199 33200 33201 33202 33203 33204 33205 33206 33207 33208 33209 33210 33211 33212 33213 33214 33215 33216 33217 33218 33219 33220 33221 33222 33223 33224 33225 33226 33227 33228 33229 33230 33231 33232 33233 33234 33235 33236 33237 33238 33239 33240 33241 33242 33243 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33180 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @call_asset_recommendation = args[:call_asset_recommendation] if args.key?(:call_asset_recommendation) @callout_asset_recommendation = args[:callout_asset_recommendation] if args.key?(:callout_asset_recommendation) @campaign = args[:campaign] if args.key?(:campaign) @campaign_budget = args[:campaign_budget] if args.key?(:campaign_budget) @campaign_budget_recommendation = args[:campaign_budget_recommendation] if args.key?(:campaign_budget_recommendation) @campaigns = args[:campaigns] if args.key?(:campaigns) @custom_audience_opt_in_recommendation = args[:custom_audience_opt_in_recommendation] if args.key?(:custom_audience_opt_in_recommendation) @dismissed = args[:dismissed] if args.key?(:dismissed) @display_expansion_opt_in_recommendation = args[:display_expansion_opt_in_recommendation] if args.key?(:display_expansion_opt_in_recommendation) @dynamic_image_extension_opt_in_recommendation = args[:dynamic_image_extension_opt_in_recommendation] if args.key?(:dynamic_image_extension_opt_in_recommendation) @enhanced_cpc_opt_in_recommendation = args[:enhanced_cpc_opt_in_recommendation] if args.key?(:enhanced_cpc_opt_in_recommendation) @forecasting_campaign_budget_recommendation = args[:forecasting_campaign_budget_recommendation] if args.key?(:forecasting_campaign_budget_recommendation) @forecasting_set_target_cpa_recommendation = args[:forecasting_set_target_cpa_recommendation] if args.key?(:forecasting_set_target_cpa_recommendation) @forecasting_set_target_roas_recommendation = args[:forecasting_set_target_roas_recommendation] if args.key?(:forecasting_set_target_roas_recommendation) @impact = args[:impact] if args.key?(:impact) @improve_demand_gen_ad_strength_recommendation = args[:improve_demand_gen_ad_strength_recommendation] if args.key?(:improve_demand_gen_ad_strength_recommendation) @improve_google_tag_coverage_recommendation = args[:improve_google_tag_coverage_recommendation] if args.key?(:improve_google_tag_coverage_recommendation) @improve_performance_max_ad_strength_recommendation = args[:improve_performance_max_ad_strength_recommendation] if args.key?(:improve_performance_max_ad_strength_recommendation) @keyword_match_type_recommendation = args[:keyword_match_type_recommendation] if args.key?(:keyword_match_type_recommendation) @keyword_recommendation = args[:keyword_recommendation] if args.key?(:keyword_recommendation) @lead_form_asset_recommendation = args[:lead_form_asset_recommendation] if args.key?(:lead_form_asset_recommendation) @lower_target_roas_recommendation = args[:lower_target_roas_recommendation] if args.key?(:lower_target_roas_recommendation) @marginal_roi_campaign_budget_recommendation = args[:marginal_roi_campaign_budget_recommendation] if args.key?(:marginal_roi_campaign_budget_recommendation) @maximize_clicks_opt_in_recommendation = args[:maximize_clicks_opt_in_recommendation] if args.key?(:maximize_clicks_opt_in_recommendation) @maximize_conversion_value_opt_in_recommendation = args[:maximize_conversion_value_opt_in_recommendation] if args.key?(:maximize_conversion_value_opt_in_recommendation) @maximize_conversions_opt_in_recommendation = args[:maximize_conversions_opt_in_recommendation] if args.key?(:maximize_conversions_opt_in_recommendation) @migrate_dynamic_search_ads_campaign_to_performance_max_recommendation = args[:migrate_dynamic_search_ads_campaign_to_performance_max_recommendation] if args.key?(:migrate_dynamic_search_ads_campaign_to_performance_max_recommendation) @move_unused_budget_recommendation = args[:move_unused_budget_recommendation] if args.key?(:move_unused_budget_recommendation) @optimize_ad_rotation_recommendation = args[:optimize_ad_rotation_recommendation] if args.key?(:optimize_ad_rotation_recommendation) @performance_max_final_url_opt_in_recommendation = args[:performance_max_final_url_opt_in_recommendation] if args.key?(:performance_max_final_url_opt_in_recommendation) @performance_max_opt_in_recommendation = args[:performance_max_opt_in_recommendation] if args.key?(:performance_max_opt_in_recommendation) @raise_target_cpa_bid_too_low_recommendation = args[:raise_target_cpa_bid_too_low_recommendation] if args.key?(:raise_target_cpa_bid_too_low_recommendation) @raise_target_cpa_recommendation = args[:raise_target_cpa_recommendation] if args.key?(:raise_target_cpa_recommendation) @refresh_customer_match_list_recommendation = args[:refresh_customer_match_list_recommendation] if args.key?(:refresh_customer_match_list_recommendation) @resource_name = args[:resource_name] if args.key?(:resource_name) @responsive_search_ad_asset_recommendation = args[:responsive_search_ad_asset_recommendation] if args.key?(:responsive_search_ad_asset_recommendation) @responsive_search_ad_improve_ad_strength_recommendation = args[:responsive_search_ad_improve_ad_strength_recommendation] if args.key?(:responsive_search_ad_improve_ad_strength_recommendation) @responsive_search_ad_recommendation = args[:responsive_search_ad_recommendation] if args.key?(:responsive_search_ad_recommendation) @search_partners_opt_in_recommendation = args[:search_partners_opt_in_recommendation] if args.key?(:search_partners_opt_in_recommendation) @set_target_cpa_recommendation = args[:set_target_cpa_recommendation] if args.key?(:set_target_cpa_recommendation) @set_target_roas_recommendation = args[:set_target_roas_recommendation] if args.key?(:set_target_roas_recommendation) @shopping_add_age_group_recommendation = args[:shopping_add_age_group_recommendation] if args.key?(:shopping_add_age_group_recommendation) @shopping_add_color_recommendation = args[:shopping_add_color_recommendation] if args.key?(:shopping_add_color_recommendation) @shopping_add_gender_recommendation = args[:shopping_add_gender_recommendation] if args.key?(:shopping_add_gender_recommendation) @shopping_add_gtin_recommendation = args[:shopping_add_gtin_recommendation] if args.key?(:shopping_add_gtin_recommendation) @shopping_add_more_identifiers_recommendation = args[:shopping_add_more_identifiers_recommendation] if args.key?(:shopping_add_more_identifiers_recommendation) @shopping_add_products_to_campaign_recommendation = args[:shopping_add_products_to_campaign_recommendation] if args.key?(:shopping_add_products_to_campaign_recommendation) @shopping_add_size_recommendation = args[:shopping_add_size_recommendation] if args.key?(:shopping_add_size_recommendation) @shopping_fix_disapproved_products_recommendation = args[:shopping_fix_disapproved_products_recommendation] if args.key?(:shopping_fix_disapproved_products_recommendation) @shopping_fix_merchant_center_account_suspension_warning_recommendation = args[:shopping_fix_merchant_center_account_suspension_warning_recommendation] if args.key?(:shopping_fix_merchant_center_account_suspension_warning_recommendation) @shopping_fix_suspended_merchant_center_account_recommendation = args[:shopping_fix_suspended_merchant_center_account_recommendation] if args.key?(:shopping_fix_suspended_merchant_center_account_recommendation) @shopping_migrate_regular_shopping_campaign_offers_to_performance_max_recommendation = args[:shopping_migrate_regular_shopping_campaign_offers_to_performance_max_recommendation] if args.key?(:shopping_migrate_regular_shopping_campaign_offers_to_performance_max_recommendation) @shopping_target_all_offers_recommendation = args[:shopping_target_all_offers_recommendation] if args.key?(:shopping_target_all_offers_recommendation) @sitelink_asset_recommendation = args[:sitelink_asset_recommendation] if args.key?(:sitelink_asset_recommendation) @target_cpa_opt_in_recommendation = args[:target_cpa_opt_in_recommendation] if args.key?(:target_cpa_opt_in_recommendation) @target_roas_opt_in_recommendation = args[:target_roas_opt_in_recommendation] if args.key?(:target_roas_opt_in_recommendation) @text_ad_recommendation = args[:text_ad_recommendation] if args.key?(:text_ad_recommendation) @type = args[:type] if args.key?(:type) @upgrade_local_campaign_to_performance_max_recommendation = args[:upgrade_local_campaign_to_performance_max_recommendation] if args.key?(:upgrade_local_campaign_to_performance_max_recommendation) @upgrade_smart_shopping_campaign_to_performance_max_recommendation = args[:upgrade_smart_shopping_campaign_to_performance_max_recommendation] if args.key?(:upgrade_smart_shopping_campaign_to_performance_max_recommendation) @use_broad_match_keyword_recommendation = args[:use_broad_match_keyword_recommendation] if args.key?(:use_broad_match_keyword_recommendation) end |