Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCalloutAssetRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The callout asset recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationCalloutAssetRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationCalloutAssetRecommendation.



17898
17899
17900
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Output only. New callout extension assets recommended at the campaign level. Corresponds to the JSON property recommendedCampaignCalloutAssets



17891
17892
17893
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17891

def recommended_campaign_callout_assets
  @recommended_campaign_callout_assets
end

Output only. New callout extension assets recommended at the customer level. Corresponds to the JSON property recommendedCustomerCalloutAssets



17896
17897
17898
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17896

def recommended_customer_callout_assets
  @recommended_customer_callout_assets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17903
17904
17905
17906
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17903

def update!(**args)
  @recommended_campaign_callout_assets = args[:recommended_campaign_callout_assets] if args.key?(:recommended_campaign_callout_assets)
  @recommended_customer_callout_assets = args[:recommended_customer_callout_assets] if args.key?(:recommended_customer_callout_assets)
end