Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudget
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A campaign budget shared amongst various budget recommendation types.
Instance Attribute Summary collapse
-
#current_amount_micros ⇒ Fixnum
Output only.
-
#new_start_date ⇒ String
Output only.
-
#recommended_new_amount_micros ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudget
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudget
Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudget.
17930 17931 17932 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17930 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_amount_micros ⇒ Fixnum
Output only. Current budget amount.
Corresponds to the JSON property currentAmountMicros
17916 17917 17918 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17916 def current_amount_micros @current_amount_micros end |
#new_start_date ⇒ String
Output only. The date when the new budget would start being used. This field
will be set for the following recommendation types:
FORECASTING_SET_TARGET_ROAS YYYY-MM-DD format, for example, 2018-04-17.
Corresponds to the JSON property newStartDate
17923 17924 17925 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17923 def new_start_date @new_start_date end |
#recommended_new_amount_micros ⇒ Fixnum
Output only. Recommended budget amount.
Corresponds to the JSON property recommendedNewAmountMicros
17928 17929 17930 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17928 def recommended_new_amount_micros @recommended_new_amount_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17935 17936 17937 17938 17939 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17935 def update!(**args) @current_amount_micros = args[:current_amount_micros] if args.key?(:current_amount_micros) @new_start_date = args[:new_start_date] if args.key?(:new_start_date) @recommended_new_amount_micros = args[:recommended_new_amount_micros] if args.key?(:recommended_new_amount_micros) end |