Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendationCampaignBudgetRecommendationOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The impact estimates for a given budget amount.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendationCampaignBudgetRecommendationOption

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendationCampaignBudgetRecommendationOption.



17709
17710
17711
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_amount_microsFixnum

Output only. The budget amount for this option. Corresponds to the JSON property budgetAmountMicros

Returns:

  • (Fixnum)


17701
17702
17703
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17701

def budget_amount_micros
  @budget_amount_micros
end

#impactGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationImpact

The impact of making the change as described in the recommendation. Some types of recommendations may not have impact information. Corresponds to the JSON property impact



17707
17708
17709
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17707

def impact
  @impact
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17714
17715
17716
17717
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17714

def update!(**args)
  @budget_amount_micros = args[:budget_amount_micros] if args.key?(:budget_amount_micros)
  @impact = args[:impact] if args.key?(:impact)
end