Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationDynamicImageExtensionOptInRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Recommendation to enable dynamic image extensions on the account, allowing Google to find the best images from ad landing pages and complement text ads.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationDynamicImageExtensionOptInRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationDynamicImageExtensionOptInRecommendation.



18011
18012
18013
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18011

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18016
18017
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18016

def update!(**args)
end