Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMigrateDynamicSearchAdsCampaignToPerformanceMaxRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The Dynamic Search Ads to Performance Max migration recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationMigrateDynamicSearchAdsCampaignToPerformanceMaxRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationMigrateDynamicSearchAdsCampaignToPerformanceMaxRecommendation.



18278
18279
18280
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18278

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Output only. A link to the Google Ads UI where the customer can manually apply the recommendation. Corresponds to the JSON property applyLink

Returns:

  • (String)


18276
18277
18278
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18276

def apply_link
  @apply_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18283
18284
18285
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18283

def update!(**args)
  @apply_link = args[:apply_link] if args.key?(:apply_link)
end