Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRaiseTargetCpaBidTooLowRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The raise target CPA bid too low recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationRaiseTargetCpaBidTooLowRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationRaiseTargetCpaBidTooLowRecommendation.



18303
18304
18305
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#average_target_cpa_microsFixnum

Output only. The current average target CPA of the campaign, in micros of customer local currency. Corresponds to the JSON property averageTargetCpaMicros

Returns:

  • (Fixnum)


18295
18296
18297
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18295

def average_target_cpa_micros
  @average_target_cpa_micros
end

Output only. A number greater than 1.0 indicating the factor by which we recommend the target CPA should be increased. Corresponds to the JSON property recommendedTargetMultiplier

Returns:

  • (Float)


18301
18302
18303
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18301

def recommended_target_multiplier
  @recommended_target_multiplier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18308
18309
18310
18311
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18308

def update!(**args)
  @average_target_cpa_micros = args[:average_target_cpa_micros] if args.key?(:average_target_cpa_micros)
  @recommended_target_multiplier = args[:recommended_target_multiplier] if args.key?(:recommended_target_multiplier)
end