Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Weekly account performance metrics. For some recommendation types, these are averaged over the past 90-day period and hence can be fractional.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationRecommendationMetrics

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationRecommendationMetrics.



18530
18531
18532
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18530

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clicksFloat

Output only. Number of ad clicks. Corresponds to the JSON property clicks

Returns:

  • (Float)


18502
18503
18504
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18502

def clicks
  @clicks
end

#conversionsFloat

Output only. Number of conversions. Corresponds to the JSON property conversions

Returns:

  • (Float)


18507
18508
18509
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18507

def conversions
  @conversions
end

#conversions_valueFloat

Output only. Sum of the conversion value of the conversions. Corresponds to the JSON property conversionsValue

Returns:

  • (Float)


18512
18513
18514
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18512

def conversions_value
  @conversions_value
end

#cost_microsFixnum

Output only. Cost (in micros) for advertising, in the local currency for the account. Corresponds to the JSON property costMicros

Returns:

  • (Fixnum)


18518
18519
18520
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18518

def cost_micros
  @cost_micros
end

#impressionsFloat

Output only. Number of ad impressions. Corresponds to the JSON property impressions

Returns:

  • (Float)


18523
18524
18525
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18523

def impressions
  @impressions
end

#video_viewsFloat

Output only. Number of video views for a video ad campaign. Corresponds to the JSON property videoViews

Returns:

  • (Float)


18528
18529
18530
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18528

def video_views
  @video_views
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18535
18536
18537
18538
18539
18540
18541
18542
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18535

def update!(**args)
  @clicks = args[:clicks] if args.key?(:clicks)
  @conversions = args[:conversions] if args.key?(:conversions)
  @conversions_value = args[:conversions_value] if args.key?(:conversions_value)
  @cost_micros = args[:cost_micros] if args.key?(:cost_micros)
  @impressions = args[:impressions] if args.key?(:impressions)
  @video_views = args[:video_views] if args.key?(:video_views)
end