Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMerchantCenterAccountSuspensionRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The shopping recommendation to fix Merchant Center account suspension issues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationShoppingMerchantCenterAccountSuspensionRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationShoppingMerchantCenterAccountSuspensionRecommendation.



18763
18764
18765
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18763

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feed_labelString

Output only. The feed label of the campaign for which the suspension happened. Corresponds to the JSON property feedLabel

Returns:

  • (String)


18756
18757
18758
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18756

def feed_label
  @feed_label
end

#merchantGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMerchantInfo

The Merchant Center account details. Corresponds to the JSON property merchant



18761
18762
18763
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18761

def merchant
  @merchant
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18768
18769
18770
18771
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18768

def update!(**args)
  @feed_label = args[:feed_label] if args.key?(:feed_label)
  @merchant = args[:merchant] if args.key?(:merchant)
end