Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The shopping recommendation to migrate Regular Shopping Campaign targeted offers to Performance Max campaigns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation.



18790
18791
18792
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18790

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feed_labelString

Output only. The feed label of the offers targeted by the campaigns sharing this suggestion. Corresponds to the JSON property feedLabel

Returns:

  • (String)


18783
18784
18785
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18783

def feed_label
  @feed_label
end

#merchantGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMerchantInfo

The Merchant Center account details. Corresponds to the JSON property merchant



18788
18789
18790
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18788

def merchant
  @merchant
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18795
18796
18797
18798
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18795

def update!(**args)
  @feed_label = args[:feed_label] if args.key?(:feed_label)
  @merchant = args[:merchant] if args.key?(:merchant)
end