Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationSubscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Recommendation Subscription resource

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationSubscription

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationSubscription.



33279
33280
33281
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33279

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_date_timeString

Output only. Time in seconds when the subscription was first created. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. Corresponds to the JSON property createDateTime

Returns:

  • (String)


33254
33255
33256
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33254

def create_date_time
  @create_date_time
end

#modify_date_timeString

Output only. Contains the time in microseconds, when the Recommendation Subscription was last updated. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property modifyDateTime

Returns:

  • (String)


33261
33262
33263
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33261

def modify_date_time
  @modify_date_time
end

#resource_nameString

Immutable. The resource name of the recommendation subscription. customers/ customer_id/recommendationSubscriptions/recommendation_type` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


33267
33268
33269
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33267

def resource_name
  @resource_name
end

#statusString

Required. Status of the subscription, either enabled or paused. Corresponds to the JSON property status

Returns:

  • (String)


33272
33273
33274
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33272

def status
  @status
end

#typeString

Required. Immutable. The type of recommendation subscribed to. Corresponds to the JSON property type

Returns:

  • (String)


33277
33278
33279
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33277

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33284
33285
33286
33287
33288
33289
33290
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33284

def update!(**args)
  @create_date_time = args[:create_date_time] if args.key?(:create_date_time)
  @modify_date_time = args[:modify_date_time] if args.key?(:modify_date_time)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end