Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetAdjustmentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Information of a target adjustment recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationTargetAdjustmentInfo

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationTargetAdjustmentInfo.



18919
18920
18921
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18919

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_average_target_microsFixnum

Output only. The current average target of the campaign or portfolio targeted by this recommendation. Corresponds to the JSON property currentAverageTargetMicros

Returns:

  • (Fixnum)


18905
18906
18907
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18905

def current_average_target_micros
  @current_average_target_micros
end

Output only. The factor by which we recommend the target to be adjusted by. Corresponds to the JSON property recommendedTargetMultiplier

Returns:

  • (Float)


18910
18911
18912
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18910

def recommended_target_multiplier
  @recommended_target_multiplier
end

#shared_setString

Output only. The shared set resource name of the portfolio bidding strategy where the target is defined. Only populated if the recommendation is portfolio level. Corresponds to the JSON property sharedSet

Returns:

  • (String)


18917
18918
18919
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18917

def shared_set
  @shared_set
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18924
18925
18926
18927
18928
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18924

def update!(**args)
  @current_average_target_micros = args[:current_average_target_micros] if args.key?(:current_average_target_micros)
  @recommended_target_multiplier = args[:recommended_target_multiplier] if args.key?(:recommended_target_multiplier)
  @shared_set = args[:shared_set] if args.key?(:shared_set)
end