Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The Target CPA opt-in recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendation.



18947
18948
18949
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18947

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#optionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendationTargetCpaOptInRecommendationOption>

Output only. The available goals and corresponding options for Target CPA strategy. Corresponds to the JSON property options



18939
18940
18941
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18939

def options
  @options
end

Output only. The recommended average CPA target. See required budget amount and impact of using this recommendation in options list. Corresponds to the JSON property recommendedTargetCpaMicros

Returns:

  • (Fixnum)


18945
18946
18947
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18945

def recommended_target_cpa_micros
  @recommended_target_cpa_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18952
18953
18954
18955
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18952

def update!(**args)
  @options = args[:options] if args.key?(:options)
  @recommended_target_cpa_micros = args[:recommended_target_cpa_micros] if args.key?(:recommended_target_cpa_micros)
end