Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationUseBroadMatchKeywordRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The use broad match keyword recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationUseBroadMatchKeywordRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationUseBroadMatchKeywordRecommendation.



19031
19032
19033
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19031

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaign_keywords_countFixnum

Output only. Total number of keywords in the campaign. Corresponds to the JSON property campaignKeywordsCount

Returns:

  • (Fixnum)


19006
19007
19008
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19006

def campaign_keywords_count
  @campaign_keywords_count
end

#campaign_uses_shared_budgetBoolean Also known as: campaign_uses_shared_budget?

Output only. Whether the associated campaign uses a shared budget. Corresponds to the JSON property campaignUsesSharedBudget

Returns:

  • (Boolean)


19011
19012
19013
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19011

def campaign_uses_shared_budget
  @campaign_uses_shared_budget
end

#keywordArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo>

Output only. Sample of keywords to be expanded to Broad Match. Corresponds to the JSON property keyword



19017
19018
19019
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19017

def keyword
  @keyword
end

#required_campaign_budget_amount_microsFixnum

Output only. The budget recommended to avoid becoming budget constrained after applying the recommendation. Corresponds to the JSON property requiredCampaignBudgetAmountMicros

Returns:

  • (Fixnum)


19023
19024
19025
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19023

def required_campaign_budget_amount_micros
  @required_campaign_budget_amount_micros
end

#suggested_keywords_countFixnum

Output only. Total number of keywords to be expanded to Broad Match in the campaign. Corresponds to the JSON property suggestedKeywordsCount

Returns:

  • (Fixnum)


19029
19030
19031
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19029

def suggested_keywords_count
  @suggested_keywords_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19036
19037
19038
19039
19040
19041
19042
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19036

def update!(**args)
  @campaign_keywords_count = args[:campaign_keywords_count] if args.key?(:campaign_keywords_count)
  @campaign_uses_shared_budget = args[:campaign_uses_shared_budget] if args.key?(:campaign_uses_shared_budget)
  @keyword = args[:keyword] if args.key?(:keyword)
  @required_campaign_budget_amount_micros = args[:required_campaign_budget_amount_micros] if args.key?(:required_campaign_budget_amount_micros)
  @suggested_keywords_count = args[:suggested_keywords_count] if args.key?(:suggested_keywords_count)
end