Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesResidency
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesResidency
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Details about the employee's medical residency. Residency is a stage of graduate medical education in which a qualified medical professional practices under the supervision of a senior clinician.
Instance Attribute Summary collapse
-
#completion_year ⇒ Fixnum
Output only.
-
#institution_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesResidency
constructor
A new instance of GoogleAdsSearchads360V23ResourcesResidency.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesResidency
Returns a new instance of GoogleAdsSearchads360V23ResourcesResidency.
33370 33371 33372 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33370 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completion_year ⇒ Fixnum
Output only. Year of completion.
Corresponds to the JSON property completionYear
33363 33364 33365 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33363 def completion_year @completion_year end |
#institution_name ⇒ String
Output only. Name of the institution at which the residency was completed.
Corresponds to the JSON property institutionName
33368 33369 33370 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33368 def institution_name @institution_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33375 33376 33377 33378 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33375 def update!(**args) @completion_year = args[:completion_year] if args.key?(:completion_year) @institution_name = args[:institution_name] if args.key?(:institution_name) end |