Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSearchAds360Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A field or resource (artifact) used by SearchAds360Service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSearchAds360Field

Returns a new instance of GoogleAdsSearchads360V23ResourcesSearchAds360Field.



33501
33502
33503
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_resourcesArray<String>

Output only. The names of all resources that are selectable with the described artifact. Fields from these resources do not segment metrics when included in search queries. This field is only set for artifacts whose category is RESOURCE. Corresponds to the JSON property attributeResources

Returns:

  • (Array<String>)


33418
33419
33420
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33418

def attribute_resources
  @attribute_resources
end

#categoryString

Output only. The category of the artifact. Corresponds to the JSON property category

Returns:

  • (String)


33423
33424
33425
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33423

def category
  @category
end

#data_typeString

Output only. This field determines the operators that can be used with the artifact in WHERE clauses. Corresponds to the JSON property dataType

Returns:

  • (String)


33429
33430
33431
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33429

def data_type
  @data_type
end

#enum_valuesArray<String>

Output only. Values the artifact can assume if it is a field of type ENUM. This field is only set for artifacts of category SEGMENT or ATTRIBUTE. Corresponds to the JSON property enumValues

Returns:

  • (Array<String>)


33435
33436
33437
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33435

def enum_values
  @enum_values
end

#filterableBoolean Also known as: filterable?

Output only. Whether the artifact can be used in a WHERE clause in search queries. Corresponds to the JSON property filterable

Returns:

  • (Boolean)


33441
33442
33443
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33441

def filterable
  @filterable
end

#is_repeatedBoolean Also known as: is_repeated?

Output only. Whether the field artifact is repeated. Corresponds to the JSON property isRepeated

Returns:

  • (Boolean)


33447
33448
33449
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33447

def is_repeated
  @is_repeated
end

#metricsArray<String>

Output only. This field lists the names of all metrics that are selectable with the described artifact when it is used in the FROM clause. It is only set for artifacts whose category is RESOURCE. Corresponds to the JSON property metrics

Returns:

  • (Array<String>)


33455
33456
33457
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33455

def metrics
  @metrics
end

#nameString

Output only. The name of the artifact. Corresponds to the JSON property name

Returns:

  • (String)


33460
33461
33462
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33460

def name
  @name
end

#resource_nameString

Output only. The resource name of the artifact. Artifact resource names have the form: SearchAds360Fields/name` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


33466
33467
33468
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33466

def resource_name
  @resource_name
end

#segmentsArray<String>

Output only. This field lists the names of all artifacts, whether a segment or another resource, that segment metrics when included in search queries and when the described artifact is used in the FROM clause. It is only set for artifacts whose category is RESOURCE. Corresponds to the JSON property segments

Returns:

  • (Array<String>)


33474
33475
33476
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33474

def segments
  @segments
end

#selectableBoolean Also known as: selectable?

Output only. Whether the artifact can be used in a SELECT clause in search queries. Corresponds to the JSON property selectable

Returns:

  • (Boolean)


33480
33481
33482
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33480

def selectable
  @selectable
end

#selectable_withArray<String>

Output only. The names of all resources, segments, and metrics that are selectable with the described artifact. Corresponds to the JSON property selectableWith

Returns:

  • (Array<String>)


33487
33488
33489
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33487

def selectable_with
  @selectable_with
end

#sortableBoolean Also known as: sortable?

Output only. Whether the artifact can be used in a ORDER BY clause in search queries. Corresponds to the JSON property sortable

Returns:

  • (Boolean)


33493
33494
33495
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33493

def sortable
  @sortable
end

#type_urlString

Output only. The URL of proto describing the artifact's data type. Corresponds to the JSON property typeUrl

Returns:

  • (String)


33499
33500
33501
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33499

def type_url
  @type_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33506
33507
33508
33509
33510
33511
33512
33513
33514
33515
33516
33517
33518
33519
33520
33521
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33506

def update!(**args)
  @attribute_resources = args[:attribute_resources] if args.key?(:attribute_resources)
  @category = args[:category] if args.key?(:category)
  @data_type = args[:data_type] if args.key?(:data_type)
  @enum_values = args[:enum_values] if args.key?(:enum_values)
  @filterable = args[:filterable] if args.key?(:filterable)
  @is_repeated = args[:is_repeated] if args.key?(:is_repeated)
  @metrics = args[:metrics] if args.key?(:metrics)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @segments = args[:segments] if args.key?(:segments)
  @selectable = args[:selectable] if args.key?(:selectable)
  @selectable_with = args[:selectable_with] if args.key?(:selectable_with)
  @sortable = args[:sortable] if args.key?(:sortable)
  @type_url = args[:type_url] if args.key?(:type_url)
end