Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedCriterion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedCriterion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A criterion belonging to a shared set.
Instance Attribute Summary collapse
-
#brand ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandInfo
Represents a Brand Criterion used for targeting based on commercial knowledge graph.
-
#criterion_id ⇒ Fixnum
Output only.
-
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo
A keyword criterion.
-
#mobile_app_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo
A mobile app category criterion.
-
#mobile_application ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo
A mobile application criterion.
-
#negative ⇒ Boolean
(also: #negative?)
Immutable.
-
#placement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo
A placement criterion.
-
#resource_name ⇒ String
Immutable.
-
#shared_set ⇒ String
Immutable.
-
#type ⇒ String
Output only.
-
#vertical_ads_item_group_rule ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo
A criterion to represent a single item group rule in Vertical Ads.
-
#webpage ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageInfo
Represents a criterion for targeting webpages of an advertiser's website.
-
#youtube_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
A YouTube Channel criterion.
-
#youtube_video ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
A YouTube Video criterion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSharedCriterion
constructor
A new instance of GoogleAdsSearchads360V23ResourcesSharedCriterion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSharedCriterion
Returns a new instance of GoogleAdsSearchads360V23ResourcesSharedCriterion.
33646 33647 33648 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#brand ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandInfo
Represents a Brand Criterion used for targeting based on commercial knowledge
graph.
Corresponds to the JSON property brand
33574 33575 33576 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33574 def brand @brand end |
#criterion_id ⇒ Fixnum
Output only. The ID of the criterion. This field is ignored for mutates.
Corresponds to the JSON property criterionId
33579 33580 33581 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33579 def criterion_id @criterion_id end |
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo
A keyword criterion.
Corresponds to the JSON property keyword
33584 33585 33586 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33584 def keyword @keyword end |
#mobile_app_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo
A mobile app category criterion.
Corresponds to the JSON property mobileAppCategory
33589 33590 33591 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33589 def mobile_app_category @mobile_app_category end |
#mobile_application ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo
A mobile application criterion.
Corresponds to the JSON property mobileApplication
33594 33595 33596 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33594 def mobile_application @mobile_application end |
#negative ⇒ Boolean Also known as: negative?
Immutable. If true, the criterion is excluded. If false, the criterion is
targeted.
Corresponds to the JSON property negative
33600 33601 33602 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33600 def negative @negative end |
#placement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo
A placement criterion. This can be used to modify bids for sites when
targeting the content network.
Corresponds to the JSON property placement
33607 33608 33609 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33607 def placement @placement end |
#resource_name ⇒ String
Immutable. The resource name of the shared criterion. Shared set resource
names have the form: customers/customer_id/sharedCriteria/shared_set_id~
criterion_id`
Corresponds to the JSON propertyresourceName`
33614 33615 33616 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33614 def resource_name @resource_name end |
#shared_set ⇒ String
Immutable. The shared set to which the shared criterion belongs.
Corresponds to the JSON property sharedSet
33619 33620 33621 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33619 def shared_set @shared_set end |
#type ⇒ String
Output only. The type of the criterion.
Corresponds to the JSON property type
33624 33625 33626 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33624 def type @type end |
#vertical_ads_item_group_rule ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo
A criterion to represent a single item group rule in Vertical Ads.
Corresponds to the JSON property verticalAdsItemGroupRule
33629 33630 33631 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33629 def vertical_ads_item_group_rule @vertical_ads_item_group_rule end |
#webpage ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageInfo
Represents a criterion for targeting webpages of an advertiser's website.
Corresponds to the JSON property webpage
33634 33635 33636 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33634 def webpage @webpage end |
#youtube_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
A YouTube Channel criterion.
Corresponds to the JSON property youtubeChannel
33639 33640 33641 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33639 def youtube_channel @youtube_channel end |
#youtube_video ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
A YouTube Video criterion.
Corresponds to the JSON property youtubeVideo
33644 33645 33646 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33644 def youtube_video @youtube_video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33651 33652 33653 33654 33655 33656 33657 33658 33659 33660 33661 33662 33663 33664 33665 33666 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33651 def update!(**args) @brand = args[:brand] if args.key?(:brand) @criterion_id = args[:criterion_id] if args.key?(:criterion_id) @keyword = args[:keyword] if args.key?(:keyword) @mobile_app_category = args[:mobile_app_category] if args.key?(:mobile_app_category) @mobile_application = args[:mobile_application] if args.key?(:mobile_application) @negative = args[:negative] if args.key?(:negative) @placement = args[:placement] if args.key?(:placement) @resource_name = args[:resource_name] if args.key?(:resource_name) @shared_set = args[:shared_set] if args.key?(:shared_set) @type = args[:type] if args.key?(:type) @vertical_ads_item_group_rule = args[:vertical_ads_item_group_rule] if args.key?(:vertical_ads_item_group_rule) @webpage = args[:webpage] if args.key?(:webpage) @youtube_channel = args[:youtube_channel] if args.key?(:youtube_channel) @youtube_video = args[:youtube_video] if args.key?(:youtube_video) end |