Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

SharedSets are used for sharing criterion exclusions across multiple campaigns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSharedSet

Returns a new instance of GoogleAdsSearchads360V23ResourcesSharedSet.



33721
33722
33723
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. The ID of this shared set. Read only. Corresponds to the JSON property id

Returns:

  • (Fixnum)


33676
33677
33678
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33676

def id
  @id
end

#member_countFixnum

Output only. The number of shared criteria within this shared set. Read only. Corresponds to the JSON property memberCount

Returns:

  • (Fixnum)


33681
33682
33683
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33681

def member_count
  @member_count
end

#nameString

The name of this shared set. Required. Shared Sets must have names that are unique among active shared sets of the same type. The length of this string should be between 1 and 255 UTF-8 bytes, inclusive. Corresponds to the JSON property name

Returns:

  • (String)


33688
33689
33690
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33688

def name
  @name
end

#reference_countFixnum

Output only. The number of campaigns associated with this shared set. Read only. Corresponds to the JSON property referenceCount

Returns:

  • (Fixnum)


33694
33695
33696
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33694

def reference_count
  @reference_count
end

#resource_nameString

Immutable. The resource name of the shared set. Shared set resource names have the form: customers/customer_id/sharedSets/shared_set_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


33700
33701
33702
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33700

def resource_name
  @resource_name
end

#statusString

Output only. The status of this shared set. Read only. Corresponds to the JSON property status

Returns:

  • (String)


33705
33706
33707
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33705

def status
  @status
end

#typeString

Immutable. The type of this shared set: each shared set holds only a single kind of resource. Required. Immutable. Corresponds to the JSON property type

Returns:

  • (String)


33711
33712
33713
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33711

def type
  @type
end

#vertical_ads_item_vertical_typeString

Immutable. Shared sets of type VERTICAL_ADS_ITEM_GROUP_RULE_LIST are associated with a particular vertical (e.g. hotels, things to do, flights, etc. ). This field is required for shared sets of type VERTICAL_ADS_ITEM_GROUP_RULE_LIST. Corresponds to the JSON property verticalAdsItemVerticalType

Returns:

  • (String)


33719
33720
33721
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33719

def vertical_ads_item_vertical_type
  @vertical_ads_item_vertical_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33726
33727
33728
33729
33730
33731
33732
33733
33734
33735
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33726

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @member_count = args[:member_count] if args.key?(:member_count)
  @name = args[:name] if args.key?(:name)
  @reference_count = args[:reference_count] if args.key?(:reference_count)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
  @vertical_ads_item_vertical_type = args[:vertical_ads_item_vertical_type] if args.key?(:vertical_ads_item_vertical_type)
end