Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesShoppingPerformanceView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Shopping performance view. Provides Shopping campaign and Performance Max campaign statistics aggregated at several product dimension levels. Product dimension values from Merchant Center such as brand, category, custom attributes, product condition, and product type will reflect the state of each dimension as of the date and time when the corresponding event was recorded. The number of impressions and clicks that shopping_performance_view returns stats for may be different from campaign reports. shopping_performance_view shows impressions and clicks on products appearing in ads, while campaign reports show impressions and clicks on the ads themselves. Depending on the format, an ad can show from zero to several products, so the numbers may not match. In Search Ads 360 UI, you can query impressions and clicks of products appearing in ads by selecting a column from "Product attributes" in the report editor. For example, selecting the "Brand" column is equivalent to selecting segments.product_brand.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesShoppingPerformanceView

Returns a new instance of GoogleAdsSearchads360V23ResourcesShoppingPerformanceView.



33588
33589
33590
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33588

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_nameString

Output only. The resource name of the Shopping performance view. Shopping performance view resource names have the form: customers/customer_id/ shoppingPerformanceView Corresponds to the JSON property resourceName

Returns:

  • (String)


33586
33587
33588
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33586

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33593
33594
33595
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33593

def update!(**args)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end