Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesShoppingProduct

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A shopping product from Google Merchant Center that can be advertised by campaigns. The resource returns currently existing products from Google Merchant Center accounts linked with the customer. A campaign includes a product by specifying its merchant id (or, if available, the Multi Client Account id of the merchant) in the ShoppingSetting, and can limit the inclusion to products having a specified feed label. Standard Shopping campaigns can also limit the inclusion through a campaign_criterion. listing_scope. Queries to this resource specify a scope: * Account: - Filters on campaigns or ad groups are not specified. - All products from the linked Google Merchant Center accounts are returned. - Metrics and some fields (see the per-field documentation) are aggregated across all Shopping and Performance Max campaigns that include a product. * Campaign: - An equality filter on campaign is specified. Supported campaign types are Shopping, Performance Max, Demand Gen, Video, App. - Only products that are included by the specified campaign are returned. - Metrics and some fields (see the per- field documentation) are restricted to the specified campaign. - Only the following metrics are supported for Demand Gen, Video, App campaigns: impressions, clicks, ctr. * Ad group: - An equality filter on ad_group and campaign is specified. Supported campaign types are Shopping, Demand Gen, Video, App. - Only products that are included by the specified campaign are returned. - Metrics and some fields (see the per-field documentation) are restricted to the specified ad group. - Only the following metrics are supported for Demand Gen, Video, App campaigns: impressions, clicks, ctr. Note that segmentation by date segments is not permitted and will return UNSUPPORTED_DATE_SEGMENTATION error. On the other hand, filtering on date segments is allowed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesShoppingProduct

Returns a new instance of GoogleAdsSearchads360V23ResourcesShoppingProduct.



34001
34002
34003
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Output only. An ad group of a campaign that includes the product. This field is selectable only in the ad group scope, which requires an equality filter on campaign and ad_group. Corresponds to the JSON property adGroup

Returns:

  • (String)


33806
33807
33808
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33806

def ad_group
  @ad_group
end

#availabilityString

Output only. The availability of the product as provided by the merchant. Corresponds to the JSON property availability

Returns:

  • (String)


33811
33812
33813
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33811

def availability
  @availability
end

#brandString

Output only. The brand of the product as provided by the merchant. Corresponds to the JSON property brand

Returns:

  • (String)


33816
33817
33818
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33816

def brand
  @brand
end

#campaignString

Output only. A campaign that includes the product. This field is selectable only in the campaign scope, which requires an equality filter on campaign. Corresponds to the JSON property campaign

Returns:

  • (String)


33822
33823
33824
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33822

def campaign
  @campaign
end

#category_level1String

Output only. The category level 1 of the product. Corresponds to the JSON property categoryLevel1

Returns:

  • (String)


33827
33828
33829
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33827

def category_level1
  @category_level1
end

#category_level2String

Output only. The category level 2 of the product. Corresponds to the JSON property categoryLevel2

Returns:

  • (String)


33832
33833
33834
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33832

def category_level2
  @category_level2
end

#category_level3String

Output only. The category level 3 of the product. Corresponds to the JSON property categoryLevel3

Returns:

  • (String)


33837
33838
33839
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33837

def category_level3
  @category_level3
end

#category_level4String

Output only. The category level 4 of the product. Corresponds to the JSON property categoryLevel4

Returns:

  • (String)


33842
33843
33844
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33842

def category_level4
  @category_level4
end

#category_level5String

Output only. The category level 5 of the product. Corresponds to the JSON property categoryLevel5

Returns:

  • (String)


33847
33848
33849
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33847

def category_level5
  @category_level5
end

#channelString

Output only. The product channel describing the locality of the product. Corresponds to the JSON property channel

Returns:

  • (String)


33852
33853
33854
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33852

def channel
  @channel
end

#channel_exclusivityString

Output only. The channel exclusivity of the product as provided by the merchant. Corresponds to the JSON property channelExclusivity

Returns:

  • (String)


33858
33859
33860
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33858

def channel_exclusivity
  @channel_exclusivity
end

#conditionString

Output only. The condition of the product as provided by the merchant. Corresponds to the JSON property condition

Returns:

  • (String)


33863
33864
33865
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33863

def condition
  @condition
end

#currency_codeString

Output only. The currency code as provided by the merchant, in ISO 4217 format. Corresponds to the JSON property currencyCode

Returns:

  • (String)


33868
33869
33870
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33868

def currency_code
  @currency_code
end

#custom_attribute0String

Output only. The custom attribute 0 of the product as provided by the merchant. Corresponds to the JSON property customAttribute0

Returns:

  • (String)


33873
33874
33875
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33873

def custom_attribute0
  @custom_attribute0
end

#custom_attribute1String

Output only. The custom attribute 1 of the product as provided by the merchant. Corresponds to the JSON property customAttribute1

Returns:

  • (String)


33878
33879
33880
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33878

def custom_attribute1
  @custom_attribute1
end

#custom_attribute2String

Output only. The custom attribute 2 of the product as provided by the merchant. Corresponds to the JSON property customAttribute2

Returns:

  • (String)


33883
33884
33885
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33883

def custom_attribute2
  @custom_attribute2
end

#custom_attribute3String

Output only. The custom attribute 3 of the product as provided by the merchant. Corresponds to the JSON property customAttribute3

Returns:

  • (String)


33888
33889
33890
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33888

def custom_attribute3
  @custom_attribute3
end

#custom_attribute4String

Output only. The custom attribute 4 of the product as provided by the merchant. Corresponds to the JSON property customAttribute4

Returns:

  • (String)


33893
33894
33895
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33893

def custom_attribute4
  @custom_attribute4
end

#effective_max_cpc_microsFixnum

Output only. The effective maximum cost-per-click (effective max. CPC) of the product. This field is available only if the query specifies the campaign or ad group scope, and if the campaign uses manual bidding. The value is the highest bid set for the product in product groups across all enabled ad groups. It represents the most you're willing to pay for a click on the product. This field can take up to 24 hours to update. Corresponds to the JSON property effectiveMaxCpcMicros

Returns:

  • (Fixnum)


33903
33904
33905
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33903

def effective_max_cpc_micros
  @effective_max_cpc_micros
end

#feed_labelString

Output only. The product feed label as provided by the merchant. Corresponds to the JSON property feedLabel

Returns:

  • (String)


33908
33909
33910
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33908

def feed_label
  @feed_label
end

#issuesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue>

Output only. The list of issues affecting whether the product can show in ads. The value of this field is restricted to the scope specified in the query, see the documentation of the resource. This field can take up to 24 hours to update. This field is not supported for App campaigns. Corresponds to the JSON property issues



33916
33917
33918
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33916

def issues
  @issues
end

#item_idString

Output only. The item id of the product as provided by the merchant. Corresponds to the JSON property itemId

Returns:

  • (String)


33921
33922
33923
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33921

def item_id
  @item_id
end

#language_codeString

Output only. The language code as provided by the merchant, in BCP 47 format. Corresponds to the JSON property languageCode

Returns:

  • (String)


33926
33927
33928
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33926

def language_code
  @language_code
end

#merchant_center_idFixnum

Output only. The id of the merchant that owns the product. Corresponds to the JSON property merchantCenterId

Returns:

  • (Fixnum)


33931
33932
33933
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33931

def merchant_center_id
  @merchant_center_id
end

#multi_client_account_idFixnum

Output only. The id of the Multi Client Account of the merchant, if present. Corresponds to the JSON property multiClientAccountId

Returns:

  • (Fixnum)


33936
33937
33938
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33936

def 
  @multi_client_account_id
end

#price_microsFixnum

Output only. The price of the product in micros as provided by the merchant, in the currency specified in currency_code (e.g. $2.97 is reported as 2970000). Corresponds to the JSON property priceMicros

Returns:

  • (Fixnum)


33943
33944
33945
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33943

def price_micros
  @price_micros
end

#product_image_uriString

Output only. The URI of the product image as provided by the merchant. Corresponds to the JSON property productImageUri

Returns:

  • (String)


33948
33949
33950
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33948

def product_image_uri
  @product_image_uri
end

#product_type_level1String

Output only. The product type level 1 as provided by the merchant. Corresponds to the JSON property productTypeLevel1

Returns:

  • (String)


33953
33954
33955
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33953

def product_type_level1
  @product_type_level1
end

#product_type_level2String

Output only. The product type level 2 as provided by the merchant. Corresponds to the JSON property productTypeLevel2

Returns:

  • (String)


33958
33959
33960
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33958

def product_type_level2
  @product_type_level2
end

#product_type_level3String

Output only. The product type level 3 as provided by the merchant. Corresponds to the JSON property productTypeLevel3

Returns:

  • (String)


33963
33964
33965
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33963

def product_type_level3
  @product_type_level3
end

#product_type_level4String

Output only. The product type level 4 as provided by the merchant. Corresponds to the JSON property productTypeLevel4

Returns:

  • (String)


33968
33969
33970
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33968

def product_type_level4
  @product_type_level4
end

#product_type_level5String

Output only. The product type level 5 as provided by the merchant. Corresponds to the JSON property productTypeLevel5

Returns:

  • (String)


33973
33974
33975
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33973

def product_type_level5
  @product_type_level5
end

#resource_nameString

Output only. The resource name of the shopping product. Shopping product resource names have the form: customers/customer_id/shoppingProducts/ merchant_center_id~channel~language_code~feed_label~item_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


33980
33981
33982
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33980

def resource_name
  @resource_name
end

#statusString

Output only. The status that indicates whether the product can show in ads. The value of this field is restricted to the scope specified in the query, see the documentation of the resource. This field can take up to 24 hours to update. This field is not supported for App campaigns. Corresponds to the JSON property status

Returns:

  • (String)


33988
33989
33990
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33988

def status
  @status
end

#target_countriesArray<String>

Output only. Upper-case two-letter ISO 3166-1 code of the regions where the product is intended to be shown in ads. Corresponds to the JSON property targetCountries

Returns:

  • (Array<String>)


33994
33995
33996
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33994

def target_countries
  @target_countries
end

#titleString

Output only. The title of the product as provided by the merchant. Corresponds to the JSON property title

Returns:

  • (String)


33999
34000
34001
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33999

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34006
34007
34008
34009
34010
34011
34012
34013
34014
34015
34016
34017
34018
34019
34020
34021
34022
34023
34024
34025
34026
34027
34028
34029
34030
34031
34032
34033
34034
34035
34036
34037
34038
34039
34040
34041
34042
34043
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34006

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @availability = args[:availability] if args.key?(:availability)
  @brand = args[:brand] if args.key?(:brand)
  @campaign = args[:campaign] if args.key?(:campaign)
  @category_level1 = args[:category_level1] if args.key?(:category_level1)
  @category_level2 = args[:category_level2] if args.key?(:category_level2)
  @category_level3 = args[:category_level3] if args.key?(:category_level3)
  @category_level4 = args[:category_level4] if args.key?(:category_level4)
  @category_level5 = args[:category_level5] if args.key?(:category_level5)
  @channel = args[:channel] if args.key?(:channel)
  @channel_exclusivity = args[:channel_exclusivity] if args.key?(:channel_exclusivity)
  @condition = args[:condition] if args.key?(:condition)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @custom_attribute0 = args[:custom_attribute0] if args.key?(:custom_attribute0)
  @custom_attribute1 = args[:custom_attribute1] if args.key?(:custom_attribute1)
  @custom_attribute2 = args[:custom_attribute2] if args.key?(:custom_attribute2)
  @custom_attribute3 = args[:custom_attribute3] if args.key?(:custom_attribute3)
  @custom_attribute4 = args[:custom_attribute4] if args.key?(:custom_attribute4)
  @effective_max_cpc_micros = args[:effective_max_cpc_micros] if args.key?(:effective_max_cpc_micros)
  @feed_label = args[:feed_label] if args.key?(:feed_label)
  @issues = args[:issues] if args.key?(:issues)
  @item_id = args[:item_id] if args.key?(:item_id)
  @language_code = args[:language_code] if args.key?(:language_code)
  @merchant_center_id = args[:merchant_center_id] if args.key?(:merchant_center_id)
  @multi_client_account_id = args[:multi_client_account_id] if args.key?(:multi_client_account_id)
  @price_micros = args[:price_micros] if args.key?(:price_micros)
  @product_image_uri = args[:product_image_uri] if args.key?(:product_image_uri)
  @product_type_level1 = args[:product_type_level1] if args.key?(:product_type_level1)
  @product_type_level2 = args[:product_type_level2] if args.key?(:product_type_level2)
  @product_type_level3 = args[:product_type_level3] if args.key?(:product_type_level3)
  @product_type_level4 = args[:product_type_level4] if args.key?(:product_type_level4)
  @product_type_level5 = args[:product_type_level5] if args.key?(:product_type_level5)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @target_countries = args[:target_countries] if args.key?(:target_countries)
  @title = args[:title] if args.key?(:title)
end