Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An issue affecting whether a product can show in ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue

Returns a new instance of GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue.



19146
19147
19148
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ads_severityString

Output only. The severity of the issue in Google Ads. Corresponds to the JSON property adsSeverity

Returns:

  • (String)


19112
19113
19114
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19112

def ads_severity
  @ads_severity
end

#affected_regionsArray<String>

Output only. List of upper-case two-letter ISO 3166-1 codes of the regions affected by the issue. If empty, all regions are affected. Corresponds to the JSON property affectedRegions

Returns:

  • (Array<String>)


19118
19119
19120
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19118

def affected_regions
  @affected_regions
end

#attribute_nameString

Output only. The name of the product's attribute, if any, that triggered the issue. Corresponds to the JSON property attributeName

Returns:

  • (String)


19124
19125
19126
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19124

def attribute_name
  @attribute_name
end

#descriptionString

Output only. The short description of the issue in English. Corresponds to the JSON property description

Returns:

  • (String)


19129
19130
19131
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19129

def description
  @description
end

#detailString

Output only. The detailed description of the issue in English. Corresponds to the JSON property detail

Returns:

  • (String)


19134
19135
19136
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19134

def detail
  @detail
end

#documentationString

Output only. The URL of the Help Center article for the issue. Corresponds to the JSON property documentation

Returns:

  • (String)


19139
19140
19141
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19139

def documentation
  @documentation
end

#error_codeString

Output only. The error code that identifies the issue. Corresponds to the JSON property errorCode

Returns:

  • (String)


19144
19145
19146
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19144

def error_code
  @error_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19151
19152
19153
19154
19155
19156
19157
19158
19159
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19151

def update!(**args)
  @ads_severity = args[:ads_severity] if args.key?(:ads_severity)
  @affected_regions = args[:affected_regions] if args.key?(:affected_regions)
  @attribute_name = args[:attribute_name] if args.key?(:attribute_name)
  @description = args[:description] if args.key?(:description)
  @detail = args[:detail] if args.key?(:detail)
  @documentation = args[:documentation] if args.key?(:documentation)
  @error_code = args[:error_code] if args.key?(:error_code)
end