Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSmartCampaignSearchTermView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSmartCampaignSearchTermView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Smart campaign search term view.
Instance Attribute Summary collapse
-
#campaign ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#search_term ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSmartCampaignSearchTermView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesSmartCampaignSearchTermView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSmartCampaignSearchTermView
Returns a new instance of GoogleAdsSearchads360V23ResourcesSmartCampaignSearchTermView.
34068 34069 34070 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34068 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign ⇒ String
Output only. The Smart campaign the search term served in.
Corresponds to the JSON property campaign
34053 34054 34055 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34053 def campaign @campaign end |
#resource_name ⇒ String
Output only. The resource name of the Smart campaign search term view. Smart
campaign search term view resource names have the form: customers/
customer_id/smartCampaignSearchTermViews/campaign_id~URL-
base64_search_term`
Corresponds to the JSON propertyresourceName`
34061 34062 34063 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34061 def resource_name @resource_name end |
#search_term ⇒ String
Output only. The search term.
Corresponds to the JSON property searchTerm
34066 34067 34068 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34066 def search_term @search_term end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34073 34074 34075 34076 34077 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34073 def update!(**args) @campaign = args[:campaign] if args.key?(:campaign) @resource_name = args[:resource_name] if args.key?(:resource_name) @search_term = args[:search_term] if args.key?(:search_term) end |