Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLinkIdentifier

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The identifiers of a Third Party App Analytics Link.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLinkIdentifier

Returns a new instance of GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLinkIdentifier.



34060
34061
34062
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34060

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_analytics_provider_idFixnum

Immutable. The ID of the app analytics provider. This field should not be empty when creating a new third party app analytics link. It is unable to be modified after the creation of the link. Corresponds to the JSON property appAnalyticsProviderId

Returns:

  • (Fixnum)


34037
34038
34039
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34037

def app_analytics_provider_id
  @app_analytics_provider_id
end

#app_idString

Immutable. A string that uniquely identifies a mobile application from which the data was collected to the Google Ads API. For iOS, the ID string is the 9 digit string that appears at the end of an App Store URL (for example, " 422689480" for "Gmail" whose App Store link is https://apps.apple.com/us/app/ gmail-email-by-google/id422689480). For Android, the ID string is the application's package name (for example, "com.google.android.gm" for "Gmail" given Google Play link https://play.google.com/store/apps/details?id=com. google.android.gm) This field should not be empty when creating a new third party app analytics link. It is unable to be modified after the creation of the link. Corresponds to the JSON property appId

Returns:

  • (String)


34051
34052
34053
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34051

def app_id
  @app_id
end

#app_vendorString

Immutable. The vendor of the app. This field should not be empty when creating a new third party app analytics link. It is unable to be modified after the creation of the link. Corresponds to the JSON property appVendor

Returns:

  • (String)


34058
34059
34060
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34058

def app_vendor
  @app_vendor
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34065
34066
34067
34068
34069
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34065

def update!(**args)
  @app_analytics_provider_id = args[:app_analytics_provider_id] if args.key?(:app_analytics_provider_id)
  @app_id = args[:app_id] if args.key?(:app_id)
  @app_vendor = args[:app_vendor] if args.key?(:app_vendor)
end