Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesTopicConstant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Use topics to target or exclude placements in the Google Display Network based on the category into which the placement falls (for example, "Pets & Animals/ Pets/Dogs").

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesTopicConstant

Returns a new instance of GoogleAdsSearchads360V23ResourcesTopicConstant.



34103
34104
34105
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34103

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. The ID of the topic. Corresponds to the JSON property id

Returns:

  • (Fixnum)


34081
34082
34083
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34081

def id
  @id
end

#pathArray<String>

Output only. The category to target or exclude. Each subsequent element in the array describes a more specific sub-category. For example, "Pets & Animals", " Pets", "Dogs" represents the "Pets & Animals/Pets/Dogs" category. List of available topic categories at https://developers.google.com/google-ads/api/ reference/data/verticals Corresponds to the JSON property path

Returns:

  • (Array<String>)


34090
34091
34092
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34090

def path
  @path
end

#resource_nameString

Output only. The resource name of the topic constant. topic constant resource names have the form: topicConstants/topic_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


34096
34097
34098
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34096

def resource_name
  @resource_name
end

#topic_constant_parentString

Output only. Resource name of parent of the topic constant. Corresponds to the JSON property topicConstantParent

Returns:

  • (String)


34101
34102
34103
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34101

def topic_constant_parent
  @topic_constant_parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34108
34109
34110
34111
34112
34113
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34108

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @path = args[:path] if args.key?(:path)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @topic_constant_parent = args[:topic_constant_parent] if args.key?(:topic_constant_parent)
end