Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesTravelActivityGroupView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A travel activity group view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesTravelActivityGroupView

Returns a new instance of GoogleAdsSearchads360V23ResourcesTravelActivityGroupView.



34148
34149
34150
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34148

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_nameString

Output only. The resource name of the travel activity group view. Travel Activity Group view resource names have the form: customers/customer_id/ travelActivityGroupViews/ad_group_id~criterion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


34146
34147
34148
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34146

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34153
34154
34155
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34153

def update!(**args)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end