Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A user list. This is a list of users a customer may target. The unique key of a user list consists of the following fields: id. Note that the name must also be unique for user lists owned by a given customer, except in some cases where access_reason is set to SHARED. Violating the unique name constraint produces error: UserListError.INVALID_NAME.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesUserList

Returns a new instance of GoogleAdsSearchads360V23ResourcesUserList.



34608
34609
34610
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34608

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_reasonString

Output only. Indicates the reason this account has been granted access to the list. The reason can be SHARED, OWNED, LICENSED or SUBSCRIBED. This field is read-only. Corresponds to the JSON property accessReason

Returns:

  • (String)


34454
34455
34456
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34454

def access_reason
  @access_reason
end

#account_user_list_statusString

Indicates if this share is still enabled. When a UserList is shared with the user this field is set to ENABLED. Later the userList owner can decide to revoke the share and make it DISABLED. The default value of this field is set to ENABLED. Corresponds to the JSON property accountUserListStatus

Returns:

  • (String)


34462
34463
34464
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34462

def 
  @account_user_list_status
end

#basic_user_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBasicUserListInfo

User list targeting as a collection of conversion or remarketing actions. Corresponds to the JSON property basicUserList



34467
34468
34469
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34467

def basic_user_list
  @basic_user_list
end

#closing_reasonString

Indicating the reason why this user list membership status is closed. It is only populated on lists that were automatically closed due to inactivity, and will be cleared once the list membership status becomes open. Corresponds to the JSON property closingReason

Returns:

  • (String)


34474
34475
34476
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34474

def closing_reason
  @closing_reason
end

#crm_based_user_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCrmBasedUserListInfo

UserList of CRM users provided by the advertiser. Corresponds to the JSON property crmBasedUserList



34479
34480
34481
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34479

def crm_based_user_list
  @crm_based_user_list
end

#descriptionString

Description of this user list. Corresponds to the JSON property description

Returns:

  • (String)


34484
34485
34486
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34484

def description
  @description
end

#eligible_for_displayBoolean Also known as: eligible_for_display?

Output only. Indicates this user list is eligible for Google Display Network. This field is read-only. Corresponds to the JSON property eligibleForDisplay

Returns:

  • (Boolean)


34490
34491
34492
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34490

def eligible_for_display
  @eligible_for_display
end

#eligible_for_searchBoolean Also known as: eligible_for_search?

Indicates if this user list is eligible for Google Search Network. Corresponds to the JSON property eligibleForSearch

Returns:

  • (Boolean)


34496
34497
34498
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34496

def eligible_for_search
  @eligible_for_search
end

#idFixnum

Output only. Id of the user list. Corresponds to the JSON property id

Returns:

  • (Fixnum)


34502
34503
34504
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34502

def id
  @id
end

#integration_codeString

An ID from external system. It is used by user list sellers to correlate IDs on their systems. Corresponds to the JSON property integrationCode

Returns:

  • (String)


34508
34509
34510
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34508

def integration_code
  @integration_code
end

#logical_user_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLogicalUserListInfo

Represents a user list that is a custom combination of user lists. Corresponds to the JSON property logicalUserList



34513
34514
34515
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34513

def logical_user_list
  @logical_user_list
end

#lookalike_user_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLookalikeUserListInfo

LookalikeUserlist, composed of users similar to those of a configurable seed ( set of UserLists) Corresponds to the JSON property lookalikeUserList



34519
34520
34521
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34519

def lookalike_user_list
  @lookalike_user_list
end

#match_rate_percentageFixnum

Output only. Indicates match rate for Customer Match lists. The range of this field is [0-100]. This will be null for other list types or when it's not possible to calculate the match rate. This field is read-only. Corresponds to the JSON property matchRatePercentage

Returns:

  • (Fixnum)


34526
34527
34528
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34526

def match_rate_percentage
  @match_rate_percentage
end

#membership_life_spanFixnum

Number of days a user's cookie stays on your list since its most recent addition to the list. This field must be between 0 and 540 inclusive. However, for CRM based userlists, this field can be set to 10000 which means no expiration. Beginning on April 7, 2025, using a value of 10000 to indicate no expiration will no longer be supported. This field is ignored for logical_user_list and rule_based_user_list types. Membership to lists of these types depends on the rules defined by the lists. Corresponds to the JSON property membershipLifeSpan

Returns:

  • (Fixnum)


34537
34538
34539
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34537

def membership_life_span
  @membership_life_span
end

#membership_statusString

Membership status of this user list. Indicates whether a user list is open or active. Only open user lists can accumulate more users and can be targeted to. Corresponds to the JSON property membershipStatus

Returns:

  • (String)


34543
34544
34545
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34543

def membership_status
  @membership_status
end

#nameString

Name of this user list. Unique per user list, except in some cases where a user list of the same name has access_reason set to SHARED. Corresponds to the JSON property name

Returns:

  • (String)


34549
34550
34551
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34549

def name
  @name
end

#read_onlyBoolean Also known as: read_only?

Output only. An option that indicates if a user may edit a list. Depends on the list ownership and list type. For example, external remarketing user lists are not editable. This field is -only. Corresponds to the JSON property readOnly

Returns:

  • (Boolean)


34556
34557
34558
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34556

def read_only
  @read_only
end

#resource_nameString

Immutable. The resource name of the user list. User list resource names have the form: customers/customer_id/userLists/user_list_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


34563
34564
34565
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34563

def resource_name
  @resource_name
end

#rule_based_user_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonRuleBasedUserListInfo

Representation of a userlist that is generated by a rule. Corresponds to the JSON property ruleBasedUserList



34568
34569
34570
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34568

def rule_based_user_list
  @rule_based_user_list
end

#similar_user_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSimilarUserListInfo

SimilarUserList is a list of users which are similar to users from another UserList. These lists are read-only and automatically created by Google. Corresponds to the JSON property similarUserList



34574
34575
34576
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34574

def similar_user_list
  @similar_user_list
end

#size_for_displayFixnum

Output only. Estimated number of users in this user list, on the Google Display Network. This value is if the number of users has not yet been determined. This field is -only. Corresponds to the JSON property sizeForDisplay

Returns:

  • (Fixnum)


34581
34582
34583
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34581

def size_for_display
  @size_for_display
end

#size_for_searchFixnum

Output only. Estimated number of users in this user list in the google.com domain. These are the users available for targeting in Search campaigns. This value is null if the number of users has not yet been determined. This field is read-only. Corresponds to the JSON property sizeForSearch

Returns:

  • (Fixnum)


34589
34590
34591
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34589

def size_for_search
  @size_for_search
end

#size_range_for_displayString

Output only. Size range in terms of number of users of the UserList, on the Google Display Network. This field is read-only. Corresponds to the JSON property sizeRangeForDisplay

Returns:

  • (String)


34595
34596
34597
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34595

def size_range_for_display
  @size_range_for_display
end

#size_range_for_searchString

Output only. Size range in terms of number of users of the UserList, for Search ads. This field is read-only. Corresponds to the JSON property sizeRangeForSearch

Returns:

  • (String)


34601
34602
34603
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34601

def size_range_for_search
  @size_range_for_search
end

#typeString

Output only. Type of this list. This field is read-only. Corresponds to the JSON property type

Returns:

  • (String)


34606
34607
34608
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34606

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34613
34614
34615
34616
34617
34618
34619
34620
34621
34622
34623
34624
34625
34626
34627
34628
34629
34630
34631
34632
34633
34634
34635
34636
34637
34638
34639
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34613

def update!(**args)
  @access_reason = args[:access_reason] if args.key?(:access_reason)
  @account_user_list_status = args[:account_user_list_status] if args.key?(:account_user_list_status)
  @basic_user_list = args[:basic_user_list] if args.key?(:basic_user_list)
  @closing_reason = args[:closing_reason] if args.key?(:closing_reason)
  @crm_based_user_list = args[:crm_based_user_list] if args.key?(:crm_based_user_list)
  @description = args[:description] if args.key?(:description)
  @eligible_for_display = args[:eligible_for_display] if args.key?(:eligible_for_display)
  @eligible_for_search = args[:eligible_for_search] if args.key?(:eligible_for_search)
  @id = args[:id] if args.key?(:id)
  @integration_code = args[:integration_code] if args.key?(:integration_code)
  @logical_user_list = args[:logical_user_list] if args.key?(:logical_user_list)
  @lookalike_user_list = args[:lookalike_user_list] if args.key?(:lookalike_user_list)
  @match_rate_percentage = args[:match_rate_percentage] if args.key?(:match_rate_percentage)
  @membership_life_span = args[:membership_life_span] if args.key?(:membership_life_span)
  @membership_status = args[:membership_status] if args.key?(:membership_status)
  @name = args[:name] if args.key?(:name)
  @read_only = args[:read_only] if args.key?(:read_only)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @rule_based_user_list = args[:rule_based_user_list] if args.key?(:rule_based_user_list)
  @similar_user_list = args[:similar_user_list] if args.key?(:similar_user_list)
  @size_for_display = args[:size_for_display] if args.key?(:size_for_display)
  @size_for_search = args[:size_for_search] if args.key?(:size_for_search)
  @size_range_for_display = args[:size_range_for_display] if args.key?(:size_range_for_display)
  @size_range_for_search = args[:size_range_for_search] if args.key?(:size_range_for_search)
  @type = args[:type] if args.key?(:type)
end