Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserLocationView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A user location view. User Location View includes all metrics aggregated at the country level, one row per country. It reports metrics at the actual physical location of the user by targeted or not targeted location. If other segment fields are used, you may get more than one row per country.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesUserLocationView

Returns a new instance of GoogleAdsSearchads360V23ResourcesUserLocationView.



34701
34702
34703
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34701

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_criterion_idFixnum

Output only. Criterion Id for the country. Corresponds to the JSON property countryCriterionId

Returns:

  • (Fixnum)


34686
34687
34688
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34686

def country_criterion_id
  @country_criterion_id
end

#resource_nameString

Output only. The resource name of the user location view. UserLocation view resource names have the form: customers/customer_id/userLocationViews/ country_criterion_id~targeting_location` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


34693
34694
34695
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34693

def resource_name
  @resource_name
end

#targeting_locationBoolean Also known as: targeting_location?

Output only. Indicates whether location was targeted or not. Corresponds to the JSON property targetingLocation

Returns:

  • (Boolean)


34698
34699
34700
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34698

def targeting_location
  @targeting_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34706
34707
34708
34709
34710
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34706

def update!(**args)
  @country_criterion_id = args[:country_criterion_id] if args.key?(:country_criterion_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @targeting_location = args[:targeting_location] if args.key?(:targeting_location)
end