Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAccountLinkOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single update on an account link.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAccountLinkOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAccountLinkOperation.



35849
35850
35851
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#removeString

Remove operation: A resource name for the account link to remove is expected, in this format: customers/customer_id/accountLinks/account_link_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


35836
35837
35838
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35836

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccountLink

Represents the data sharing connection between a Google Ads account and another account Corresponds to the JSON property update



35842
35843
35844
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35842

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


35847
35848
35849
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35847

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35854
35855
35856
35857
35858
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35854

def update!(**args)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end