Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on an ad group ad label.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation.



36012
36013
36014
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdLabel

A relationship between an ad group ad and a label. Corresponds to the JSON property create



36003
36004
36005
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36003

def create
  @create
end

#removeString

Remove operation: A resource name for the ad group ad label being removed, in this format: customers/customer_id/adGroupAdLabels/ad_group_id~ad_id~ label_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


36010
36011
36012
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36010

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36017
36018
36019
36020
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36017

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end