Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove, update) on an ad group bid modifier.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation.



36160
36161
36162
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupBidModifier

Represents an ad group bid modifier. Corresponds to the JSON property create



36141
36142
36143
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36141

def create
  @create
end

#removeString

Remove operation: A resource name for the removed ad group bid modifier is expected, in this format: customers/customer_id/adGroupBidModifiers/ ad_group_id~criterion_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


36148
36149
36150
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36148

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupBidModifier

Represents an ad group bid modifier. Corresponds to the JSON property update



36153
36154
36155
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36153

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


36158
36159
36160
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36158

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36165
36166
36167
36168
36169
36170
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36165

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end