Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionCustomizerOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionCustomizerOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on a customizer attribute.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionCustomizer
A customizer value for the associated CustomizerAttribute at the AdGroupCriterion level.
-
#remove ⇒ String
Remove operation: A resource name for the removed ad group criterion customizer is expected, in this format:
customers/customer_id/ adGroupCriterionCustomizers/ad_group_id~criterion_id~customizer_attribute_id`Corresponds to the JSON propertyremove`.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupCriterionCustomizerOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAdGroupCriterionCustomizerOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupCriterionCustomizerOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupCriterionCustomizerOperation.
36056 36057 36058 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36056 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionCustomizer
A customizer value for the associated CustomizerAttribute at the
AdGroupCriterion level.
Corresponds to the JSON property create
36046 36047 36048 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36046 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed ad group criterion
customizer is expected, in this format: customers/customer_id/
adGroupCriterionCustomizers/ad_group_id~criterion_id~
customizer_attribute_id`
Corresponds to the JSON propertyremove`
36054 36055 36056 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36054 def remove @remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36061 36062 36063 36064 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36061 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) end |