Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionLabelOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on an ad group criterion label.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupCriterionLabelOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupCriterionLabelOperation.



36218
36219
36220
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionLabel

A relationship between an ad group criterion and a label. Corresponds to the JSON property create



36209
36210
36211
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36209

def create
  @create
end

#removeString

Remove operation: A resource name for the ad group criterion label being removed, in this format: customers/customer_id/adGroupCriterionLabels/ ad_group_id~criterion_id~label_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


36216
36217
36218
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36216

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36223
36224
36225
36226
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36223

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end