Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCustomizerOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCustomizerOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on a customizer attribute.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCustomizer
A customizer value for the associated CustomizerAttribute at the AdGroup level.
-
#remove ⇒ String
Remove operation: A resource name for the removed ad group customizer is expected, in this format:
customers/customer_id/adGroupCustomizers/ad_group_id~customizer_attribute_id`Corresponds to the JSON propertyremove`.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupCustomizerOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAdGroupCustomizerOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupCustomizerOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupCustomizerOperation.
36369 36370 36371 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCustomizer
A customizer value for the associated CustomizerAttribute at the AdGroup level.
Corresponds to the JSON property create
36360 36361 36362 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36360 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed ad group customizer is
expected, in this format: customers/customer_id/adGroupCustomizers/
ad_group_id~customizer_attribute_id`
Corresponds to the JSON propertyremove`
36367 36368 36369 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36367 def remove @remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36374 36375 36376 36377 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36374 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) end |