Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupLabelOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on an ad group label.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupLabelOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupLabelOperation.



36440
36441
36442
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupLabel

A relationship between an ad group and a label. Corresponds to the JSON property create



36432
36433
36434
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36432

def create
  @create
end

#removeString

Remove operation: A resource name for the ad group label being removed, in this format: customers/customer_id/adGroupLabels/ad_group_id~label_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


36438
36439
36440
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36438

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36445
36446
36447
36448
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36445

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end