Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on an ad group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupOperation.



36476
36477
36478
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup

An ad group. Corresponds to the JSON property create



36458
36459
36460
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36458

def create
  @create
end

#removeString

Remove operation: A resource name for the removed ad group is expected, in this format: customers/customer_id/adGroups/ad_group_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


36464
36465
36466
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36464

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup

An ad group. Corresponds to the JSON property update



36469
36470
36471
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36469

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


36474
36475
36476
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36474

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36481
36482
36483
36484
36485
36486
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36481

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end