Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single update operation on an ad.
Instance Attribute Summary collapse
-
#policy_validation_parameter ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyValidationParameter
Parameter for controlling how policy exemption is done.
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAd
An ad.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAdOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAdOperation.
36301 36302 36303 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36301 def initialize(**args) update!(**args) end |
Instance Attribute Details
#policy_validation_parameter ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyValidationParameter
Parameter for controlling how policy exemption is done.
Corresponds to the JSON property policyValidationParameter
36289 36290 36291 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36289 def policy_validation_parameter @policy_validation_parameter end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAd
An ad.
Corresponds to the JSON property update
36294 36295 36296 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36294 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
36299 36300 36301 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36299 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36306 36307 36308 36309 36310 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36306 def update!(**args) @policy_validation_parameter = args[:policy_validation_parameter] if args.key?(:policy_validation_parameter) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |