Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAddBatchJobOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAddBatchJobOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for BatchJobService.AddBatchJobOperations.
Instance Attribute Summary collapse
-
#next_sequence_token ⇒ String
The sequence token to be used when calling AddBatchJobOperations again if more operations need to be added.
-
#total_operations ⇒ Fixnum
The total number of operations added so far for this batch job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAddBatchJobOperationsResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesAddBatchJobOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAddBatchJobOperationsResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesAddBatchJobOperationsResponse.
36545 36546 36547 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36545 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_sequence_token ⇒ String
The sequence token to be used when calling AddBatchJobOperations again if more
operations need to be added. The next AddBatchJobOperations request must set
the sequence_token field to the value of this field.
Corresponds to the JSON property nextSequenceToken
36538 36539 36540 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36538 def next_sequence_token @next_sequence_token end |
#total_operations ⇒ Fixnum
The total number of operations added so far for this batch job.
Corresponds to the JSON property totalOperations
36543 36544 36545 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36543 def total_operations @total_operations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36550 36551 36552 36553 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36550 def update!(**args) @next_sequence_token = args[:next_sequence_token] if args.key?(:next_sequence_token) @total_operations = args[:total_operations] if args.key?(:total_operations) end |