Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAddOfflineUserDataJobOperationsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for OfflineUserDataJobService.AddOfflineUserDataJobOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAddOfflineUserDataJobOperationsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesAddOfflineUserDataJobOperationsRequest.



36451
36452
36453
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36451

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_partial_failureBoolean Also known as: enable_partial_failure?

True to enable partial failure for the offline user data job. Corresponds to the JSON property enablePartialFailure

Returns:

  • (Boolean)


36428
36429
36430
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36428

def enable_partial_failure
  @enable_partial_failure
end

#enable_warningsBoolean Also known as: enable_warnings?

True to enable warnings for the offline user data job. When enabled, a warning will not block the OfflineUserDataJobOperation, and will also return warning messages about malformed field values. Corresponds to the JSON property enableWarnings

Returns:

  • (Boolean)


36436
36437
36438
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36436

def enable_warnings
  @enable_warnings
end

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesOfflineUserDataJobOperation>

Required. The list of operations to be done. Corresponds to the JSON property operations



36442
36443
36444
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36442

def operations
  @operations
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


36448
36449
36450
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36448

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36456
36457
36458
36459
36460
36461
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36456

def update!(**args)
  @enable_partial_failure = args[:enable_partial_failure] if args.key?(:enable_partial_failure)
  @enable_warnings = args[:enable_warnings] if args.key?(:enable_warnings)
  @operations = args[:operations] if args.key?(:operations)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end