Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationForecastingSetTargetRoasParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Parameters to use when applying a forecasting set target roas recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationForecastingSetTargetRoasParameters

Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationForecastingSetTargetRoasParameters.



34931
34932
34933
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaign_budget_amount_microsFixnum

New campaign budget amount to set for a campaign resource. Corresponds to the JSON property campaignBudgetAmountMicros

Returns:

  • (Fixnum)


34923
34924
34925
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34923

def campaign_budget_amount_micros
  @campaign_budget_amount_micros
end

#target_roasFloat

New target ROAS (revenue per unit of spend) to set for a campaign resource. The value is between 0.01 and 1000.0, inclusive. Corresponds to the JSON property targetRoas

Returns:

  • (Float)


34929
34930
34931
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34929

def target_roas
  @target_roas
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34936
34937
34938
34939
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34936

def update!(**args)
  @campaign_budget_amount_micros = args[:campaign_budget_amount_micros] if args.key?(:campaign_budget_amount_micros)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
end