Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationMoveUnusedBudgetParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Parameters to use when applying move unused budget recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationMoveUnusedBudgetParameters

Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationMoveUnusedBudgetParameters.



35206
35207
35208
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_micros_to_moveFixnum

Budget amount to move from excess budget to constrained budget. This is a required field. Corresponds to the JSON property budgetMicrosToMove

Returns:

  • (Fixnum)


35204
35205
35206
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35204

def budget_micros_to_move
  @budget_micros_to_move
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35211
35212
35213
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35211

def update!(**args)
  @budget_micros_to_move = args[:budget_micros_to_move] if args.key?(:budget_micros_to_move)
end