Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationRaiseTargetCpaBidTooLowParameters
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationRaiseTargetCpaBidTooLowParameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Parameters to use when applying a raise target CPA bid too low recommendation. The apply is asynchronous and can take minutes depending on the number of ad groups there is in the related campaign..
Instance Attribute Summary collapse
-
#target_multiplier ⇒ Float
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationRaiseTargetCpaBidTooLowParameters
constructor
A new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationRaiseTargetCpaBidTooLowParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationRaiseTargetCpaBidTooLowParameters
Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationRaiseTargetCpaBidTooLowParameters.
35228 35229 35230 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_multiplier ⇒ Float
Required. A number greater than 1.0 indicating the factor by which to increase
the target CPA. This is a required field.
Corresponds to the JSON property targetMultiplier
35226 35227 35228 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35226 def target_multiplier @target_multiplier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35233 35234 35235 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35233 def update!(**args) @target_multiplier = args[:target_multiplier] if args.key?(:target_multiplier) end |