Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationUseBroadMatchKeywordParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Parameters to use when applying a use broad match keyword recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationUseBroadMatchKeywordParameters

Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationUseBroadMatchKeywordParameters.



35433
35434
35435
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_budget_amount_microsFixnum

New budget amount to set for target budget resource. Corresponds to the JSON property newBudgetAmountMicros

Returns:

  • (Fixnum)


35431
35432
35433
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35431

def new_budget_amount_micros
  @new_budget_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35438
35439
35440
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35438

def update!(**args)
  @new_budget_amount_micros = args[:new_budget_amount_micros] if args.key?(:new_budget_amount_micros)
end