Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for RecommendationService.ApplyRecommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationResponse.



37044
37045
37046
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



37037
37038
37039
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37037

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationResult>

Results of operations to apply recommendations. Corresponds to the JSON property results



37042
37043
37044
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37042

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37049
37050
37051
37052
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37049

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end