Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on an asset group asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation.



37102
37103
37104
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupAsset

AssetGroupAsset is the link between an asset and an asset group. Adding an AssetGroupAsset links an asset with an asset group. Corresponds to the JSON property create



37082
37083
37084
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37082

def create
  @create
end

#removeString

Remove operation: A resource name for the removed asset group asset is expected, in this format: customers/customer_id/assetGroupAssets/ asset_group_id~asset_id~field_type` Corresponds to the JSON propertyremove`

Returns:

  • (String)


37089
37090
37091
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37089

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupAsset

AssetGroupAsset is the link between an asset and an asset group. Adding an AssetGroupAsset links an asset with an asset group. Corresponds to the JSON property update



37095
37096
37097
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37095

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


37100
37101
37102
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37100

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37107
37108
37109
37110
37111
37112
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37107

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end