Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetsWithFieldType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The combination of system asset and field type to remove.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetsWithFieldType

Returns a new instance of GoogleAdsSearchads360V23ServicesAssetsWithFieldType.



37290
37291
37292
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetString

Required. The resource name of the asset to be removed. Corresponds to the JSON property asset

Returns:

  • (String)


37283
37284
37285
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37283

def asset
  @asset
end

#asset_field_typeString

Required. The asset field type. Corresponds to the JSON property assetFieldType

Returns:

  • (String)


37288
37289
37290
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37288

def asset_field_type
  @asset_field_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37295
37296
37297
37298
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37295

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @asset_field_type = args[:asset_field_type] if args.key?(:asset_field_type)
end