Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBatchJobResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An individual batch job result.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBatchJobResult

Returns a new instance of GoogleAdsSearchads360V23ServicesBatchJobResult.



37669
37670
37671
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37669

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mutate_operation_responseGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperationResponse

Response message for the resource mutate. Corresponds to the JSON property mutateOperationResponse



37652
37653
37654
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37652

def mutate_operation_response
  @mutate_operation_response
end

#operation_indexFixnum

Index of the mutate operation. Corresponds to the JSON property operationIndex

Returns:

  • (Fixnum)


37657
37658
37659
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37657

def operation_index
  @operation_index
end

#statusGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



37667
37668
37669
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37667

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37674
37675
37676
37677
37678
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37674

def update!(**args)
  @mutate_operation_response = args[:mutate_operation_response] if args.key?(:mutate_operation_response)
  @operation_index = args[:operation_index] if args.key?(:operation_index)
  @status = args[:status] if args.key?(:status)
end