Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBenchmarksProductMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The metadata associated with a product supported for benchmarks data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBenchmarksProductMetadata

Returns a new instance of GoogleAdsSearchads360V23ServicesBenchmarksProductMetadata.



37734
37735
37736
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37734

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#marketing_objectiveString

The marketing objective associated with the product. A marketing objective is a broader classification of products. Corresponds to the JSON property marketingObjective

Returns:

  • (String)


37721
37722
37723
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37721

def marketing_objective
  @marketing_objective
end

#product_codeString

The identifier of the product. The identifier can be used as inputs for BenchmarksService.GenerateBenchmarksMetrics. Corresponds to the JSON property productCode

Returns:

  • (String)


37727
37728
37729
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37727

def product_code
  @product_code
end

#product_nameString

The name of the product. Corresponds to the JSON property productName

Returns:

  • (String)


37732
37733
37734
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37732

def product_name
  @product_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37739
37740
37741
37742
37743
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37739

def update!(**args)
  @marketing_objective = args[:marketing_objective] if args.key?(:marketing_objective)
  @product_code = args[:product_code] if args.key?(:product_code)
  @product_name = args[:product_name] if args.key?(:product_name)
end