Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove, update) on a seasonality adjustment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation.



37822
37823
37824
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37822

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment

Represents a bidding seasonality adjustment. Cannot be used in manager accounts. See "About seasonality adjustments" at https://support.google.com/ google-ads/answer/10369906. Corresponds to the JSON property create



37801
37802
37803
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37801

def create
  @create
end

#removeString

Remove operation: A resource name for the removed seasonality adjustment is expected, in this format: customers/customer_id/ biddingSeasonalityAdjustments/seasonality_adjustment_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


37808
37809
37810
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37808

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment

Represents a bidding seasonality adjustment. Cannot be used in manager accounts. See "About seasonality adjustments" at https://support.google.com/ google-ads/answer/10369906. Corresponds to the JSON property update



37815
37816
37817
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37815

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


37820
37821
37822
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37820

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37827
37828
37829
37830
37831
37832
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37827

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end