Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBillingSetupOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation on a billing setup, which describes the cancellation of an existing billing setup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBillingSetupOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesBillingSetupOperation.



37964
37965
37966
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37964

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBillingSetup

A billing setup, which associates a payments account and an advertiser. A billing setup is specific to one advertiser. Corresponds to the JSON property create



37955
37956
37957
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37955

def create
  @create
end

#removeString

Resource name of the billing setup to remove. A setup cannot be removed unless it is in a pending state or its scheduled start time is in the future. The resource name looks like customers/customer_id/billingSetups/billing_id`. Corresponds to the JSON propertyremove`

Returns:

  • (String)


37962
37963
37964
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37962

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37969
37970
37971
37972
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37969

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end