Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCallConversion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A call conversion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCallConversion

Returns a new instance of GoogleAdsSearchads360V23ServicesCallConversion.



38060
38061
38062
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38060

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_start_date_timeString

The date time at which the call occurred. The timezone must be specified. The format is "yyyy-mm-dd hh:mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08: 00". Corresponds to the JSON property callStartDateTime

Returns:

  • (String)


38016
38017
38018
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38016

def call_start_date_time
  @call_start_date_time
end

#caller_idString

The caller id from which this call was placed. Caller id is expected to be in E.164 format with preceding '+' sign, for example, "+16502531234". Corresponds to the JSON property callerId

Returns:

  • (String)


38022
38023
38024
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38022

def caller_id
  @caller_id
end

Consent Corresponds to the JSON property consent



38027
38028
38029
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38027

def consent
  @consent
end

#conversion_actionString

Resource name of the conversion action associated with this conversion. Note: Although this resource name consists of a customer id and a conversion action id, validation will ignore the customer id and use the conversion action id as the sole identifier of the conversion action. Corresponds to the JSON property conversionAction

Returns:

  • (String)


38035
38036
38037
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38035

def conversion_action
  @conversion_action
end

#conversion_date_timeString

The date time at which the conversion occurred. Must be after the call time. The timezone must be specified. The format is "yyyy-mm-dd hh:mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08:00". Corresponds to the JSON property conversionDateTime

Returns:

  • (String)


38042
38043
38044
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38042

def conversion_date_time
  @conversion_date_time
end

#conversion_valueFloat

The value of the conversion for the advertiser. Corresponds to the JSON property conversionValue

Returns:

  • (Float)


38047
38048
38049
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38047

def conversion_value
  @conversion_value
end

#currency_codeString

Currency associated with the conversion value. This is the ISO 4217 3- character currency code. For example: USD, EUR. Corresponds to the JSON property currencyCode

Returns:

  • (String)


38053
38054
38055
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38053

def currency_code
  @currency_code
end

#custom_variablesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomVariable>

The custom variables associated with this conversion. Corresponds to the JSON property customVariables



38058
38059
38060
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38058

def custom_variables
  @custom_variables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38065
38066
38067
38068
38069
38070
38071
38072
38073
38074
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38065

def update!(**args)
  @call_start_date_time = args[:call_start_date_time] if args.key?(:call_start_date_time)
  @caller_id = args[:caller_id] if args.key?(:caller_id)
  @consent = args[:consent] if args.key?(:consent)
  @conversion_action = args[:conversion_action] if args.key?(:conversion_action)
  @conversion_date_time = args[:conversion_date_time] if args.key?(:conversion_date_time)
  @conversion_value = args[:conversion_value] if args.key?(:conversion_value)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @custom_variables = args[:custom_variables] if args.key?(:custom_variables)
end