Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCallConversionResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCallConversionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Identifying information for a successfully processed CallConversionUpload.
Instance Attribute Summary collapse
-
#call_start_date_time ⇒ String
The date time at which the call occurred.
-
#caller_id ⇒ String
The caller id from which this call was placed.
-
#conversion_action ⇒ String
Resource name of the conversion action associated with this conversion.
-
#conversion_date_time ⇒ String
The date time at which the conversion occurred.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCallConversionResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesCallConversionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCallConversionResult
Returns a new instance of GoogleAdsSearchads360V23ServicesCallConversionResult.
38104 38105 38106 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#call_start_date_time ⇒ String
The date time at which the call occurred. The format is "yyyy-mm-dd hh:mm:ss+|-
hh:mm", for example, "2019-01-01 12:32:45-08:00".
Corresponds to the JSON property callStartDateTime
38085 38086 38087 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38085 def call_start_date_time @call_start_date_time end |
#caller_id ⇒ String
The caller id from which this call was placed. Caller id is expected to be in
E.164 format with preceding '+' sign.
Corresponds to the JSON property callerId
38091 38092 38093 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38091 def caller_id @caller_id end |
#conversion_action ⇒ String
Resource name of the conversion action associated with this conversion.
Corresponds to the JSON property conversionAction
38096 38097 38098 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38096 def conversion_action @conversion_action end |
#conversion_date_time ⇒ String
The date time at which the conversion occurred. The format is "yyyy-mm-dd hh:
mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08:00".
Corresponds to the JSON property conversionDateTime
38102 38103 38104 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38102 def conversion_date_time @conversion_date_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38109 38110 38111 38112 38113 38114 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38109 def update!(**args) @call_start_date_time = args[:call_start_date_time] if args.key?(:call_start_date_time) @caller_id = args[:caller_id] if args.key?(:caller_id) @conversion_action = args[:conversion_action] if args.key?(:conversion_action) @conversion_date_time = args[:conversion_date_time] if args.key?(:conversion_date_time) end |