Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove, update) on a campaign bid modifier.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation.



38210
38211
38212
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBidModifier

Represents a bid-modifiable only criterion at the campaign level. Corresponds to the JSON property create



38191
38192
38193
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38191

def create
  @create
end

#removeString

Remove operation: A resource name for the removed campaign bid modifier is expected, in this format: customers/customer_id/CampaignBidModifiers/ campaign_id~criterion_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


38198
38199
38200
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38198

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBidModifier

Represents a bid-modifiable only criterion at the campaign level. Corresponds to the JSON property update



38203
38204
38205
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38203

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


38208
38209
38210
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38208

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38215
38216
38217
38218
38219
38220
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38215

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end