Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a campaign budget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignBudgetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignBudgetOperation.



38274
38275
38276
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBudget

A campaign budget. Corresponds to the JSON property create



38256
38257
38258
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38256

def create
  @create
end

#removeString

Remove operation: A resource name for the removed budget is expected, in this format: customers/customer_id/campaignBudgets/budget_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


38262
38263
38264
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38262

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBudget

A campaign budget. Corresponds to the JSON property update



38267
38268
38269
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38267

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


38272
38273
38274
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38272

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38279
38280
38281
38282
38283
38284
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38279

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end