Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (update) on a campaign conversion goal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation.



38230
38231
38232
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignConversionGoal

The biddability setting for the specified campaign only for all conversion actions with a matching category and origin. Corresponds to the JSON property update



38223
38224
38225
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38223

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


38228
38229
38230
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38228

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38235
38236
38237
38238
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38235

def update!(**args)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end