Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCriterionOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCriterionOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a campaign criterion.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion
A campaign criterion.
-
#remove ⇒ String
Remove operation: A resource name for the removed criterion is expected, in this format:
customers/customer_id/campaignCriteria/campaign_id~criterion_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion
A campaign criterion.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignCriterionOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignCriterionOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignCriterionOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignCriterionOperation.
38339 38340 38341 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38339 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion
A campaign criterion.
Corresponds to the JSON property create
38320 38321 38322 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38320 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed criterion is expected, in
this format: customers/customer_id/campaignCriteria/campaign_id~
criterion_id`
Corresponds to the JSON propertyremove`
38327 38328 38329 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38327 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion
A campaign criterion.
Corresponds to the JSON property update
38332 38333 38334 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38332 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
38337 38338 38339 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38337 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38344 38345 38346 38347 38348 38349 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38344 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |