Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCustomizerOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCustomizerOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on a customizer attribute.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCustomizer
A customizer value for the associated CustomizerAttribute at the Campaign level.
-
#remove ⇒ String
Remove operation: A resource name for the removed campaign customizer is expected, in this format:
customers/customer_id/campaignCustomizers/campaign_id~customizer_attribute_id`Corresponds to the JSON propertyremove`.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignCustomizerOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignCustomizerOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignCustomizerOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignCustomizerOperation.
38369 38370 38371 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCustomizer
A customizer value for the associated CustomizerAttribute at the Campaign
level.
Corresponds to the JSON property create
38360 38361 38362 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38360 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed campaign customizer is
expected, in this format: customers/customer_id/campaignCustomizers/
campaign_id~customizer_attribute_id`
Corresponds to the JSON propertyremove`
38367 38368 38369 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38367 def remove @remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38374 38375 38376 38377 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38374 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) end |