Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGoalConfigOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single mutate operation on the campaign goal config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignGoalConfigOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignGoalConfigOperation.



38469
38470
38471
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38469

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGoalConfig

A link between a campaign and a goal enabling campaign-specific optimization. Corresponds to the JSON property create



38452
38453
38454
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38452

def create
  @create
end

#removeString

Remove an existing campaign goal config. Corresponds to the JSON property remove

Returns:

  • (String)


38457
38458
38459
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38457

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGoalConfig

A link between a campaign and a goal enabling campaign-specific optimization. Corresponds to the JSON property update



38462
38463
38464
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38462

def update
  @update
end

#update_maskString

FieldMask that determines which fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


38467
38468
38469
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38467

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38474
38475
38476
38477
38478
38479
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38474

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end