Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignLabelOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignLabelOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on a campaign-label relationship.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignLabel
Represents a relationship between a campaign and a label.
-
#remove ⇒ String
Remove operation: A resource name for the campaign-label relationship being removed, in this format:
customers/customer_id/campaignLabels/campaign_id~label_id`Corresponds to the JSON propertyremove`.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignLabelOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignLabelOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignLabelOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignLabelOperation.
38219 38220 38221 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38219 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignLabel
Represents a relationship between a campaign and a label.
Corresponds to the JSON property create
38210 38211 38212 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38210 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the campaign-label relationship being
removed, in this format: customers/customer_id/campaignLabels/campaign_id~
label_id`
Corresponds to the JSON propertyremove`
38217 38218 38219 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38217 def remove @remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38224 38225 38226 38227 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38224 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) end |