Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignOperation.



38604
38605
38606
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38604

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaign

A campaign. Corresponds to the JSON property create



38586
38587
38588
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38586

def create
  @create
end

#removeString

Remove operation: A resource name for the removed campaign is expected, in this format: customers/customer_id/campaigns/campaign_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


38592
38593
38594
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38592

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaign

A campaign. Corresponds to the JSON property update



38597
38598
38599
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38597

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


38602
38603
38604
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38602

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38609
38610
38611
38612
38613
38614
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38609

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end