Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignSharedSetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on a campaign shared set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignSharedSetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignSharedSetOperation.



38562
38563
38564
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSharedSet

CampaignSharedSets are used for managing the shared sets associated with a campaign. Corresponds to the JSON property create



38553
38554
38555
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38553

def create
  @create
end

#removeString

Remove operation: A resource name for the removed campaign shared set is expected, in this format: customers/customer_id/campaignSharedSets/ campaign_id~shared_set_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


38560
38561
38562
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38560

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38567
38568
38569
38570
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38567

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end