Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignToForecast

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A campaign to do a keyword campaign forecast.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignToForecast

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignToForecast.



38691
38692
38693
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecastAdGroup>

The ad groups in the new campaign to forecast. Corresponds to the JSON property adGroups



38652
38653
38654
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38652

def ad_groups
  @ad_groups
end

#bidding_strategyGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignToForecastCampaignBiddingStrategy

Supported bidding strategies for new campaign forecasts. Corresponds to the JSON property biddingStrategy



38657
38658
38659
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38657

def bidding_strategy
  @bidding_strategy
end

#conversion_rateFloat

The expected conversion rate (number of conversions divided by number of total clicks) as defined by the user. This value is expressed as a decimal value, so an expected conversion rate of 2% should be entered as 0.02. If left empty, an estimated conversion rate will be used. Corresponds to the JSON property conversionRate

Returns:

  • (Float)


38665
38666
38667
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38665

def conversion_rate
  @conversion_rate
end

#geo_modifiersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCriterionBidModifier>

Locations to be targeted. Locations must be unique. Corresponds to the JSON property geoModifiers



38670
38671
38672
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38670

def geo_modifiers
  @geo_modifiers
end

#keyword_plan_networkString

Required. The network used for targeting. Corresponds to the JSON property keywordPlanNetwork

Returns:

  • (String)


38675
38676
38677
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38675

def keyword_plan_network
  @keyword_plan_network
end

#language_constantsArray<String>

The list of resource names of languages to be targeted. The resource name is of the format "languageConstants/criterion_id". See https://developers. google.com/google-ads/api/data/codes-formats#languages for the list of language criterion codes. Corresponds to the JSON property languageConstants

Returns:

  • (Array<String>)


38683
38684
38685
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38683

def language_constants
  @language_constants
end

#negative_keywordsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo>

The list of negative keywords to be used in the campaign when doing the forecast. Corresponds to the JSON property negativeKeywords



38689
38690
38691
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38689

def negative_keywords
  @negative_keywords
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38696
38697
38698
38699
38700
38701
38702
38703
38704
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38696

def update!(**args)
  @ad_groups = args[:ad_groups] if args.key?(:ad_groups)
  @bidding_strategy = args[:bidding_strategy] if args.key?(:bidding_strategy)
  @conversion_rate = args[:conversion_rate] if args.key?(:conversion_rate)
  @geo_modifiers = args[:geo_modifiers] if args.key?(:geo_modifiers)
  @keyword_plan_network = args[:keyword_plan_network] if args.key?(:keyword_plan_network)
  @language_constants = args[:language_constants] if args.key?(:language_constants)
  @negative_keywords = args[:negative_keywords] if args.key?(:negative_keywords)
end