Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCartData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Contains additional information about cart data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCartData

Returns a new instance of GoogleAdsSearchads360V23ServicesCartData.



38738
38739
38740
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38738

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feed_country_codeString

The country code associated with the feed where the items are uploaded. Corresponds to the JSON property feedCountryCode

Returns:

  • (String)


38714
38715
38716
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38714

def feed_country_code
  @feed_country_code
end

#feed_language_codeString

The language code associated with the feed where the items are uploaded. Corresponds to the JSON property feedLanguageCode

Returns:

  • (String)


38719
38720
38721
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38719

def feed_language_code
  @feed_language_code
end

#itemsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCartDataItem>

Data of the items purchased. Corresponds to the JSON property items



38724
38725
38726
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38724

def items
  @items
end

#local_transaction_costFloat

Sum of all transaction level discounts, such as free shipping and coupon discounts for the whole cart. The currency code is the same as that in the ClickConversion message. Corresponds to the JSON property localTransactionCost

Returns:

  • (Float)


38731
38732
38733
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38731

def local_transaction_cost
  @local_transaction_cost
end

#merchant_idFixnum

The Merchant Center ID where the items are uploaded. Corresponds to the JSON property merchantId

Returns:

  • (Fixnum)


38736
38737
38738
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38736

def merchant_id
  @merchant_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38743
38744
38745
38746
38747
38748
38749
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38743

def update!(**args)
  @feed_country_code = args[:feed_country_code] if args.key?(:feed_country_code)
  @feed_language_code = args[:feed_language_code] if args.key?(:feed_language_code)
  @items = args[:items] if args.key?(:items)
  @local_transaction_cost = args[:local_transaction_cost] if args.key?(:local_transaction_cost)
  @merchant_id = args[:merchant_id] if args.key?(:merchant_id)
end