Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCartDataItem
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCartDataItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Contains data of the items purchased.
Instance Attribute Summary collapse
-
#product_id ⇒ String
The shopping id of the item.
-
#quantity ⇒ Fixnum
Number of items sold.
-
#unit_price ⇒ Float
Unit price excluding tax, shipping, and any transaction level discounts.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCartDataItem
constructor
A new instance of GoogleAdsSearchads360V23ServicesCartDataItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCartDataItem
Returns a new instance of GoogleAdsSearchads360V23ServicesCartDataItem.
35495 35496 35497 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35495 def initialize(**args) update!(**args) end |
Instance Attribute Details
#product_id ⇒ String
The shopping id of the item. Must be equal to the Merchant Center product
identifier.
Corresponds to the JSON property productId
35482 35483 35484 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35482 def product_id @product_id end |
#quantity ⇒ Fixnum
Number of items sold.
Corresponds to the JSON property quantity
35487 35488 35489 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35487 def quantity @quantity end |
#unit_price ⇒ Float
Unit price excluding tax, shipping, and any transaction level discounts. The
currency code is the same as that in the ClickConversion message.
Corresponds to the JSON property unitPrice
35493 35494 35495 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35493 def unit_price @unit_price end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35500 35501 35502 35503 35504 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35500 def update!(**args) @product_id = args[:product_id] if args.key?(:product_id) @quantity = args[:quantity] if args.key?(:quantity) @unit_price = args[:unit_price] if args.key?(:unit_price) end |