Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesClickConversion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A click conversion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesClickConversion

Returns a new instance of GoogleAdsSearchads360V23ServicesClickConversion.



38871
38872
38873
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38871

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cart_dataGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCartData

Contains additional information about cart data. Corresponds to the JSON property cartData



38759
38760
38761
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38759

def cart_data
  @cart_data
end

Consent Corresponds to the JSON property consent



38764
38765
38766
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38764

def consent
  @consent
end

#conversion_actionString

Resource name of the conversion action associated with this conversion. Note: Although this resource name consists of a customer id and a conversion action id, validation will ignore the customer id and use the conversion action id as the sole identifier of the conversion action. Corresponds to the JSON property conversionAction

Returns:

  • (String)


38772
38773
38774
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38772

def conversion_action
  @conversion_action
end

#conversion_date_timeString

The date time at which the conversion occurred. Must be after the click time. The timezone must be specified. The format is "yyyy-mm-dd hh:mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08:00". Corresponds to the JSON property conversionDateTime

Returns:

  • (String)


38779
38780
38781
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38779

def conversion_date_time
  @conversion_date_time
end

#conversion_environmentString

The environment this conversion was recorded on, for example, App or Web. Corresponds to the JSON property conversionEnvironment

Returns:

  • (String)


38784
38785
38786
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38784

def conversion_environment
  @conversion_environment
end

#conversion_valueFloat

The value of the conversion for the advertiser. Corresponds to the JSON property conversionValue

Returns:

  • (Float)


38789
38790
38791
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38789

def conversion_value
  @conversion_value
end

#currency_codeString

Currency associated with the conversion value. This is the ISO 4217 3- character currency code. For example: USD, EUR. Corresponds to the JSON property currencyCode

Returns:

  • (String)


38795
38796
38797
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38795

def currency_code
  @currency_code
end

#custom_variablesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomVariable>

The custom variables associated with this conversion. Corresponds to the JSON property customVariables



38800
38801
38802
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38800

def custom_variables
  @custom_variables
end

#customer_typeString

Type of the customer associated with the conversion (new or returning). Corresponds to the JSON property customerType

Returns:

  • (String)


38805
38806
38807
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38805

def customer_type
  @customer_type
end

#external_attribution_dataGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExternalAttributionData

Contains additional information about externally attributed conversions. Corresponds to the JSON property externalAttributionData



38810
38811
38812
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38810

def external_attribution_data
  @external_attribution_data
end

#gbraidString

The URL parameter for clicks associated with app conversions. Corresponds to the JSON property gbraid

Returns:

  • (String)


38815
38816
38817
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38815

def gbraid
  @gbraid
end

#gclidString

The Google click ID (gclid) associated with this conversion. Corresponds to the JSON property gclid

Returns:

  • (String)


38820
38821
38822
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38820

def gclid
  @gclid
end

#order_idString

The order ID associated with the conversion. An order id can only be used for one conversion per conversion action. Corresponds to the JSON property orderId

Returns:

  • (String)


38826
38827
38828
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38826

def order_id
  @order_id
end

#session_attributes_encodedString

The session attributes for the event, represented as a base64-encoded JSON string. The content should be generated by Google-provided library. To set session attributes individually, use session_attributes_key_value_pairs instead. This field is only available to allowlisted users. To include this field in conversion imports, upgrade to the Data Manager API. Corresponds to the JSON property sessionAttributesEncoded NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


38836
38837
38838
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38836

def session_attributes_encoded
  @session_attributes_encoded
end

#session_attributes_key_value_pairsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSessionAttributesKeyValuePairs

Contains session attributes of the conversion, represented as key-value pairs. Corresponds to the JSON property sessionAttributesKeyValuePairs



38841
38842
38843
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38841

def session_attributes_key_value_pairs
  @session_attributes_key_value_pairs
end

#user_identifiersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserIdentifier>

The user identifiers associated with this conversion. Only hashed_email and hashed_phone_number are supported for conversion uploads. The maximum number of user identifiers for each conversion is 5. Corresponds to the JSON property userIdentifiers



38848
38849
38850
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38848

def user_identifiers
  @user_identifiers
end

#user_ip_addressString

The IP address of the customer when they arrived on the landing page after an ad click but before a conversion event. This is the IP address of the customer' s device, not the advertiser's server. Google Ads does not support IP address matching for end users in the European Economic Area (EEA), United Kingdom (UK) , or Switzerland (CH). Add logic to conditionally exclude sharing IP addresses from users from these regions and ensure that you provide users with clear and comprehensive information about the data you collect on your sites, apps, and other properties and get consent where required by law or any applicable Google policies. See About offline conversion imports page for more details. This field is only available to allowlisted users. To include this field in conversion imports, upgrade to the Data Manager API. Corresponds to the JSON property userIpAddress

Returns:

  • (String)


38864
38865
38866
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38864

def user_ip_address
  @user_ip_address
end

#wbraidString

The URL parameter for clicks associated with web conversions. Corresponds to the JSON property wbraid

Returns:

  • (String)


38869
38870
38871
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38869

def wbraid
  @wbraid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38876
38877
38878
38879
38880
38881
38882
38883
38884
38885
38886
38887
38888
38889
38890
38891
38892
38893
38894
38895
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38876

def update!(**args)
  @cart_data = args[:cart_data] if args.key?(:cart_data)
  @consent = args[:consent] if args.key?(:consent)
  @conversion_action = args[:conversion_action] if args.key?(:conversion_action)
  @conversion_date_time = args[:conversion_date_time] if args.key?(:conversion_date_time)
  @conversion_environment = args[:conversion_environment] if args.key?(:conversion_environment)
  @conversion_value = args[:conversion_value] if args.key?(:conversion_value)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @custom_variables = args[:custom_variables] if args.key?(:custom_variables)
  @customer_type = args[:customer_type] if args.key?(:customer_type)
  @external_attribution_data = args[:external_attribution_data] if args.key?(:external_attribution_data)
  @gbraid = args[:gbraid] if args.key?(:gbraid)
  @gclid = args[:gclid] if args.key?(:gclid)
  @order_id = args[:order_id] if args.key?(:order_id)
  @session_attributes_encoded = args[:session_attributes_encoded] if args.key?(:session_attributes_encoded)
  @session_attributes_key_value_pairs = args[:session_attributes_key_value_pairs] if args.key?(:session_attributes_key_value_pairs)
  @user_identifiers = args[:user_identifiers] if args.key?(:user_identifiers)
  @user_ip_address = args[:user_ip_address] if args.key?(:user_ip_address)
  @wbraid = args[:wbraid] if args.key?(:wbraid)
end