Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesClickConversionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Identifying information for a successfully processed ClickConversion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesClickConversionResult

Returns a new instance of GoogleAdsSearchads360V23ServicesClickConversionResult.



38935
38936
38937
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38935

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversion_actionString

Resource name of the conversion action associated with this conversion. Corresponds to the JSON property conversionAction

Returns:

  • (String)


38905
38906
38907
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38905

def conversion_action
  @conversion_action
end

#conversion_date_timeString

The date time at which the conversion occurred. The format is "yyyy-mm-dd hh: mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08:00". Corresponds to the JSON property conversionDateTime

Returns:

  • (String)


38911
38912
38913
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38911

def conversion_date_time
  @conversion_date_time
end

#gbraidString

The URL parameter for clicks associated with app conversions. Corresponds to the JSON property gbraid

Returns:

  • (String)


38916
38917
38918
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38916

def gbraid
  @gbraid
end

#gclidString

The Google Click ID (gclid) associated with this conversion. Corresponds to the JSON property gclid

Returns:

  • (String)


38921
38922
38923
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38921

def gclid
  @gclid
end

#user_identifiersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserIdentifier>

The user identifiers associated with this conversion. Only hashed_email and hashed_phone_number are supported for conversion uploads. The maximum number of user identifiers for each conversion is 5. Corresponds to the JSON property userIdentifiers



38928
38929
38930
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38928

def user_identifiers
  @user_identifiers
end

#wbraidString

The URL parameter for clicks associated with web conversions. Corresponds to the JSON property wbraid

Returns:

  • (String)


38933
38934
38935
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38933

def wbraid
  @wbraid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38940
38941
38942
38943
38944
38945
38946
38947
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38940

def update!(**args)
  @conversion_action = args[:conversion_action] if args.key?(:conversion_action)
  @conversion_date_time = args[:conversion_date_time] if args.key?(:conversion_date_time)
  @gbraid = args[:gbraid] if args.key?(:gbraid)
  @gclid = args[:gclid] if args.key?(:gclid)
  @user_identifiers = args[:user_identifiers] if args.key?(:user_identifiers)
  @wbraid = args[:wbraid] if args.key?(:wbraid)
end