Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionAdjustmentResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionAdjustmentResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Information identifying a successfully processed ConversionAdjustment.
Instance Attribute Summary collapse
-
#adjustment_date_time ⇒ String
The date time at which the adjustment occurred.
-
#adjustment_type ⇒ String
The adjustment type.
-
#conversion_action ⇒ String
Resource name of the conversion action associated with this conversion adjustment.
-
#gclid_date_time_pair ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGclidDateTimePair
Uniquely identifies a conversion that was reported without an order ID specified.
-
#order_id ⇒ String
The order ID of the conversion to be adjusted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionAdjustmentResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesConversionAdjustmentResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionAdjustmentResult
Returns a new instance of GoogleAdsSearchads360V23ServicesConversionAdjustmentResult.
39285 39286 39287 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adjustment_date_time ⇒ String
The date time at which the adjustment occurred. The format is "yyyy-mm-dd hh:
mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08:00".
Corresponds to the JSON property adjustmentDateTime
39261 39262 39263 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39261 def adjustment_date_time @adjustment_date_time end |
#adjustment_type ⇒ String
The adjustment type.
Corresponds to the JSON property adjustmentType
39266 39267 39268 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39266 def adjustment_type @adjustment_type end |
#conversion_action ⇒ String
Resource name of the conversion action associated with this conversion
adjustment.
Corresponds to the JSON property conversionAction
39272 39273 39274 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39272 def conversion_action @conversion_action end |
#gclid_date_time_pair ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGclidDateTimePair
Uniquely identifies a conversion that was reported without an order ID
specified.
Corresponds to the JSON property gclidDateTimePair
39278 39279 39280 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39278 def gclid_date_time_pair @gclid_date_time_pair end |
#order_id ⇒ String
The order ID of the conversion to be adjusted.
Corresponds to the JSON property orderId
39283 39284 39285 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39283 def order_id @order_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39290 39291 39292 39293 39294 39295 39296 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39290 def update!(**args) @adjustment_date_time = args[:adjustment_date_time] if args.key?(:adjustment_date_time) @adjustment_type = args[:adjustment_type] if args.key?(:adjustment_type) @conversion_action = args[:conversion_action] if args.key?(:conversion_action) @gclid_date_time_pair = args[:gclid_date_time_pair] if args.key?(:gclid_date_time_pair) @order_id = args[:order_id] if args.key?(:order_id) end |