Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomMetricHeader
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomMetricHeader
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Message for conversion custom metric header.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
The conversion custom metric ID.
-
#name ⇒ String
The user defined name of the conversion custom metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionCustomMetricHeader
constructor
A new instance of GoogleAdsSearchads360V23ServicesConversionCustomMetricHeader.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionCustomMetricHeader
Returns a new instance of GoogleAdsSearchads360V23ServicesConversionCustomMetricHeader.
39266 39267 39268 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39266 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
The conversion custom metric ID.
Corresponds to the JSON property id
39259 39260 39261 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39259 def id @id end |
#name ⇒ String
The user defined name of the conversion custom metric.
Corresponds to the JSON property name
39264 39265 39266 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39264 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39271 39272 39273 39274 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39271 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) end |