Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update) on a conversion custom variable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation.



39372
39373
39374
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionCustomVariable

A conversion custom variable. See "About custom Floodlight metrics and dimensions in the new Search Ads 360" at https://support.google.com/sa360/ answer/13567857 Corresponds to the JSON property create



39358
39359
39360
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39358

def create
  @create
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionCustomVariable

A conversion custom variable. See "About custom Floodlight metrics and dimensions in the new Search Ads 360" at https://support.google.com/sa360/ answer/13567857 Corresponds to the JSON property update



39365
39366
39367
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39365

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


39370
39371
39372
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39370

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39377
39378
39379
39380
39381
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39377

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end