Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a conversion value rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionValueRuleOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesConversionValueRuleOperation.



39474
39475
39476
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRule

A conversion value rule Corresponds to the JSON property create



39455
39456
39457
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39455

def create
  @create
end

#removeString

Remove operation: A resource name for the removed conversion value rule is expected, in this format: customers/customer_id/conversionValueRules/ conversion_value_rule_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


39462
39463
39464
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39462

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRule

A conversion value rule Corresponds to the JSON property update



39467
39468
39469
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39467

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


39472
39473
39474
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39472

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39479
39480
39481
39482
39483
39484
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39479

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end