Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a conversion value rule set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation.



39517
39518
39519
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39517

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleSet

A conversion value rule set is a collection of conversion value rules that lets you adjust conversion values based on the dimensions specified in the dimensions field. Corresponds to the JSON property create



39496
39497
39498
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39496

def create
  @create
end

#removeString

Remove operation: A resource name for the removed conversion value rule set is expected, in this format: customers/customer_id/conversionValueRuleSets/ conversion_value_rule_set_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


39503
39504
39505
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39503

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleSet

A conversion value rule set is a collection of conversion value rules that lets you adjust conversion values based on the dimensions specified in the dimensions field. Corresponds to the JSON property update



39510
39511
39512
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39510

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


39515
39516
39517
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39515

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39522
39523
39524
39525
39526
39527
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39522

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end