Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCreateAccountLinkRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AccountLinkService.CreateAccountLink.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCreateAccountLinkRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesCreateAccountLinkRequest.



39540
39541
39542
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39540

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Represents the data sharing connection between a Google Ads account and another account Corresponds to the JSON property accountLink



39538
39539
39540
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39538

def 
  @account_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39545
39546
39547
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39545

def update!(**args)
  @account_link = args[:account_link] if args.key?(:account_link)
end