Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCreateCustomerClientRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomerService.CreateCustomerClient.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCreateCustomerClientRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesCreateCustomerClientRequest.



39525
39526
39527
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39525

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_roleString

The proposed role of user on the created client customer. Accessible only to customers on the allow-list. Corresponds to the JSON property accessRole

Returns:

  • (String)


39505
39506
39507
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39505

def access_role
  @access_role
end

#customer_clientGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomer

A customer. Corresponds to the JSON property customerClient



39510
39511
39512
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39510

def customer_client
  @customer_client
end

#email_addressString

Email address of the user who should be invited on the created client customer. Accessible only to customers on the allow-list. Corresponds to the JSON property emailAddress

Returns:

  • (String)


39516
39517
39518
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39516

def email_address
  @email_address
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


39522
39523
39524
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39522

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39530
39531
39532
39533
39534
39535
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39530

def update!(**args)
  @access_role = args[:access_role] if args.key?(:access_role)
  @customer_client = args[:customer_client] if args.key?(:customer_client)
  @email_address = args[:email_address] if args.key?(:email_address)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end