Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCreateProductLinkInvitationRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCreateProductLinkInvitationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for ProductLinkInvitationService.CreateProductLinkInvitation.
Instance Attribute Summary collapse
-
#product_link_invitation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesProductLinkInvitation
Represents an invitation for data sharing connection between a Google Ads account and another account.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCreateProductLinkInvitationRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesCreateProductLinkInvitationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCreateProductLinkInvitationRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesCreateProductLinkInvitationRequest.
39061 39062 39063 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39061 def initialize(**args) update!(**args) end |
Instance Attribute Details
#product_link_invitation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesProductLinkInvitation
Represents an invitation for data sharing connection between a Google Ads
account and another account.
Corresponds to the JSON property productLinkInvitation
39059 39060 39061 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39059 def product_link_invitation @product_link_invitation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39066 39067 39068 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39066 def update!(**args) @product_link_invitation = args[:product_link_invitation] if args.key?(:product_link_invitation) end |