Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCriterionBidModifier
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCriterionBidModifier
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Location Criterion bid modifier.
Instance Attribute Summary collapse
-
#bid_modifier ⇒ Float
The associated multiplier for the criterion_id.
-
#geo_target_constant ⇒ String
The resource name of the geo location to target.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCriterionBidModifier
constructor
A new instance of GoogleAdsSearchads360V23ServicesCriterionBidModifier.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCriterionBidModifier
Returns a new instance of GoogleAdsSearchads360V23ServicesCriterionBidModifier.
39751 39752 39753 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39751 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bid_modifier ⇒ Float
The associated multiplier for the criterion_id. If set, this value cannot be 0.
Corresponds to the JSON property bidModifier
39743 39744 39745 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39743 def bid_modifier @bid_modifier end |
#geo_target_constant ⇒ String
The resource name of the geo location to target. The resource name is of the
format "geoTargetConstants/criterion_id".
Corresponds to the JSON property geoTargetConstant
39749 39750 39751 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39749 def geo_target_constant @geo_target_constant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39756 39757 39758 39759 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39756 def update!(**args) @bid_modifier = args[:bid_modifier] if args.key?(:bid_modifier) @geo_target_constant = args[:geo_target_constant] if args.key?(:geo_target_constant) end |