Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomAudienceOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update) on a custom audience.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomAudienceOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCustomAudienceOperation.



39863
39864
39865
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudience

A custom audience. This is a list of users by interest. The unique key of a custom audience consists of the following fields: name. Violating the unique key constraint produces error: CustomAudienceError.NAME_ALREADY_USED Corresponds to the JSON property create



39843
39844
39845
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39843

def create
  @create
end

#removeString

Remove operation: A resource name for the removed custom audience is expected, in this format: customers/customer_id/customAudiences/custom_audience_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


39849
39850
39851
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39849

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudience

A custom audience. This is a list of users by interest. The unique key of a custom audience consists of the following fields: name. Violating the unique key constraint produces error: CustomAudienceError.NAME_ALREADY_USED Corresponds to the JSON property update



39856
39857
39858
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39856

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


39861
39862
39863
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39861

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39868
39869
39870
39871
39872
39873
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39868

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end