Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomConversionGoalOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on a custom conversion goal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomConversionGoalOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCustomConversionGoalOperation.



39934
39935
39936
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39934

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomConversionGoal

Custom conversion goal that can make arbitrary conversion actions biddable. Corresponds to the JSON property create



39915
39916
39917
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39915

def create
  @create
end

#removeString

Remove operation: A resource name for the removed custom conversion goal is expected, in this format: 'customers/customer_id/customConversionGoals/ goal_id' Corresponds to the JSON property remove

Returns:

  • (String)


39922
39923
39924
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39922

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomConversionGoal

Custom conversion goal that can make arbitrary conversion actions biddable. Corresponds to the JSON property update



39927
39928
39929
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39927

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


39932
39933
39934
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39932

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39939
39940
39941
39942
39943
39944
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39939

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end