Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomInterestOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomInterestOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update) on a custom interest.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomInterest
A custom interest.
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomInterest
A custom interest.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomInterestOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCustomInterestOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomInterestOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCustomInterestOperation.
39286 39287 39288 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39286 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomInterest
A custom interest. This is a list of users by interest.
Corresponds to the JSON property create
39274 39275 39276 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39274 def create @create end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomInterest
A custom interest. This is a list of users by interest.
Corresponds to the JSON property update
39279 39280 39281 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39279 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
39284 39285 39286 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39284 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39291 39292 39293 39294 39295 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39291 def update!(**args) @create = args[:create] if args.key?(:create) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |