Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a customer asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerAssetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerAssetOperation.



40034
40035
40036
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40034

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAsset

A link between a customer and an asset. Corresponds to the JSON property create



40015
40016
40017
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40015

def create
  @create
end

#removeString

Remove operation: A resource name for the removed customer asset is expected, in this format: customers/customer_id/customerAssets/asset_id~field_type Corresponds to the JSON property remove

Returns:

  • (String)


40022
40023
40024
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40022

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAsset

A link between a customer and an asset. Corresponds to the JSON property update



40027
40028
40029
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40027

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


40032
40033
40034
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40032

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40039
40040
40041
40042
40043
40044
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40039

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end