Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetSetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on a customer asset set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerAssetSetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerAssetSetOperation.



40064
40065
40066
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAssetSet

CustomerAssetSet is the linkage between a customer and an asset set. Adding a CustomerAssetSet links an asset set with a customer. Corresponds to the JSON property create



40055
40056
40057
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40055

def create
  @create
end

#removeString

Remove operation: A resource name for the removed customer asset set is expected, in this format: customers/customer_id/customerAssetSets/ asset_set_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


40062
40063
40064
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40062

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40069
40070
40071
40072
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40069

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end