Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update) on a CustomerClientLink.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClientLink
Represents customer client link relationship.
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClientLink
Represents customer client link relationship.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation.
40094 40095 40096 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40094 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClientLink
Represents customer client link relationship.
Corresponds to the JSON property create
40082 40083 40084 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40082 def create @create end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClientLink
Represents customer client link relationship.
Corresponds to the JSON property update
40087 40088 40089 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40087 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
40092 40093 40094 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40092 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40099 40100 40101 40102 40103 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40099 def update!(**args) @create = args[:create] if args.key?(:create) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |