Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (update) on a customer conversion goal.
Instance Attribute Summary collapse
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerConversionGoal
Biddability control for conversion actions with a matching category and origin.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation.
40048 40049 40050 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40048 def initialize(**args) update!(**args) end |
Instance Attribute Details
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerConversionGoal
Biddability control for conversion actions with a matching category and origin.
Corresponds to the JSON property update
40041 40042 40043 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40041 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
40046 40047 40048 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40046 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40053 40054 40055 40056 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40053 def update!(**args) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |