Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on a customizer attribute.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerCustomizer
A customizer value for the associated CustomizerAttribute at the Customer level.
-
#remove ⇒ String
Remove operation: A resource name for the removed customer customizer is expected, in this format:
customers/customer_id/customerCustomizers/customizer_attribute_id`Corresponds to the JSON propertyremove`.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation.
40076 40077 40078 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerCustomizer
A customizer value for the associated CustomizerAttribute at the Customer
level.
Corresponds to the JSON property create
40067 40068 40069 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40067 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed customer customizer is
expected, in this format: customers/customer_id/customerCustomizers/
customizer_attribute_id`
Corresponds to the JSON propertyremove`
40074 40075 40076 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40074 def remove @remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40081 40082 40083 40084 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40081 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) end |