Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerManagerLinkOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerManagerLinkOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Updates the status of a CustomerManagerLink. The following actions are possible: 1. Update operation with status ACTIVE accepts a pending invitation.
- Update operation with status REFUSED declines a pending invitation. 3. Update operation with status INACTIVE terminates link to manager.
Instance Attribute Summary collapse
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerManagerLink
Represents customer-manager link relationship.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerManagerLinkOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCustomerManagerLinkOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerManagerLinkOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerManagerLinkOperation.
39526 39527 39528 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39526 def initialize(**args) update!(**args) end |
Instance Attribute Details
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerManagerLink
Represents customer-manager link relationship.
Corresponds to the JSON property update
39519 39520 39521 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39519 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
39524 39525 39526 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39524 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39531 39532 39533 39534 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39531 def update!(**args) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |