Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single update on a customer.
Instance Attribute Summary collapse
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomer
A customer.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCustomerOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerOperation.
39577 39578 39579 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39577 def initialize(**args) update!(**args) end |
Instance Attribute Details
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomer
A customer.
Corresponds to the JSON property update
39570 39571 39572 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39570 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
39575 39576 39577 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39575 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39582 39583 39584 39585 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39582 def update!(**args) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |