Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomizerAttributeOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on a customizer attribute.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomizerAttributeOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCustomizerAttributeOperation.



40401
40402
40403
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomizerAttribute

A customizer attribute. Use CustomerCustomizer, CampaignCustomizer, AdGroupCustomizer, or AdGroupCriterionCustomizer to associate a customizer attribute and set its value at the customer, campaign, ad group, or ad group criterion level, respectively. Corresponds to the JSON property create



40387
40388
40389
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40387

def create
  @create
end

#removeString

Remove operation: A resource name for the removed customizer attribute is expected, in this format: customers/customer_id/customizerAttributes/ customizer_attribute_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


40394
40395
40396
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40394

def remove
  @remove
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


40399
40400
40401
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40399

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40406
40407
40408
40409
40410
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40406

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end