Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCyoIncentives
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCyoIncentives
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An incentive offer in the Choose-Your-Own Incentive feature where a user can select from a set of incentives with different money amounts.
Instance Attribute Summary collapse
-
#high_offer ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive
An incentive that a user can claim for their account.
-
#low_offer ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive
An incentive that a user can claim for their account.
-
#medium_offer ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive
An incentive that a user can claim for their account.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCyoIncentives
constructor
A new instance of GoogleAdsSearchads360V23ServicesCyoIncentives.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCyoIncentives
Returns a new instance of GoogleAdsSearchads360V23ServicesCyoIncentives.
40433 40434 40435 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40433 def initialize(**args) update!(**args) end |
Instance Attribute Details
#high_offer ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive
An incentive that a user can claim for their account.
Corresponds to the JSON property highOffer
40421 40422 40423 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40421 def high_offer @high_offer end |
#low_offer ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive
An incentive that a user can claim for their account.
Corresponds to the JSON property lowOffer
40426 40427 40428 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40426 def low_offer @low_offer end |
#medium_offer ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive
An incentive that a user can claim for their account.
Corresponds to the JSON property mediumOffer
40431 40432 40433 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40431 def medium_offer @medium_offer end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40438 40439 40440 40441 40442 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40438 def update!(**args) @high_offer = args[:high_offer] if args.key?(:high_offer) @low_offer = args[:low_offer] if args.key?(:low_offer) @medium_offer = args[:medium_offer] if args.key?(:medium_offer) end |