Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDismissRecommendationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for RecommendationService.DismissRecommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesDismissRecommendationRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesDismissRecommendationRequest.



40419
40420
40421
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDismissRecommendationRequestDismissRecommendationOperation>

Required. The list of operations to dismiss recommendations. If partial_failure=false all recommendations should be of the same type There is a limit of 100 operations per request. Corresponds to the JSON property operations



40409
40410
40411
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40409

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, operations will be carried in a single transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


40416
40417
40418
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40416

def partial_failure
  @partial_failure
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40424
40425
40426
40427
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40424

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
end