Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesEffectiveFrequencyLimit
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesEffectiveFrequencyLimit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Effective frequency limit.
Instance Attribute Summary collapse
-
#effective_frequency_breakdown_limit ⇒ Fixnum
The highest effective frequency value to include in Forecast.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesEffectiveFrequencyLimit
constructor
A new instance of GoogleAdsSearchads360V23ServicesEffectiveFrequencyLimit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesEffectiveFrequencyLimit
Returns a new instance of GoogleAdsSearchads360V23ServicesEffectiveFrequencyLimit.
39886 39887 39888 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39886 def initialize(**args) update!(**args) end |
Instance Attribute Details
#effective_frequency_breakdown_limit ⇒ Fixnum
The highest effective frequency value to include in Forecast.
effective_frequency_breakdowns. This field supports frequencies 1-10,
inclusive.
Corresponds to the JSON property effectiveFrequencyBreakdownLimit
39884 39885 39886 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39884 def effective_frequency_breakdown_limit @effective_frequency_breakdown_limit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39891 39892 39893 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39891 def update!(**args) @effective_frequency_breakdown_limit = args[:effective_frequency_breakdown_limit] if args.key?(:effective_frequency_breakdown_limit) end |