Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentArmOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentArmOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation on an experiment arm.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArm
A Google ads experiment for users to experiment changes on multiple campaigns, compare the performance, and apply the effective changes.
-
#remove ⇒ String
Remove operation: The experiment arm is expected to have a valid resource name, in this format:
customers/customer_id/experiments/campaign_experiment_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArm
A Google ads experiment for users to experiment changes on multiple campaigns, compare the performance, and apply the effective changes.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesExperimentArmOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesExperimentArmOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesExperimentArmOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesExperimentArmOperation.
40787 40788 40789 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArm
A Google ads experiment for users to experiment changes on multiple campaigns,
compare the performance, and apply the effective changes.
Corresponds to the JSON property create
40768 40769 40770 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40768 def create @create end |
#remove ⇒ String
Remove operation: The experiment arm is expected to have a valid resource name,
in this format: customers/customer_id/experiments/campaign_experiment_id`
Corresponds to the JSON propertyremove`
40774 40775 40776 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40774 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArm
A Google ads experiment for users to experiment changes on multiple campaigns,
compare the performance, and apply the effective changes.
Corresponds to the JSON property update
40780 40781 40782 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40780 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
40785 40786 40787 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40785 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40792 40793 40794 40795 40796 40797 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40792 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |