Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation on an experiment.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperiment
A Google ads experiment for users to experiment changes on multiple campaigns, compare the performance, and apply the effective changes.
-
#remove ⇒ String
Remove operation: The experiment is expected to have a valid resource name, in this format:
customers/customer_id/experiments/campaign_experiment_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperiment
A Google ads experiment for users to experiment changes on multiple campaigns, compare the performance, and apply the effective changes.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesExperimentOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesExperimentOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesExperimentOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesExperimentOperation.
40827 40828 40829 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40827 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperiment
A Google ads experiment for users to experiment changes on multiple campaigns,
compare the performance, and apply the effective changes.
Corresponds to the JSON property create
40808 40809 40810 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40808 def create @create end |
#remove ⇒ String
Remove operation: The experiment is expected to have a valid resource name, in
this format: customers/customer_id/experiments/campaign_experiment_id`
Corresponds to the JSON propertyremove`
40814 40815 40816 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40814 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperiment
A Google ads experiment for users to experiment changes on multiple campaigns,
compare the performance, and apply the effective changes.
Corresponds to the JSON property update
40820 40821 40822 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40820 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
40825 40826 40827 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40825 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40832 40833 40834 40835 40836 40837 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40832 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |