Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExternalAttributionData
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExternalAttributionData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Contains additional information about externally attributed conversions.
Instance Attribute Summary collapse
-
#external_attribution_credit ⇒ Float
Represents the fraction of the conversion that is attributed to the Google Ads click.
-
#external_attribution_model ⇒ String
Specifies the attribution model name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesExternalAttributionData
constructor
A new instance of GoogleAdsSearchads360V23ServicesExternalAttributionData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesExternalAttributionData
Returns a new instance of GoogleAdsSearchads360V23ServicesExternalAttributionData.
40783 40784 40785 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40783 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_attribution_credit ⇒ Float
Represents the fraction of the conversion that is attributed to the Google Ads
click.
Corresponds to the JSON property externalAttributionCredit
40776 40777 40778 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40776 def external_attribution_credit @external_attribution_credit end |
#external_attribution_model ⇒ String
Specifies the attribution model name.
Corresponds to the JSON property externalAttributionModel
40781 40782 40783 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40781 def external_attribution_model @external_attribution_model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40788 40789 40790 40791 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40788 def update!(**args) @external_attribution_credit = args[:external_attribution_credit] if args.key?(:external_attribution_credit) @external_attribution_model = args[:external_attribution_model] if args.key?(:external_attribution_model) end |