Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesFetchIncentiveResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response from getting the acquisition incentive for a user when they visit a specific marketing page.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesFetchIncentiveResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesFetchIncentiveResponse.



40805
40806
40807
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#incentive_offerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentiveOffer

An acquisition incentive offer for a user. An offer means how the user is treated. An offer can have no incentive or multiple incentives. Corresponds to the JSON property incentiveOffer



40803
40804
40805
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40803

def incentive_offer
  @incentive_offer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40810
40811
40812
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40810

def update!(**args)
  @incentive_offer = args[:incentive_offer] if args.key?(:incentive_offer)
end