Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecast

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Forecasted traffic metrics for the planned products and targeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesForecast

Returns a new instance of GoogleAdsSearchads360V23ServicesForecast.



40978
40979
40980
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40978

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversionsFloat

The number of conversions. This metric is only available for DEMAND_GEN plannable products. See https://support.google.com/google-ads/answer/2375431 for more information on conversions. Corresponds to the JSON property conversions

Returns:

  • (Float)


40896
40897
40898
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40896

def conversions
  @conversions
end

#effective_frequency_breakdownsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesEffectiveFrequencyBreakdown>

A list of effective frequency forecasts. The list is ordered starting with 1+ and ending with the value set in GenerateReachForecastRequest. effective_frequency_limit. If no effective_frequency_limit was set, this list will be empty. Corresponds to the JSON property effectiveFrequencyBreakdowns



40904
40905
40906
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40904

def effective_frequency_breakdowns
  @effective_frequency_breakdowns
end

#on_target_coview_impressionsFixnum

Number of ad impressions that exactly matches the Targeting including co- viewers. Corresponds to the JSON property onTargetCoviewImpressions

Returns:

  • (Fixnum)


40910
40911
40912
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40910

def on_target_coview_impressions
  @on_target_coview_impressions
end

#on_target_coview_reachFixnum

Number of unique people reached that exactly matches the Targeting including co-viewers. Corresponds to the JSON property onTargetCoviewReach

Returns:

  • (Fixnum)


40916
40917
40918
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40916

def on_target_coview_reach
  @on_target_coview_reach
end

#on_target_impressionsFixnum

Number of ad impressions that exactly matches the Targeting. Corresponds to the JSON property onTargetImpressions

Returns:

  • (Fixnum)


40921
40922
40923
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40921

def on_target_impressions
  @on_target_impressions
end

#on_target_reachFixnum

Number of unique people reached at least GenerateReachForecastRequest. min_effective_frequency or GenerateReachForecastRequest. effective_frequency_limit times that exactly matches the Targeting. Note that a minimum number of unique people must be reached in order for data to be reported. If the minimum number is not met, the on_target_reach value will be rounded to 0. Corresponds to the JSON property onTargetReach

Returns:

  • (Fixnum)


40931
40932
40933
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40931

def on_target_reach
  @on_target_reach
end

#total_coview_impressionsFixnum

Total number of ad impressions including co-viewers. This includes impressions that may fall outside the specified Targeting, due to insufficient information on signed-in users. Corresponds to the JSON property totalCoviewImpressions

Returns:

  • (Fixnum)


40938
40939
40940
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40938

def total_coview_impressions
  @total_coview_impressions
end

#total_coview_reachFixnum

Number of unique people reached including co-viewers. This includes people that may fall outside the specified Targeting. Corresponds to the JSON property totalCoviewReach

Returns:

  • (Fixnum)


40944
40945
40946
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40944

def total_coview_reach
  @total_coview_reach
end

#total_impressionsFixnum

Total number of ad impressions. This includes impressions that may fall outside the specified Targeting, due to insufficient information on signed-in users. Corresponds to the JSON property totalImpressions

Returns:

  • (Fixnum)


40951
40952
40953
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40951

def total_impressions
  @total_impressions
end

#total_reachFixnum

Total number of unique people reached at least GenerateReachForecastRequest. min_effective_frequency or GenerateReachForecastRequest. effective_frequency_limit times. This includes people that may fall outside the specified Targeting. Note that a minimum number of unique people must be reached in order for data to be reported. If the minimum number is not met, the total_reach value will be rounded to 0. Corresponds to the JSON property totalReach

Returns:

  • (Fixnum)


40961
40962
40963
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40961

def total_reach
  @total_reach
end

#trueview_viewsFixnum

Number of ad views forecasted for the specified product and targeting. A TrueView View is counted when a viewer views a larger portion or the entirety of an ad beyond an impression. See https://support.google.com/google-ads/ answer/2375431 for more information on TrueView Views. Corresponds to the JSON property trueviewViews

Returns:

  • (Fixnum)


40969
40970
40971
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40969

def trueview_views
  @trueview_views
end

#viewable_impressionsFixnum

Number of times the ad's impressions were considered viewable. See https:// support.google.com/google-ads/answer/7029393 for more information about what makes an ad viewable and how viewability is measured. Corresponds to the JSON property viewableImpressions

Returns:

  • (Fixnum)


40976
40977
40978
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40976

def viewable_impressions
  @viewable_impressions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40983
40984
40985
40986
40987
40988
40989
40990
40991
40992
40993
40994
40995
40996
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40983

def update!(**args)
  @conversions = args[:conversions] if args.key?(:conversions)
  @effective_frequency_breakdowns = args[:effective_frequency_breakdowns] if args.key?(:effective_frequency_breakdowns)
  @on_target_coview_impressions = args[:on_target_coview_impressions] if args.key?(:on_target_coview_impressions)
  @on_target_coview_reach = args[:on_target_coview_reach] if args.key?(:on_target_coview_reach)
  @on_target_impressions = args[:on_target_impressions] if args.key?(:on_target_impressions)
  @on_target_reach = args[:on_target_reach] if args.key?(:on_target_reach)
  @total_coview_impressions = args[:total_coview_impressions] if args.key?(:total_coview_impressions)
  @total_coview_reach = args[:total_coview_reach] if args.key?(:total_coview_reach)
  @total_impressions = args[:total_impressions] if args.key?(:total_impressions)
  @total_reach = args[:total_reach] if args.key?(:total_reach)
  @trueview_views = args[:trueview_views] if args.key?(:trueview_views)
  @viewable_impressions = args[:viewable_impressions] if args.key?(:viewable_impressions)
end