Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AudienceInsightsService.GenerateAudienceDefinition.
Instance Attribute Summary collapse
-
#audience_description ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceDescription
A text description of the audience of interest for which insights are being requested in AudienceInsightsService.
-
#customer_insights_group ⇒ String
Optional.
-
#insights_application_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo
Additional information about the application/tool issuing the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionRequest.
41191 41192 41193 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41191 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience_description ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceDescription
A text description of the audience of interest for which insights are being
requested in AudienceInsightsService.
Corresponds to the JSON property audienceDescription
41176 41177 41178 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41176 def audience_description @audience_description end |
#customer_insights_group ⇒ String
Optional. The name of the customer being planned for. This is a user-defined
value.
Corresponds to the JSON property customerInsightsGroup
41182 41183 41184 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41182 def customer_insights_group @customer_insights_group end |
#insights_application_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo
Additional information about the application/tool issuing the request. This
field is only used by ContentCreatorInsightsService, AudienceInsightsService,
and ReachPlanService APIs.
Corresponds to the JSON property insightsApplicationInfo
41189 41190 41191 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41189 def insights_application_info @insights_application_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41196 41197 41198 41199 41200 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41196 def update!(**args) @audience_description = args[:audience_description] if args.key?(:audience_description) @customer_insights_group = args[:customer_insights_group] if args.key?(:customer_insights_group) @insights_application_info = args[:insights_application_info] if args.key?(:insights_application_info) end |