Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for AudienceInsightsService.GenerateAudienceDefinition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionResponse.



41291
41292
41293
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41291

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#high_relevance_attributesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata>

The attributes that make up the audience definition. Corresponds to the JSON property highRelevanceAttributes



41282
41283
41284
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41282

def high_relevance_attributes
  @high_relevance_attributes
end

#medium_relevance_attributesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata>

Additional attributes that are less relevant but still related to the audience description. Use these attributes to broaden the audience definition to reach more users. Corresponds to the JSON property mediumRelevanceAttributes



41289
41290
41291
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41289

def medium_relevance_attributes
  @medium_relevance_attributes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41296
41297
41298
41299
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41296

def update!(**args)
  @high_relevance_attributes = args[:high_relevance_attributes] if args.key?(:high_relevance_attributes)
  @medium_relevance_attributes = args[:medium_relevance_attributes] if args.key?(:medium_relevance_attributes)
end