Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateConversionRatesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for ReachPlanService.GenerateConversionRates, containing conversion rate suggestions for supported plannable products.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateConversionRatesResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateConversionRatesResponse.



41506
41507
41508
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversion_rate_suggestionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionRateSuggestion>

A list containing conversion rate suggestions. Each repeated element will have an associated product code. Multiple suggestions may share the same product code. Corresponds to the JSON property conversionRateSuggestions



41504
41505
41506
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41504

def conversion_rate_suggestions
  @conversion_rate_suggestions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41511
41512
41513
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41511

def update!(**args)
  @conversion_rate_suggestions = args[:conversion_rate_suggestions] if args.key?(:conversion_rate_suggestions)
end