Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AudienceInsightsService.GenerateInsightsFinderReport.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportRequest.



41544
41545
41546
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#baseline_audienceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience

A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService. Corresponds to the JSON property baselineAudience



41524
41525
41526
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41524

def baseline_audience
  @baseline_audience
end

#customer_insights_groupString

The name of the customer being planned for. This is a user-defined value. Corresponds to the JSON property customerInsightsGroup

Returns:

  • (String)


41529
41530
41531
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41529

def customer_insights_group
  @customer_insights_group
end

#insights_application_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo

Additional information about the application/tool issuing the request. This field is only used by ContentCreatorInsightsService, AudienceInsightsService, and ReachPlanService APIs. Corresponds to the JSON property insightsApplicationInfo



41536
41537
41538
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41536

def insights_application_info
  @insights_application_info
end

#specific_audienceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience

A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService. Corresponds to the JSON property specificAudience



41542
41543
41544
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41542

def specific_audience
  @specific_audience
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41549
41550
41551
41552
41553
41554
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41549

def update!(**args)
  @baseline_audience = args[:baseline_audience] if args.key?(:baseline_audience)
  @customer_insights_group = args[:customer_insights_group] if args.key?(:customer_insights_group)
  @insights_application_info = args[:insights_application_info] if args.key?(:insights_application_info)
  @specific_audience = args[:specific_audience] if args.key?(:specific_audience)
end