Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The response message for AudienceInsightsService.GenerateInsightsFinderReport, containing the shareable URL for the report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportResponse.



41568
41569
41570
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#saved_report_urlString

An HTTPS URL providing a deep link into the Insights Finder UI with the report inputs filled in according to the request. Corresponds to the JSON property savedReportUrl

Returns:

  • (String)


41566
41567
41568
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41566

def saved_report_url
  @saved_report_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41573
41574
41575
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41573

def update!(**args)
  @saved_report_url = args[:saved_report_url] if args.key?(:saved_report_url)
end