Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordHistoricalMetricsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for KeywordPlanIdeaService.GenerateKeywordHistoricalMetrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateKeywordHistoricalMetricsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateKeywordHistoricalMetricsRequest.



41679
41680
41681
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregate_metricsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanAggregateMetrics

The aggregate metrics specification of the request. Corresponds to the JSON property aggregateMetrics



41639
41640
41641
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41639

def aggregate_metrics
  @aggregate_metrics
end

#geo_target_constantsArray<String>

The resource names of the location to target. Maximum is 10. An empty list MAY be used to specify all targeting geos. Corresponds to the JSON property geoTargetConstants

Returns:

  • (Array<String>)


41645
41646
41647
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41645

def geo_target_constants
  @geo_target_constants
end

#historical_metrics_optionsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHistoricalMetricsOptions

Historical metrics options. Corresponds to the JSON property historicalMetricsOptions



41650
41651
41652
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41650

def historical_metrics_options
  @historical_metrics_options
end

#include_adult_keywordsBoolean Also known as: include_adult_keywords?

If true, adult keywords will be included in response. The default value is false. Corresponds to the JSON property includeAdultKeywords

Returns:

  • (Boolean)


41656
41657
41658
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41656

def include_adult_keywords
  @include_adult_keywords
end

#keyword_plan_networkString

Targeting network. If not set, Google Search And Partners Network will be used. Corresponds to the JSON property keywordPlanNetwork

Returns:

  • (String)


41662
41663
41664
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41662

def keyword_plan_network
  @keyword_plan_network
end

#keywordsArray<String>

A list of keywords to get historical metrics. Not all inputs will be returned as a result of near-exact deduplication. For example, if stats for "car" and " cars" are requested, only "car" will be returned. A maximum of 10,000 keywords can be used. Corresponds to the JSON property keywords

Returns:

  • (Array<String>)


41670
41671
41672
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41670

def keywords
  @keywords
end

#languageString

The resource name of the language to target. Each keyword belongs to some set of languages; a keyword is included if language is one of its languages. If not set, all keywords will be included. Corresponds to the JSON property language

Returns:

  • (String)


41677
41678
41679
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41677

def language
  @language
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41684
41685
41686
41687
41688
41689
41690
41691
41692
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41684

def update!(**args)
  @aggregate_metrics = args[:aggregate_metrics] if args.key?(:aggregate_metrics)
  @geo_target_constants = args[:geo_target_constants] if args.key?(:geo_target_constants)
  @historical_metrics_options = args[:historical_metrics_options] if args.key?(:historical_metrics_options)
  @include_adult_keywords = args[:include_adult_keywords] if args.key?(:include_adult_keywords)
  @keyword_plan_network = args[:keyword_plan_network] if args.key?(:keyword_plan_network)
  @keywords = args[:keywords] if args.key?(:keywords)
  @language = args[:language] if args.key?(:language)
end