Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for KeywordPlanIdeaService.GenerateKeywordIdeas.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResponse.



41784
41785
41786
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41784

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregate_metric_resultsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanAggregateMetricResults

The aggregated historical metrics for keyword plan keywords. Corresponds to the JSON property aggregateMetricResults



41765
41766
41767
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41765

def aggregate_metric_results
  @aggregate_metric_results
end

#next_page_tokenString

Pagination token used to retrieve the next page of results. Pass the content of this string as the page_token attribute of the next request. next_page_token is not returned for the last page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41772
41773
41774
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41772

def next_page_token
  @next_page_token
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResult>

Results of generating keyword ideas. Corresponds to the JSON property results



41777
41778
41779
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41777

def results
  @results
end

#total_sizeFixnum

Total number of results available. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


41782
41783
41784
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41782

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41789
41790
41791
41792
41793
41794
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41789

def update!(**args)
  @aggregate_metric_results = args[:aggregate_metric_results] if args.key?(:aggregate_metric_results)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @results = args[:results] if args.key?(:results)
  @total_size = args[:total_size] if args.key?(:total_size)
end