Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The result of generating keyword ideas.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResult

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResult.



41827
41828
41829
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#close_variantsArray<String>

The list of close variants from the requested keywords that are combined into this GenerateKeywordIdeaResult. See https://support.google.com/google-ads/ answer/9342105 for the definition of "close variants". Corresponds to the JSON property closeVariants

Returns:

  • (Array<String>)


41806
41807
41808
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41806

def close_variants
  @close_variants
end

#keyword_annotationsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordAnnotations

The annotations for the keyword plan keywords. Corresponds to the JSON property keywordAnnotations



41811
41812
41813
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41811

def keyword_annotations
  @keyword_annotations
end

#keyword_idea_metricsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics

Historical metrics specific to the targeting options selected. Targeting options include geographies, network, and so on. Refer to https://support. google.com/google-ads/answer/3022575 for more details. Corresponds to the JSON property keywordIdeaMetrics



41818
41819
41820
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41818

def keyword_idea_metrics
  @keyword_idea_metrics
end

#textString

Text of the keyword idea. As in Keyword Plan historical metrics, this text may not be an actual keyword, but the canonical form of multiple keywords. See KeywordPlanKeywordHistoricalMetrics message in KeywordPlanService. Corresponds to the JSON property text

Returns:

  • (String)


41825
41826
41827
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41825

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41832
41833
41834
41835
41836
41837
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41832

def update!(**args)
  @close_variants = args[:close_variants] if args.key?(:close_variants)
  @keyword_annotations = args[:keyword_annotations] if args.key?(:keyword_annotations)
  @keyword_idea_metrics = args[:keyword_idea_metrics] if args.key?(:keyword_idea_metrics)
  @text = args[:text] if args.key?(:text)
end