Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for RecommendationService.GenerateRecommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequest.



42204
42205
42206
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42204

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_infoArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestAdGroupInfo>

Optional. Current AdGroup Information. Supports information from a single AdGroup. This field is optional for the following recommendation_types: KEYWORD Corresponds to the JSON property adGroupInfo



42069
42070
42071
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42069

def ad_group_info
  @ad_group_info
end

#advertising_channel_typeString

Required. Advertising channel type of the campaign. The following advertising_channel_types are supported for recommendation generation: PERFORMANCE_MAX and SEARCH Corresponds to the JSON property advertisingChannelType

Returns:

  • (String)


42076
42077
42078
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42076

def advertising_channel_type
  @advertising_channel_type
end

#asset_group_infoArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestAssetGroupInfo>

Optional. Current AssetGroup Information. This field is required for the following recommendation_types: CAMPAIGN_BUDGET Corresponds to the JSON property assetGroupInfo



42082
42083
42084
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42082

def asset_group_info
  @asset_group_info
end

#bidding_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestBiddingInfo

Current bidding information of the campaign. Provides a wrapper for bidding- related signals that inform recommendations. Corresponds to the JSON property biddingInfo



42088
42089
42090
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42088

def bidding_info
  @bidding_info
end

#budget_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestBudgetInfo

Current budget information of the campaign. Corresponds to the JSON property budgetInfo



42093
42094
42095
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42093

def budget_info
  @budget_info
end

#campaign_call_asset_countFixnum

Optional. Current campaign call asset count. This field is optional for the following recommendation_types: CAMPAIGN_BUDGET Corresponds to the JSON property campaignCallAssetCount

Returns:

  • (Fixnum)


42099
42100
42101
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42099

def campaign_call_asset_count
  @campaign_call_asset_count
end

#campaign_image_asset_countFixnum

Optional. Current campaign image asset count. This field is optional for the following recommendation_types: CAMPAIGN_BUDGET Corresponds to the JSON property campaignImageAssetCount

Returns:

  • (Fixnum)


42105
42106
42107
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42105

def campaign_image_asset_count
  @campaign_image_asset_count
end

Optional. Number of sitelinks on the campaign. This field is necessary for the following recommendation_types: SITELINK_ASSET Corresponds to the JSON property campaignSitelinkCount

Returns:

  • (Fixnum)


42111
42112
42113
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42111

def campaign_sitelink_count
  @campaign_sitelink_count
end

#conversion_tracking_statusString

Optional. Current conversion tracking status. This field is necessary for the following recommendation_types: MAXIMIZE_CLICKS_OPT_IN, MAXIMIZE_CONVERSIONS_OPT_IN, MAXIMIZE_CONVERSION_VALUE_OPT_IN, SET_TARGET_CPA, SET_TARGET_ROAS, TARGET_CPA_OPT_IN, TARGET_ROAS_OPT_IN Corresponds to the JSON property conversionTrackingStatus

Returns:

  • (String)


42119
42120
42121
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42119

def conversion_tracking_status
  @conversion_tracking_status
end

#country_codesArray<String>

Optional. Current campaign country codes. This field is required for the following recommendation_types: CAMPAIGN_BUDGET if AdvertisingChannelType is SEARCH Corresponds to the JSON property countryCodes

Returns:

  • (Array<String>)


42126
42127
42128
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42126

def country_codes
  @country_codes
end

#is_new_customerBoolean Also known as: is_new_customer?

Optional. Whether or not this customer should be treated as a "new" customer ( that is, a customer who has not yet created a campaign). Setting this to true will cause the backend to generate recommendations using a dedicated recommendation model for onboarding new customers, as opposed to the default model for existing customers. This is only recommended for customers with 0 campaigns. This field is optional for the following recommendation_types: CAMPAIGN_BUDGET Corresponds to the JSON property isNewCustomer

Returns:

  • (Boolean)


42137
42138
42139
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42137

def is_new_customer
  @is_new_customer
end

#language_codesArray<String>

Optional. Current campaign language codes. This field is required for the following recommendation_types: CAMPAIGN_BUDGET if AdvertisingChannelType is SEARCH Corresponds to the JSON property languageCodes

Returns:

  • (Array<String>)


42145
42146
42147
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42145

def language_codes
  @language_codes
end

#merchant_center_account_idFixnum

Optional. Merchant Center account ID. This field should only be set when advertising_channel_type is PERFORMANCE_MAX. Setting this field causes RecommendationService to generate recommendations for Performance Max for retail instead of standard Performance Max. This field is optional for the following recommendation_types: CAMPAIGN_BUDGET Corresponds to the JSON property merchantCenterAccountId

Returns:

  • (Fixnum)


42154
42155
42156
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42154

def 
  @merchant_center_account_id
end

#negative_locations_idsArray<Fixnum>

Optional. Current campaign negative location ids. One of this field OR positive_location_ids is required for the following recommendation_types: CAMPAIGN_BUDGET if AdvertisingChannelType is SEARCH Corresponds to the JSON property negativeLocationsIds

Returns:

  • (Array<Fixnum>)


42161
42162
42163
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42161

def negative_locations_ids
  @negative_locations_ids
end

#positive_locations_idsArray<Fixnum>

Optional. Current campaign positive location ids. One of this field OR negative_location_ids is required for the following recommendation_types: CAMPAIGN_BUDGET if AdvertisingChannelType is SEARCH Corresponds to the JSON property positiveLocationsIds

Returns:

  • (Array<Fixnum>)


42168
42169
42170
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42168

def positive_locations_ids
  @positive_locations_ids
end

#recommendation_typesArray<String>

Required. List of eligible recommendation_types to generate. If the uploaded criteria isn't sufficient to make a recommendation, or the campaign is already in the recommended state, no recommendation will be returned for that type. Generally, a recommendation is returned if all required fields for that recommendation_type are uploaded, but there are cases where this is still not sufficient. The following recommendation_types are supported for recommendation generation: KEYWORD, MAXIMIZE_CLICKS_OPT_IN, MAXIMIZE_CONVERSIONS_OPT_IN, MAXIMIZE_CONVERSION_VALUE_OPT_IN, SET_TARGET_CPA, SET_TARGET_ROAS, SITELINK_ASSET, TARGET_CPA_OPT_IN, TARGET_ROAS_OPT_IN Corresponds to the JSON property recommendationTypes

Returns:

  • (Array<String>)


42181
42182
42183
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42181

def recommendation_types
  @recommendation_types
end

#seed_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestSeedInfo

A keyword seed and a specific url to generate keywords from. Corresponds to the JSON property seedInfo



42186
42187
42188
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42186

def seed_info
  @seed_info
end

#target_content_networkBoolean Also known as: target_content_network?

Optional. If true, the campaign is opted into serving ads on specified placements in the Google Display Network. This field is optional for the following recommendation_types: CAMPAIGN_BUDGET Corresponds to the JSON property targetContentNetwork

Returns:

  • (Boolean)


42193
42194
42195
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42193

def target_content_network
  @target_content_network
end

#target_partner_search_networkBoolean Also known as: target_partner_search_network?

Optional. If true, the campaign is opted into serving ads on the Google Partner Network. This field is optional for the following recommendation_types: CAMPAIGN_BUDGET Corresponds to the JSON property targetPartnerSearchNetwork

Returns:

  • (Boolean)


42201
42202
42203
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42201

def target_partner_search_network
  @target_partner_search_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42209
42210
42211
42212
42213
42214
42215
42216
42217
42218
42219
42220
42221
42222
42223
42224
42225
42226
42227
42228
42229
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42209

def update!(**args)
  @ad_group_info = args[:ad_group_info] if args.key?(:ad_group_info)
  @advertising_channel_type = args[:advertising_channel_type] if args.key?(:advertising_channel_type)
  @asset_group_info = args[:asset_group_info] if args.key?(:asset_group_info)
  @bidding_info = args[:bidding_info] if args.key?(:bidding_info)
  @budget_info = args[:budget_info] if args.key?(:budget_info)
  @campaign_call_asset_count = args[:campaign_call_asset_count] if args.key?(:campaign_call_asset_count)
  @campaign_image_asset_count = args[:campaign_image_asset_count] if args.key?(:campaign_image_asset_count)
  @campaign_sitelink_count = args[:campaign_sitelink_count] if args.key?(:campaign_sitelink_count)
  @conversion_tracking_status = args[:conversion_tracking_status] if args.key?(:conversion_tracking_status)
  @country_codes = args[:country_codes] if args.key?(:country_codes)
  @is_new_customer = args[:is_new_customer] if args.key?(:is_new_customer)
  @language_codes = args[:language_codes] if args.key?(:language_codes)
  @merchant_center_account_id = args[:merchant_center_account_id] if args.key?(:merchant_center_account_id)
  @negative_locations_ids = args[:negative_locations_ids] if args.key?(:negative_locations_ids)
  @positive_locations_ids = args[:positive_locations_ids] if args.key?(:positive_locations_ids)
  @recommendation_types = args[:recommendation_types] if args.key?(:recommendation_types)
  @seed_info = args[:seed_info] if args.key?(:seed_info)
  @target_content_network = args[:target_content_network] if args.key?(:target_content_network)
  @target_partner_search_network = args[:target_partner_search_network] if args.key?(:target_partner_search_network)
end