Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestBiddingInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Current bidding information of the campaign. Provides a wrapper for bidding- related signals that inform recommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestBiddingInfo

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestBiddingInfo.



35429
35430
35431
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bidding_strategy_typeString

Current bidding strategy. This field is necessary for the following recommendation_types: MAXIMIZE_CLICKS_OPT_IN, MAXIMIZE_CONVERSIONS_OPT_IN, MAXIMIZE_CONVERSION_VALUE_OPT_IN, SET_TARGET_CPA, SET_TARGET_ROAS, TARGET_CPA_OPT_IN, TARGET_ROAS_OPT_IN Corresponds to the JSON property biddingStrategyType

Returns:

  • (String)


35410
35411
35412
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35410

def bidding_strategy_type
  @bidding_strategy_type
end

#target_cpa_microsFixnum

Current target_cpa in micros. This can be populated for campaigns with a bidding strategy type of TARGET_CPA or MAXIMIZE_CONVERSIONS. Corresponds to the JSON property targetCpaMicros

Returns:

  • (Fixnum)


35416
35417
35418
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35416

def target_cpa_micros
  @target_cpa_micros
end

#target_impression_share_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestTargetImpressionShareInfo

Current Target Impression Share information of the campaign. Corresponds to the JSON property targetImpressionShareInfo



35421
35422
35423
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35421

def target_impression_share_info
  @target_impression_share_info
end

#target_roasFloat

Current target_roas. This can be populated for campaigns with a bidding strategy type of TARGET_ROAS or MAXIMIZE_CONVERSION_VALUE. Corresponds to the JSON property targetRoas

Returns:

  • (Float)


35427
35428
35429
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35427

def target_roas
  @target_roas
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35434
35435
35436
35437
35438
35439
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35434

def update!(**args)
  @bidding_strategy_type = args[:bidding_strategy_type] if args.key?(:bidding_strategy_type)
  @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros)
  @target_impression_share_info = args[:target_impression_share_info] if args.key?(:target_impression_share_info)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
end