Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestSeedInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A keyword seed and a specific url to generate keywords from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestSeedInfo

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestSeedInfo.



35477
35478
35479
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyword_seedsArray<String>

Optional. Keywords or phrases to generate ideas from, for example: cars or " car dealership near me". Corresponds to the JSON property keywordSeeds

Returns:

  • (Array<String>)


35470
35471
35472
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35470

def keyword_seeds
  @keyword_seeds
end

#url_seedString

A specific url to generate ideas from, for example: www.example.com/cars. Corresponds to the JSON property urlSeed

Returns:

  • (String)


35475
35476
35477
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35475

def url_seed
  @url_seed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35482
35483
35484
35485
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35482

def update!(**args)
  @keyword_seeds = args[:keyword_seeds] if args.key?(:keyword_seeds)
  @url_seed = args[:url_seed] if args.key?(:url_seed)
end