Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateSuggestedTargetingInsightsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AudienceInsightsService.GenerateSuggestedTargetingInsights.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateSuggestedTargetingInsightsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateSuggestedTargetingInsightsRequest.



42211
42212
42213
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audience_definitionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceDefinition

A structured definition of the audience of interest for which insights are being requested in AudienceInsightsService. Corresponds to the JSON property audienceDefinition



42190
42191
42192
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42190

def audience_definition
  @audience_definition
end

#audience_descriptionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceDescription

A text description of the audience of interest for which insights are being requested in AudienceInsightsService. Corresponds to the JSON property audienceDescription



42196
42197
42198
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42196

def audience_description
  @audience_description
end

#customer_insights_groupString

Optional. The name of the customer being planned for. This is a user-defined value. Corresponds to the JSON property customerInsightsGroup

Returns:

  • (String)


42202
42203
42204
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42202

def customer_insights_group
  @customer_insights_group
end

#insights_application_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo

Additional information about the application/tool issuing the request. This field is only used by ContentCreatorInsightsService, AudienceInsightsService, and ReachPlanService APIs. Corresponds to the JSON property insightsApplicationInfo



42209
42210
42211
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42209

def insights_application_info
  @insights_application_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42216
42217
42218
42219
42220
42221
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42216

def update!(**args)
  @audience_definition = args[:audience_definition] if args.key?(:audience_definition)
  @audience_description = args[:audience_description] if args.key?(:audience_description)
  @customer_insights_group = args[:customer_insights_group] if args.key?(:customer_insights_group)
  @insights_application_info = args[:insights_application_info] if args.key?(:insights_application_info)
end