Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGetSmartCampaignStatusResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for SmartCampaignSettingService.GetSmartCampaignStatus.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGetSmartCampaignStatusResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesGetSmartCampaignStatusResponse.



42472
42473
42474
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42472

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eligible_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails

Details related to Smart campaigns that are eligible to serve. Corresponds to the JSON property eligibleDetails



42445
42446
42447
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42445

def eligible_details
  @eligible_details
end

#ended_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignEndedDetails

Details related to Smart campaigns that have ended. Corresponds to the JSON property endedDetails



42450
42451
42452
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42450

def ended_details
  @ended_details
end

#not_eligible_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails

Details related to Smart campaigns that are not eligible to serve. Corresponds to the JSON property notEligibleDetails



42455
42456
42457
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42455

def not_eligible_details
  @not_eligible_details
end

#paused_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignPausedDetails

Details related to paused Smart campaigns. Corresponds to the JSON property pausedDetails



42460
42461
42462
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42460

def paused_details
  @paused_details
end

#removed_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignRemovedDetails

Details related to removed Smart campaigns. Corresponds to the JSON property removedDetails



42465
42466
42467
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42465

def removed_details
  @removed_details
end

#smart_campaign_statusString

The status of this Smart campaign. Corresponds to the JSON property smartCampaignStatus

Returns:

  • (String)


42470
42471
42472
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42470

def smart_campaign_status
  @smart_campaign_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42477
42478
42479
42480
42481
42482
42483
42484
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42477

def update!(**args)
  @eligible_details = args[:eligible_details] if args.key?(:eligible_details)
  @ended_details = args[:ended_details] if args.key?(:ended_details)
  @not_eligible_details = args[:not_eligible_details] if args.key?(:not_eligible_details)
  @paused_details = args[:paused_details] if args.key?(:paused_details)
  @removed_details = args[:removed_details] if args.key?(:removed_details)
  @smart_campaign_status = args[:smart_campaign_status] if args.key?(:smart_campaign_status)
end