Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGoalOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGoalOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single mutate operation on the goal.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGoal
Representation of goals.
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGoal
Representation of goals.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGoalOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesGoalOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGoalOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesGoalOperation.
42434 42435 42436 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42434 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGoal
Representation of goals.
Corresponds to the JSON property create
42422 42423 42424 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42422 def create @create end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGoal
Representation of goals.
Corresponds to the JSON property update
42427 42428 42429 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42427 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
42432 42433 42434 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42432 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42439 42440 42441 42442 42443 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42439 def update!(**args) @create = args[:create] if args.key?(:create) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |