Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGraduateExperimentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ExperimentService.GraduateExperiment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGraduateExperimentRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesGraduateExperimentRequest.



42464
42465
42466
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaign_budget_mappingsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetMapping>

Required. List of campaign budget mappings for graduation. Each campaign that appears here will graduate, and will be assigned a new budget that is paired with it in the mapping. The maximum size is one. Corresponds to the JSON property campaignBudgetMappings



42455
42456
42457
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42455

def campaign_budget_mappings
  @campaign_budget_mappings
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


42461
42462
42463
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42461

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42469
42470
42471
42472
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42469

def update!(**args)
  @campaign_budget_mappings = args[:campaign_budget_mappings] if args.key?(:campaign_budget_mappings)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end