Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIdentityVerification

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An identity verification for a customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIdentityVerification

Returns a new instance of GoogleAdsSearchads360V23ServicesIdentityVerification.



42674
42675
42676
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42674

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#identity_verification_requirementGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIdentityVerificationRequirement

Information regarding the verification requirement for a verification program type. Corresponds to the JSON property identityVerificationRequirement



42661
42662
42663
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42661

def identity_verification_requirement
  @identity_verification_requirement
end

#verification_programString

The verification program type. Corresponds to the JSON property verificationProgram

Returns:

  • (String)


42666
42667
42668
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42666

def verification_program
  @verification_program
end

#verification_progressGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIdentityVerificationProgress

Information regarding the verification progress for a verification program type. Corresponds to the JSON property verificationProgress



42672
42673
42674
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42672

def verification_progress
  @verification_progress
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42679
42680
42681
42682
42683
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42679

def update!(**args)
  @identity_verification_requirement = args[:identity_verification_requirement] if args.key?(:identity_verification_requirement)
  @verification_program = args[:verification_program] if args.key?(:verification_program)
  @verification_progress = args[:verification_progress] if args.key?(:verification_progress)
end