Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentiveOffer
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentiveOffer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An acquisition incentive offer for a user. An offer means how the user is treated. An offer can have no incentive or multiple incentives.
Instance Attribute Summary collapse
-
#consolidated_terms_and_conditions_url ⇒ String
Optional.
-
#cyo_incentives ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCyoIncentives
An incentive offer in the Choose-Your-Own Incentive feature where a user can select from a set of incentives with different money amounts.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIncentiveOffer
constructor
A new instance of GoogleAdsSearchads360V23ServicesIncentiveOffer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIncentiveOffer
Returns a new instance of GoogleAdsSearchads360V23ServicesIncentiveOffer.
42806 42807 42808 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42806 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consolidated_terms_and_conditions_url ⇒ String
Optional. The URL of the terms and conditions for the incentive offer.
Corresponds to the JSON property consolidatedTermsAndConditionsUrl
42793 42794 42795 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42793 def consolidated_terms_and_conditions_url @consolidated_terms_and_conditions_url end |
#cyo_incentives ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCyoIncentives
An incentive offer in the Choose-Your-Own Incentive feature where a user can
select from a set of incentives with different money amounts.
Corresponds to the JSON property cyoIncentives
42799 42800 42801 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42799 def cyo_incentives @cyo_incentives end |
#type ⇒ String
Required. The type of this acquisition incentive offer.
Corresponds to the JSON property type
42804 42805 42806 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42804 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42811 42812 42813 42814 42815 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42811 def update!(**args) @consolidated_terms_and_conditions_url = args[:consolidated_terms_and_conditions_url] if args.key?(:consolidated_terms_and_conditions_url) @cyo_incentives = args[:cyo_incentives] if args.key?(:cyo_incentives) @type = args[:type] if args.key?(:type) end |