Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIndustryVerticalInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIndustryVerticalInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The information associated with an Industry Vertical.
Instance Attribute Summary collapse
-
#industry_vertical_id ⇒ Fixnum
The unique identifier of the Industry Vertical.
-
#industry_vertical_name ⇒ String
The name of the Industry Vertical.
-
#parent_industry_vertical_id ⇒ Fixnum
The unique identifier of the parent Industry Vertical, if exists.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIndustryVerticalInfo
constructor
A new instance of GoogleAdsSearchads360V23ServicesIndustryVerticalInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIndustryVerticalInfo
Returns a new instance of GoogleAdsSearchads360V23ServicesIndustryVerticalInfo.
42837 42838 42839 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42837 def initialize(**args) update!(**args) end |
Instance Attribute Details
#industry_vertical_id ⇒ Fixnum
The unique identifier of the Industry Vertical.
Corresponds to the JSON property industryVerticalId
42825 42826 42827 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42825 def industry_vertical_id @industry_vertical_id end |
#industry_vertical_name ⇒ String
The name of the Industry Vertical.
Corresponds to the JSON property industryVerticalName
42830 42831 42832 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42830 def industry_vertical_name @industry_vertical_name end |
#parent_industry_vertical_id ⇒ Fixnum
The unique identifier of the parent Industry Vertical, if exists.
Corresponds to the JSON property parentIndustryVerticalId
42835 42836 42837 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42835 def parent_industry_vertical_id @parent_industry_vertical_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42842 42843 42844 42845 42846 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42842 def update!(**args) @industry_vertical_id = args[:industry_vertical_id] if args.key?(:industry_vertical_id) @industry_vertical_name = args[:industry_vertical_name] if args.key?(:industry_vertical_name) @parent_industry_vertical_id = args[:parent_industry_vertical_id] if args.key?(:parent_industry_vertical_id) end |