Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesInsightsAudience

Returns a new instance of GoogleAdsSearchads360V23ServicesInsightsAudience.



42909
42910
42911
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42909

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_rangesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo>

Age ranges for the audience. If absent, the audience represents all people over 18 that match the other attributes. Corresponds to the JSON property ageRanges



42858
42859
42860
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42858

def age_ranges
  @age_ranges
end

#country_locationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>

Required. The countries for the audience. Corresponds to the JSON property countryLocations



42863
42864
42865
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42863

def country_locations
  @country_locations
end

#genderGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo

A gender criterion. Corresponds to the JSON property gender



42868
42869
42870
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42868

def gender
  @gender
end

#income_rangesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIncomeRangeInfo>

Household income percentile ranges for the audience. If absent, the audience does not restrict by household income range. Corresponds to the JSON property incomeRanges



42874
42875
42876
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42874

def income_ranges
  @income_ranges
end

#lineupsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsLineup>

Lineups representing the YouTube content viewed by the audience. Corresponds to the JSON property lineups



42879
42880
42881
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42879

def lineups
  @lineups
end

#parental_statusGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo

A parental status criterion. Corresponds to the JSON property parentalStatus



42884
42885
42886
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42884

def parental_status
  @parental_status
end

#sub_country_locationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>

Sub-country geographic location attributes. If present, each of these must be contained in one of the countries in this audience. If absent, the audience is geographically to the country_locations and no further. Corresponds to the JSON property subCountryLocations



42891
42892
42893
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42891

def sub_country_locations
  @sub_country_locations
end

#topic_audience_combinationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceAttributeGroup>

A combination of entity, category and user interest attributes defining the audience. The combination has a logical AND-of-ORs structure: Attributes within each InsightsAudienceAttributeGroup are combined with OR, and the combinations themselves are combined together with AND. For example, the expression (Entity OR Affinity) AND (In-Market OR Category) can be formed using two InsightsAudienceAttributeGroups with two Attributes each. Corresponds to the JSON property topicAudienceCombinations



42901
42902
42903
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42901

def topic_audience_combinations
  @topic_audience_combinations
end

#user_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListInfo

A User List criterion. Represents a user list that is defined by the advertiser to be targeted. Corresponds to the JSON property userList



42907
42908
42909
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42907

def user_list
  @user_list
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42914
42915
42916
42917
42918
42919
42920
42921
42922
42923
42924
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42914

def update!(**args)
  @age_ranges = args[:age_ranges] if args.key?(:age_ranges)
  @country_locations = args[:country_locations] if args.key?(:country_locations)
  @gender = args[:gender] if args.key?(:gender)
  @income_ranges = args[:income_ranges] if args.key?(:income_ranges)
  @lineups = args[:lineups] if args.key?(:lineups)
  @parental_status = args[:parental_status] if args.key?(:parental_status)
  @sub_country_locations = args[:sub_country_locations] if args.key?(:sub_country_locations)
  @topic_audience_combinations = args[:topic_audience_combinations] if args.key?(:topic_audience_combinations)
  @user_list = args[:user_list] if args.key?(:user_list)
end