Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceDefinition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A structured definition of the audience of interest for which insights are being requested in AudienceInsightsService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesInsightsAudienceDefinition

Returns a new instance of GoogleAdsSearchads360V23ServicesInsightsAudienceDefinition.



42973
42974
42975
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audienceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience

A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService. Corresponds to the JSON property audience



42958
42959
42960
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42958

def audience
  @audience
end

#baseline_audienceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience

A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService. Corresponds to the JSON property baselineAudience



42964
42965
42966
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42964

def baseline_audience
  @baseline_audience
end

#data_monthString

Optional. The one-month range of historical data to use for insights, in the format "yyyy-mm". If unset, insights will be returned for the last thirty days of data. Corresponds to the JSON property dataMonth

Returns:

  • (String)


42971
42972
42973
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42971

def data_month
  @data_month
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42978
42979
42980
42981
42982
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42978

def update!(**args)
  @audience = args[:audience] if args.key?(:audience)
  @baseline_audience = args[:baseline_audience] if args.key?(:baseline_audience)
  @data_month = args[:data_month] if args.key?(:data_month)
end