Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordAndUrlSeed

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Keyword And Url Seed

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordAndUrlSeed

Returns a new instance of GoogleAdsSearchads360V23ServicesKeywordAndUrlSeed.



42968
42969
42970
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keywordsArray<String>

Requires at least one keyword and no more than 20 keywords. Corresponds to the JSON property keywords

Returns:

  • (Array<String>)


42961
42962
42963
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42961

def keywords
  @keywords
end

#urlString

The URL to crawl in order to generate keyword ideas. Corresponds to the JSON property url

Returns:

  • (String)


42966
42967
42968
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42966

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42973
42974
42975
42976
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42973

def update!(**args)
  @keywords = args[:keywords] if args.key?(:keywords)
  @url = args[:url] if args.key?(:url)
end