Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a Keyword Plan ad group keyword.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword
A Keyword Plan ad group keyword.
-
#remove ⇒ String
Remove operation: A resource name for the removed Keyword Plan ad group keyword is expected, in this format:
customers/customer_id/ keywordPlanAdGroupKeywords/kp_ad_group_keyword_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword
A Keyword Plan ad group keyword.
-
#update_mask ⇒ String
The FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation.
43140 43141 43142 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43140 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword
A Keyword Plan ad group keyword. Max number of keyword plan keywords per plan:
10000.
Corresponds to the JSON property create
43120 43121 43122 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43120 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed Keyword Plan ad group
keyword is expected, in this format: customers/customer_id/
keywordPlanAdGroupKeywords/kp_ad_group_keyword_id`
Corresponds to the JSON propertyremove`
43127 43128 43129 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43127 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword
A Keyword Plan ad group keyword. Max number of keyword plan keywords per plan:
10000.
Corresponds to the JSON property update
43133 43134 43135 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43133 def update @update end |
#update_mask ⇒ String
The FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
43138 43139 43140 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43138 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43145 43146 43147 43148 43149 43150 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43145 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |