Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a Keyword Plan campaign keyword.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaignKeyword
A Keyword Plan Campaign keyword.
-
#remove ⇒ String
Remove operation: A resource name for the removed Keyword Plan campaign keywords expected in this format:
customers/customer_id/ keywordPlanCampaignKeywords/kp_campaign_keyword_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaignKeyword
A Keyword Plan Campaign keyword.
-
#update_mask ⇒ String
The FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation.
43148 43149 43150 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43148 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaignKeyword
A Keyword Plan Campaign keyword. Only negative keywords are supported for
Campaign Keyword.
Corresponds to the JSON property create
43128 43129 43130 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43128 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed Keyword Plan campaign
keywords expected in this format: customers/customer_id/
keywordPlanCampaignKeywords/kp_campaign_keyword_id`
Corresponds to the JSON propertyremove`
43135 43136 43137 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43135 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaignKeyword
A Keyword Plan Campaign keyword. Only negative keywords are supported for
Campaign Keyword.
Corresponds to the JSON property update
43141 43142 43143 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43141 def update @update end |
#update_mask ⇒ String
The FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
43146 43147 43148 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43146 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43153 43154 43155 43156 43157 43158 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43153 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |