Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordSeed
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordSeed
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Keyword Seed
Instance Attribute Summary collapse
-
#keywords ⇒ Array<String>
Requires at least one keyword and no more than 20 keywords.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordSeed
constructor
A new instance of GoogleAdsSearchads360V23ServicesKeywordSeed.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordSeed
Returns a new instance of GoogleAdsSearchads360V23ServicesKeywordSeed.
42558 42559 42560 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#keywords ⇒ Array<String>
Requires at least one keyword and no more than 20 keywords.
Corresponds to the JSON property keywords
42556 42557 42558 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42556 def keywords @keywords end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42563 42564 42565 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42563 def update!(**args) @keywords = args[:keywords] if args.key?(:keywords) end |