Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListAccessibleCustomersResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListAccessibleCustomersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for CustomerService.ListAccessibleCustomers.
Instance Attribute Summary collapse
-
#resource_names ⇒ Array<String>
Resource name of customers directly accessible by the user authenticating the call.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListAccessibleCustomersResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesListAccessibleCustomersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListAccessibleCustomersResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesListAccessibleCustomersResponse.
42616 42617 42618 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_names ⇒ Array<String>
Resource name of customers directly accessible by the user authenticating the
call.
Corresponds to the JSON property resourceNames
42614 42615 42616 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42614 def resource_names @resource_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42621 42622 42623 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42621 def update!(**args) @resource_names = args[:resource_names] if args.key?(:resource_names) end |