Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListBatchJobResultsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListBatchJobResultsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for BatchJobService.ListBatchJobResults.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Pagination token used to retrieve the next page of results.
-
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBatchJobResult>
The list of rows that matched the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListBatchJobResultsResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesListBatchJobResultsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListBatchJobResultsResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesListBatchJobResultsResponse.
43414 43415 43416 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43414 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Pagination token used to retrieve the next page of results. Pass the content
of this string as the page_token attribute of the next request.
next_page_token is not returned for the last page.
Corresponds to the JSON property nextPageToken
43407 43408 43409 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43407 def next_page_token @next_page_token end |
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBatchJobResult>
The list of rows that matched the query.
Corresponds to the JSON property results
43412 43413 43414 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43412 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43419 43420 43421 43422 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43419 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @results = args[:results] if args.key?(:results) end |