Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListInvoicesResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListInvoicesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for InvoiceService.ListInvoices.
Instance Attribute Summary collapse
-
#invoices ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoice>
The list of invoices that match the billing setup and time period.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListInvoicesResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesListInvoicesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListInvoicesResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesListInvoicesResponse.
43028 43029 43030 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43028 def initialize(**args) update!(**args) end |
Instance Attribute Details
#invoices ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoice>
The list of invoices that match the billing setup and time period.
Corresponds to the JSON property invoices
43026 43027 43028 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43026 def invoices @invoices end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43033 43034 43035 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43033 def update!(**args) @invoices = args[:invoices] if args.key?(:invoices) end |