Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListPlannableProductsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListPlannableProductsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A response with all available products.
Instance Attribute Summary collapse
-
#product_metadata ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesProductMetadata>
The list of products available for planning and related targeting metadata.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListPlannableProductsResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesListPlannableProductsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListPlannableProductsResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesListPlannableProductsResponse.
43828 43829 43830 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43828 def initialize(**args) update!(**args) end |
Instance Attribute Details
#product_metadata ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesProductMetadata>
The list of products available for planning and related targeting metadata.
Corresponds to the JSON property productMetadata
43826 43827 43828 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43826 def @product_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43833 43834 43835 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43833 def update!(**args) @product_metadata = args[:product_metadata] if args.key?(:product_metadata) end |