Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListPlannableUserInterestsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ReachPlanService.ListPlannableUserInterests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListPlannableUserInterestsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesListPlannableUserInterestsRequest.



43948
43949
43950
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customer_idString

Required. The ID of the customer. Corresponds to the JSON property customerId

Returns:

  • (String)


43917
43918
43919
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43917

def customer_id
  @customer_id
end

#name_queryString

A filter by user interest name. If set, only user interests with a name containing the literal string (case insensitive) in the filter will be returned. Maximum length is 200 characters. Corresponds to the JSON property nameQuery

Returns:

  • (String)


43924
43925
43926
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43924

def name_query
  @name_query
end

#path_queryString

A filter by user interest path. If set, only user interests with a path containing the literal string (case insensitive) in the filter will be returned. Maximum length is 200 characters. Corresponds to the JSON property pathQuery

Returns:

  • (String)


43931
43932
43933
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43931

def path_query
  @path_query
end

#reach_application_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo

Additional information about the application/tool issuing the request. This field is only used by ContentCreatorInsightsService, AudienceInsightsService, and ReachPlanService APIs. Corresponds to the JSON property reachApplicationInfo



43938
43939
43940
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43938

def reach_application_info
  @reach_application_info
end

#user_interest_taxonomy_typesArray<String>

Optional. A filter by user interest type. If set, only user interests with a type listed in the filter will be returned. If not set, user interests of all supported types will be returned. Supported user interest types are AFFINITY and IN_MARKET. Each type must be specified at most once. Corresponds to the JSON property userInterestTaxonomyTypes

Returns:

  • (Array<String>)


43946
43947
43948
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43946

def user_interest_taxonomy_types
  @user_interest_taxonomy_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43953
43954
43955
43956
43957
43958
43959
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43953

def update!(**args)
  @customer_id = args[:customer_id] if args.key?(:customer_id)
  @name_query = args[:name_query] if args.key?(:name_query)
  @path_query = args[:path_query] if args.key?(:path_query)
  @reach_application_info = args[:reach_application_info] if args.key?(:reach_application_info)
  @user_interest_taxonomy_types = args[:user_interest_taxonomy_types] if args.key?(:user_interest_taxonomy_types)
end