Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesManualCpcBiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Manual CPC Bidding Strategy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesManualCpcBiddingStrategy

Returns a new instance of GoogleAdsSearchads360V23ServicesManualCpcBiddingStrategy.



44051
44052
44053
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44051

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#daily_budget_microsFixnum

Campaign level budget in micros. If set, a minimum value is enforced for the local currency used in the campaign. An error will occur showing the minimum value if this field is set too low. Corresponds to the JSON property dailyBudgetMicros

Returns:

  • (Fixnum)


44043
44044
44045
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44043

def daily_budget_micros
  @daily_budget_micros
end

#max_cpc_bid_microsFixnum

Required. A bid in micros to be applied to ad groups within the campaign for a manual CPC bidding strategy. Corresponds to the JSON property maxCpcBidMicros

Returns:

  • (Fixnum)


44049
44050
44051
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44049

def max_cpc_bid_micros
  @max_cpc_bid_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44056
44057
44058
44059
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44056

def update!(**args)
  @daily_budget_micros = args[:daily_budget_micros] if args.key?(:daily_budget_micros)
  @max_cpc_bid_micros = args[:max_cpc_bid_micros] if args.key?(:max_cpc_bid_micros)
end