Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMoveManagerLinkRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomerManagerLinkService.MoveManagerLink.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMoveManagerLinkRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMoveManagerLinkRequest.



44106
44107
44108
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44106

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_managerString

Required. The resource name of the new manager customer that the client wants to move to. Customer resource names have the format: "customers/customer_id" Corresponds to the JSON property newManager

Returns:

  • (String)


44090
44091
44092
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44090

def new_manager
  @new_manager
end

Required. The resource name of the previous CustomerManagerLink. The resource name has the form: customers/customer_id/customerManagerLinks/ manager_customer_id~manager_link_id` Corresponds to the JSON propertypreviousCustomerManagerLink`

Returns:

  • (String)


44097
44098
44099
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44097

def previous_customer_manager_link
  @previous_customer_manager_link
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


44103
44104
44105
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44103

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44111
44112
44113
44114
44115
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44111

def update!(**args)
  @new_manager = args[:new_manager] if args.key?(:new_manager)
  @previous_customer_manager_link = args[:previous_customer_manager_link] if args.key?(:previous_customer_manager_link)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end