Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountBudgetProposalRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountBudgetProposalRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AccountBudgetProposalService.MutateAccountBudgetProposal.
Instance Attribute Summary collapse
-
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAccountBudgetProposalOperation
A single operation to propose the creation of a new account-level budget or edit/end/remove an existing one.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAccountBudgetProposalRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAccountBudgetProposalRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAccountBudgetProposalRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAccountBudgetProposalRequest.
44155 44156 44157 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44155 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAccountBudgetProposalOperation
A single operation to propose the creation of a new account-level budget or
edit/end/remove an existing one.
Corresponds to the JSON property operation
44146 44147 44148 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44146 def operation @operation end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
44152 44153 44154 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44152 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44160 44161 44162 44163 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44160 def update!(**args) @operation = args[:operation] if args.key?(:operation) @validate_only = args[:validate_only] if args.key?(:validate_only) end |