Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdLabelsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for an ad group ad labels mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupAdLabelsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupAdLabelsResponse.



44435
44436
44437
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44435

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



44428
44429
44430
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44428

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdLabelResult>

All results for the mutate. Corresponds to the JSON property results



44433
44434
44435
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44433

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44440
44441
44442
44443
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44440

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end