Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAssetResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAssetResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the ad group asset mutate.
Instance Attribute Summary collapse
-
#ad_group_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAsset
A link between an ad group and an asset.
-
#resource_name ⇒ String
Returned for successful operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupAssetResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupAssetResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupAssetResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupAssetResult.
43793 43794 43795 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43793 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAsset
A link between an ad group and an asset.
Corresponds to the JSON property adGroupAsset
43786 43787 43788 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43786 def ad_group_asset @ad_group_asset end |
#resource_name ⇒ String
Returned for successful operations.
Corresponds to the JSON property resourceName
43791 43792 43793 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43791 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43798 43799 43800 43801 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43798 def update!(**args) @ad_group_asset = args[:ad_group_asset] if args.key?(:ad_group_asset) @resource_name = args[:resource_name] if args.key?(:resource_name) end |