Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAssetSetResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The result for the ad group asset set mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupAssetSetResult

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupAssetSetResult.



44584
44585
44586
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_asset_setGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAssetSet

AdGroupAssetSet is the linkage between an ad group and an asset set. Creating an AdGroupAssetSet links an asset set with an ad group. Corresponds to the JSON property adGroupAssetSet



44577
44578
44579
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44577

def ad_group_asset_set
  @ad_group_asset_set
end

#resource_nameString

Returned for successful operations. Corresponds to the JSON property resourceName

Returns:

  • (String)


44582
44583
44584
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44582

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44589
44590
44591
44592
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44589

def update!(**args)
  @ad_group_asset_set = args[:ad_group_asset_set] if args.key?(:ad_group_asset_set)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end