Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AdGroupLabelService.MutateAdGroupLabels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupLabelsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupLabelsRequest.



45266
45267
45268
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupLabelOperation>

Required. The list of operations to perform on ad group labels. Corresponds to the JSON property operations



45249
45250
45251
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45249

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


45256
45257
45258
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45256

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


45263
45264
45265
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45263

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45271
45272
45273
45274
45275
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45271

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end