Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdParametersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for an ad parameter mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdParametersResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdParametersResponse.



45497
45498
45499
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



45490
45491
45492
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45490

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdParameterResult>

All results for the mutate. Corresponds to the JSON property results



45495
45496
45497
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45495

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45502
45503
45504
45505
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45502

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end