Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AssetGroupService.MutateAssetGroups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetGroupsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAssetGroupsRequest.



45909
45910
45911
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45909

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupOperation>

Required. The list of operations to perform on individual asset groups. Corresponds to the JSON property operations



45900
45901
45902
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45900

def operations
  @operations
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


45906
45907
45908
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45906

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45914
45915
45916
45917
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45914

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end