Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the asset set asset mutate.
Instance Attribute Summary collapse
-
#asset_set_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset
AssetSetAsset is the link between an asset and an asset set.
-
#resource_name ⇒ String
Returned for successful operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult.
45993 45994 45995 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45993 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_set_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset
AssetSetAsset is the link between an asset and an asset set. Adding an
AssetSetAsset links an asset with an asset set.
Corresponds to the JSON property assetSetAsset
45986 45987 45988 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45986 def asset_set_asset @asset_set_asset end |
#resource_name ⇒ String
Returned for successful operations.
Corresponds to the JSON property resourceName
45991 45992 45993 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45991 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45998 45999 46000 46001 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45998 def update!(**args) @asset_set_asset = args[:asset_set_asset] if args.key?(:asset_set_asset) @resource_name = args[:resource_name] if args.key?(:resource_name) end |