Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetAssetsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AssetSetAssetService.MutateAssetSetAssets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetSetAssetsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAssetSetAssetsRequest.



46034
46035
46036
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46034

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetAssetOperation>

Required. The list of operations to perform on individual asset set assets. Corresponds to the JSON property operations



46011
46012
46013
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46011

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


46018
46019
46020
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46018

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


46025
46026
46027
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46025

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


46031
46032
46033
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46031

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46039
46040
46041
46042
46043
46044
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46039

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end