Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AssetService.MutateAssets

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAssetsRequest.



46206
46207
46208
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetOperation>

Required. The list of operations to perform on individual assets. Corresponds to the JSON property operations



46183
46184
46185
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46183

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


46190
46191
46192
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46190

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


46197
46198
46199
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46197

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


46203
46204
46205
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46203

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46211
46212
46213
46214
46215
46216
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46211

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end