Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for an asset mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAssetsResponse.



46238
46239
46240
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46238

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



46231
46232
46233
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46231

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetResult>

All results for the mutate. Corresponds to the JSON property results



46236
46237
46238
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46236

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46243
46244
46245
46246
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46243

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end