Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingStrategiesRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingStrategiesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for BiddingStrategyService.MutateBiddingStrategies.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingStrategyOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateBiddingStrategiesRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateBiddingStrategiesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateBiddingStrategiesRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateBiddingStrategiesRequest.
46639 46640 46641 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46639 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingStrategyOperation>
Required. The list of operations to perform on individual bidding strategies.
Corresponds to the JSON property operations
46616 46617 46618 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46616 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
46623 46624 46625 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46623 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
46630 46631 46632 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46630 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
46636 46637 46638 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46636 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46644 46645 46646 46647 46648 46649 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46644 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |