Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBillingSetupRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBillingSetupRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for billing setup mutate operations.
Instance Attribute Summary collapse
-
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBillingSetupOperation
A single operation on a billing setup, which describes the cancellation of an existing billing setup.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateBillingSetupRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateBillingSetupRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateBillingSetupRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateBillingSetupRequest.
46645 46646 46647 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46645 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBillingSetupOperation
A single operation on a billing setup, which describes the cancellation of an
existing billing setup.
Corresponds to the JSON property operation
46643 46644 46645 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46643 def operation @operation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46650 46651 46652 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46650 def update!(**args) @operation = args[:operation] if args.key?(:operation) end |