Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBidModifiersRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBidModifiersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CampaignBidModifierService.MutateCampaignBidModifiers.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignBidModifiersRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCampaignBidModifiersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignBidModifiersRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignBidModifiersRequest.
47018 47019 47020 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47018 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation>
Required. The list of operations to perform on individual campaign bid
modifiers.
Corresponds to the JSON property operations
46995 46996 46997 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46995 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
47002 47003 47004 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47002 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
47009 47010 47011 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47009 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
47015 47016 47017 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47015 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47023 47024 47025 47026 47027 47028 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47023 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |