Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CampaignConversionGoalService. MutateCampaignConversionGoals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalsRequest.



47196
47197
47198
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47196

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation>

Required. The list of operations to perform on individual campaign conversion goal. Corresponds to the JSON property operations



47187
47188
47189
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47187

def operations
  @operations
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


47193
47194
47195
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47193

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47201
47202
47203
47204
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47201

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end