Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCustomizersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CampaignCustomizerService.MutateCampaignCustomizers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignCustomizersRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignCustomizersRequest.



47380
47381
47382
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCustomizerOperation>

Required. The list of operations to perform on individual campaign customizers. Corresponds to the JSON property operations



47357
47358
47359
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47357

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


47364
47365
47366
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47364

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


47371
47372
47373
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47371

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


47377
47378
47379
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47377

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47385
47386
47387
47388
47389
47390
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47385

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end