Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignDraftsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CampaignDraftService.MutateCampaignDrafts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignDraftsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignDraftsRequest.



47478
47479
47480
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignDraftOperation>

Required. The list of operations to perform on individual campaign drafts. Corresponds to the JSON property operations



47455
47456
47457
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47455

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


47462
47463
47464
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47462

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


47469
47470
47471
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47469

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


47475
47476
47477
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47475

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47483
47484
47485
47486
47487
47488
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47483

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end