Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignSharedSetResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignSharedSetResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the campaign shared set mutate.
Instance Attribute Summary collapse
-
#campaign_shared_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSharedSet
CampaignSharedSets are used for managing the shared sets associated with a campaign.
-
#resource_name ⇒ String
Returned for successful operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignSharedSetResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCampaignSharedSetResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignSharedSetResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignSharedSetResult.
47829 47830 47831 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47829 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign_shared_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSharedSet
CampaignSharedSets are used for managing the shared sets associated with a
campaign.
Corresponds to the JSON property campaignSharedSet
47822 47823 47824 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47822 def campaign_shared_set @campaign_shared_set end |
#resource_name ⇒ String
Returned for successful operations.
Corresponds to the JSON property resourceName
47827 47828 47829 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47827 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47834 47835 47836 47837 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47834 def update!(**args) @campaign_shared_set = args[:campaign_shared_set] if args.key?(:campaign_shared_set) @resource_name = args[:resource_name] if args.key?(:resource_name) end |