Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ConversionGoalCampaignConfigService. MutateConversionGoalCampaignConfigs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigsRequest.



48236
48237
48238
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionGoalCampaignConfigOperation>

Required. The list of operations to perform on individual conversion goal campaign config. Corresponds to the JSON property operations



48221
48222
48223
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48221

def operations
  @operations
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


48227
48228
48229
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48227

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


48233
48234
48235
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48233

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48241
48242
48243
48244
48245
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48241

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end