Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The result for the conversion value rule set mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult.



48308
48309
48310
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversion_value_rule_setGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleSet

A conversion value rule set is a collection of conversion value rules that lets you adjust conversion values based on the dimensions specified in the dimensions field. Corresponds to the JSON property conversionValueRuleSet



48301
48302
48303
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48301

def conversion_value_rule_set
  @conversion_value_rule_set
end

#resource_nameString

Returned for successful operations. Corresponds to the JSON property resourceName

Returns:

  • (String)


48306
48307
48308
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48306

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48313
48314
48315
48316
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48313

def update!(**args)
  @conversion_value_rule_set = args[:conversion_value_rule_set] if args.key?(:conversion_value_rule_set)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end