Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for ConversionValueRuleSetService. MutateConversionValueRuleSets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetsResponse.



48384
48385
48386
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48384

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



48377
48378
48379
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48377

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult>

All results for the mutate. Corresponds to the JSON property results



48382
48383
48384
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48382

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48389
48390
48391
48392
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48389

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end