Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRulesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ConversionValueRuleService.MutateConversionValueRules.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionValueRulesRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateConversionValueRulesRequest.



48354
48355
48356
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleOperation>

Required. The list of operations to perform on individual conversion value rules. Corresponds to the JSON property operations



48331
48332
48333
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48331

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


48338
48339
48340
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48338

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


48345
48346
48347
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48345

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


48351
48352
48353
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48351

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48359
48360
48361
48362
48363
48364
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48359

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end