Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the custom conversion goal mutate.
Instance Attribute Summary collapse
-
#custom_conversion_goal ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomConversionGoal
Custom conversion goal that can make arbitrary conversion actions biddable.
-
#resource_name ⇒ String
Returned for successful operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult.
48548 48549 48550 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48548 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_conversion_goal ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomConversionGoal
Custom conversion goal that can make arbitrary conversion actions biddable.
Corresponds to the JSON property customConversionGoal
48541 48542 48543 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48541 def custom_conversion_goal @custom_conversion_goal end |
#resource_name ⇒ String
Returned for successful operations.
Corresponds to the JSON property resourceName
48546 48547 48548 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48546 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48553 48554 48555 48556 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48553 def update!(**args) @custom_conversion_goal = args[:custom_conversion_goal] if args.key?(:custom_conversion_goal) @resource_name = args[:resource_name] if args.key?(:resource_name) end |