Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomConversionGoalService.MutateCustomConversionGoals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalsRequest.



47817
47818
47819
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomConversionGoalOperation>

Required. The list of operations to perform on individual custom conversion goal. Corresponds to the JSON property operations



47802
47803
47804
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47802

def operations
  @operations
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


47808
47809
47810
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47808

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


47814
47815
47816
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47814

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47822
47823
47824
47825
47826
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47822

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end