Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the customer asset set mutate.
Instance Attribute Summary collapse
-
#customer_asset_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAssetSet
CustomerAssetSet is the linkage between a customer and an asset set.
-
#resource_name ⇒ String
Returned for successful operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetResult.
47953 47954 47955 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47953 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer_asset_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAssetSet
CustomerAssetSet is the linkage between a customer and an asset set. Adding a
CustomerAssetSet links an asset set with a customer.
Corresponds to the JSON property customerAssetSet
47946 47947 47948 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47946 def customer_asset_set @customer_asset_set end |
#resource_name ⇒ String
Returned for successful operations.
Corresponds to the JSON property resourceName
47951 47952 47953 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47951 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47958 47959 47960 47961 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47958 def update!(**args) @customer_asset_set = args[:customer_asset_set] if args.key?(:customer_asset_set) @resource_name = args[:resource_name] if args.key?(:resource_name) end |