Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomerAssetSetService.MutateCustomerAssetSets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetsRequest.



48759
48760
48761
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48759

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetSetOperation>

Required. The list of operations to perform on individual customer asset sets. Corresponds to the JSON property operations



48736
48737
48738
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48736

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


48743
48744
48745
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48743

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


48750
48751
48752
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48750

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


48756
48757
48758
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48756

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48764
48765
48766
48767
48768
48769
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48764

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end