Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CustomerClientLinkService.MutateCustomerClientLink.
Instance Attribute Summary collapse
-
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation
A single operation (create, update) on a CustomerClientLink.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkRequest.
48891 48892 48893 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48891 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation
A single operation (create, update) on a CustomerClientLink.
Corresponds to the JSON property operation
48882 48883 48884 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48882 def operation @operation end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
48888 48889 48890 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48888 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48896 48897 48898 48899 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48896 def update!(**args) @operation = args[:operation] if args.key?(:operation) @validate_only = args[:validate_only] if args.key?(:validate_only) end |