Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for a CustomerClientLink mutate.
Instance Attribute Summary collapse
-
#result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkResult
The result for a single customer client link mutate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkResponse.
48839 48840 48841 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkResult
The result for a single customer client link mutate.
Corresponds to the JSON property result
48837 48838 48839 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48837 def result @result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48844 48845 48846 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48844 def update!(**args) @result = args[:result] if args.key?(:result) end |