Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CustomerCustomizerService.MutateCustomerCustomizers.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest.
49063 49064 49065 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49063 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation>
Required. The list of operations to perform on individual customer customizers.
Corresponds to the JSON property operations
49040 49041 49042 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49040 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
49047 49048 49049 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49047 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
49054 49055 49056 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49054 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
49060 49061 49062 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49060 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49068 49069 49070 49071 49072 49073 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49068 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |