Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomerLabelService.MutateCustomerLabels. A single MutateCustomerLabelsRequest can only modify labels for the single customer account specified in the request. To apply a label to multiple different accounts, separate MutateCustomerLabelsRequest calls must be made.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerLabelsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerLabelsRequest.



49152
49153
49154
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49152

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerLabelOperation>

Required. The list of operations to perform on customer-label relationships. Corresponds to the JSON property operations



49135
49136
49137
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49135

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


49142
49143
49144
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49142

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


49149
49150
49151
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49149

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49157
49158
49159
49160
49161
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49157

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end