Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerManagerLinkResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerManagerLinkResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for a CustomerManagerLink mutate.
Instance Attribute Summary collapse
-
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerManagerLinkResult>
A result that identifies the resource affected by the mutate request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerManagerLinkResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomerManagerLinkResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerManagerLinkResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerManagerLinkResponse.
49159 49160 49161 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49159 def initialize(**args) update!(**args) end |
Instance Attribute Details
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerManagerLinkResult>
A result that identifies the resource affected by the mutate request.
Corresponds to the JSON property results
49157 49158 49159 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49157 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49164 49165 49166 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49164 def update!(**args) @results = args[:results] if args.key?(:results) end |