Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerNegativeCriteriaResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerNegativeCriteriaResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the criterion mutate.
Instance Attribute Summary collapse
-
#customer_negative_criterion ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion
A negative criterion for exclusions at the customer level.
-
#resource_name ⇒ String
Returned for successful operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerNegativeCriteriaResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomerNegativeCriteriaResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerNegativeCriteriaResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerNegativeCriteriaResult.
49276 49277 49278 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49276 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer_negative_criterion ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion
A negative criterion for exclusions at the customer level.
Corresponds to the JSON property customerNegativeCriterion
49269 49270 49271 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49269 def customer_negative_criterion @customer_negative_criterion end |
#resource_name ⇒ String
Returned for successful operations.
Corresponds to the JSON property resourceName
49274 49275 49276 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49274 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49281 49282 49283 49284 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49281 def update!(**args) @customer_negative_criterion = args[:customer_negative_criterion] if args.key?(:customer_negative_criterion) @resource_name = args[:resource_name] if args.key?(:resource_name) end |