Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomerService.MutateCustomer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerRequest.



49381
49382
49383
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerOperation

A single update on a customer. Corresponds to the JSON property operation



49366
49367
49368
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49366

def operation
  @operation
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


49372
49373
49374
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49372

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


49378
49379
49380
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49378

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49386
49387
49388
49389
49390
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49386

def update!(**args)
  @operation = args[:operation] if args.key?(:operation)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end