Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomizerAttributeResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The result for the customizer attribute mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomizerAttributeResult

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomizerAttributeResult.



49588
49589
49590
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49588

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customizer_attributeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomizerAttribute

A customizer attribute. Use CustomerCustomizer, CampaignCustomizer, AdGroupCustomizer, or AdGroupCriterionCustomizer to associate a customizer attribute and set its value at the customer, campaign, ad group, or ad group criterion level, respectively. Corresponds to the JSON property customizerAttribute



49581
49582
49583
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49581

def customizer_attribute
  @customizer_attribute
end

#resource_nameString

Returned for successful operations. Corresponds to the JSON property resourceName

Returns:

  • (String)


49586
49587
49588
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49586

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49593
49594
49595
49596
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49593

def update!(**args)
  @customizer_attribute = args[:customizer_attribute] if args.key?(:customizer_attribute)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end