Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomizerAttributesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomizerAttributeService.MutateCustomizerAttributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomizerAttributesRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomizerAttributesRequest.



49702
49703
49704
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomizerAttributeOperation>

Required. The list of operations to perform on individual customizer attributes. Corresponds to the JSON property operations



49679
49680
49681
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49679

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


49686
49687
49688
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49686

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


49693
49694
49695
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49693

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


49699
49700
49701
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49699

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49707
49708
49709
49710
49711
49712
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49707

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end