Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentArmsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ExperimentArmService.MutateExperimentArms.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateExperimentArmsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateExperimentArmsRequest.



49801
49802
49803
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49801

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentArmOperation>

Required. The list of operations to perform on individual experiment arm. Corresponds to the JSON property operations



49778
49779
49780
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49778

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


49785
49786
49787
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49785

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


49792
49793
49794
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49792

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


49798
49799
49800
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49798

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49806
49807
49808
49809
49810
49811
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49806

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end