Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for KeywordPlanService.MutateKeywordPlans.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlansRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlansRequest.



50385
50386
50387
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50385

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanOperation>

Required. The list of operations to perform on individual keyword plans. Corresponds to the JSON property operations



50368
50369
50370
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50368

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


50375
50376
50377
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50375

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


50382
50383
50384
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50382

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50390
50391
50392
50393
50394
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50390

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end