Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperationResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperationResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for the resource mutate.
Instance Attribute Summary collapse
-
#ad_group_ad_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdLabelResult
The result for an ad group ad label mutate.
-
#ad_group_ad_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdResult
The result for the ad mutate.
-
#ad_group_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAssetResult
The result for the ad group asset mutate.
-
#ad_group_bid_modifier_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupBidModifierResult
The result for the criterion mutate.
-
#ad_group_criterion_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizerResult
The result for the ad group criterion customizer mutate.
-
#ad_group_criterion_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelResult
The result for an ad group criterion label mutate.
-
#ad_group_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionResult
The result for the criterion mutate.
-
#ad_group_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizerResult
The result for the ad group customizer mutate.
-
#ad_group_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupLabelResult
The result for an ad group label mutate.
-
#ad_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupResult
The result for the ad group mutate.
-
#ad_parameter_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdParameterResult
The result for the ad parameter mutate.
-
#ad_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdResult
The result for the ad mutate.
-
#asset_group_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupAssetResult
The result for the asset group asset mutate.
-
#asset_group_listing_group_filter_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupListingGroupFilterResult
The result for the asset group listing group filter mutate.
-
#asset_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupResult
The result for the asset group mutate.
-
#asset_group_signal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupSignalResult
The result for the asset group signal mutate.
-
#asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetResult
The result for the asset mutate.
-
#asset_set_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult
The result for the asset set asset mutate.
-
#asset_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetResult
The result for the asset set mutate.
-
#audience_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAudienceResult
The result for the audience mutate.
-
#bidding_data_exclusion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingDataExclusionsResult
The result for the data exclusion mutate.
-
#bidding_seasonality_adjustment_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingSeasonalityAdjustmentsResult
The result for the seasonality adjustment mutate.
-
#bidding_strategy_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingStrategyResult
The result for the bidding strategy mutate.
-
#campaign_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetResult
The result for the campaign asset mutate.
-
#campaign_asset_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetResult
The result for the campaign asset set mutate.
-
#campaign_bid_modifier_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBidModifierResult
The result for the criterion mutate.
-
#campaign_budget_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBudgetResult
The result for the campaign budget mutate.
-
#campaign_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalResult
The result for the campaign conversion goal mutate.
-
#campaign_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCriterionResult
The result for the criterion mutate.
-
#campaign_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCustomizerResult
The result for the campaign customizer mutate.
-
#campaign_draft_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignDraftResult
The result for the campaign draft mutate.
-
#campaign_goal_config_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignGoalConfigResult
The result for the campaign goal config mutate.
-
#campaign_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignGroupResult
The result for the campaign group mutate.
-
#campaign_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignLabelResult
The result for a campaign label mutate.
-
#campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignResult
The result for the campaign mutate.
-
#campaign_shared_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignSharedSetResult
The result for the campaign shared set mutate.
-
#conversion_action_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionActionResult
The result for the conversion action mutate.
-
#conversion_custom_variable_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionCustomVariableResult
The result for the conversion custom variable mutate.
-
#conversion_goal_campaign_config_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigResult
The result for the conversion goal campaign config mutate.
-
#conversion_value_rule_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleResult
The result for the conversion value rule mutate.
-
#conversion_value_rule_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult
The result for the conversion value rule set mutate.
-
#custom_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult
The result for the custom conversion goal mutate.
-
#customer_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerAssetResult
The result for the customer asset mutate.
-
#customer_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerConversionGoalResult
The result for the customer conversion goal mutate.
-
#customer_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerCustomizerResult
The result for the customizer attribute mutate.
-
#customer_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerLabelResult
The result for a customer label mutate.
-
#customer_negative_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerNegativeCriteriaResult
The result for the criterion mutate.
-
#customer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerResult
The result for the customer mutate.
-
#customizer_attribute_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomizerAttributeResult
The result for the customizer attribute mutate.
-
#experiment_arm_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentArmResult
The result for the experiment arm mutate.
-
#experiment_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentResult
The result for the campaign experiment mutate.
-
#keyword_plan_ad_group_keyword_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordResult
The result for the Keyword Plan ad group keyword mutate.
-
#keyword_plan_ad_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupResult
The result for the Keyword Plan ad group mutate.
-
#keyword_plan_campaign_keyword_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignKeywordResult
The result for the Keyword Plan campaign keyword mutate.
-
#keyword_plan_campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignResult
The result for the Keyword Plan campaign mutate.
-
#keyword_plan_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansResult
The result for the keyword plan mutate.
-
#label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateLabelResult
The result for a label mutate.
-
#recommendation_subscription_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResult
Result message for RecommendationSubscriptionService.
-
#remarketing_action_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRemarketingActionResult
The result for the remarketing action mutate.
-
#search_ads360_campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSearchAds360CampaignResult
The result for the Search Ads 360 campaign mutate.
-
#shared_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedCriterionResult
The result for the shared criterion mutate.
-
#shared_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedSetResult
The result for the shared set mutate.
-
#smart_campaign_setting_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSmartCampaignSettingResult
The result for the Smart campaign setting mutate.
-
#user_list_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateUserListResult
The result for the user list mutate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateOperationResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateOperationResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateOperationResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateOperationResponse.
51270 51271 51272 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51270 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_ad_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdLabelResult
The result for an ad group ad label mutate.
Corresponds to the JSON property adGroupAdLabelResult
50952 50953 50954 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50952 def ad_group_ad_label_result @ad_group_ad_label_result end |
#ad_group_ad_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdResult
The result for the ad mutate.
Corresponds to the JSON property adGroupAdResult
50957 50958 50959 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50957 def ad_group_ad_result @ad_group_ad_result end |
#ad_group_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAssetResult
The result for the ad group asset mutate.
Corresponds to the JSON property adGroupAssetResult
50962 50963 50964 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50962 def ad_group_asset_result @ad_group_asset_result end |
#ad_group_bid_modifier_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupBidModifierResult
The result for the criterion mutate.
Corresponds to the JSON property adGroupBidModifierResult
50967 50968 50969 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50967 def ad_group_bid_modifier_result @ad_group_bid_modifier_result end |
#ad_group_criterion_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizerResult
The result for the ad group criterion customizer mutate.
Corresponds to the JSON property adGroupCriterionCustomizerResult
50972 50973 50974 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50972 def ad_group_criterion_customizer_result @ad_group_criterion_customizer_result end |
#ad_group_criterion_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelResult
The result for an ad group criterion label mutate.
Corresponds to the JSON property adGroupCriterionLabelResult
50977 50978 50979 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50977 def ad_group_criterion_label_result @ad_group_criterion_label_result end |
#ad_group_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionResult
The result for the criterion mutate.
Corresponds to the JSON property adGroupCriterionResult
50982 50983 50984 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50982 def ad_group_criterion_result @ad_group_criterion_result end |
#ad_group_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizerResult
The result for the ad group customizer mutate.
Corresponds to the JSON property adGroupCustomizerResult
50987 50988 50989 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50987 def ad_group_customizer_result @ad_group_customizer_result end |
#ad_group_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupLabelResult
The result for an ad group label mutate.
Corresponds to the JSON property adGroupLabelResult
50992 50993 50994 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50992 def ad_group_label_result @ad_group_label_result end |
#ad_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupResult
The result for the ad group mutate.
Corresponds to the JSON property adGroupResult
50997 50998 50999 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50997 def ad_group_result @ad_group_result end |
#ad_parameter_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdParameterResult
The result for the ad parameter mutate.
Corresponds to the JSON property adParameterResult
51002 51003 51004 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51002 def ad_parameter_result @ad_parameter_result end |
#ad_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdResult
The result for the ad mutate.
Corresponds to the JSON property adResult
51007 51008 51009 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51007 def ad_result @ad_result end |
#asset_group_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupAssetResult
The result for the asset group asset mutate.
Corresponds to the JSON property assetGroupAssetResult
51012 51013 51014 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51012 def asset_group_asset_result @asset_group_asset_result end |
#asset_group_listing_group_filter_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupListingGroupFilterResult
The result for the asset group listing group filter mutate.
Corresponds to the JSON property assetGroupListingGroupFilterResult
51017 51018 51019 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51017 def asset_group_listing_group_filter_result @asset_group_listing_group_filter_result end |
#asset_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupResult
The result for the asset group mutate.
Corresponds to the JSON property assetGroupResult
51022 51023 51024 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51022 def asset_group_result @asset_group_result end |
#asset_group_signal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupSignalResult
The result for the asset group signal mutate.
Corresponds to the JSON property assetGroupSignalResult
51027 51028 51029 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51027 def asset_group_signal_result @asset_group_signal_result end |
#asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetResult
The result for the asset mutate.
Corresponds to the JSON property assetResult
51032 51033 51034 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51032 def asset_result @asset_result end |
#asset_set_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult
The result for the asset set asset mutate.
Corresponds to the JSON property assetSetAssetResult
51037 51038 51039 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51037 def asset_set_asset_result @asset_set_asset_result end |
#asset_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetResult
The result for the asset set mutate.
Corresponds to the JSON property assetSetResult
51042 51043 51044 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51042 def asset_set_result @asset_set_result end |
#audience_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAudienceResult
The result for the audience mutate.
Corresponds to the JSON property audienceResult
51047 51048 51049 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51047 def audience_result @audience_result end |
#bidding_data_exclusion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingDataExclusionsResult
The result for the data exclusion mutate.
Corresponds to the JSON property biddingDataExclusionResult
51052 51053 51054 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51052 def bidding_data_exclusion_result @bidding_data_exclusion_result end |
#bidding_seasonality_adjustment_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingSeasonalityAdjustmentsResult
The result for the seasonality adjustment mutate.
Corresponds to the JSON property biddingSeasonalityAdjustmentResult
51057 51058 51059 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51057 def bidding_seasonality_adjustment_result @bidding_seasonality_adjustment_result end |
#bidding_strategy_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingStrategyResult
The result for the bidding strategy mutate.
Corresponds to the JSON property biddingStrategyResult
51062 51063 51064 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51062 def bidding_strategy_result @bidding_strategy_result end |
#campaign_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetResult
The result for the campaign asset mutate.
Corresponds to the JSON property campaignAssetResult
51067 51068 51069 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51067 def campaign_asset_result @campaign_asset_result end |
#campaign_asset_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetResult
The result for the campaign asset set mutate.
Corresponds to the JSON property campaignAssetSetResult
51072 51073 51074 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51072 def campaign_asset_set_result @campaign_asset_set_result end |
#campaign_bid_modifier_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBidModifierResult
The result for the criterion mutate.
Corresponds to the JSON property campaignBidModifierResult
51077 51078 51079 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51077 def campaign_bid_modifier_result @campaign_bid_modifier_result end |
#campaign_budget_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBudgetResult
The result for the campaign budget mutate.
Corresponds to the JSON property campaignBudgetResult
51082 51083 51084 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51082 def campaign_budget_result @campaign_budget_result end |
#campaign_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalResult
The result for the campaign conversion goal mutate.
Corresponds to the JSON property campaignConversionGoalResult
51087 51088 51089 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51087 def campaign_conversion_goal_result @campaign_conversion_goal_result end |
#campaign_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCriterionResult
The result for the criterion mutate.
Corresponds to the JSON property campaignCriterionResult
51092 51093 51094 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51092 def campaign_criterion_result @campaign_criterion_result end |
#campaign_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCustomizerResult
The result for the campaign customizer mutate.
Corresponds to the JSON property campaignCustomizerResult
51097 51098 51099 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51097 def campaign_customizer_result @campaign_customizer_result end |
#campaign_draft_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignDraftResult
The result for the campaign draft mutate.
Corresponds to the JSON property campaignDraftResult
51102 51103 51104 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51102 def campaign_draft_result @campaign_draft_result end |
#campaign_goal_config_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignGoalConfigResult
The result for the campaign goal config mutate.
Corresponds to the JSON property campaignGoalConfigResult
51107 51108 51109 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51107 def campaign_goal_config_result @campaign_goal_config_result end |
#campaign_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignGroupResult
The result for the campaign group mutate.
Corresponds to the JSON property campaignGroupResult
51112 51113 51114 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51112 def campaign_group_result @campaign_group_result end |
#campaign_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignLabelResult
The result for a campaign label mutate.
Corresponds to the JSON property campaignLabelResult
51117 51118 51119 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51117 def campaign_label_result @campaign_label_result end |
#campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignResult
The result for the campaign mutate.
Corresponds to the JSON property campaignResult
51122 51123 51124 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51122 def campaign_result @campaign_result end |
#campaign_shared_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignSharedSetResult
The result for the campaign shared set mutate.
Corresponds to the JSON property campaignSharedSetResult
51127 51128 51129 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51127 def campaign_shared_set_result @campaign_shared_set_result end |
#conversion_action_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionActionResult
The result for the conversion action mutate.
Corresponds to the JSON property conversionActionResult
51132 51133 51134 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51132 def conversion_action_result @conversion_action_result end |
#conversion_custom_variable_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionCustomVariableResult
The result for the conversion custom variable mutate.
Corresponds to the JSON property conversionCustomVariableResult
51137 51138 51139 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51137 def conversion_custom_variable_result @conversion_custom_variable_result end |
#conversion_goal_campaign_config_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigResult
The result for the conversion goal campaign config mutate.
Corresponds to the JSON property conversionGoalCampaignConfigResult
51142 51143 51144 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51142 def conversion_goal_campaign_config_result @conversion_goal_campaign_config_result end |
#conversion_value_rule_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleResult
The result for the conversion value rule mutate.
Corresponds to the JSON property conversionValueRuleResult
51147 51148 51149 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51147 def conversion_value_rule_result @conversion_value_rule_result end |
#conversion_value_rule_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult
The result for the conversion value rule set mutate.
Corresponds to the JSON property conversionValueRuleSetResult
51152 51153 51154 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51152 def conversion_value_rule_set_result @conversion_value_rule_set_result end |
#custom_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult
The result for the custom conversion goal mutate.
Corresponds to the JSON property customConversionGoalResult
51157 51158 51159 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51157 def custom_conversion_goal_result @custom_conversion_goal_result end |
#customer_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerAssetResult
The result for the customer asset mutate.
Corresponds to the JSON property customerAssetResult
51162 51163 51164 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51162 def customer_asset_result @customer_asset_result end |
#customer_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerConversionGoalResult
The result for the customer conversion goal mutate.
Corresponds to the JSON property customerConversionGoalResult
51167 51168 51169 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51167 def customer_conversion_goal_result @customer_conversion_goal_result end |
#customer_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerCustomizerResult
The result for the customizer attribute mutate.
Corresponds to the JSON property customerCustomizerResult
51172 51173 51174 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51172 def customer_customizer_result @customer_customizer_result end |
#customer_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerLabelResult
The result for a customer label mutate.
Corresponds to the JSON property customerLabelResult
51177 51178 51179 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51177 def customer_label_result @customer_label_result end |
#customer_negative_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerNegativeCriteriaResult
The result for the criterion mutate.
Corresponds to the JSON property customerNegativeCriterionResult
51182 51183 51184 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51182 def customer_negative_criterion_result @customer_negative_criterion_result end |
#customer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerResult
The result for the customer mutate.
Corresponds to the JSON property customerResult
51187 51188 51189 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51187 def customer_result @customer_result end |
#customizer_attribute_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomizerAttributeResult
The result for the customizer attribute mutate.
Corresponds to the JSON property customizerAttributeResult
51192 51193 51194 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51192 def customizer_attribute_result @customizer_attribute_result end |
#experiment_arm_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentArmResult
The result for the experiment arm mutate.
Corresponds to the JSON property experimentArmResult
51197 51198 51199 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51197 def experiment_arm_result @experiment_arm_result end |
#experiment_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentResult
The result for the campaign experiment mutate.
Corresponds to the JSON property experimentResult
51202 51203 51204 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51202 def experiment_result @experiment_result end |
#keyword_plan_ad_group_keyword_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordResult
The result for the Keyword Plan ad group keyword mutate.
Corresponds to the JSON property keywordPlanAdGroupKeywordResult
51207 51208 51209 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51207 def keyword_plan_ad_group_keyword_result @keyword_plan_ad_group_keyword_result end |
#keyword_plan_ad_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupResult
The result for the Keyword Plan ad group mutate.
Corresponds to the JSON property keywordPlanAdGroupResult
51212 51213 51214 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51212 def keyword_plan_ad_group_result @keyword_plan_ad_group_result end |
#keyword_plan_campaign_keyword_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignKeywordResult
The result for the Keyword Plan campaign keyword mutate.
Corresponds to the JSON property keywordPlanCampaignKeywordResult
51217 51218 51219 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51217 def keyword_plan_campaign_keyword_result @keyword_plan_campaign_keyword_result end |
#keyword_plan_campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignResult
The result for the Keyword Plan campaign mutate.
Corresponds to the JSON property keywordPlanCampaignResult
51222 51223 51224 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51222 def keyword_plan_campaign_result @keyword_plan_campaign_result end |
#keyword_plan_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansResult
The result for the keyword plan mutate.
Corresponds to the JSON property keywordPlanResult
51227 51228 51229 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51227 def keyword_plan_result @keyword_plan_result end |
#label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateLabelResult
The result for a label mutate.
Corresponds to the JSON property labelResult
51232 51233 51234 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51232 def label_result @label_result end |
#recommendation_subscription_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResult
Result message for RecommendationSubscriptionService.
MutateRecommendationSubscription
Corresponds to the JSON property recommendationSubscriptionResult
51238 51239 51240 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51238 def recommendation_subscription_result @recommendation_subscription_result end |
#remarketing_action_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRemarketingActionResult
The result for the remarketing action mutate.
Corresponds to the JSON property remarketingActionResult
51243 51244 51245 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51243 def remarketing_action_result @remarketing_action_result end |
#search_ads360_campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSearchAds360CampaignResult
The result for the Search Ads 360 campaign mutate.
Corresponds to the JSON property searchAds360CampaignResult
51248 51249 51250 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51248 def search_ads360_campaign_result @search_ads360_campaign_result end |
#shared_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedCriterionResult
The result for the shared criterion mutate.
Corresponds to the JSON property sharedCriterionResult
51253 51254 51255 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51253 def shared_criterion_result @shared_criterion_result end |
#shared_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedSetResult
The result for the shared set mutate.
Corresponds to the JSON property sharedSetResult
51258 51259 51260 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51258 def shared_set_result @shared_set_result end |
#smart_campaign_setting_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSmartCampaignSettingResult
The result for the Smart campaign setting mutate.
Corresponds to the JSON property smartCampaignSettingResult
51263 51264 51265 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51263 def smart_campaign_setting_result @smart_campaign_setting_result end |
#user_list_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateUserListResult
The result for the user list mutate.
Corresponds to the JSON property userListResult
51268 51269 51270 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51268 def user_list_result @user_list_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51275 51276 51277 51278 51279 51280 51281 51282 51283 51284 51285 51286 51287 51288 51289 51290 51291 51292 51293 51294 51295 51296 51297 51298 51299 51300 51301 51302 51303 51304 51305 51306 51307 51308 51309 51310 51311 51312 51313 51314 51315 51316 51317 51318 51319 51320 51321 51322 51323 51324 51325 51326 51327 51328 51329 51330 51331 51332 51333 51334 51335 51336 51337 51338 51339 51340 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51275 def update!(**args) @ad_group_ad_label_result = args[:ad_group_ad_label_result] if args.key?(:ad_group_ad_label_result) @ad_group_ad_result = args[:ad_group_ad_result] if args.key?(:ad_group_ad_result) @ad_group_asset_result = args[:ad_group_asset_result] if args.key?(:ad_group_asset_result) @ad_group_bid_modifier_result = args[:ad_group_bid_modifier_result] if args.key?(:ad_group_bid_modifier_result) @ad_group_criterion_customizer_result = args[:ad_group_criterion_customizer_result] if args.key?(:ad_group_criterion_customizer_result) @ad_group_criterion_label_result = args[:ad_group_criterion_label_result] if args.key?(:ad_group_criterion_label_result) @ad_group_criterion_result = args[:ad_group_criterion_result] if args.key?(:ad_group_criterion_result) @ad_group_customizer_result = args[:ad_group_customizer_result] if args.key?(:ad_group_customizer_result) @ad_group_label_result = args[:ad_group_label_result] if args.key?(:ad_group_label_result) @ad_group_result = args[:ad_group_result] if args.key?(:ad_group_result) @ad_parameter_result = args[:ad_parameter_result] if args.key?(:ad_parameter_result) @ad_result = args[:ad_result] if args.key?(:ad_result) @asset_group_asset_result = args[:asset_group_asset_result] if args.key?(:asset_group_asset_result) @asset_group_listing_group_filter_result = args[:asset_group_listing_group_filter_result] if args.key?(:asset_group_listing_group_filter_result) @asset_group_result = args[:asset_group_result] if args.key?(:asset_group_result) @asset_group_signal_result = args[:asset_group_signal_result] if args.key?(:asset_group_signal_result) @asset_result = args[:asset_result] if args.key?(:asset_result) @asset_set_asset_result = args[:asset_set_asset_result] if args.key?(:asset_set_asset_result) @asset_set_result = args[:asset_set_result] if args.key?(:asset_set_result) @audience_result = args[:audience_result] if args.key?(:audience_result) @bidding_data_exclusion_result = args[:bidding_data_exclusion_result] if args.key?(:bidding_data_exclusion_result) @bidding_seasonality_adjustment_result = args[:bidding_seasonality_adjustment_result] if args.key?(:bidding_seasonality_adjustment_result) @bidding_strategy_result = args[:bidding_strategy_result] if args.key?(:bidding_strategy_result) @campaign_asset_result = args[:campaign_asset_result] if args.key?(:campaign_asset_result) @campaign_asset_set_result = args[:campaign_asset_set_result] if args.key?(:campaign_asset_set_result) @campaign_bid_modifier_result = args[:campaign_bid_modifier_result] if args.key?(:campaign_bid_modifier_result) @campaign_budget_result = args[:campaign_budget_result] if args.key?(:campaign_budget_result) @campaign_conversion_goal_result = args[:campaign_conversion_goal_result] if args.key?(:campaign_conversion_goal_result) @campaign_criterion_result = args[:campaign_criterion_result] if args.key?(:campaign_criterion_result) @campaign_customizer_result = args[:campaign_customizer_result] if args.key?(:campaign_customizer_result) @campaign_draft_result = args[:campaign_draft_result] if args.key?(:campaign_draft_result) @campaign_goal_config_result = args[:campaign_goal_config_result] if args.key?(:campaign_goal_config_result) @campaign_group_result = args[:campaign_group_result] if args.key?(:campaign_group_result) @campaign_label_result = args[:campaign_label_result] if args.key?(:campaign_label_result) @campaign_result = args[:campaign_result] if args.key?(:campaign_result) @campaign_shared_set_result = args[:campaign_shared_set_result] if args.key?(:campaign_shared_set_result) @conversion_action_result = args[:conversion_action_result] if args.key?(:conversion_action_result) @conversion_custom_variable_result = args[:conversion_custom_variable_result] if args.key?(:conversion_custom_variable_result) @conversion_goal_campaign_config_result = args[:conversion_goal_campaign_config_result] if args.key?(:conversion_goal_campaign_config_result) @conversion_value_rule_result = args[:conversion_value_rule_result] if args.key?(:conversion_value_rule_result) @conversion_value_rule_set_result = args[:conversion_value_rule_set_result] if args.key?(:conversion_value_rule_set_result) @custom_conversion_goal_result = args[:custom_conversion_goal_result] if args.key?(:custom_conversion_goal_result) @customer_asset_result = args[:customer_asset_result] if args.key?(:customer_asset_result) @customer_conversion_goal_result = args[:customer_conversion_goal_result] if args.key?(:customer_conversion_goal_result) @customer_customizer_result = args[:customer_customizer_result] if args.key?(:customer_customizer_result) @customer_label_result = args[:customer_label_result] if args.key?(:customer_label_result) @customer_negative_criterion_result = args[:customer_negative_criterion_result] if args.key?(:customer_negative_criterion_result) @customer_result = args[:customer_result] if args.key?(:customer_result) @customizer_attribute_result = args[:customizer_attribute_result] if args.key?(:customizer_attribute_result) @experiment_arm_result = args[:experiment_arm_result] if args.key?(:experiment_arm_result) @experiment_result = args[:experiment_result] if args.key?(:experiment_result) @keyword_plan_ad_group_keyword_result = args[:keyword_plan_ad_group_keyword_result] if args.key?(:keyword_plan_ad_group_keyword_result) @keyword_plan_ad_group_result = args[:keyword_plan_ad_group_result] if args.key?(:keyword_plan_ad_group_result) @keyword_plan_campaign_keyword_result = args[:keyword_plan_campaign_keyword_result] if args.key?(:keyword_plan_campaign_keyword_result) @keyword_plan_campaign_result = args[:keyword_plan_campaign_result] if args.key?(:keyword_plan_campaign_result) @keyword_plan_result = args[:keyword_plan_result] if args.key?(:keyword_plan_result) @label_result = args[:label_result] if args.key?(:label_result) @recommendation_subscription_result = args[:recommendation_subscription_result] if args.key?(:recommendation_subscription_result) @remarketing_action_result = args[:remarketing_action_result] if args.key?(:remarketing_action_result) @search_ads360_campaign_result = args[:search_ads360_campaign_result] if args.key?(:search_ads360_campaign_result) @shared_criterion_result = args[:shared_criterion_result] if args.key?(:shared_criterion_result) @shared_set_result = args[:shared_set_result] if args.key?(:shared_set_result) @smart_campaign_setting_result = args[:smart_campaign_setting_result] if args.key?(:smart_campaign_setting_result) @user_list_result = args[:user_list_result] if args.key?(:user_list_result) end |