Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRemarketingActionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for RemarketingActionService.MutateRemarketingActions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateRemarketingActionsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateRemarketingActionsRequest.



51489
51490
51491
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51489

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemarketingActionOperation>

Required. The list of operations to perform on individual remarketing actions. Corresponds to the JSON property operations



51472
51473
51474
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51472

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


51479
51480
51481
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51479

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


51486
51487
51488
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51486

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51494
51495
51496
51497
51498
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51494

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end