Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedSetResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedSetResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the shared set mutate.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Returned for successful operations.
-
#shared_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedSet
SharedSets are used for sharing criterion exclusions across multiple campaigns.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSharedSetResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateSharedSetResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSharedSetResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateSharedSetResult.
50962 50963 50964 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50962 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Returned for successful operations.
Corresponds to the JSON property resourceName
50955 50956 50957 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50955 def resource_name @resource_name end |
#shared_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedSet
SharedSets are used for sharing criterion exclusions across multiple campaigns.
Corresponds to the JSON property sharedSet
50960 50961 50962 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50960 def shared_set @shared_set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50967 50968 50969 50970 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50967 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) @shared_set = args[:shared_set] if args.key?(:shared_set) end |