Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateUserListsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateUserListsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for UserListService.MutateUserLists.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUserListOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateUserListsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateUserListsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateUserListsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateUserListsRequest.
52116 52117 52118 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52116 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUserListOperation>
Required. The list of operations to perform on individual user lists.
Corresponds to the JSON property operations
52099 52100 52101 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52099 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
52106 52107 52108 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52106 def partial_failure @partial_failure end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
52113 52114 52115 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52113 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52121 52122 52123 52124 52125 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52121 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @validate_only = args[:validate_only] if args.key?(:validate_only) end |