Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProduct

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A product being planned for reach.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannedProduct

Returns a new instance of GoogleAdsSearchads360V23ServicesPlannedProduct.



52436
52437
52438
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_product_targetingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdvancedProductTargeting

Advanced targeting settings for products. Corresponds to the JSON property advancedProductTargeting



52412
52413
52414
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52412

def advanced_product_targeting
  @advanced_product_targeting
end

#budget_microsFixnum

Required. Maximum budget allocation in micros for the selected product. The value is specified in the selected planning currency_code. For example: 1 000 000$ = 1 000 000 000 000 micros. Corresponds to the JSON property budgetMicros

Returns:

  • (Fixnum)


52419
52420
52421
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52419

def budget_micros
  @budget_micros
end

#conversion_rateFloat

Conversion rate as a decimal between 0 and 1, exclusive. For example: if 2% of ad interactions are expected to lead to conversions, conversion_rate should be 0.02. This field is required for DEMAND_GEN plannable products. It is not supported for other plannable products. Corresponds to the JSON property conversionRate

Returns:

  • (Float)


52427
52428
52429
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52427

def conversion_rate
  @conversion_rate
end

#plannable_product_codeString

Required. Selected product for planning. The code associated with the ad product (for example: Trueview, Bumper). To list the available plannable product codes use ReachPlanService.ListPlannableProducts. Corresponds to the JSON property plannableProductCode

Returns:

  • (String)


52434
52435
52436
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52434

def plannable_product_code
  @plannable_product_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52441
52442
52443
52444
52445
52446
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52441

def update!(**args)
  @advanced_product_targeting = args[:advanced_product_targeting] if args.key?(:advanced_product_targeting)
  @budget_micros = args[:budget_micros] if args.key?(:budget_micros)
  @conversion_rate = args[:conversion_rate] if args.key?(:conversion_rate)
  @plannable_product_code = args[:plannable_product_code] if args.key?(:plannable_product_code)
end