Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProductForecast

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Forecasted traffic metrics for a planned product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannedProductForecast

Returns a new instance of GoogleAdsSearchads360V23ServicesPlannedProductForecast.



52537
52538
52539
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52537

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#average_frequencyFloat

The number of times per selected time unit a user will see an ad, averaged over the number of time units in the forecast length. This field will only be populated for a Target Frequency campaign. See https://support.google.com/ google-ads/answer/12400225 for more information about Target Frequency campaigns. Corresponds to the JSON property averageFrequency

Returns:

  • (Float)


52460
52461
52462
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52460

def average_frequency
  @average_frequency
end

#conversionsFloat

The number of conversions. This metric is only available for DEMAND_GEN plannable products. See https://support.google.com/google-ads/answer/2375431 for more information on conversions. Corresponds to the JSON property conversions

Returns:

  • (Float)


52467
52468
52469
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52467

def conversions
  @conversions
end

#on_target_coview_impressionsFixnum

Number of ad impressions that exactly matches the Targeting including co- viewers. Corresponds to the JSON property onTargetCoviewImpressions

Returns:

  • (Fixnum)


52473
52474
52475
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52473

def on_target_coview_impressions
  @on_target_coview_impressions
end

#on_target_coview_reachFixnum

Number of unique people reached that exactly matches the Targeting including co-viewers. Corresponds to the JSON property onTargetCoviewReach

Returns:

  • (Fixnum)


52479
52480
52481
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52479

def on_target_coview_reach
  @on_target_coview_reach
end

#on_target_impressionsFixnum

Number of ad impressions that exactly matches the Targeting. Corresponds to the JSON property onTargetImpressions

Returns:

  • (Fixnum)


52484
52485
52486
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52484

def on_target_impressions
  @on_target_impressions
end

#on_target_reachFixnum

Number of unique people reached that exactly matches the Targeting. Note that a minimum number of unique people must be reached in order for data to be reported. If the minimum number is not met, the on_target_reach value will be rounded to 0. Corresponds to the JSON property onTargetReach

Returns:

  • (Fixnum)


52492
52493
52494
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52492

def on_target_reach
  @on_target_reach
end

#total_coview_impressionsFixnum

Total number of ad impressions including co-viewers. This includes impressions that may fall outside the specified Targeting, due to insufficient information on signed-in users. Corresponds to the JSON property totalCoviewImpressions

Returns:

  • (Fixnum)


52499
52500
52501
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52499

def total_coview_impressions
  @total_coview_impressions
end

#total_coview_reachFixnum

Number of unique people reached including co-viewers. This includes people that may fall outside the specified Targeting. Corresponds to the JSON property totalCoviewReach

Returns:

  • (Fixnum)


52505
52506
52507
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52505

def total_coview_reach
  @total_coview_reach
end

#total_impressionsFixnum

Total number of ad impressions. This includes impressions that may fall outside the specified Targeting, due to insufficient information on signed-in users. Corresponds to the JSON property totalImpressions

Returns:

  • (Fixnum)


52512
52513
52514
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52512

def total_impressions
  @total_impressions
end

#total_reachFixnum

Number of unique people reached. This includes people that may fall outside the specified Targeting. Note that a minimum number of unique people must be reached in order for data to be reported. If the minimum number is not met, the total_reach value will be rounded to 0. Corresponds to the JSON property totalReach

Returns:

  • (Fixnum)


52520
52521
52522
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52520

def total_reach
  @total_reach
end

#trueview_viewsFixnum

Number of ad views forecasted for the specified product and targeting. A TrueView View is counted when a viewer views a larger portion or the entirety of an ad beyond an impression. See https://support.google.com/google-ads/ answer/2375431 for more information on TrueView Views. Corresponds to the JSON property trueviewViews

Returns:

  • (Fixnum)


52528
52529
52530
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52528

def trueview_views
  @trueview_views
end

#viewable_impressionsFixnum

Number of times the ad's impressions were considered viewable. See https:// support.google.com/google-ads/answer/7029393 for more information about what makes an ad viewable and how viewability is measured. Corresponds to the JSON property viewableImpressions

Returns:

  • (Fixnum)


52535
52536
52537
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52535

def viewable_impressions
  @viewable_impressions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52542
52543
52544
52545
52546
52547
52548
52549
52550
52551
52552
52553
52554
52555
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52542

def update!(**args)
  @average_frequency = args[:average_frequency] if args.key?(:average_frequency)
  @conversions = args[:conversions] if args.key?(:conversions)
  @on_target_coview_impressions = args[:on_target_coview_impressions] if args.key?(:on_target_coview_impressions)
  @on_target_coview_reach = args[:on_target_coview_reach] if args.key?(:on_target_coview_reach)
  @on_target_impressions = args[:on_target_impressions] if args.key?(:on_target_impressions)
  @on_target_reach = args[:on_target_reach] if args.key?(:on_target_reach)
  @total_coview_impressions = args[:total_coview_impressions] if args.key?(:total_coview_impressions)
  @total_coview_reach = args[:total_coview_reach] if args.key?(:total_coview_reach)
  @total_impressions = args[:total_impressions] if args.key?(:total_impressions)
  @total_reach = args[:total_reach] if args.key?(:total_reach)
  @trueview_views = args[:trueview_views] if args.key?(:trueview_views)
  @viewable_impressions = args[:viewable_impressions] if args.key?(:viewable_impressions)
end