Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPromoteCampaignDraftRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPromoteCampaignDraftRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CampaignDraftService.PromoteCampaignDraft.
Instance Attribute Summary collapse
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but no Long Running Operation is created.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPromoteCampaignDraftRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesPromoteCampaignDraftRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPromoteCampaignDraftRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesPromoteCampaignDraftRequest.
52674 52675 52676 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but no Long Running Operation is created.
Only errors are returned.
Corresponds to the JSON property validateOnly
52671 52672 52673 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52671 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52679 52680 52681 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52679 def update!(**args) @validate_only = args[:validate_only] if args.key?(:validate_only) end |