Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesProvideLeadFeedbackRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for LocalServicesLeadService.ProvideLeadFeedback.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesProvideLeadFeedbackRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesProvideLeadFeedbackRequest.



52659
52660
52661
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52659

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#survey_answerString

Required. Survey answer for Local Services Ads Lead. Corresponds to the JSON property surveyAnswer

Returns:

  • (String)


52647
52648
52649
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52647

def survey_answer
  @survey_answer
end

#survey_dissatisfiedGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurveyDissatisfied

Details about various factors for not being satisfied with the lead. Corresponds to the JSON property surveyDissatisfied



52652
52653
52654
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52652

def survey_dissatisfied
  @survey_dissatisfied
end

#survey_satisfiedGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurveySatisfied

Details about various factors for being satisfied with the lead. Corresponds to the JSON property surveySatisfied



52657
52658
52659
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52657

def survey_satisfied
  @survey_satisfied
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52664
52665
52666
52667
52668
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52664

def update!(**args)
  @survey_answer = args[:survey_answer] if args.key?(:survey_answer)
  @survey_dissatisfied = args[:survey_dissatisfied] if args.key?(:survey_dissatisfied)
  @survey_satisfied = args[:survey_satisfied] if args.key?(:survey_satisfied)
end