Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRateMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Average rate metrics. Metrics that represent monetary values are returned in USD by default, if unspecified in the request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRateMetrics

Returns a new instance of GoogleAdsSearchads360V23ServicesRateMetrics.



52863
52864
52865
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_view_viewabilityFloat

The percentage of time when your ad appeared on an Active View enabled site ( measurable impressions) and was viewable (viewable impressions). Corresponds to the JSON property activeViewViewability

Returns:

  • (Float)


52784
52785
52786
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52784

def active_view_viewability
  @active_view_viewability
end

#average_active_view_cpmFloat

Average cost-per-thousand viewable impressions. Corresponds to the JSON property averageActiveViewCpm

Returns:

  • (Float)


52789
52790
52791
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52789

def average_active_view_cpm
  @average_active_view_cpm
end

#average_cpcFloat

The average cost-per-click (CPC) is defined by the total cost of all clicks divided by the total number of clicks received. Corresponds to the JSON property averageCpc

Returns:

  • (Float)


52795
52796
52797
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52795

def average_cpc
  @average_cpc
end

#average_cpeFloat

The average cost-per-engagement (CPE) is defined by the total cost of all ad engagements divided by the total number of ad engagements. Corresponds to the JSON property averageCpe

Returns:

  • (Float)


52801
52802
52803
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52801

def average_cpe
  @average_cpe
end

#average_cpiFloat

The average cost-per-interaction (CPI) is defined by the total cost of all interactions divided by the total number of interactions. Corresponds to the JSON property averageCpi

Returns:

  • (Float)


52807
52808
52809
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52807

def average_cpi
  @average_cpi
end

#average_cpmFloat

Average cost-per-thousand impressions (CPM). Corresponds to the JSON property averageCpm

Returns:

  • (Float)


52812
52813
52814
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52812

def average_cpm
  @average_cpm
end

#click_through_rateFloat

The number of clicks your ad receives (Clicks) divided by the number of times your ad is shown (Impressions). Corresponds to the JSON property clickThroughRate

Returns:

  • (Float)


52818
52819
52820
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52818

def click_through_rate
  @click_through_rate
end

#engagement_rateFloat

How often people engage with your ad after it's shown to them. This is the number of ad expansions divided by the number of times your ad is shown. Corresponds to the JSON property engagementRate

Returns:

  • (Float)


52824
52825
52826
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52824

def engagement_rate
  @engagement_rate
end

#interaction_rateFloat

How often people interact with your ad after it is shown to them. This is the number of interactions divided by the number of times your ad is shown. Corresponds to the JSON property interactionRate

Returns:

  • (Float)


52830
52831
52832
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52830

def interaction_rate
  @interaction_rate
end

#trueview_average_cpvFloat

The average TrueView cost-per-view (CPV) is defined by the total cost of all ad TrueView views divided by the number of TrueView views. Corresponds to the JSON property trueviewAverageCpv

Returns:

  • (Float)


52836
52837
52838
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52836

def trueview_average_cpv
  @trueview_average_cpv
end

#trueview_view_rateFloat

Number of completed TrueView views divided by the number of impressions. Corresponds to the JSON property trueviewViewRate

Returns:

  • (Float)


52841
52842
52843
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52841

def trueview_view_rate
  @trueview_view_rate
end

#video_completion_p100_rateFloat

Percentage of impressions where the viewer watched all of your video. Corresponds to the JSON property videoCompletionP100Rate

Returns:

  • (Float)


52846
52847
52848
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52846

def video_completion_p100_rate
  @video_completion_p100_rate
end

#video_completion_p25_rateFloat

Percentage of impressions where the viewer watched 25% of your video. Corresponds to the JSON property videoCompletionP25Rate

Returns:

  • (Float)


52851
52852
52853
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52851

def video_completion_p25_rate
  @video_completion_p25_rate
end

#video_completion_p50_rateFloat

Percentage of impressions where the viewer watched 50% of your video. Corresponds to the JSON property videoCompletionP50Rate

Returns:

  • (Float)


52856
52857
52858
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52856

def video_completion_p50_rate
  @video_completion_p50_rate
end

#video_completion_p75_rateFloat

Percentage of impressions where the viewer watched 75% of your video. Corresponds to the JSON property videoCompletionP75Rate

Returns:

  • (Float)


52861
52862
52863
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52861

def video_completion_p75_rate
  @video_completion_p75_rate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52868
52869
52870
52871
52872
52873
52874
52875
52876
52877
52878
52879
52880
52881
52882
52883
52884
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52868

def update!(**args)
  @active_view_viewability = args[:active_view_viewability] if args.key?(:active_view_viewability)
  @average_active_view_cpm = args[:average_active_view_cpm] if args.key?(:average_active_view_cpm)
  @average_cpc = args[:average_cpc] if args.key?(:average_cpc)
  @average_cpe = args[:average_cpe] if args.key?(:average_cpe)
  @average_cpi = args[:average_cpi] if args.key?(:average_cpi)
  @average_cpm = args[:average_cpm] if args.key?(:average_cpm)
  @click_through_rate = args[:click_through_rate] if args.key?(:click_through_rate)
  @engagement_rate = args[:engagement_rate] if args.key?(:engagement_rate)
  @interaction_rate = args[:interaction_rate] if args.key?(:interaction_rate)
  @trueview_average_cpv = args[:trueview_average_cpv] if args.key?(:trueview_average_cpv)
  @trueview_view_rate = args[:trueview_view_rate] if args.key?(:trueview_view_rate)
  @video_completion_p100_rate = args[:video_completion_p100_rate] if args.key?(:video_completion_p100_rate)
  @video_completion_p25_rate = args[:video_completion_p25_rate] if args.key?(:video_completion_p25_rate)
  @video_completion_p50_rate = args[:video_completion_p50_rate] if args.key?(:video_completion_p50_rate)
  @video_completion_p75_rate = args[:video_completion_p75_rate] if args.key?(:video_completion_p75_rate)
end