Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Message for raw event conversion dimension header.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
The conversion custom variable ID.
-
#name ⇒ String
The user defined name of the raw event dimension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader
constructor
A new instance of GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader
Returns a new instance of GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader.
52901 52902 52903 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
The conversion custom variable ID.
Corresponds to the JSON property id
52894 52895 52896 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52894 def id @id end |
#name ⇒ String
The user defined name of the raw event dimension.
Corresponds to the JSON property name
52899 52900 52901 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52899 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52906 52907 52908 52909 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52906 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) end |