Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemoveProductLinkRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemoveProductLinkRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for ProductLinkService.RemoveProductLink.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Required.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRemoveProductLinkRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesRemoveProductLinkRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRemoveProductLinkRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesRemoveProductLinkRequest.
53270 53271 53272 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53270 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Required. Remove operation: A resource name for the product link to remove is
expected, in this format:
Corresponds to the JSON property resourceName
53261 53262 53263 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53261 def resource_name @resource_name end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
53267 53268 53269 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53267 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53275 53276 53277 53278 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53275 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) @validate_only = args[:validate_only] if args.key?(:validate_only) end |