Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRestatementValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Contains information needed to restate a conversion's value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRestatementValue

Returns a new instance of GoogleAdsSearchads360V23ServicesRestatementValue.



53334
53335
53336
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adjusted_valueFloat

The restated conversion value. This is the value of the conversion after restatement. For example, to change the value of a conversion from 100 to 70, an adjusted value of 70 should be reported. NOTE: If you want to upload a second restatement with a different adjusted value, it must have a new, more recent, adjustment occurrence time. Otherwise, it will be treated as a duplicate of the previous restatement and ignored. Corresponds to the JSON property adjustedValue

Returns:

  • (Float)


53324
53325
53326
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53324

def adjusted_value
  @adjusted_value
end

#currency_codeString

The currency of the restated value. If not provided, then the default currency from the conversion action is used, and if that is not set then the account currency is used. This is the ISO 4217 3-character currency code for example, USD or EUR. Corresponds to the JSON property currencyCode

Returns:

  • (String)


53332
53333
53334
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53332

def currency_code
  @currency_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53339
53340
53341
53342
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53339

def update!(**args)
  @adjusted_value = args[:adjusted_value] if args.key?(:adjusted_value)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
end