Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRunOfflineUserDataJobRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRunOfflineUserDataJobRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for OfflineUserDataJobService.RunOfflineUserDataJob.
Instance Attribute Summary collapse
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRunOfflineUserDataJobRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesRunOfflineUserDataJobRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRunOfflineUserDataJobRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesRunOfflineUserDataJobRequest.
52493 52494 52495 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
52490 52491 52492 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52490 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52498 52499 52500 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52498 def update!(**args) @validate_only = args[:validate_only] if args.key?(:validate_only) end |