Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesScheduleExperimentRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesScheduleExperimentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for ExperimentService.ScheduleExperiment.
Instance Attribute Summary collapse
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesScheduleExperimentRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesScheduleExperimentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesScheduleExperimentRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesScheduleExperimentRequest.
53325 53326 53327 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
53322 53323 53324 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53322 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53330 53331 53332 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53330 def update!(**args) @validate_only = args[:validate_only] if args.key?(:validate_only) end |