Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (update) on a Search Ads 360 campaign.
Instance Attribute Summary collapse
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSearchAds360Campaign
A Search Ads 360 campaign.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation.
53349 53350 53351 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53349 def initialize(**args) update!(**args) end |
Instance Attribute Details
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSearchAds360Campaign
A Search Ads 360 campaign.
Corresponds to the JSON property update
53342 53343 53344 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53342 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
53347 53348 53349 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53347 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53354 53355 53356 53357 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53354 def update!(**args) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |