Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchSearchAds360FieldsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for SearchAds360FieldService.SearchSearchAds360Fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSearchSearchAds360FieldsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesSearchSearchAds360FieldsResponse.



53983
53984
53985
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53983

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Pagination token used to retrieve the next page of results. Pass the content of this string as the page_token attribute of the next request. next_page_token is not returned for the last page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53971
53972
53973
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53971

def next_page_token
  @next_page_token
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSearchAds360Field>

The list of fields that matched the query. Corresponds to the JSON property results



53976
53977
53978
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53976

def results
  @results
end

#total_results_countFixnum

Total number of results that match the query ignoring the LIMIT clause. Corresponds to the JSON property totalResultsCount

Returns:

  • (Fixnum)


53981
53982
53983
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53981

def total_results_count
  @total_results_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53988
53989
53990
53991
53992
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53988

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @results = args[:results] if args.key?(:results)
  @total_results_count = args[:total_results_count] if args.key?(:total_results_count)
end