Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedCriterionOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedCriterionOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on an shared criterion.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedCriterion
A criterion belonging to a shared set.
-
#remove ⇒ String
Remove operation: A resource name for the removed shared criterion is expected, in this format:
customers/customer_id/sharedCriteria/shared_set_id~criterion_id`Corresponds to the JSON propertyremove`.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSharedCriterionOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesSharedCriterionOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSharedCriterionOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesSharedCriterionOperation.
54183 54184 54185 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedCriterion
A criterion belonging to a shared set.
Corresponds to the JSON property create
54174 54175 54176 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54174 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed shared criterion is expected,
in this format: customers/customer_id/sharedCriteria/shared_set_id~
criterion_id`
Corresponds to the JSON propertyremove`
54181 54182 54183 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54181 def remove @remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54188 54189 54190 54191 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54188 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) end |