Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Details related to Smart campaigns that are eligible to serve.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails

Returns a new instance of GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails.



55195
55196
55197
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55195

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_date_timeString

The timestamp of when the campaign will end, if applicable. The timestamp is in the customer’s timezone and in “yyyy-MM-dd HH:mm:ss” format. Corresponds to the JSON property endDateTime

Returns:

  • (String)


55186
55187
55188
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55186

def end_date_time
  @end_date_time
end

#last_impression_date_timeString

The timestamp of the last impression observed in the last 48 hours for this campaign. The timestamp is in the customer’s timezone and in “yyyy-MM-dd HH:mm: ss” format. Corresponds to the JSON property lastImpressionDateTime

Returns:

  • (String)


55193
55194
55195
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55193

def last_impression_date_time
  @last_impression_date_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55200
55201
55202
55203
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55200

def update!(**args)
  @end_date_time = args[:end_date_time] if args.key?(:end_date_time)
  @last_impression_date_time = args[:last_impression_date_time] if args.key?(:last_impression_date_time)
end