Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Details related to Smart campaigns that are not eligible to serve.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails

Returns a new instance of GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails.



55235
55236
55237
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#not_eligible_reasonString

The reason why the Smart campaign is not eligible to serve. Corresponds to the JSON property notEligibleReason

Returns:

  • (String)


55233
55234
55235
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55233

def not_eligible_reason
  @not_eligible_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55240
55241
55242
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55240

def update!(**args)
  @not_eligible_reason = args[:not_eligible_reason] if args.key?(:not_eligible_reason)
end