Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Information needed to get suggestion for Smart Campaign. More information provided will help the system to derive better suggestions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfo

Returns a new instance of GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfo.



55378
55379
55380
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_schedulesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>

Optional. The business ad schedule. Corresponds to the JSON property adSchedules



55330
55331
55332
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55330

def ad_schedules
  @ad_schedules
end

#business_contextGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfoBusinessContext

A context that describes a business. Corresponds to the JSON property businessContext



55335
55336
55337
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55335

def business_context
  @business_context
end

#business_profile_locationString

Optional. The resource name of a Business Profile location. Business Profile location resource names can be fetched through the Business Profile API and adhere to the following format: locations/locationId`. See the [Business Profile API] (https://developers.google.com/my-business/reference/ businessinformation/rest/v1/accounts.locations) for additional details. Corresponds to the JSON propertybusinessProfileLocation`

Returns:

  • (String)


55344
55345
55346
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55344

def business_profile_location
  @business_profile_location
end

#final_urlString

Optional. Landing page URL of the campaign. Corresponds to the JSON property finalUrl

Returns:

  • (String)


55349
55350
55351
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55349

def final_url
  @final_url
end

#keyword_themesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordThemeInfo>

Optional. Smart campaign keyword themes. This field may greatly improve suggestion accuracy and we recommend always setting it if possible. Corresponds to the JSON property keywordThemes



55355
55356
55357
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55355

def keyword_themes
  @keyword_themes
end

#language_codeString

Optional. The two letter advertising language for the Smart campaign to be constructed, default to 'en' if not set. Corresponds to the JSON property languageCode

Returns:

  • (String)


55361
55362
55363
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55361

def language_code
  @language_code
end

#location_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfoLocationList

A list of locations. Corresponds to the JSON property locationList



55366
55367
55368
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55366

def location_list
  @location_list
end

#proximityGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProximityInfo

A Proximity criterion. The geo point and radius determine what geographical area is included. The address is a description of the geo point that does not affect ad serving. There are two ways to create a proximity. First, by setting an address and radius. The geo point will be automatically computed. Second, by setting a geo point and radius. The address is an optional label that won't be validated. Corresponds to the JSON property proximity



55376
55377
55378
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55376

def proximity
  @proximity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55383
55384
55385
55386
55387
55388
55389
55390
55391
55392
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55383

def update!(**args)
  @ad_schedules = args[:ad_schedules] if args.key?(:ad_schedules)
  @business_context = args[:business_context] if args.key?(:business_context)
  @business_profile_location = args[:business_profile_location] if args.key?(:business_profile_location)
  @final_url = args[:final_url] if args.key?(:final_url)
  @keyword_themes = args[:keyword_themes] if args.key?(:keyword_themes)
  @language_code = args[:language_code] if args.key?(:language_code)
  @location_list = args[:location_list] if args.key?(:location_list)
  @proximity = args[:proximity] if args.key?(:proximity)
end