Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for GeoTargetConstantService.SuggestGeoTargetConstants.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequest.



55440
55441
55442
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Returned geo targets are restricted to this country code. Corresponds to the JSON property countryCode

Returns:

  • (String)


55422
55423
55424
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55422

def country_code
  @country_code
end

#geo_targetsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequestGeoTargets

A list of geo target constant resource names. Corresponds to the JSON property geoTargets



55427
55428
55429
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55427

def geo_targets
  @geo_targets
end

#localeString

If possible, returned geo targets are translated using this locale. If not, en is used by default. This is also used as a hint for returned geo targets. Corresponds to the JSON property locale

Returns:

  • (String)


55433
55434
55435
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55433

def locale
  @locale
end

#location_namesGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequestLocationNames

A list of location names. Corresponds to the JSON property locationNames



55438
55439
55440
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55438

def location_names
  @location_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55445
55446
55447
55448
55449
55450
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55445

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @geo_targets = args[:geo_targets] if args.key?(:geo_targets)
  @locale = args[:locale] if args.key?(:locale)
  @location_names = args[:location_names] if args.key?(:location_names)
end