Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargetingCombinations

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The surface targeting combinations available for an ad product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSurfaceTargetingCombinations

Returns a new instance of GoogleAdsSearchads360V23ServicesSurfaceTargetingCombinations.



55662
55663
55664
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55662

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_targeting_combinationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargeting>

Available surface target combinations for the ad product. Corresponds to the JSON property availableTargetingCombinations



55654
55655
55656
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55654

def available_targeting_combinations
  @available_targeting_combinations
end

#default_targetingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargeting

Container for surfaces for a product. Surfaces refer to the available types of ad inventories such as In-Feed, In-Stream, and Shorts. Corresponds to the JSON property defaultTargeting



55660
55661
55662
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55660

def default_targeting
  @default_targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55667
55668
55669
55670
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55667

def update!(**args)
  @available_targeting_combinations = args[:available_targeting_combinations] if args.key?(:available_targeting_combinations)
  @default_targeting = args[:default_targeting] if args.key?(:default_targeting)
end