Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurveyDissatisfied

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Details about various factors for not being satisfied with the lead.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSurveyDissatisfied

Returns a new instance of GoogleAdsSearchads360V23ServicesSurveyDissatisfied.



55772
55773
55774
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#other_reason_commentString

Optional. Provider's free form comments. This field is required when OTHER_DISSATISFIED_REASON is selected as the reason. Corresponds to the JSON property otherReasonComment

Returns:

  • (String)


55765
55766
55767
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55765

def other_reason_comment
  @other_reason_comment
end

#survey_dissatisfied_reasonString

Required. Provider's reason for not being satisfied with the lead. Corresponds to the JSON property surveyDissatisfiedReason

Returns:

  • (String)


55770
55771
55772
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55770

def survey_dissatisfied_reason
  @survey_dissatisfied_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55777
55778
55779
55780
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55777

def update!(**args)
  @other_reason_comment = args[:other_reason_comment] if args.key?(:other_reason_comment)
  @survey_dissatisfied_reason = args[:survey_dissatisfied_reason] if args.key?(:survey_dissatisfied_reason)
end