Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The targeting for which traffic metrics will be reported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesTargeting

Returns a new instance of GoogleAdsSearchads360V23ServicesTargeting.



55885
55886
55887
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55885

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_rangeString

Targeted age range. An unset value is equivalent to targeting all ages. Corresponds to the JSON property ageRange

Returns:

  • (String)


55841
55842
55843
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55841

def age_range
  @age_range
end

#audience_targetingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceTargeting

Audience targeting for reach forecast. Corresponds to the JSON property audienceTargeting



55846
55847
55848
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55846

def audience_targeting
  @audience_targeting
end

#devicesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo>

Targeted devices. If not specified, targets all applicable devices. Applicable devices vary by product and region and can be obtained from ReachPlanService. ListPlannableProducts. Corresponds to the JSON property devices



55853
55854
55855
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55853

def devices
  @devices
end

#gendersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo>

Targeted genders. An unset value is equivalent to targeting MALE and FEMALE. Corresponds to the JSON property genders



55858
55859
55860
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55858

def genders
  @genders
end

#networkString

Targetable network for the ad product. If not specified, targets all applicable networks. Applicable networks vary by product and region and can be obtained from ReachPlanService.ListPlannableProducts. Corresponds to the JSON property network

Returns:

  • (String)


55865
55866
55867
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55865

def network
  @network
end

#plannable_location_idString

The ID of the selected location. Plannable location IDs can be obtained from ReachPlanService.ListPlannableLocations. Requests must set either this field or plannable_location_ids. This field is deprecated as of V12 and will be removed in a future release. Use plannable_location_ids instead. Corresponds to the JSON property plannableLocationId

Returns:

  • (String)


55873
55874
55875
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55873

def plannable_location_id
  @plannable_location_id
end

#plannable_location_idsArray<String>

The list of plannable location IDs to target with this forecast. If more than one ID is provided, all IDs must have the same parent_country_id. Planning for more than parent_county is not supported. Plannable location IDs and their parent_country_id can be obtained from ReachPlanService. ListPlannableLocations. Requests must set either this field or plannable_location_id. Corresponds to the JSON property plannableLocationIds

Returns:

  • (Array<String>)


55883
55884
55885
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55883

def plannable_location_ids
  @plannable_location_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55890
55891
55892
55893
55894
55895
55896
55897
55898
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55890

def update!(**args)
  @age_range = args[:age_range] if args.key?(:age_range)
  @audience_targeting = args[:audience_targeting] if args.key?(:audience_targeting)
  @devices = args[:devices] if args.key?(:devices)
  @genders = args[:genders] if args.key?(:genders)
  @network = args[:network] if args.key?(:network)
  @plannable_location_id = args[:plannable_location_id] if args.key?(:plannable_location_id)
  @plannable_location_ids = args[:plannable_location_ids] if args.key?(:plannable_location_ids)
end