Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadClickConversionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadClickConversionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for ConversionUploadService.UploadClickConversions.
Instance Attribute Summary collapse
-
#job_id ⇒ Fixnum
Job ID for the upload batch.
-
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesClickConversionResult>
Returned for successfully processed conversions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadClickConversionsResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesUploadClickConversionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadClickConversionsResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesUploadClickConversionsResponse.
56227 56228 56229 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56227 def initialize(**args) update!(**args) end |
Instance Attribute Details
#job_id ⇒ Fixnum
Job ID for the upload batch.
Corresponds to the JSON property jobId
56208 56209 56210 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56208 def job_id @job_id end |
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property partialFailureError
56218 56219 56220 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56218 def partial_failure_error @partial_failure_error end |
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesClickConversionResult>
Returned for successfully processed conversions. Proto will be empty for rows
that received an error. Results are not returned when validate_only is true
.
Corresponds to the JSON property results
56225 56226 56227 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56225 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56232 56233 56234 56235 56236 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56232 def update!(**args) @job_id = args[:job_id] if args.key?(:job_id) @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error) @results = args[:results] if args.key?(:results) end |