Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadConversionAdjustmentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ConversionAdjustmentUploadService. UploadConversionAdjustments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadConversionAdjustmentsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesUploadConversionAdjustmentsRequest.



56275
56276
56277
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56275

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversion_adjustmentsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionAdjustment>

Required. The conversion adjustments that are being uploaded. Corresponds to the JSON property conversionAdjustments



56247
56248
56249
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56247

def conversion_adjustments
  @conversion_adjustments
end

#job_idFixnum

Optional. Optional input to set job ID. Must be a non-negative number that is less than 2^31 if provided. If this field is not provided, the API will generate a job ID in the range [2^31, (2^63)-1]. The API will return the value for this request in the job_id field of the UploadConversionAdjustmentsResponse. Corresponds to the JSON property jobId

Returns:

  • (Fixnum)


56256
56257
56258
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56256

def job_id
  @job_id
end

#partial_failureBoolean Also known as: partial_failure?

Required. If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. This should always be set to true. See https://developers.google.com/google-ads/api/docs/best-practices/ partial-failures for more information about partial failure. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


56265
56266
56267
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56265

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


56272
56273
56274
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56272

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56280
56281
56282
56283
56284
56285
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56280

def update!(**args)
  @conversion_adjustments = args[:conversion_adjustments] if args.key?(:conversion_adjustments)
  @job_id = args[:job_id] if args.key?(:job_id)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end