Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadConversionAdjustmentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for ConversionAdjustmentUploadService. UploadConversionAdjustments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadConversionAdjustmentsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesUploadConversionAdjustmentsResponse.



56315
56316
56317
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#job_idFixnum

Job ID for the upload batch. Corresponds to the JSON property jobId

Returns:

  • (Fixnum)


56296
56297
56298
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56296

def job_id
  @job_id
end

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



56306
56307
56308
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56306

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionAdjustmentResult>

Returned for successfully processed conversion adjustments. Proto will be empty for rows that received an error. Results are not returned when validate_only is true. Corresponds to the JSON property results



56313
56314
56315
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56313

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56320
56321
56322
56323
56324
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56320

def update!(**args)
  @job_id = args[:job_id] if args.key?(:job_id)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end