Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUrlSeed
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUrlSeed
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Url Seed
Instance Attribute Summary collapse
-
#url ⇒ String
The URL to crawl in order to generate keyword ideas.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUrlSeed
constructor
A new instance of GoogleAdsSearchads360V23ServicesUrlSeed.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUrlSeed
Returns a new instance of GoogleAdsSearchads360V23ServicesUrlSeed.
55210 55211 55212 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55210 def initialize(**args) update!(**args) end |
Instance Attribute Details
#url ⇒ String
The URL to crawl in order to generate keyword ideas.
Corresponds to the JSON property url
55208 55209 55210 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55208 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55215 55216 55217 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55215 def update!(**args) @url = args[:url] if args.key?(:url) end |