Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V0ErrorsErrorCode
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V0ErrorsErrorCode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The error reason represented by type and enum.
Instance Attribute Summary collapse
-
#authentication_error ⇒ String
Indicates failure to properly authenticate user.
-
#authorization_error ⇒ String
An error encountered when trying to authorize a user.
-
#conversion_custom_variable_error ⇒ String
The reasons for the conversion custom variable error Corresponds to the JSON property
conversionCustomVariableError. -
#custom_column_error ⇒ String
The reasons for the custom column error Corresponds to the JSON property
customColumnError. -
#date_error ⇒ String
The reasons for the date error Corresponds to the JSON property
dateError. -
#date_range_error ⇒ String
The reasons for the date range error Corresponds to the JSON property
dateRangeError. -
#distinct_error ⇒ String
The reasons for the distinct error Corresponds to the JSON property
distinctError. -
#header_error ⇒ String
The reasons for the header error.
-
#internal_error ⇒ String
An unexpected server-side error.
-
#invalid_parameter_error ⇒ String
The reasons for invalid parameter errors.
-
#query_error ⇒ String
An error with the query Corresponds to the JSON property
queryError. -
#quota_error ⇒ String
An error with the amount of quota remaining.
-
#request_error ⇒ String
An error caused by the request Corresponds to the JSON property
requestError. -
#size_limit_error ⇒ String
The reasons for the size limit error Corresponds to the JSON property
sizeLimitError.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsErrorCode
constructor
A new instance of GoogleAdsSearchads360V0ErrorsErrorCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V0ErrorsErrorCode
Returns a new instance of GoogleAdsSearchads360V0ErrorsErrorCode.
168 169 170 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_error ⇒ String
Indicates failure to properly authenticate user.
Corresponds to the JSON property authenticationError
101 102 103 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 101 def authentication_error @authentication_error end |
#authorization_error ⇒ String
An error encountered when trying to authorize a user.
Corresponds to the JSON property authorizationError
106 107 108 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 106 def @authorization_error end |
#conversion_custom_variable_error ⇒ String
The reasons for the conversion custom variable error
Corresponds to the JSON property conversionCustomVariableError
111 112 113 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 111 def conversion_custom_variable_error @conversion_custom_variable_error end |
#custom_column_error ⇒ String
The reasons for the custom column error
Corresponds to the JSON property customColumnError
116 117 118 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 116 def custom_column_error @custom_column_error end |
#date_error ⇒ String
The reasons for the date error
Corresponds to the JSON property dateError
121 122 123 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 121 def date_error @date_error end |
#date_range_error ⇒ String
The reasons for the date range error
Corresponds to the JSON property dateRangeError
126 127 128 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 126 def date_range_error @date_range_error end |
#distinct_error ⇒ String
The reasons for the distinct error
Corresponds to the JSON property distinctError
131 132 133 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 131 def distinct_error @distinct_error end |
#header_error ⇒ String
The reasons for the header error.
Corresponds to the JSON property headerError
136 137 138 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 136 def header_error @header_error end |
#internal_error ⇒ String
An unexpected server-side error.
Corresponds to the JSON property internalError
141 142 143 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 141 def internal_error @internal_error end |
#invalid_parameter_error ⇒ String
The reasons for invalid parameter errors.
Corresponds to the JSON property invalidParameterError
146 147 148 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 146 def invalid_parameter_error @invalid_parameter_error end |
#query_error ⇒ String
An error with the query
Corresponds to the JSON property queryError
151 152 153 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 151 def query_error @query_error end |
#quota_error ⇒ String
An error with the amount of quota remaining.
Corresponds to the JSON property quotaError
156 157 158 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 156 def quota_error @quota_error end |
#request_error ⇒ String
An error caused by the request
Corresponds to the JSON property requestError
161 162 163 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 161 def request_error @request_error end |
#size_limit_error ⇒ String
The reasons for the size limit error
Corresponds to the JSON property sizeLimitError
166 167 168 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 166 def size_limit_error @size_limit_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 173 def update!(**args) @authentication_error = args[:authentication_error] if args.key?(:authentication_error) @authorization_error = args[:authorization_error] if args.key?(:authorization_error) @conversion_custom_variable_error = args[:conversion_custom_variable_error] if args.key?(:conversion_custom_variable_error) @custom_column_error = args[:custom_column_error] if args.key?(:custom_column_error) @date_error = args[:date_error] if args.key?(:date_error) @date_range_error = args[:date_range_error] if args.key?(:date_range_error) @distinct_error = args[:distinct_error] if args.key?(:distinct_error) @header_error = args[:header_error] if args.key?(:header_error) @internal_error = args[:internal_error] if args.key?(:internal_error) @invalid_parameter_error = args[:invalid_parameter_error] if args.key?(:invalid_parameter_error) @query_error = args[:query_error] if args.key?(:query_error) @quota_error = args[:quota_error] if args.key?(:quota_error) @request_error = args[:request_error] if args.key?(:request_error) @size_limit_error = args[:size_limit_error] if args.key?(:size_limit_error) end |