Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdAssetPolicySummary
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdAssetPolicySummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Contains policy information for an asset inside an ad.
Instance Attribute Summary collapse
-
#approval_status ⇒ String
The overall approval status of this asset, which is calculated based on the status of its individual policy topic entries.
-
#policy_topic_entries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry>
The list of policy findings for this asset.
-
#review_status ⇒ String
Where in the review process this asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdAssetPolicySummary
constructor
A new instance of GoogleAdsSearchads360V23CommonAdAssetPolicySummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdAssetPolicySummary
Returns a new instance of GoogleAdsSearchads360V23CommonAdAssetPolicySummary.
791 792 793 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 791 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval_status ⇒ String
The overall approval status of this asset, which is calculated based on the
status of its individual policy topic entries.
Corresponds to the JSON property approvalStatus
779 780 781 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 779 def approval_status @approval_status end |
#policy_topic_entries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry>
The list of policy findings for this asset.
Corresponds to the JSON property policyTopicEntries
784 785 786 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 784 def policy_topic_entries @policy_topic_entries end |
#review_status ⇒ String
Where in the review process this asset.
Corresponds to the JSON property reviewStatus
789 790 791 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 789 def review_status @review_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
796 797 798 799 800 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 796 def update!(**args) @approval_status = args[:approval_status] if args.key?(:approval_status) @policy_topic_entries = args[:policy_topic_entries] if args.key?(:policy_topic_entries) @review_status = args[:review_status] if args.key?(:review_status) end |