Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdCallToActionAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdCallToActionAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A call to action asset used inside an ad.
Instance Attribute Summary collapse
-
#asset ⇒ String
The Asset resource name of this call to action asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdCallToActionAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonAdCallToActionAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdCallToActionAsset
Returns a new instance of GoogleAdsSearchads360V23CommonAdCallToActionAsset.
752 753 754 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset ⇒ String
The Asset resource name of this call to action asset.
Corresponds to the JSON property asset
750 751 752 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 750 def asset @asset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
757 758 759 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 757 def update!(**args) @asset = args[:asset] if args.key?(:asset) end |