Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents an AdSchedule criterion. AdSchedule is specified as the day of the week and a time interval within which ads will be shown. No more than six AdSchedules can be added for the same day.
Instance Attribute Summary collapse
-
#day_of_week ⇒ String
Day of the week the schedule applies to.
-
#end_hour ⇒ Fixnum
Ending hour in 24 hour time; 24 signifies end of the day.
-
#end_minute ⇒ String
Minutes after the end hour at which this schedule ends.
-
#start_hour ⇒ Fixnum
Starting hour in 24 hour time.
-
#start_minute ⇒ String
Minutes after the start hour at which this schedule starts.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdScheduleInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonAdScheduleInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdScheduleInfo
Returns a new instance of GoogleAdsSearchads360V23CommonAdScheduleInfo.
858 859 860 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 858 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day_of_week ⇒ String
Day of the week the schedule applies to. This field is required for CREATE
operations and is prohibited on UPDATE operations.
Corresponds to the JSON property dayOfWeek
829 830 831 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 829 def day_of_week @day_of_week end |
#end_hour ⇒ Fixnum
Ending hour in 24 hour time; 24 signifies end of the day. This field must be
between 0 and 24, inclusive. This field is required for CREATE operations and
is prohibited on UPDATE operations.
Corresponds to the JSON property endHour
836 837 838 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 836 def end_hour @end_hour end |
#end_minute ⇒ String
Minutes after the end hour at which this schedule ends. The schedule is
exclusive of the end minute. This field is required for CREATE operations and
is prohibited on UPDATE operations.
Corresponds to the JSON property endMinute
843 844 845 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 843 def end_minute @end_minute end |
#start_hour ⇒ Fixnum
Starting hour in 24 hour time. This field must be between 0 and 23, inclusive.
This field is required for CREATE operations and is prohibited on UPDATE
operations.
Corresponds to the JSON property startHour
850 851 852 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 850 def start_hour @start_hour end |
#start_minute ⇒ String
Minutes after the start hour at which this schedule starts. This field is
required for CREATE operations and is prohibited on UPDATE operations.
Corresponds to the JSON property startMinute
856 857 858 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 856 def start_minute @start_minute end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
863 864 865 866 867 868 869 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 863 def update!(**args) @day_of_week = args[:day_of_week] if args.key?(:day_of_week) @end_hour = args[:end_hour] if args.key?(:end_hour) @end_minute = args[:end_minute] if args.key?(:end_minute) @start_hour = args[:start_hour] if args.key?(:start_hour) @start_minute = args[:start_minute] if args.key?(:start_minute) end |