Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A text asset used inside an ad.
Instance Attribute Summary collapse
-
#asset_performance_label ⇒ String
The performance label of this text asset.
-
#pinned_field ⇒ String
The pinned field of the asset.
-
#policy_summary_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdAssetPolicySummary
Contains policy information for an asset inside an ad.
-
#text ⇒ String
Asset text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdTextAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonAdTextAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdTextAsset
Returns a new instance of GoogleAdsSearchads360V23CommonAdTextAsset.
959 960 961 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 959 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_performance_label ⇒ String
The performance label of this text asset.
Corresponds to the JSON property assetPerformanceLabel
939 940 941 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 939 def asset_performance_label @asset_performance_label end |
#pinned_field ⇒ String
The pinned field of the asset. This restricts the asset to only serve within
this field. Multiple assets can be pinned to the same field. An asset that is
unpinned or pinned to a different field will not serve in a field where some
other asset has been pinned.
Corresponds to the JSON property pinnedField
947 948 949 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 947 def pinned_field @pinned_field end |
#policy_summary_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdAssetPolicySummary
Contains policy information for an asset inside an ad.
Corresponds to the JSON property policySummaryInfo
952 953 954 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 952 def policy_summary_info @policy_summary_info end |
#text ⇒ String
Asset text.
Corresponds to the JSON property text
957 958 959 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 957 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
964 965 966 967 968 969 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 964 def update!(**args) @asset_performance_label = args[:asset_performance_label] if args.key?(:asset_performance_label) @pinned_field = args[:pinned_field] if args.key?(:pinned_field) @policy_summary_info = args[:policy_summary_info] if args.key?(:policy_summary_info) @text = args[:text] if args.key?(:text) end |