Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A text asset used inside an ad.
Instance Attribute Summary collapse
-
#asset_performance_label ⇒ String
The performance label of this text asset.
-
#pinned_field ⇒ String
The pinned field of the asset.
-
#policy_summary_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdAssetPolicySummary
Contains policy information for an asset inside an ad.
-
#text ⇒ String
Asset text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdTextAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonAdTextAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAdTextAsset
Returns a new instance of GoogleAdsSearchads360V23CommonAdTextAsset.
899 900 901 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 899 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_performance_label ⇒ String
The performance label of this text asset.
Corresponds to the JSON property assetPerformanceLabel
879 880 881 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 879 def asset_performance_label @asset_performance_label end |
#pinned_field ⇒ String
The pinned field of the asset. This restricts the asset to only serve within
this field. Multiple assets can be pinned to the same field. An asset that is
unpinned or pinned to a different field will not serve in a field where some
other asset has been pinned.
Corresponds to the JSON property pinnedField
887 888 889 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 887 def pinned_field @pinned_field end |
#policy_summary_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdAssetPolicySummary
Contains policy information for an asset inside an ad.
Corresponds to the JSON property policySummaryInfo
892 893 894 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 892 def policy_summary_info @policy_summary_info end |
#text ⇒ String
Asset text.
Corresponds to the JSON property text
897 898 899 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 897 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
904 905 906 907 908 909 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 904 def update!(**args) @asset_performance_label = args[:asset_performance_label] if args.key?(:asset_performance_label) @pinned_field = args[:pinned_field] if args.key?(:pinned_field) @policy_summary_info = args[:policy_summary_info] if args.key?(:policy_summary_info) @text = args[:text] if args.key?(:text) end |