Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppAdInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppAdInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An app ad.
Instance Attribute Summary collapse
-
#app_deep_link ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdAppDeepLinkAsset
An app deep link used inside an ad.
-
#descriptions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets for descriptions.
-
#headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets for headlines.
-
#html5_media_bundles ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdMediaBundleAsset>
List of media bundle assets that may be used with the ad.
-
#images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
List of image assets that may be displayed with the ad.
-
#mandatory_ad_text ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
-
#youtube_videos ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAsset>
List of YouTube video assets that may be displayed with the ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAppAdInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonAppAdInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAppAdInfo
Returns a new instance of GoogleAdsSearchads360V23CommonAppAdInfo.
1176 1177 1178 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1176 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_deep_link ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdAppDeepLinkAsset
An app deep link used inside an ad.
Corresponds to the JSON property appDeepLink
1142 1143 1144 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1142 def app_deep_link @app_deep_link end |
#descriptions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets for descriptions. When the ad serves the descriptions will
be selected from this list.
Corresponds to the JSON property descriptions
1148 1149 1150 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1148 def descriptions @descriptions end |
#headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets for headlines. When the ad serves the headlines will be
selected from this list.
Corresponds to the JSON property headlines
1154 1155 1156 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1154 def headlines @headlines end |
#html5_media_bundles ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdMediaBundleAsset>
List of media bundle assets that may be used with the ad.
Corresponds to the JSON property html5MediaBundles
1159 1160 1161 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1159 def html5_media_bundles @html5_media_bundles end |
#images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
List of image assets that may be displayed with the ad.
Corresponds to the JSON property images
1164 1165 1166 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1164 def images @images end |
#mandatory_ad_text ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
Corresponds to the JSON property mandatoryAdText
1169 1170 1171 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1169 def mandatory_ad_text @mandatory_ad_text end |
#youtube_videos ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAsset>
List of YouTube video assets that may be displayed with the ad.
Corresponds to the JSON property youtubeVideos
1174 1175 1176 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1174 def youtube_videos @youtube_videos end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1181 1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1181 def update!(**args) @app_deep_link = args[:app_deep_link] if args.key?(:app_deep_link) @descriptions = args[:descriptions] if args.key?(:descriptions) @headlines = args[:headlines] if args.key?(:headlines) @html5_media_bundles = args[:html5_media_bundles] if args.key?(:html5_media_bundles) @images = args[:images] if args.key?(:images) @mandatory_ad_text = args[:mandatory_ad_text] if args.key?(:mandatory_ad_text) @youtube_videos = args[:youtube_videos] if args.key?(:youtube_videos) end |