Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppDeepLinkAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppDeepLinkAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An app deep link asset
Instance Attribute Summary collapse
-
#app_deep_link_uri ⇒ String
The uri for the app deep link, The uri can be either a custom scheme uri (e.g. mystore://shoes) or universal uri (e.g. http://www.mystore.com/shoes).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAppDeepLinkAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonAppDeepLinkAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAppDeepLinkAsset
Returns a new instance of GoogleAdsSearchads360V23CommonAppDeepLinkAsset.
1202 1203 1204 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1202 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_deep_link_uri ⇒ String
The uri for the app deep link, The uri can be either a custom scheme uri (e.g.
mystore://shoes) or universal uri (e.g. http://www.mystore.com/shoes).
Corresponds to the JSON property appDeepLinkUri
1200 1201 1202 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1200 def app_deep_link_uri @app_deep_link_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1207 1208 1209 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1207 def update!(**args) @app_deep_link_uri = args[:app_deep_link_uri] if args.key?(:app_deep_link_uri) end |