Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppEngagementAdInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

App engagement ads allow you to write text encouraging a specific action in the app, like checking in, making a purchase, or booking a flight. They allow you to send users to a specific part of your app where they can find what they' re looking for easier and faster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAppEngagementAdInfo

Returns a new instance of GoogleAdsSearchads360V23CommonAppEngagementAdInfo.



1241
1242
1243
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1241

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

List of text assets for descriptions. When the ad serves the descriptions will be selected from this list. Corresponds to the JSON property descriptions



1223
1224
1225
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1223

def descriptions
  @descriptions
end

#headlinesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

List of text assets for headlines. When the ad serves the headlines will be selected from this list. Corresponds to the JSON property headlines



1229
1230
1231
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1229

def headlines
  @headlines
end

#imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

List of image assets that may be displayed with the ad. Corresponds to the JSON property images



1234
1235
1236
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1234

def images
  @images
end

#videosArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAsset>

List of video assets that may be displayed with the ad. Corresponds to the JSON property videos



1239
1240
1241
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1239

def videos
  @videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1246
1247
1248
1249
1250
1251
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1246

def update!(**args)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @headlines = args[:headlines] if args.key?(:headlines)
  @images = args[:images] if args.key?(:images)
  @videos = args[:videos] if args.key?(:videos)
end