Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppPreRegistrationAdInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

App pre-registration ads link to your app or game listing on Google Play, and can run on Google Play, on YouTube (in-stream only), and within other apps and mobile websites on the Display Network. It will help capture people's interest in your app or game and generate an early install base for your app or game before a launch.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAppPreRegistrationAdInfo

Returns a new instance of GoogleAdsSearchads360V23CommonAppPreRegistrationAdInfo.



1303
1304
1305
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

List of text assets for descriptions. When the ad serves the descriptions will be selected from this list. Corresponds to the JSON property descriptions



1285
1286
1287
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1285

def descriptions
  @descriptions
end

#headlinesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

List of text assets for headlines. When the ad serves the headlines will be selected from this list. Corresponds to the JSON property headlines



1291
1292
1293
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1291

def headlines
  @headlines
end

#imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

List of image asset IDs whose images may be displayed with the ad. Corresponds to the JSON property images



1296
1297
1298
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1296

def images
  @images
end

#youtube_videosArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAsset>

List of YouTube video asset IDs whose videos may be displayed with the ad. Corresponds to the JSON property youtubeVideos



1301
1302
1303
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1301

def youtube_videos
  @youtube_videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1308
1309
1310
1311
1312
1313
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1308

def update!(**args)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @headlines = args[:headlines] if args.key?(:headlines)
  @images = args[:images] if args.key?(:images)
  @youtube_videos = args[:youtube_videos] if args.key?(:youtube_videos)
end