Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetInteractionTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An AssetInteractionTarget segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAssetInteractionTarget

Returns a new instance of GoogleAdsSearchads360V23CommonAssetInteractionTarget.



1352
1353
1354
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1352

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetString

The asset resource name. Corresponds to the JSON property asset

Returns:

  • (String)


1342
1343
1344
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1342

def asset
  @asset
end

#interaction_on_this_assetBoolean Also known as: interaction_on_this_asset?

Only used with CustomerAsset, CampaignAsset and AdGroupAsset metrics. Indicates whether the interaction metrics occurred on the asset itself or a different asset or ad unit. Corresponds to the JSON property interactionOnThisAsset

Returns:

  • (Boolean)


1349
1350
1351
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1349

def interaction_on_this_asset
  @interaction_on_this_asset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1357
1358
1359
1360
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1357

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @interaction_on_this_asset = args[:interaction_on_this_asset] if args.key?(:interaction_on_this_asset)
end