Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceDimension
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceDimension
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Positive dimension specifying user's audience.
Instance Attribute Summary collapse
-
#age ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeDimension
Dimension specifying users by their age.
-
#audience_segments ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceSegmentDimension
Dimension specifying users by their membership in other audience segments.
-
#gender ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderDimension
Dimension specifying users by their gender.
-
#household_income ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHouseholdIncomeDimension
Dimension specifying users by their household income.
-
#parental_status ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusDimension
Dimension specifying users by their parental status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAudienceDimension
constructor
A new instance of GoogleAdsSearchads360V23CommonAudienceDimension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAudienceDimension
Returns a new instance of GoogleAdsSearchads360V23CommonAudienceDimension.
1453 1454 1455 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1453 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeDimension
Dimension specifying users by their age.
Corresponds to the JSON property age
1431 1432 1433 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1431 def age @age end |
#audience_segments ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceSegmentDimension
Dimension specifying users by their membership in other audience segments.
Corresponds to the JSON property audienceSegments
1436 1437 1438 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1436 def audience_segments @audience_segments end |
#gender ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderDimension
Dimension specifying users by their gender.
Corresponds to the JSON property gender
1441 1442 1443 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1441 def gender @gender end |
#household_income ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHouseholdIncomeDimension
Dimension specifying users by their household income.
Corresponds to the JSON property householdIncome
1446 1447 1448 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1446 def household_income @household_income end |
#parental_status ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusDimension
Dimension specifying users by their parental status.
Corresponds to the JSON property parentalStatus
1451 1452 1453 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1451 def parental_status @parental_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1458 1459 1460 1461 1462 1463 1464 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1458 def update!(**args) @age = args[:age] if args.key?(:age) @audience_segments = args[:audience_segments] if args.key?(:audience_segments) @gender = args[:gender] if args.key?(:gender) @household_income = args[:household_income] if args.key?(:household_income) @parental_status = args[:parental_status] if args.key?(:parental_status) end |