Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An audience attribute, with metadata about it, returned in response to a search.
Instance Attribute Summary collapse
-
#attribute ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttribute
An audience attribute that can be used to request insights about the audience.
-
#dimension ⇒ String
The type of the attribute.
-
#display_info ⇒ String
A string that supplements the display_name to identify the attribute.
-
#display_name ⇒ String
The human-readable name of the attribute.
-
#knowledge_graph_attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKnowledgeGraphAttributeMetadata
Metadata associated with a Knowledge Graph Entity attribute.
-
#lineup_attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLineupAttributeMetadata
Metadata associated with a Lineup attribute.
-
#location_attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationAttributeMetadata
Metadata associated with a Location attribute.
-
#potential_youtube_reach ⇒ Fixnum
An estimate of the number of reachable YouTube users matching this attribute in the requested location, or zero if that information is not available for this attribute.
-
#subscriber_share ⇒ Float
The share of subscribers within this attribute, between and including 0 and 1.
-
#user_interest_attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserInterestAttributeMetadata
Metadata associated with a User Interest attribute.
-
#user_list_attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListAttributeMetadata
Metadata associated with a User List attribute.
-
#viewer_share ⇒ Float
The share of viewers within this attribute, between and including 0 and 1.
-
#youtube_channel_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelAttributeMetadata
Metadata associated with a YouTube channel attribute.
-
#youtube_video_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoAttributeMetadata
Metadata for a YouTube video attribute.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata
constructor
A new instance of GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata
Returns a new instance of GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata.
1680 1681 1682 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1680 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribute ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttribute
An audience attribute that can be used to request insights about the audience.
Corresponds to the JSON property attribute
1605 1606 1607 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1605 def attribute @attribute end |
#dimension ⇒ String
The type of the attribute.
Corresponds to the JSON property dimension
1610 1611 1612 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1610 def dimension @dimension end |
#display_info ⇒ String
A string that supplements the display_name to identify the attribute. If the
dimension is TOPIC, this is a brief description of the Knowledge Graph entity,
such as "American singer-songwriter". If the dimension is CATEGORY, this is
the complete path to the category in The Product & Service taxonomy, for
example "/Apparel/Clothing/Outerwear".
Corresponds to the JSON property displayInfo
1619 1620 1621 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1619 def display_info @display_info end |
#display_name ⇒ String
The human-readable name of the attribute.
Corresponds to the JSON property displayName
1624 1625 1626 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1624 def display_name @display_name end |
#knowledge_graph_attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKnowledgeGraphAttributeMetadata
Metadata associated with a Knowledge Graph Entity attribute.
Corresponds to the JSON property knowledgeGraphAttributeMetadata
1629 1630 1631 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1629 def @knowledge_graph_attribute_metadata end |
#lineup_attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLineupAttributeMetadata
Metadata associated with a Lineup attribute.
Corresponds to the JSON property lineupAttributeMetadata
1634 1635 1636 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1634 def @lineup_attribute_metadata end |
#location_attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationAttributeMetadata
Metadata associated with a Location attribute.
Corresponds to the JSON property locationAttributeMetadata
1639 1640 1641 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1639 def @location_attribute_metadata end |
#potential_youtube_reach ⇒ Fixnum
An estimate of the number of reachable YouTube users matching this attribute
in the requested location, or zero if that information is not available for
this attribute. This field is not populated in every response.
Corresponds to the JSON property potentialYoutubeReach
1646 1647 1648 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1646 def potential_youtube_reach @potential_youtube_reach end |
#subscriber_share ⇒ Float
The share of subscribers within this attribute, between and including 0 and 1.
This field is not populated in every response.
Corresponds to the JSON property subscriberShare
1652 1653 1654 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1652 def subscriber_share @subscriber_share end |
#user_interest_attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserInterestAttributeMetadata
Metadata associated with a User Interest attribute.
Corresponds to the JSON property userInterestAttributeMetadata
1657 1658 1659 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1657 def @user_interest_attribute_metadata end |
#user_list_attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListAttributeMetadata
Metadata associated with a User List attribute.
Corresponds to the JSON property userListAttributeMetadata
1662 1663 1664 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1662 def @user_list_attribute_metadata end |
#viewer_share ⇒ Float
The share of viewers within this attribute, between and including 0 and 1.
This field is not populated in every response.
Corresponds to the JSON property viewerShare
1668 1669 1670 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1668 def viewer_share @viewer_share end |
#youtube_channel_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelAttributeMetadata
Metadata associated with a YouTube channel attribute.
Corresponds to the JSON property youtubeChannelMetadata
1673 1674 1675 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1673 def @youtube_channel_metadata end |
#youtube_video_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoAttributeMetadata
Metadata for a YouTube video attribute.
Corresponds to the JSON property youtubeVideoMetadata
1678 1679 1680 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1678 def @youtube_video_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1685 def update!(**args) @attribute = args[:attribute] if args.key?(:attribute) @dimension = args[:dimension] if args.key?(:dimension) @display_info = args[:display_info] if args.key?(:display_info) @display_name = args[:display_name] if args.key?(:display_name) @knowledge_graph_attribute_metadata = args[:knowledge_graph_attribute_metadata] if args.key?(:knowledge_graph_attribute_metadata) @lineup_attribute_metadata = args[:lineup_attribute_metadata] if args.key?(:lineup_attribute_metadata) @location_attribute_metadata = args[:location_attribute_metadata] if args.key?(:location_attribute_metadata) @potential_youtube_reach = args[:potential_youtube_reach] if args.key?(:potential_youtube_reach) @subscriber_share = args[:subscriber_share] if args.key?(:subscriber_share) @user_interest_attribute_metadata = args[:user_interest_attribute_metadata] if args.key?(:user_interest_attribute_metadata) @user_list_attribute_metadata = args[:user_list_attribute_metadata] if args.key?(:user_list_attribute_metadata) @viewer_share = args[:viewer_share] if args.key?(:viewer_share) @youtube_channel_metadata = args[:youtube_channel_metadata] if args.key?(:youtube_channel_metadata) @youtube_video_metadata = args[:youtube_video_metadata] if args.key?(:youtube_video_metadata) end |