Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A group of audience attributes with metadata, returned in response to a search.
Instance Attribute Summary collapse
-
#attributes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata>
Attributes with metadata returned in response to a search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup
constructor
A new instance of GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup
Returns a new instance of GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup.
1772 1773 1774 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata>
Attributes with metadata returned in response to a search.
Corresponds to the JSON property attributes
1770 1771 1772 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1770 def attributes @attributes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1777 1778 1779 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1777 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) end |