Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A group of audience attributes with metadata, returned in response to a search.
Instance Attribute Summary collapse
-
#attributes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata>
Attributes with metadata returned in response to a search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup
constructor
A new instance of GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup
Returns a new instance of GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup.
1712 1713 1714 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1712 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata>
Attributes with metadata returned in response to a search.
Corresponds to the JSON property attributes
1710 1711 1712 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1710 def attributes @attributes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1717 1718 1719 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1717 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) end |