Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceSegmentDimension

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Dimension specifying users by their membership in other audience segments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonAudienceSegmentDimension

Returns a new instance of GoogleAdsSearchads360V23CommonAudienceSegmentDimension.



1832
1833
1834
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1832

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#segmentsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceSegment>

Included audience segments. Users are included if they belong to at least one segment. Corresponds to the JSON property segments



1830
1831
1832
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1830

def segments
  @segments
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1837
1838
1839
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1837

def update!(**args)
  @segments = args[:segments] if args.key?(:segments)
end