Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents a Brand Criterion used for targeting based on commercial knowledge graph.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#entity_id ⇒ String
The Commercial KG MID for the brand.
-
#primary_url ⇒ String
Output only.
-
#rejection_reason ⇒ String
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBrandInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonBrandInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBrandInfo
Returns a new instance of GoogleAdsSearchads360V23CommonBrandInfo.
1905 1906 1907 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1905 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. A text representation of a brand.
Corresponds to the JSON property displayName
1883 1884 1885 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1883 def display_name @display_name end |
#entity_id ⇒ String
The Commercial KG MID for the brand.
Corresponds to the JSON property entityId
1888 1889 1890 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1888 def entity_id @entity_id end |
#primary_url ⇒ String
Output only. The primary url of a brand.
Corresponds to the JSON property primaryUrl
1893 1894 1895 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1893 def primary_url @primary_url end |
#rejection_reason ⇒ String
Output only. The rejection reason when a brand status is REJECTED.
Corresponds to the JSON property rejectionReason
1898 1899 1900 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1898 def rejection_reason @rejection_reason end |
#status ⇒ String
Output only. The status of a brand.
Corresponds to the JSON property status
1903 1904 1905 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1903 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1910 1911 1912 1913 1914 1915 1916 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1910 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @entity_id = args[:entity_id] if args.key?(:entity_id) @primary_url = args[:primary_url] if args.key?(:primary_url) @rejection_reason = args[:rejection_reason] if args.key?(:rejection_reason) @status = args[:status] if args.key?(:status) end |