Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandListInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandListInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Brand List Criterion is used to specify a list of brands. The list is represented as a SharedSet id type BRAND_HINT. A criterion of this type can be either targeted or excluded.
Instance Attribute Summary collapse
-
#shared_set ⇒ String
Shared set resource name of the brand list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBrandListInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonBrandListInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBrandListInfo
Returns a new instance of GoogleAdsSearchads360V23CommonBrandListInfo.
1930 1931 1932 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1930 def initialize(**args) update!(**args) end |
Instance Attribute Details
#shared_set ⇒ String
Shared set resource name of the brand list.
Corresponds to the JSON property sharedSet
1928 1929 1930 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1928 def shared_set @shared_set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1935 1936 1937 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1935 def update!(**args) @shared_set = args[:shared_set] if args.key?(:shared_set) end |