Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBudgetSimulationPoint
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBudgetSimulationPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Projected metrics for a specific budget amount.
Instance Attribute Summary collapse
-
#biddable_conversions ⇒ Float
Projected number of biddable conversions.
-
#biddable_conversions_value ⇒ Float
Projected total value of biddable conversions.
-
#budget_amount_micros ⇒ Fixnum
The simulated budget upon which projected metrics are based.
-
#clicks ⇒ Fixnum
Projected number of clicks.
-
#cost_micros ⇒ Fixnum
Projected cost in micros.
-
#impressions ⇒ Fixnum
Projected number of impressions.
-
#interactions ⇒ Fixnum
Projected number of interactions.
-
#required_cpc_bid_ceiling_micros ⇒ Fixnum
Projected required daily cpc bid ceiling that the advertiser must set to realize this simulation, in micros of the advertiser currency.
-
#top_slot_impressions ⇒ Fixnum
Projected number of top slot impressions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBudgetSimulationPoint
constructor
A new instance of GoogleAdsSearchads360V23CommonBudgetSimulationPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBudgetSimulationPoint
Returns a new instance of GoogleAdsSearchads360V23CommonBudgetSimulationPoint.
1993 1994 1995 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1993 def initialize(**args) update!(**args) end |
Instance Attribute Details
#biddable_conversions ⇒ Float
Projected number of biddable conversions.
Corresponds to the JSON property biddableConversions
1947 1948 1949 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1947 def biddable_conversions @biddable_conversions end |
#biddable_conversions_value ⇒ Float
Projected total value of biddable conversions.
Corresponds to the JSON property biddableConversionsValue
1952 1953 1954 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1952 def biddable_conversions_value @biddable_conversions_value end |
#budget_amount_micros ⇒ Fixnum
The simulated budget upon which projected metrics are based.
Corresponds to the JSON property budgetAmountMicros
1957 1958 1959 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1957 def budget_amount_micros @budget_amount_micros end |
#clicks ⇒ Fixnum
Projected number of clicks.
Corresponds to the JSON property clicks
1962 1963 1964 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1962 def clicks @clicks end |
#cost_micros ⇒ Fixnum
Projected cost in micros.
Corresponds to the JSON property costMicros
1967 1968 1969 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1967 def cost_micros @cost_micros end |
#impressions ⇒ Fixnum
Projected number of impressions.
Corresponds to the JSON property impressions
1972 1973 1974 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1972 def impressions @impressions end |
#interactions ⇒ Fixnum
Projected number of interactions. Only discovery advertising channel type
supports this field.
Corresponds to the JSON property interactions
1978 1979 1980 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1978 def interactions @interactions end |
#required_cpc_bid_ceiling_micros ⇒ Fixnum
Projected required daily cpc bid ceiling that the advertiser must set to
realize this simulation, in micros of the advertiser currency. Only campaigns
with the Target Spend bidding strategy support this field.
Corresponds to the JSON property requiredCpcBidCeilingMicros
1985 1986 1987 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1985 def required_cpc_bid_ceiling_micros @required_cpc_bid_ceiling_micros end |
#top_slot_impressions ⇒ Fixnum
Projected number of top slot impressions. Only search advertising channel type
supports this field.
Corresponds to the JSON property topSlotImpressions
1991 1992 1993 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1991 def top_slot_impressions @top_slot_impressions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 1998 def update!(**args) @biddable_conversions = args[:biddable_conversions] if args.key?(:biddable_conversions) @biddable_conversions_value = args[:biddable_conversions_value] if args.key?(:biddable_conversions_value) @budget_amount_micros = args[:budget_amount_micros] if args.key?(:budget_amount_micros) @clicks = args[:clicks] if args.key?(:clicks) @cost_micros = args[:cost_micros] if args.key?(:cost_micros) @impressions = args[:impressions] if args.key?(:impressions) @interactions = args[:interactions] if args.key?(:interactions) @required_cpc_bid_ceiling_micros = args[:required_cpc_bid_ceiling_micros] if args.key?(:required_cpc_bid_ceiling_micros) @top_slot_impressions = args[:top_slot_impressions] if args.key?(:top_slot_impressions) end |