Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessMessageAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessMessageAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A business message asset.
Instance Attribute Summary collapse
-
#call_to_action ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessMessageCallToActionInfo
Display information that encourages the user to take action.
-
#facebook_messenger_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFacebookMessengerBusinessMessageInfo
Facebook Messenger information to use for messaging.
-
#message_provider ⇒ String
Required.
-
#starter_message ⇒ String
Required.
-
#whatsapp_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWhatsappBusinessMessageInfo
Whatsapp information to use for messaging.
-
#zalo_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonZaloBusinessMessageInfo
Zalo information to use for messaging.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBusinessMessageAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonBusinessMessageAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBusinessMessageAsset
Returns a new instance of GoogleAdsSearchads360V23CommonBusinessMessageAsset.
2064 2065 2066 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2064 def initialize(**args) update!(**args) end |
Instance Attribute Details
#call_to_action ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessMessageCallToActionInfo
Display information that encourages the user to take action.
Corresponds to the JSON property callToAction
2037 2038 2039 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2037 def call_to_action @call_to_action end |
#facebook_messenger_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFacebookMessengerBusinessMessageInfo
Facebook Messenger information to use for messaging.
Corresponds to the JSON property facebookMessengerInfo
2042 2043 2044 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2042 def facebook_messenger_info @facebook_messenger_info end |
#message_provider ⇒ String
Required. Message provider of the business message asset.
Corresponds to the JSON property messageProvider
2047 2048 2049 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2047 def @message_provider end |
#starter_message ⇒ String
Required. A welcome message to prompt the user to initiate a conversation.
Corresponds to the JSON property starterMessage
2052 2053 2054 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2052 def @starter_message end |
#whatsapp_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWhatsappBusinessMessageInfo
Whatsapp information to use for messaging.
Corresponds to the JSON property whatsappInfo
2057 2058 2059 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2057 def whatsapp_info @whatsapp_info end |
#zalo_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonZaloBusinessMessageInfo
Zalo information to use for messaging.
Corresponds to the JSON property zaloInfo
2062 2063 2064 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2062 def zalo_info @zalo_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2069 2070 2071 2072 2073 2074 2075 2076 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2069 def update!(**args) @call_to_action = args[:call_to_action] if args.key?(:call_to_action) @facebook_messenger_info = args[:facebook_messenger_info] if args.key?(:facebook_messenger_info) @message_provider = args[:message_provider] if args.key?(:message_provider) @starter_message = args[:starter_message] if args.key?(:starter_message) @whatsapp_info = args[:whatsapp_info] if args.key?(:whatsapp_info) @zalo_info = args[:zalo_info] if args.key?(:zalo_info) end |