Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessMessageCallToActionInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessMessageCallToActionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Display information that encourages the user to take action.
Instance Attribute Summary collapse
-
#call_to_action_description ⇒ String
Required.
-
#call_to_action_selection ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBusinessMessageCallToActionInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonBusinessMessageCallToActionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBusinessMessageCallToActionInfo
Returns a new instance of GoogleAdsSearchads360V23CommonBusinessMessageCallToActionInfo.
2095 2096 2097 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2095 def initialize(**args) update!(**args) end |
Instance Attribute Details
#call_to_action_description ⇒ String
Required. Text providing a clear value proposition of what users expect once
they take the action. Examples: 'Message us for a quote', 'Ask our expert team'
.
Corresponds to the JSON property callToActionDescription
2088 2089 2090 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2088 def call_to_action_description @call_to_action_description end |
#call_to_action_selection ⇒ String
Required. Pre-defined call to action text.
Corresponds to the JSON property callToActionSelection
2093 2094 2095 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2093 def call_to_action_selection @call_to_action_selection end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2100 2101 2102 2103 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2100 def update!(**args) @call_to_action_description = args[:call_to_action_description] if args.key?(:call_to_action_description) @call_to_action_selection = args[:call_to_action_selection] if args.key?(:call_to_action_selection) end |