Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileBusinessNameFilter
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileBusinessNameFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Business Profile location group business name filter.
Instance Attribute Summary collapse
-
#business_name ⇒ String
Business name string to use for filtering.
-
#filter_type ⇒ String
The type of string matching to use when filtering with business_name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBusinessProfileBusinessNameFilter
constructor
A new instance of GoogleAdsSearchads360V23CommonBusinessProfileBusinessNameFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBusinessProfileBusinessNameFilter
Returns a new instance of GoogleAdsSearchads360V23CommonBusinessProfileBusinessNameFilter.
2120 2121 2122 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_name ⇒ String
Business name string to use for filtering.
Corresponds to the JSON property businessName
2113 2114 2115 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2113 def business_name @business_name end |
#filter_type ⇒ String
The type of string matching to use when filtering with business_name.
Corresponds to the JSON property filterType
2118 2119 2120 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2118 def filter_type @filter_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2125 2126 2127 2128 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2125 def update!(**args) @business_name = args[:business_name] if args.key?(:business_name) @filter_type = args[:filter_type] if args.key?(:filter_type) end |