Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileLocation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Business Profile location data synced from the linked Business Profile account.
Instance Attribute Summary collapse
-
#labels ⇒ Array<String>
Advertiser specified label for the location on the Business Profile account.
-
#listing_id ⇒ Fixnum
Listing ID of this Business Profile location.
-
#store_code ⇒ String
Business Profile store code of this location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBusinessProfileLocation
constructor
A new instance of GoogleAdsSearchads360V23CommonBusinessProfileLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBusinessProfileLocation
Returns a new instance of GoogleAdsSearchads360V23CommonBusinessProfileLocation.
2153 2154 2155 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2153 def initialize(**args) update!(**args) end |
Instance Attribute Details
#labels ⇒ Array<String>
Advertiser specified label for the location on the Business Profile account.
This is synced from the Business Profile account.
Corresponds to the JSON property labels
2139 2140 2141 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2139 def labels @labels end |
#listing_id ⇒ Fixnum
Listing ID of this Business Profile location. This is synced from the linked
Business Profile account.
Corresponds to the JSON property listingId
2145 2146 2147 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2145 def listing_id @listing_id end |
#store_code ⇒ String
Business Profile store code of this location. This is synced from the Business
Profile account.
Corresponds to the JSON property storeCode
2151 2152 2153 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2151 def store_code @store_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2158 2159 2160 2161 2162 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2158 def update!(**args) @labels = args[:labels] if args.key?(:labels) @listing_id = args[:listing_id] if args.key?(:listing_id) @store_code = args[:store_code] if args.key?(:store_code) end |