Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileLocationSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Data used to configure a location set populated from Google Business Profile locations. Different types of filters are AND'ed together, if they are specified.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonBusinessProfileLocationSet

Returns a new instance of GoogleAdsSearchads360V23CommonBusinessProfileLocationSet.



2235
2236
2237
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_account_idString

Immutable. The account ID of the managed business whose locations are to be used. If this field is not set, then all businesses accessible by the user ( specified by the emailAddress) are used. Corresponds to the JSON property businessAccountId

Returns:

  • (String)


2198
2199
2200
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2198

def 
  @business_account_id
end

#business_name_filterString

Used to filter Google Business Profile listings by business name. If businessNameFilter is set, only listings with a matching business name are candidates to be sync'd into Assets. Corresponds to the JSON property businessNameFilter

Returns:

  • (String)


2205
2206
2207
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2205

def business_name_filter
  @business_name_filter
end

#email_addressString

Required. Immutable. Email address of a Google Business Profile account or email address of a manager of the Google Business Profile account. Corresponds to the JSON property emailAddress

Returns:

  • (String)


2211
2212
2213
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2211

def email_address
  @email_address
end

#http_authorization_tokenString

Required. Immutable. The HTTP authorization token used to obtain authorization. Corresponds to the JSON property httpAuthorizationToken

Returns:

  • (String)


2216
2217
2218
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2216

def http_authorization_token
  @http_authorization_token
end

#label_filtersArray<String>

Used to filter Google Business Profile listings by labels. If entries exist in labelFilters, only listings that have any of the labels set are candidates to be synchronized into Assets. If no entries exist in labelFilters, then all listings are candidates for syncing. Label filters are OR'ed together. Corresponds to the JSON property labelFilters

Returns:

  • (Array<String>)


2224
2225
2226
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2224

def label_filters
  @label_filters
end

#listing_id_filtersArray<Fixnum>

Used to filter Google Business Profile listings by listing id. If entries exist in listingIdFilters, only listings specified by the filters are candidates to be synchronized into Assets. If no entries exist in listingIdFilters, then all listings are candidates for syncing. Listing ID filters are OR'ed together. Corresponds to the JSON property listingIdFilters

Returns:

  • (Array<Fixnum>)


2233
2234
2235
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2233

def listing_id_filters
  @listing_id_filters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2240
2241
2242
2243
2244
2245
2246
2247
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2240

def update!(**args)
  @business_account_id = args[:business_account_id] if args.key?(:business_account_id)
  @business_name_filter = args[:business_name_filter] if args.key?(:business_name_filter)
  @email_address = args[:email_address] if args.key?(:email_address)
  @http_authorization_token = args[:http_authorization_token] if args.key?(:http_authorization_token)
  @label_filters = args[:label_filters] if args.key?(:label_filters)
  @listing_id_filters = args[:listing_id_filters] if args.key?(:listing_id_filters)
end