Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCallFeedItem
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCallFeedItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents a Call extension.
Instance Attribute Summary collapse
-
#call_conversion_action ⇒ String
The conversion action to attribute a call conversion to.
-
#call_conversion_reporting_state ⇒ String
Enum value that indicates whether this call extension uses its own call conversion setting (or just have call conversion disabled), or following the account level setting.
-
#call_conversion_tracking_disabled ⇒ Boolean
(also: #call_conversion_tracking_disabled?)
If true, disable call conversion tracking.
-
#call_tracking_enabled ⇒ Boolean
(also: #call_tracking_enabled?)
Indicates whether call tracking is enabled.
-
#country_code ⇒ String
Uppercase two-letter country code of the advertiser's phone number.
-
#phone_number ⇒ String
The advertiser's phone number to append to the ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCallFeedItem
constructor
A new instance of GoogleAdsSearchads360V23CommonCallFeedItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCallFeedItem
Returns a new instance of GoogleAdsSearchads360V23CommonCallFeedItem.
2343 2344 2345 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#call_conversion_action ⇒ String
The conversion action to attribute a call conversion to. If not set a default
conversion action is used. This field only has effect if call_tracking_enabled
is set to true. Otherwise this field is ignored.
Corresponds to the JSON property callConversionAction
2308 2309 2310 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2308 def call_conversion_action @call_conversion_action end |
#call_conversion_reporting_state ⇒ String
Enum value that indicates whether this call extension uses its own call
conversion setting (or just have call conversion disabled), or following the
account level setting.
Corresponds to the JSON property callConversionReportingState
2315 2316 2317 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2315 def call_conversion_reporting_state @call_conversion_reporting_state end |
#call_conversion_tracking_disabled ⇒ Boolean Also known as: call_conversion_tracking_disabled?
If true, disable call conversion tracking. call_conversion_action should not
be set if this is true. Optional.
Corresponds to the JSON property callConversionTrackingDisabled
2321 2322 2323 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2321 def call_conversion_tracking_disabled @call_conversion_tracking_disabled end |
#call_tracking_enabled ⇒ Boolean Also known as: call_tracking_enabled?
Indicates whether call tracking is enabled. By default, call tracking is not
enabled.
Corresponds to the JSON property callTrackingEnabled
2328 2329 2330 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2328 def call_tracking_enabled @call_tracking_enabled end |
#country_code ⇒ String
Uppercase two-letter country code of the advertiser's phone number. This
string must not be empty.
Corresponds to the JSON property countryCode
2335 2336 2337 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2335 def country_code @country_code end |
#phone_number ⇒ String
The advertiser's phone number to append to the ad. This string must not be
empty.
Corresponds to the JSON property phoneNumber
2341 2342 2343 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2341 def phone_number @phone_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2348 2349 2350 2351 2352 2353 2354 2355 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2348 def update!(**args) @call_conversion_action = args[:call_conversion_action] if args.key?(:call_conversion_action) @call_conversion_reporting_state = args[:call_conversion_reporting_state] if args.key?(:call_conversion_reporting_state) @call_conversion_tracking_disabled = args[:call_conversion_tracking_disabled] if args.key?(:call_conversion_tracking_disabled) @call_tracking_enabled = args[:call_tracking_enabled] if args.key?(:call_tracking_enabled) @country_code = args[:country_code] if args.key?(:country_code) @phone_number = args[:phone_number] if args.key?(:phone_number) end |