Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCalloutAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Callout asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCalloutAsset

Returns a new instance of GoogleAdsSearchads360V23CommonCalloutAsset.



2405
2406
2407
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2405

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_schedule_targetsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>

List of non-overlapping schedules specifying all time intervals for which the asset may serve. There can be a maximum of 6 schedules per day, 42 in total. Corresponds to the JSON property adScheduleTargets



2385
2386
2387
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2385

def ad_schedule_targets
  @ad_schedule_targets
end

#callout_textString

Required. The callout text. The length of this string should be between 1 and 25, inclusive. Corresponds to the JSON property calloutText

Returns:

  • (String)


2391
2392
2393
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2391

def callout_text
  @callout_text
end

#end_dateString

Last date of when this asset is effective and still serving, in yyyy-MM-dd format. Corresponds to the JSON property endDate

Returns:

  • (String)


2397
2398
2399
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2397

def end_date
  @end_date
end

#start_dateString

Start date of when this asset is effective and can begin serving, in yyyy-MM- dd format. Corresponds to the JSON property startDate

Returns:

  • (String)


2403
2404
2405
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2403

def start_date
  @start_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2410
2411
2412
2413
2414
2415
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2410

def update!(**args)
  @ad_schedule_targets = args[:ad_schedule_targets] if args.key?(:ad_schedule_targets)
  @callout_text = args[:callout_text] if args.key?(:callout_text)
  @end_date = args[:end_date] if args.key?(:end_date)
  @start_date = args[:start_date] if args.key?(:start_date)
end