Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonChainFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

One chain level filter on location in a feed item set. The filtering logic among all the fields is AND.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonChainFilter

Returns a new instance of GoogleAdsSearchads360V23CommonChainFilter.



2635
2636
2637
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2635

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chain_idFixnum

Required. Used to filter chain locations by chain id. Only chain locations that belong to the specified chain will be in the asset set. Corresponds to the JSON property chainId

Returns:

  • (Fixnum)


2626
2627
2628
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2626

def chain_id
  @chain_id
end

#location_attributesArray<String>

Used to filter chain locations by location attributes. Only chain locations that belong to all of the specified attribute(s) will be in the asset set. If this field is empty, it means no filtering on this field. Corresponds to the JSON property locationAttributes

Returns:

  • (Array<String>)


2633
2634
2635
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2633

def location_attributes
  @location_attributes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2640
2641
2642
2643
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2640

def update!(**args)
  @chain_id = args[:chain_id] if args.key?(:chain_id)
  @location_attributes = args[:location_attributes] if args.key?(:location_attributes)
end