Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonChainSet
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonChainSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Data used to configure a location set populated with the specified chains.
Instance Attribute Summary collapse
-
#chains ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonChainFilter>
Required.
-
#relationship_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonChainSet
constructor
A new instance of GoogleAdsSearchads360V23CommonChainSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonChainSet
Returns a new instance of GoogleAdsSearchads360V23CommonChainSet.
2682 2683 2684 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2682 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chains ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonChainFilter>
Required. A list of chain level filters, all filters are OR'ed together.
Corresponds to the JSON property chains
2674 2675 2676 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2674 def chains @chains end |
#relationship_type ⇒ String
Required. Immutable. Relationship type the specified chains have with this
advertiser.
Corresponds to the JSON property relationshipType
2680 2681 2682 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2680 def relationship_type @relationship_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2687 2688 2689 2690 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2687 def update!(**args) @chains = args[:chains] if args.key?(:chains) @relationship_type = args[:relationship_type] if args.key?(:relationship_type) end |