Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpcBidSimulationPoint
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpcBidSimulationPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Projected metrics for a specific CPC bid amount.
Instance Attribute Summary collapse
-
#biddable_conversions ⇒ Float
Projected number of biddable conversions.
-
#biddable_conversions_value ⇒ Float
Projected total value of biddable conversions.
-
#clicks ⇒ Fixnum
Projected number of clicks.
-
#cost_micros ⇒ Fixnum
Projected cost in micros.
-
#cpc_bid_micros ⇒ Fixnum
The simulated CPC bid upon which projected metrics are based.
-
#cpc_bid_scaling_modifier ⇒ Float
The simulated scaling modifier upon which projected metrics are based.
-
#impressions ⇒ Fixnum
Projected number of impressions.
-
#required_budget_amount_micros ⇒ Fixnum
Projected required daily budget that the advertiser must set in order to receive the estimated traffic, in micros of advertiser currency.
-
#top_slot_impressions ⇒ Fixnum
Projected number of top slot impressions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCpcBidSimulationPoint
constructor
A new instance of GoogleAdsSearchads360V23CommonCpcBidSimulationPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCpcBidSimulationPoint
Returns a new instance of GoogleAdsSearchads360V23CommonCpcBidSimulationPoint.
2960 2961 2962 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2960 def initialize(**args) update!(**args) end |
Instance Attribute Details
#biddable_conversions ⇒ Float
Projected number of biddable conversions.
Corresponds to the JSON property biddableConversions
2915 2916 2917 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2915 def biddable_conversions @biddable_conversions end |
#biddable_conversions_value ⇒ Float
Projected total value of biddable conversions.
Corresponds to the JSON property biddableConversionsValue
2920 2921 2922 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2920 def biddable_conversions_value @biddable_conversions_value end |
#clicks ⇒ Fixnum
Projected number of clicks.
Corresponds to the JSON property clicks
2925 2926 2927 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2925 def clicks @clicks end |
#cost_micros ⇒ Fixnum
Projected cost in micros.
Corresponds to the JSON property costMicros
2930 2931 2932 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2930 def cost_micros @cost_micros end |
#cpc_bid_micros ⇒ Fixnum
The simulated CPC bid upon which projected metrics are based.
Corresponds to the JSON property cpcBidMicros
2935 2936 2937 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2935 def cpc_bid_micros @cpc_bid_micros end |
#cpc_bid_scaling_modifier ⇒ Float
The simulated scaling modifier upon which projected metrics are based. All CPC
bids relevant to the simulated entity are scaled by this modifier.
Corresponds to the JSON property cpcBidScalingModifier
2941 2942 2943 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2941 def cpc_bid_scaling_modifier @cpc_bid_scaling_modifier end |
#impressions ⇒ Fixnum
Projected number of impressions.
Corresponds to the JSON property impressions
2946 2947 2948 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2946 def impressions @impressions end |
#required_budget_amount_micros ⇒ Fixnum
Projected required daily budget that the advertiser must set in order to
receive the estimated traffic, in micros of advertiser currency.
Corresponds to the JSON property requiredBudgetAmountMicros
2952 2953 2954 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2952 def required_budget_amount_micros @required_budget_amount_micros end |
#top_slot_impressions ⇒ Fixnum
Projected number of top slot impressions. Only search advertising channel type
supports this field.
Corresponds to the JSON property topSlotImpressions
2958 2959 2960 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2958 def top_slot_impressions @top_slot_impressions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 2965 def update!(**args) @biddable_conversions = args[:biddable_conversions] if args.key?(:biddable_conversions) @biddable_conversions_value = args[:biddable_conversions_value] if args.key?(:biddable_conversions_value) @clicks = args[:clicks] if args.key?(:clicks) @cost_micros = args[:cost_micros] if args.key?(:cost_micros) @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros) @cpc_bid_scaling_modifier = args[:cpc_bid_scaling_modifier] if args.key?(:cpc_bid_scaling_modifier) @impressions = args[:impressions] if args.key?(:impressions) @required_budget_amount_micros = args[:required_budget_amount_micros] if args.key?(:required_budget_amount_micros) @top_slot_impressions = args[:top_slot_impressions] if args.key?(:top_slot_impressions) end |