Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryAvailability
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryAvailability
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Information of category availability, per advertising channel.
Instance Attribute Summary collapse
-
#channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryChannelAvailability
Information of advertising channel type and subtypes a category is available in.
-
#locale ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryLocaleAvailability>
Locales that are available to the category for the channel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCriterionCategoryAvailability
constructor
A new instance of GoogleAdsSearchads360V23CommonCriterionCategoryAvailability.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCriterionCategoryAvailability
Returns a new instance of GoogleAdsSearchads360V23CommonCriterionCategoryAvailability.
3008 3009 3010 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3008 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryChannelAvailability
Information of advertising channel type and subtypes a category is available
in.
Corresponds to the JSON property channel
3001 3002 3003 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3001 def channel @channel end |
#locale ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryLocaleAvailability>
Locales that are available to the category for the channel.
Corresponds to the JSON property locale
3006 3007 3008 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3006 def locale @locale end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3013 3014 3015 3016 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3013 def update!(**args) @channel = args[:channel] if args.key?(:channel) @locale = args[:locale] if args.key?(:locale) end |