Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryChannelAvailability
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryChannelAvailability
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Information of advertising channel type and subtypes a category is available in.
Instance Attribute Summary collapse
-
#advertising_channel_sub_type ⇒ Array<String>
Channel subtypes under the channel type the category is available to.
-
#advertising_channel_type ⇒ String
Channel type the category is available to.
-
#availability_mode ⇒ String
Format of the channel availability.
-
#include_default_channel_sub_type ⇒ Boolean
(also: #include_default_channel_sub_type?)
Whether default channel sub type is included.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCriterionCategoryChannelAvailability
constructor
A new instance of GoogleAdsSearchads360V23CommonCriterionCategoryChannelAvailability.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCriterionCategoryChannelAvailability
Returns a new instance of GoogleAdsSearchads360V23CommonCriterionCategoryChannelAvailability.
3053 3054 3055 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertising_channel_sub_type ⇒ Array<String>
Channel subtypes under the channel type the category is available to.
Corresponds to the JSON property advertisingChannelSubType
3027 3028 3029 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3027 def advertising_channel_sub_type @advertising_channel_sub_type end |
#advertising_channel_type ⇒ String
Channel type the category is available to.
Corresponds to the JSON property advertisingChannelType
3032 3033 3034 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3032 def advertising_channel_type @advertising_channel_type end |
#availability_mode ⇒ String
Format of the channel availability. Can be ALL_CHANNELS (the rest of the
fields will not be set), CHANNEL_TYPE (only advertising_channel_type type will
be set, the category is available to all sub types under it) or
CHANNEL_TYPE_AND_SUBTYPES (advertising_channel_type,
advertising_channel_sub_type, and include_default_channel_sub_type will all be
set).
Corresponds to the JSON property availabilityMode
3042 3043 3044 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3042 def availability_mode @availability_mode end |
#include_default_channel_sub_type ⇒ Boolean Also known as: include_default_channel_sub_type?
Whether default channel sub type is included. For example,
advertising_channel_type being DISPLAY and include_default_channel_sub_type
being false means that the default display campaign where channel sub type is
not set is not included in this availability configuration.
Corresponds to the JSON property includeDefaultChannelSubType
3050 3051 3052 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3050 def include_default_channel_sub_type @include_default_channel_sub_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3058 3059 3060 3061 3062 3063 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3058 def update!(**args) @advertising_channel_sub_type = args[:advertising_channel_sub_type] if args.key?(:advertising_channel_sub_type) @advertising_channel_type = args[:advertising_channel_type] if args.key?(:advertising_channel_type) @availability_mode = args[:availability_mode] if args.key?(:availability_mode) @include_default_channel_sub_type = args[:include_default_channel_sub_type] if args.key?(:include_default_channel_sub_type) end |