Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCrmBasedUserListInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

UserList of CRM users provided by the advertiser.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCrmBasedUserListInfo

Returns a new instance of GoogleAdsSearchads360V23CommonCrmBasedUserListInfo.



3128
3129
3130
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

A string that uniquely identifies a mobile application from which the data was collected. For iOS, the ID string is the 9 digit string that appears at the end of an App Store URL (for example, "476943146" for "Flood-It! 2" whose App Store link is http://itunes.apple.com/us/app/flood-it!-2/id476943146). For Android, the ID string is the application's package name (for example, "com. labpixies.colordrips" for "Color Drips" given Google Play link https://play. google.com/store/apps/details?id=com.labpixies.colordrips). Required when creating CrmBasedUserList for uploading mobile advertising IDs. Corresponds to the JSON property appId

Returns:

  • (String)


3114
3115
3116
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3114

def app_id
  @app_id
end

#data_source_typeString

Data source of the list. Default value is FIRST_PARTY. Only customers on the allow-list can create third-party sourced CRM lists. Corresponds to the JSON property dataSourceType

Returns:

  • (String)


3120
3121
3122
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3120

def data_source_type
  @data_source_type
end

#upload_key_typeString

Matching key type of the list. Mixed data types are not allowed on the same list. This field is required for an ADD operation. Corresponds to the JSON property uploadKeyType

Returns:

  • (String)


3126
3127
3128
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3126

def upload_key_type
  @upload_key_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3133
3134
3135
3136
3137
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3133

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @data_source_type = args[:data_source_type] if args.key?(:data_source_type)
  @upload_key_type = args[:upload_key_type] if args.key?(:upload_key_type)
end