Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerLifecycleOptimizationValueSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Lifecycle goal optimization value settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomerLifecycleOptimizationValueSettings

Returns a new instance of GoogleAdsSearchads360V23CommonCustomerLifecycleOptimizationValueSettings.



3260
3261
3262
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3260

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_high_lifetime_valueFloat

High lifetime value of the lifecycle goal. For example, for customer acquisition goals, high lifetime value is the incremental conversion value for lapsed customers who are of high value. High lifetime value should be greater than value, if set. Corresponds to the JSON property additionalHighLifetimeValue

Returns:

  • (Float)


3252
3253
3254
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3252

def additional_high_lifetime_value
  @additional_high_lifetime_value
end

#additional_valueFloat

Value of the lifecycle goal. For example, for retention goals, value is the incremental conversion value for lapsed customers who are not of high value. Corresponds to the JSON property additionalValue

Returns:

  • (Float)


3258
3259
3260
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3258

def additional_value
  @additional_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3265
3266
3267
3268
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3265

def update!(**args)
  @additional_high_lifetime_value = args[:additional_high_lifetime_value] if args.key?(:additional_high_lifetime_value)
  @additional_value = args[:additional_value] if args.key?(:additional_value)
end