Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Metadata for customer match user list.
Instance Attribute Summary collapse
-
#consent ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonConsent
Consent Corresponds to the JSON property
consent. -
#user_list ⇒ String
The resource name of remarketing list to update data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata
constructor
A new instance of GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata
Returns a new instance of GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata.
3286 3287 3288 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3286 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consent ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonConsent
Consent
Corresponds to the JSON property consent
3278 3279 3280 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3278 def @consent end |
#user_list ⇒ String
The resource name of remarketing list to update data. Required for job of
CUSTOMER_MATCH_USER_LIST type.
Corresponds to the JSON property userList
3284 3285 3286 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3284 def user_list @user_list end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3291 3292 3293 3294 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3291 def update!(**args) @consent = args[:consent] if args.key?(:consent) @user_list = args[:user_list] if args.key?(:user_list) end |