Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerThirdPartyBrandLiftIntegrationPartner

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Container for third party Brand Lift integration data for Customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomerThirdPartyBrandLiftIntegrationPartner

Returns a new instance of GoogleAdsSearchads360V23CommonCustomerThirdPartyBrandLiftIntegrationPartner.



3312
3313
3314
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3312

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_share_costBoolean Also known as: allow_share_cost?

If true, cost data can be shared with this vendor. Corresponds to the JSON property allowShareCost

Returns:

  • (Boolean)


3304
3305
3306
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3304

def allow_share_cost
  @allow_share_cost
end

#brand_lift_integration_partnerString

Allowed Third Party integration partners for Brand Lift verification. Corresponds to the JSON property brandLiftIntegrationPartner

Returns:

  • (String)


3310
3311
3312
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3310

def brand_lift_integration_partner
  @brand_lift_integration_partner
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3317
3318
3319
3320
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3317

def update!(**args)
  @allow_share_cost = args[:allow_share_cost] if args.key?(:allow_share_cost)
  @brand_lift_integration_partner = args[:brand_lift_integration_partner] if args.key?(:brand_lift_integration_partner)
end