Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerThirdPartyBrandSafetyIntegrationPartner
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerThirdPartyBrandSafetyIntegrationPartner
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Container for third party brand safety integration data for Customer.
Instance Attribute Summary collapse
-
#brand_safety_integration_partner ⇒ String
Allowed third party integration partners for brand safety verification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomerThirdPartyBrandSafetyIntegrationPartner
constructor
A new instance of GoogleAdsSearchads360V23CommonCustomerThirdPartyBrandSafetyIntegrationPartner.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomerThirdPartyBrandSafetyIntegrationPartner
Returns a new instance of GoogleAdsSearchads360V23CommonCustomerThirdPartyBrandSafetyIntegrationPartner.
3332 3333 3334 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3332 def initialize(**args) update!(**args) end |
Instance Attribute Details
#brand_safety_integration_partner ⇒ String
Allowed third party integration partners for brand safety verification.
Corresponds to the JSON property brandSafetyIntegrationPartner
3330 3331 3332 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3330 def brand_safety_integration_partner @brand_safety_integration_partner end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3337 3338 3339 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3337 def update!(**args) @brand_safety_integration_partner = args[:brand_safety_integration_partner] if args.key?(:brand_safety_integration_partner) end |