Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerThirdPartyReachIntegrationPartner

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Container for third party reach integration data for Customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomerThirdPartyReachIntegrationPartner

Returns a new instance of GoogleAdsSearchads360V23CommonCustomerThirdPartyReachIntegrationPartner.



3394
3395
3396
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3394

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_share_costBoolean Also known as: allow_share_cost?

If true, cost data can be shared with this vendor. Corresponds to the JSON property allowShareCost

Returns:

  • (Boolean)


3386
3387
3388
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3386

def allow_share_cost
  @allow_share_cost
end

#reach_integration_partnerString

Allowed Third Party integration partners for reach verification. Corresponds to the JSON property reachIntegrationPartner

Returns:

  • (String)


3392
3393
3394
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3392

def reach_integration_partner
  @reach_integration_partner
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3399
3400
3401
3402
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3399

def update!(**args)
  @allow_share_cost = args[:allow_share_cost] if args.key?(:allow_share_cost)
  @reach_integration_partner = args[:reach_integration_partner] if args.key?(:reach_integration_partner)
end