Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerThirdPartyViewabilityIntegrationPartner
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerThirdPartyViewabilityIntegrationPartner
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Container for third party viewability integration data for Customer.
Instance Attribute Summary collapse
-
#allow_share_cost ⇒ Boolean
(also: #allow_share_cost?)
If true, cost data can be shared with this vendor.
-
#viewability_integration_partner ⇒ String
Allowed third party integration partners for YouTube viewability verification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomerThirdPartyViewabilityIntegrationPartner
constructor
A new instance of GoogleAdsSearchads360V23CommonCustomerThirdPartyViewabilityIntegrationPartner.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomerThirdPartyViewabilityIntegrationPartner
Returns a new instance of GoogleAdsSearchads360V23CommonCustomerThirdPartyViewabilityIntegrationPartner.
3420 3421 3422 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3420 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_share_cost ⇒ Boolean Also known as:
If true, cost data can be shared with this vendor.
Corresponds to the JSON property allowShareCost
3412 3413 3414 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3412 def allow_share_cost @allow_share_cost end |
#viewability_integration_partner ⇒ String
Allowed third party integration partners for YouTube viewability verification.
Corresponds to the JSON property viewabilityIntegrationPartner
3418 3419 3420 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3418 def viewability_integration_partner @viewability_integration_partner end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3425 3426 3427 3428 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3425 def update!(**args) @allow_share_cost = args[:allow_share_cost] if args.key?(:allow_share_cost) @viewability_integration_partner = args[:viewability_integration_partner] if args.key?(:viewability_integration_partner) end |