Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A customizer value that is referenced in customizer linkage entities like CustomerCustomizer, CampaignCustomizer, etc.
Instance Attribute Summary collapse
-
#string_value ⇒ String
Required.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomizerValue
constructor
A new instance of GoogleAdsSearchads360V23CommonCustomizerValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonCustomizerValue
Returns a new instance of GoogleAdsSearchads360V23CommonCustomizerValue.
3449 3450 3451 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3449 def initialize(**args) update!(**args) end |
Instance Attribute Details
#string_value ⇒ String
Required. Value to insert in creative text. Customizer values of all types are
stored as string to make formatting unambiguous.
Corresponds to the JSON property stringValue
3440 3441 3442 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3440 def string_value @string_value end |
#type ⇒ String
Required. The data type for the customizer value. It must match the attribute
type. The string_value content must match the constraints associated with the
type.
Corresponds to the JSON property type
3447 3448 3449 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3447 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3454 3455 3456 3457 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3454 def update!(**args) @string_value = args[:string_value] if args.key?(:string_value) @type = args[:type] if args.key?(:type) end |