Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenCarouselCardAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenCarouselCardAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Demand Gen Carousel Card asset.
Instance Attribute Summary collapse
-
#call_to_action_text ⇒ String
Call to action text.
-
#headline ⇒ String
Required.
-
#marketing_image_asset ⇒ String
Asset resource name of the associated 1.91:1 marketing image.
-
#portrait_marketing_image_asset ⇒ String
Asset resource name of the associated 4:5 portrait marketing image.
-
#square_marketing_image_asset ⇒ String
Asset resource name of the associated square marketing image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDemandGenCarouselCardAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonDemandGenCarouselCardAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDemandGenCarouselCardAsset
Returns a new instance of GoogleAdsSearchads360V23CommonDemandGenCarouselCardAsset.
3565 3566 3567 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#call_to_action_text ⇒ String
Call to action text.
Corresponds to the JSON property callToActionText
3541 3542 3543 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3541 def call_to_action_text @call_to_action_text end |
#headline ⇒ String
Required. Headline of the carousel card.
Corresponds to the JSON property headline
3546 3547 3548 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3546 def headline @headline end |
#marketing_image_asset ⇒ String
Asset resource name of the associated 1.91:1 marketing image. This and/or
square marketing image asset is required.
Corresponds to the JSON property marketingImageAsset
3552 3553 3554 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3552 def marketing_image_asset @marketing_image_asset end |
#portrait_marketing_image_asset ⇒ String
Asset resource name of the associated 4:5 portrait marketing image.
Corresponds to the JSON property portraitMarketingImageAsset
3557 3558 3559 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3557 def portrait_marketing_image_asset @portrait_marketing_image_asset end |
#square_marketing_image_asset ⇒ String
Asset resource name of the associated square marketing image. This and/or a
marketing image asset is required.
Corresponds to the JSON property squareMarketingImageAsset
3563 3564 3565 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3563 def square_marketing_image_asset @square_marketing_image_asset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3570 3571 3572 3573 3574 3575 3576 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3570 def update!(**args) @call_to_action_text = args[:call_to_action_text] if args.key?(:call_to_action_text) @headline = args[:headline] if args.key?(:headline) @marketing_image_asset = args[:marketing_image_asset] if args.key?(:marketing_image_asset) @portrait_marketing_image_asset = args[:portrait_marketing_image_asset] if args.key?(:portrait_marketing_image_asset) @square_marketing_image_asset = args[:square_marketing_image_asset] if args.key?(:square_marketing_image_asset) end |