Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenMultiAssetAdInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenMultiAssetAdInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Demand Gen multi asset ad.
Instance Attribute Summary collapse
-
#business_name ⇒ String
The Advertiser/brand name.
-
#call_to_action_text ⇒ String
Call to action text.
-
#descriptions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
The descriptive text of the ad.
-
#headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
Headline text asset of the ad.
-
#logo_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Logo image assets to be used in the ad.
-
#marketing_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Marketing image assets to be used in the ad.
-
#portrait_marketing_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Portrait marketing image assets to be used in the ad.
-
#square_marketing_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Square marketing image assets to be used in the ad.
-
#tall_portrait_marketing_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Tall portrait marketing image assets to be used in the ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDemandGenMultiAssetAdInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonDemandGenMultiAssetAdInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDemandGenMultiAssetAdInfo
Returns a new instance of GoogleAdsSearchads360V23CommonDemandGenMultiAssetAdInfo.
3701 3702 3703 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3701 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_name ⇒ String
The Advertiser/brand name. Maximum display width is 25. Required.
Corresponds to the JSON property businessName
3646 3647 3648 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3646 def business_name @business_name end |
#call_to_action_text ⇒ String
Call to action text.
Corresponds to the JSON property callToActionText
3651 3652 3653 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3651 def call_to_action_text @call_to_action_text end |
#descriptions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
The descriptive text of the ad. Maximum display width is 90. At least 1 and
max 5 descriptions can be specified.
Corresponds to the JSON property descriptions
3657 3658 3659 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3657 def descriptions @descriptions end |
#headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
Headline text asset of the ad. Maximum display width is 30. At least 1 and max
5 headlines can be specified.
Corresponds to the JSON property headlines
3663 3664 3665 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3663 def headlines @headlines end |
#logo_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Logo image assets to be used in the ad. Valid image types are GIF, JPEG, and
PNG. The minimum size is 128x128 and the aspect ratio must be 1:1 (+-1%). At
least 1 and max 5 logo images can be specified.
Corresponds to the JSON property logoImages
3670 3671 3672 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3670 def logo_images @logo_images end |
#marketing_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Marketing image assets to be used in the ad. Valid image types are GIF, JPEG,
and PNG. The minimum size is 600x314 and the aspect ratio must be 1.91:1 (+-1%)
. Required if square_marketing_images is not present.
Corresponds to the JSON property marketingImages
3677 3678 3679 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3677 def marketing_images @marketing_images end |
#portrait_marketing_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Portrait marketing image assets to be used in the ad. Valid image types are
GIF, JPEG, and PNG. The minimum size is 480x600 and the aspect ratio must be 4:
5 (+-1%).
Corresponds to the JSON property portraitMarketingImages
3684 3685 3686 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3684 def portrait_marketing_images @portrait_marketing_images end |
#square_marketing_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Square marketing image assets to be used in the ad. Valid image types are GIF,
JPEG, and PNG. The minimum size is 300x300 and the aspect ratio must be 1:1 (+-
1%). Required if marketing_images is not present.
Corresponds to the JSON property squareMarketingImages
3691 3692 3693 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3691 def square_marketing_images @square_marketing_images end |
#tall_portrait_marketing_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Tall portrait marketing image assets to be used in the ad. Valid image types
are GIF, JPEG, and PNG. The minimum size is 600x1067 and the aspect ratio must
be 9:16 (+-1%). Combined with marketing_images, square_marketing_images,
and portrait_marketing_images, the maximum is 20.
Corresponds to the JSON property tallPortraitMarketingImages
3699 3700 3701 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3699 def tall_portrait_marketing_images @tall_portrait_marketing_images end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3706 3707 3708 3709 3710 3711 3712 3713 3714 3715 3716 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3706 def update!(**args) @business_name = args[:business_name] if args.key?(:business_name) @call_to_action_text = args[:call_to_action_text] if args.key?(:call_to_action_text) @descriptions = args[:descriptions] if args.key?(:descriptions) @headlines = args[:headlines] if args.key?(:headlines) @logo_images = args[:logo_images] if args.key?(:logo_images) @marketing_images = args[:marketing_images] if args.key?(:marketing_images) @portrait_marketing_images = args[:portrait_marketing_images] if args.key?(:portrait_marketing_images) @square_marketing_images = args[:square_marketing_images] if args.key?(:square_marketing_images) @tall_portrait_marketing_images = args[:tall_portrait_marketing_images] if args.key?(:tall_portrait_marketing_images) end |