Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenMultiAssetAdInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Demand Gen multi asset ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDemandGenMultiAssetAdInfo

Returns a new instance of GoogleAdsSearchads360V23CommonDemandGenMultiAssetAdInfo.



3641
3642
3643
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3641

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

The Advertiser/brand name. Maximum display width is 25. Required. Corresponds to the JSON property businessName

Returns:

  • (String)


3586
3587
3588
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3586

def business_name
  @business_name
end

#call_to_action_textString

Call to action text. Corresponds to the JSON property callToActionText

Returns:

  • (String)


3591
3592
3593
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3591

def call_to_action_text
  @call_to_action_text
end

#descriptionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

The descriptive text of the ad. Maximum display width is 90. At least 1 and max 5 descriptions can be specified. Corresponds to the JSON property descriptions



3597
3598
3599
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3597

def descriptions
  @descriptions
end

#headlinesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>

Headline text asset of the ad. Maximum display width is 30. At least 1 and max 5 headlines can be specified. Corresponds to the JSON property headlines



3603
3604
3605
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3603

def headlines
  @headlines
end

#logo_imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

Logo image assets to be used in the ad. Valid image types are GIF, JPEG, and PNG. The minimum size is 128x128 and the aspect ratio must be 1:1 (+-1%). At least 1 and max 5 logo images can be specified. Corresponds to the JSON property logoImages



3610
3611
3612
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3610

def logo_images
  @logo_images
end

#marketing_imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

Marketing image assets to be used in the ad. Valid image types are GIF, JPEG, and PNG. The minimum size is 600x314 and the aspect ratio must be 1.91:1 (+-1%) . Required if square_marketing_images is not present. Corresponds to the JSON property marketingImages



3617
3618
3619
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3617

def marketing_images
  @marketing_images
end

#portrait_marketing_imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

Portrait marketing image assets to be used in the ad. Valid image types are GIF, JPEG, and PNG. The minimum size is 480x600 and the aspect ratio must be 4: 5 (+-1%). Corresponds to the JSON property portraitMarketingImages



3624
3625
3626
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3624

def portrait_marketing_images
  @portrait_marketing_images
end

#square_marketing_imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

Square marketing image assets to be used in the ad. Valid image types are GIF, JPEG, and PNG. The minimum size is 300x300 and the aspect ratio must be 1:1 (+- 1%). Required if marketing_images is not present. Corresponds to the JSON property squareMarketingImages



3631
3632
3633
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3631

def square_marketing_images
  @square_marketing_images
end

#tall_portrait_marketing_imagesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>

Tall portrait marketing image assets to be used in the ad. Valid image types are GIF, JPEG, and PNG. The minimum size is 600x1067 and the aspect ratio must be 9:16 (+-1%). Combined with marketing_images, square_marketing_images, and portrait_marketing_images, the maximum is 20. Corresponds to the JSON property tallPortraitMarketingImages



3639
3640
3641
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3639

def tall_portrait_marketing_images
  @tall_portrait_marketing_images
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3646

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @call_to_action_text = args[:call_to_action_text] if args.key?(:call_to_action_text)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @headlines = args[:headlines] if args.key?(:headlines)
  @logo_images = args[:logo_images] if args.key?(:logo_images)
  @marketing_images = args[:marketing_images] if args.key?(:marketing_images)
  @portrait_marketing_images = args[:portrait_marketing_images] if args.key?(:portrait_marketing_images)
  @square_marketing_images = args[:square_marketing_images] if args.key?(:square_marketing_images)
  @tall_portrait_marketing_images = args[:tall_portrait_marketing_images] if args.key?(:tall_portrait_marketing_images)
end