Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenProductAdInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenProductAdInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Demand Gen product ad.
Instance Attribute Summary collapse
-
#breadcrumb1 ⇒ String
First part of text that appears in the ad with the displayed URL.
-
#breadcrumb2 ⇒ String
Second part of text that appears in the ad with the displayed URL.
-
#business_name ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
-
#call_to_action ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdCallToActionAsset
A call to action asset used inside an ad.
-
#description ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
-
#headline ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
-
#logo_image ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset
An image asset used inside an ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDemandGenProductAdInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonDemandGenProductAdInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDemandGenProductAdInfo
Returns a new instance of GoogleAdsSearchads360V23CommonDemandGenProductAdInfo.
3758 3759 3760 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3758 def initialize(**args) update!(**args) end |
Instance Attribute Details
#breadcrumb1 ⇒ String
First part of text that appears in the ad with the displayed URL.
Corresponds to the JSON property breadcrumb1
3726 3727 3728 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3726 def @breadcrumb1 end |
#breadcrumb2 ⇒ String
Second part of text that appears in the ad with the displayed URL.
Corresponds to the JSON property breadcrumb2
3731 3732 3733 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3731 def @breadcrumb2 end |
#business_name ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
Corresponds to the JSON property businessName
3736 3737 3738 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3736 def business_name @business_name end |
#call_to_action ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdCallToActionAsset
A call to action asset used inside an ad.
Corresponds to the JSON property callToAction
3741 3742 3743 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3741 def call_to_action @call_to_action end |
#description ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
Corresponds to the JSON property description
3746 3747 3748 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3746 def description @description end |
#headline ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
Corresponds to the JSON property headline
3751 3752 3753 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3751 def headline @headline end |
#logo_image ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset
An image asset used inside an ad.
Corresponds to the JSON property logoImage
3756 3757 3758 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3756 def logo_image @logo_image end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3763 3764 3765 3766 3767 3768 3769 3770 3771 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3763 def update!(**args) @breadcrumb1 = args[:breadcrumb1] if args.key?(:breadcrumb1) @breadcrumb2 = args[:breadcrumb2] if args.key?(:breadcrumb2) @business_name = args[:business_name] if args.key?(:business_name) @call_to_action = args[:call_to_action] if args.key?(:call_to_action) @description = args[:description] if args.key?(:description) @headline = args[:headline] if args.key?(:headline) @logo_image = args[:logo_image] if args.key?(:logo_image) end |