Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenProductAdInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenProductAdInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Demand Gen product ad.
Instance Attribute Summary collapse
-
#breadcrumb1 ⇒ String
First part of text that appears in the ad with the displayed URL.
-
#breadcrumb2 ⇒ String
Second part of text that appears in the ad with the displayed URL.
-
#business_name ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
-
#call_to_action ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdCallToActionAsset
A call to action asset used inside an ad.
-
#description ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
-
#headline ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
-
#logo_image ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset
An image asset used inside an ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDemandGenProductAdInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonDemandGenProductAdInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDemandGenProductAdInfo
Returns a new instance of GoogleAdsSearchads360V23CommonDemandGenProductAdInfo.
3698 3699 3700 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3698 def initialize(**args) update!(**args) end |
Instance Attribute Details
#breadcrumb1 ⇒ String
First part of text that appears in the ad with the displayed URL.
Corresponds to the JSON property breadcrumb1
3666 3667 3668 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3666 def @breadcrumb1 end |
#breadcrumb2 ⇒ String
Second part of text that appears in the ad with the displayed URL.
Corresponds to the JSON property breadcrumb2
3671 3672 3673 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3671 def @breadcrumb2 end |
#business_name ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
Corresponds to the JSON property businessName
3676 3677 3678 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3676 def business_name @business_name end |
#call_to_action ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdCallToActionAsset
A call to action asset used inside an ad.
Corresponds to the JSON property callToAction
3681 3682 3683 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3681 def call_to_action @call_to_action end |
#description ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
Corresponds to the JSON property description
3686 3687 3688 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3686 def description @description end |
#headline ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
Corresponds to the JSON property headline
3691 3692 3693 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3691 def headline @headline end |
#logo_image ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset
An image asset used inside an ad.
Corresponds to the JSON property logoImage
3696 3697 3698 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3696 def logo_image @logo_image end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3703 3704 3705 3706 3707 3708 3709 3710 3711 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3703 def update!(**args) @breadcrumb1 = args[:breadcrumb1] if args.key?(:breadcrumb1) @breadcrumb2 = args[:breadcrumb2] if args.key?(:breadcrumb2) @business_name = args[:business_name] if args.key?(:business_name) @call_to_action = args[:call_to_action] if args.key?(:call_to_action) @description = args[:description] if args.key?(:description) @headline = args[:headline] if args.key?(:headline) @logo_image = args[:logo_image] if args.key?(:logo_image) end |