Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenVideoResponsiveAdInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenVideoResponsiveAdInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Demand Gen video responsive ad.
Instance Attribute Summary collapse
-
#breadcrumb1 ⇒ String
First part of text that appears in the ad with the displayed URL.
-
#breadcrumb2 ⇒ String
Second part of text that appears in the ad with the displayed URL.
-
#business_name ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
-
#call_to_actions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdCallToActionAsset>
Assets of type CallToActionAsset used for the "Call To Action" button.
-
#companion_banners ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
List of image assets used for the companion banner.
-
#descriptions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets used for the description.
-
#headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets used for the short headline.
-
#logo_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Logo image to be used in the ad.
-
#long_headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets used for the long headline.
-
#videos ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAsset>
List of YouTube video assets used for the ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDemandGenVideoResponsiveAdInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonDemandGenVideoResponsiveAdInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDemandGenVideoResponsiveAdInfo
Returns a new instance of GoogleAdsSearchads360V23CommonDemandGenVideoResponsiveAdInfo.
3770 3771 3772 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3770 def initialize(**args) update!(**args) end |
Instance Attribute Details
#breadcrumb1 ⇒ String
First part of text that appears in the ad with the displayed URL.
Corresponds to the JSON property breadcrumb1
3721 3722 3723 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3721 def @breadcrumb1 end |
#breadcrumb2 ⇒ String
Second part of text that appears in the ad with the displayed URL.
Corresponds to the JSON property breadcrumb2
3726 3727 3728 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3726 def @breadcrumb2 end |
#business_name ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
Corresponds to the JSON property businessName
3731 3732 3733 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3731 def business_name @business_name end |
#call_to_actions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdCallToActionAsset>
Assets of type CallToActionAsset used for the "Call To Action" button.
Corresponds to the JSON property callToActions
3736 3737 3738 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3736 def call_to_actions @call_to_actions end |
#companion_banners ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
List of image assets used for the companion banner. Currently, only a single
value for the companion banner asset is supported.
Corresponds to the JSON property companionBanners
3742 3743 3744 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3742 def @companion_banners end |
#descriptions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets used for the description.
Corresponds to the JSON property descriptions
3747 3748 3749 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3747 def descriptions @descriptions end |
#headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets used for the short headline.
Corresponds to the JSON property headlines
3752 3753 3754 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3752 def headlines @headlines end |
#logo_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Logo image to be used in the ad. Valid image types are GIF, JPEG, and PNG. The
minimum size is 128x128 and the aspect ratio must be 1:1 (+-1%).
Corresponds to the JSON property logoImages
3758 3759 3760 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3758 def logo_images @logo_images end |
#long_headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets used for the long headline.
Corresponds to the JSON property longHeadlines
3763 3764 3765 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3763 def long_headlines @long_headlines end |
#videos ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAsset>
List of YouTube video assets used for the ad.
Corresponds to the JSON property videos
3768 3769 3770 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3768 def videos @videos end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3775 def update!(**args) @breadcrumb1 = args[:breadcrumb1] if args.key?(:breadcrumb1) @breadcrumb2 = args[:breadcrumb2] if args.key?(:breadcrumb2) @business_name = args[:business_name] if args.key?(:business_name) @call_to_actions = args[:call_to_actions] if args.key?(:call_to_actions) @companion_banners = args[:companion_banners] if args.key?(:companion_banners) @descriptions = args[:descriptions] if args.key?(:descriptions) @headlines = args[:headlines] if args.key?(:headlines) @logo_images = args[:logo_images] if args.key?(:logo_images) @long_headlines = args[:long_headlines] if args.key?(:long_headlines) @videos = args[:videos] if args.key?(:videos) end |