Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDisplayUploadAdInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A generic type of display ad. The exact ad format is controlled by the display_upload_product_type field, which determines what kinds of data need to be included with the ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDisplayUploadAdInfo

Returns a new instance of GoogleAdsSearchads360V23CommonDisplayUploadAdInfo.



3843
3844
3845
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3843

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_upload_product_typeString

The product type of this ad. See comments on the enum for details. Corresponds to the JSON property displayUploadProductType

Returns:

  • (String)


3836
3837
3838
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3836

def display_upload_product_type
  @display_upload_product_type
end

#media_bundleGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdMediaBundleAsset

A media bundle asset used inside an ad. Corresponds to the JSON property mediaBundle



3841
3842
3843
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3841

def media_bundle
  @media_bundle
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3848
3849
3850
3851
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3848

def update!(**args)
  @display_upload_product_type = args[:display_upload_product_type] if args.key?(:display_upload_product_type)
  @media_bundle = args[:media_bundle] if args.key?(:media_bundle)
end