Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicBusinessProfileLocationGroupFilter
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicBusinessProfileLocationGroupFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents a filter on Business Profile locations in an asset set. If multiple filters are provided, they are AND'ed together.
Instance Attribute Summary collapse
-
#business_name_filter ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileBusinessNameFilter
Business Profile location group business name filter.
-
#label_filters ⇒ Array<String>
Used to filter Business Profile locations by label.
-
#listing_id_filters ⇒ Array<Fixnum>
Used to filter Business Profile locations by listing ids.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicBusinessProfileLocationGroupFilter
constructor
A new instance of GoogleAdsSearchads360V23CommonDynamicBusinessProfileLocationGroupFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicBusinessProfileLocationGroupFilter
Returns a new instance of GoogleAdsSearchads360V23CommonDynamicBusinessProfileLocationGroupFilter.
3936 3937 3938 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3936 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_name_filter ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileBusinessNameFilter
Business Profile location group business name filter.
Corresponds to the JSON property businessNameFilter
3922 3923 3924 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3922 def business_name_filter @business_name_filter end |
#label_filters ⇒ Array<String>
Used to filter Business Profile locations by label. Only locations that have
any of the listed labels will be in the asset set. Label filters are OR'ed
together.
Corresponds to the JSON property labelFilters
3929 3930 3931 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3929 def label_filters @label_filters end |
#listing_id_filters ⇒ Array<Fixnum>
Used to filter Business Profile locations by listing ids.
Corresponds to the JSON property listingIdFilters
3934 3935 3936 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3934 def listing_id_filters @listing_id_filters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3941 3942 3943 3944 3945 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3941 def update!(**args) @business_name_filter = args[:business_name_filter] if args.key?(:business_name_filter) @label_filters = args[:label_filters] if args.key?(:label_filters) @listing_id_filters = args[:listing_id_filters] if args.key?(:listing_id_filters) end |