Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicBusinessProfileLocationGroupFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a filter on Business Profile locations in an asset set. If multiple filters are provided, they are AND'ed together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicBusinessProfileLocationGroupFilter

Returns a new instance of GoogleAdsSearchads360V23CommonDynamicBusinessProfileLocationGroupFilter.



3876
3877
3878
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3876

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_name_filterGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileBusinessNameFilter

Business Profile location group business name filter. Corresponds to the JSON property businessNameFilter



3862
3863
3864
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3862

def business_name_filter
  @business_name_filter
end

#label_filtersArray<String>

Used to filter Business Profile locations by label. Only locations that have any of the listed labels will be in the asset set. Label filters are OR'ed together. Corresponds to the JSON property labelFilters

Returns:

  • (Array<String>)


3869
3870
3871
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3869

def label_filters
  @label_filters
end

#listing_id_filtersArray<Fixnum>

Used to filter Business Profile locations by listing ids. Corresponds to the JSON property listingIdFilters

Returns:

  • (Array<Fixnum>)


3874
3875
3876
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3874

def listing_id_filters
  @listing_id_filters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3881
3882
3883
3884
3885
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3881

def update!(**args)
  @business_name_filter = args[:business_name_filter] if args.key?(:business_name_filter)
  @label_filters = args[:label_filters] if args.key?(:label_filters)
  @listing_id_filters = args[:listing_id_filters] if args.key?(:listing_id_filters)
end