Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicCustomAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicCustomAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A dynamic custom asset.
Instance Attribute Summary collapse
-
#android_app_link ⇒ String
Android deep link, for example, android-app://com.example.android/http/example.
-
#contextual_keywords ⇒ Array<String>
Contextual keywords, for example, Sedans, 4 door sedans.
-
#formatted_price ⇒ String
Formatted price which can be any characters.
-
#formatted_sale_price ⇒ String
Formatted sale price which can be any characters.
-
#id ⇒ String
Required.
-
#id2 ⇒ String
ID2 which can be any sequence of letters and digits, for example, red.
-
#image_url ⇒ String
Image URL, for example, http://www.example.com/image.png.
-
#ios_app_link ⇒ String
iOS deep link, for example, exampleApp://content/page.
-
#ios_app_store_id ⇒ Fixnum
iOS app store ID.
-
#item_address ⇒ String
Item address which can be specified in one of the following formats.
-
#item_category ⇒ String
Item category, for example, Sedans.
-
#item_description ⇒ String
Item description, for example, Best selling mid-size car.
-
#item_subtitle ⇒ String
Item subtitle, for example, At your Mountain View dealership.
-
#item_title ⇒ String
Required.
-
#price ⇒ String
Price which can be number followed by the alphabetic currency code, ISO 4217 standard.
-
#sale_price ⇒ String
Sale price which can be number followed by the alphabetic currency code, ISO 4217 standard.
-
#similar_ids ⇒ Array<String>
Similar IDs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicCustomAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonDynamicCustomAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicCustomAsset
Returns a new instance of GoogleAdsSearchads360V23CommonDynamicCustomAsset.
3991 3992 3993 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3991 def initialize(**args) update!(**args) end |
Instance Attribute Details
#android_app_link ⇒ String
Android deep link, for example, android-app://com.example.android/http/example.
com/gizmos?1234.
Corresponds to the JSON property androidAppLink
3896 3897 3898 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3896 def android_app_link @android_app_link end |
#contextual_keywords ⇒ Array<String>
Contextual keywords, for example, Sedans, 4 door sedans.
Corresponds to the JSON property contextualKeywords
3901 3902 3903 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3901 def contextual_keywords @contextual_keywords end |
#formatted_price ⇒ String
Formatted price which can be any characters. If set, this attribute will be
used instead of 'price', for example, Starting at $20,000.00.
Corresponds to the JSON property formattedPrice
3907 3908 3909 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3907 def formatted_price @formatted_price end |
#formatted_sale_price ⇒ String
Formatted sale price which can be any characters. If set, this attribute will
be used instead of 'sale price', for example, On sale for $15,000.00.
Corresponds to the JSON property formattedSalePrice
3913 3914 3915 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3913 def formatted_sale_price @formatted_sale_price end |
#id ⇒ String
Required. ID which can be any sequence of letters and digits, and must be
unique and match the values of remarketing tag, for example, sedan. Required.
Corresponds to the JSON property id
3919 3920 3921 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3919 def id @id end |
#id2 ⇒ String
ID2 which can be any sequence of letters and digits, for example, red. ID
sequence (ID + ID2) must be unique.
Corresponds to the JSON property id2
3925 3926 3927 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3925 def id2 @id2 end |
#image_url ⇒ String
Image URL, for example, http://www.example.com/image.png. The image will not
be uploaded as image asset.
Corresponds to the JSON property imageUrl
3931 3932 3933 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3931 def image_url @image_url end |
#ios_app_link ⇒ String
iOS deep link, for example, exampleApp://content/page.
Corresponds to the JSON property iosAppLink
3936 3937 3938 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3936 def ios_app_link @ios_app_link end |
#ios_app_store_id ⇒ Fixnum
iOS app store ID. This is used to check if the user has the app installed on
their device before deep linking. If this field is set, then the ios_app_link
field must also be present.
Corresponds to the JSON property iosAppStoreId
3943 3944 3945 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3943 def ios_app_store_id @ios_app_store_id end |
#item_address ⇒ String
Item address which can be specified in one of the following formats. (1) City,
state, code, country, for example, Mountain View, CA, USA. (2) Full address,
for example, 123 Boulevard St, Mountain View, CA 94043. (3) Latitude-longitude
in the DDD format, for example, 41.40338, 2.17403
Corresponds to the JSON property itemAddress
3951 3952 3953 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3951 def item_address @item_address end |
#item_category ⇒ String
Item category, for example, Sedans.
Corresponds to the JSON property itemCategory
3956 3957 3958 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3956 def item_category @item_category end |
#item_description ⇒ String
Item description, for example, Best selling mid-size car.
Corresponds to the JSON property itemDescription
3961 3962 3963 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3961 def item_description @item_description end |
#item_subtitle ⇒ String
Item subtitle, for example, At your Mountain View dealership.
Corresponds to the JSON property itemSubtitle
3966 3967 3968 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3966 def item_subtitle @item_subtitle end |
#item_title ⇒ String
Required. Item title, for example, Mid-size sedan. Required.
Corresponds to the JSON property itemTitle
3971 3972 3973 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3971 def item_title @item_title end |
#price ⇒ String
Price which can be number followed by the alphabetic currency code, ISO 4217
standard. Use '.' as the decimal mark, for example, 20,000.00 USD.
Corresponds to the JSON property price
3977 3978 3979 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3977 def price @price end |
#sale_price ⇒ String
Sale price which can be number followed by the alphabetic currency code, ISO
4217 standard. Use '.' as the decimal mark, for example, 15,000.00 USD. Must
be less than the 'price' field.
Corresponds to the JSON property salePrice
3984 3985 3986 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3984 def sale_price @sale_price end |
#similar_ids ⇒ Array<String>
Similar IDs.
Corresponds to the JSON property similarIds
3989 3990 3991 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3989 def similar_ids @similar_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3996 3997 3998 3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 4013 4014 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 3996 def update!(**args) @android_app_link = args[:android_app_link] if args.key?(:android_app_link) @contextual_keywords = args[:contextual_keywords] if args.key?(:contextual_keywords) @formatted_price = args[:formatted_price] if args.key?(:formatted_price) @formatted_sale_price = args[:formatted_sale_price] if args.key?(:formatted_sale_price) @id = args[:id] if args.key?(:id) @id2 = args[:id2] if args.key?(:id2) @image_url = args[:image_url] if args.key?(:image_url) @ios_app_link = args[:ios_app_link] if args.key?(:ios_app_link) @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id) @item_address = args[:item_address] if args.key?(:item_address) @item_category = args[:item_category] if args.key?(:item_category) @item_description = args[:item_description] if args.key?(:item_description) @item_subtitle = args[:item_subtitle] if args.key?(:item_subtitle) @item_title = args[:item_title] if args.key?(:item_title) @price = args[:price] if args.key?(:price) @sale_price = args[:sale_price] if args.key?(:sale_price) @similar_ids = args[:similar_ids] if args.key?(:similar_ids) end |