Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicEducationAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Dynamic Education asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicEducationAsset

Returns a new instance of GoogleAdsSearchads360V23CommonDynamicEducationAsset.



4100
4101
4102
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

School address which can be specified in one of the following formats. (1) City, state, code, country, for example, Mountain View, CA, USA. (2) Full address, for example, 123 Boulevard St, Mountain View, CA 94043. (3) Latitude- longitude in the DDD format, for example, 41.40338, 2.17403 Corresponds to the JSON property address

Returns:

  • (String)


4027
4028
4029
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4027

def address
  @address
end

Android deep link, for example, android-app://com.example.android/http/example. com/gizmos?1234. Corresponds to the JSON property androidAppLink

Returns:

  • (String)


4033
4034
4035
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4033

def android_app_link
  @android_app_link
end

#contextual_keywordsArray<String>

Contextual keywords, for example, Nursing certification, Health, Mountain View. Corresponds to the JSON property contextualKeywords

Returns:

  • (Array<String>)


4038
4039
4040
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4038

def contextual_keywords
  @contextual_keywords
end

#image_urlString

Image url, for example, http://www.example.com/image.png. The image will not be uploaded as image asset. Corresponds to the JSON property imageUrl

Returns:

  • (String)


4044
4045
4046
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4044

def image_url
  @image_url
end

iOS deep link, for example, exampleApp://content/page. Corresponds to the JSON property iosAppLink

Returns:

  • (String)


4049
4050
4051
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4049

def ios_app_link
  @ios_app_link
end

#ios_app_store_idFixnum

iOS app store ID. This is used to check if the user has the app installed on their device before deep linking. If this field is set, then the ios_app_link field must also be present. Corresponds to the JSON property iosAppStoreId

Returns:

  • (Fixnum)


4056
4057
4058
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4056

def ios_app_store_id
  @ios_app_store_id
end

#location_idString

Location ID which can be any sequence of letters and digits and must be unique. Corresponds to the JSON property locationId

Returns:

  • (String)


4061
4062
4063
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4061

def location_id
  @location_id
end

#program_descriptionString

Program description, for example, Nursing Certification. Corresponds to the JSON property programDescription

Returns:

  • (String)


4066
4067
4068
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4066

def program_description
  @program_description
end

#program_idString

Required. Program ID which can be any sequence of letters and digits, and must be unique and match the values of remarketing tag. Required. Corresponds to the JSON property programId

Returns:

  • (String)


4072
4073
4074
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4072

def program_id
  @program_id
end

#program_nameString

Required. Program name, for example, Nursing. Required. Corresponds to the JSON property programName

Returns:

  • (String)


4077
4078
4079
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4077

def program_name
  @program_name
end

#school_nameString

School name, for example, Mountain View School of Nursing. Corresponds to the JSON property schoolName

Returns:

  • (String)


4082
4083
4084
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4082

def school_name
  @school_name
end

#similar_program_idsArray<String>

Similar program IDs. Corresponds to the JSON property similarProgramIds

Returns:

  • (Array<String>)


4087
4088
4089
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4087

def similar_program_ids
  @similar_program_ids
end

#subjectString

Subject of study, for example, Health. Corresponds to the JSON property subject

Returns:

  • (String)


4092
4093
4094
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4092

def subject
  @subject
end

#thumbnail_image_urlString

Thumbnail image url, for example, http://www.example.com/thumbnail.png. The thumbnail image will not be uploaded as image asset. Corresponds to the JSON property thumbnailImageUrl

Returns:

  • (String)


4098
4099
4100
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4098

def thumbnail_image_url
  @thumbnail_image_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
4119
4120
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4105

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @android_app_link = args[:android_app_link] if args.key?(:android_app_link)
  @contextual_keywords = args[:contextual_keywords] if args.key?(:contextual_keywords)
  @image_url = args[:image_url] if args.key?(:image_url)
  @ios_app_link = args[:ios_app_link] if args.key?(:ios_app_link)
  @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id)
  @location_id = args[:location_id] if args.key?(:location_id)
  @program_description = args[:program_description] if args.key?(:program_description)
  @program_id = args[:program_id] if args.key?(:program_id)
  @program_name = args[:program_name] if args.key?(:program_name)
  @school_name = args[:school_name] if args.key?(:school_name)
  @similar_program_ids = args[:similar_program_ids] if args.key?(:similar_program_ids)
  @subject = args[:subject] if args.key?(:subject)
  @thumbnail_image_url = args[:thumbnail_image_url] if args.key?(:thumbnail_image_url)
end