Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicFlightsAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicFlightsAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A dynamic flights asset.
Instance Attribute Summary collapse
-
#android_app_link ⇒ String
Android deep link, for example, android-app://com.example.android/http/example.
-
#custom_mapping ⇒ String
A custom field which can be multiple key to values mapping separated by delimiters (",", "|" and ":"), in the forms of ": , , ...
-
#destination_id ⇒ String
Required.
-
#destination_name ⇒ String
Destination name, for example, Paris.
-
#flight_description ⇒ String
Required.
-
#flight_price ⇒ String
Flight price which can be number followed by the alphabetic currency code, ISO 4217 standard.
-
#flight_sale_price ⇒ String
Flight sale price which can be number followed by the alphabetic currency code, ISO 4217 standard.
-
#formatted_price ⇒ String
Formatted price which can be any characters.
-
#formatted_sale_price ⇒ String
Formatted sale price which can be any characters.
-
#image_url ⇒ String
Image URL, for example, http://www.example.com/image.png.
-
#ios_app_link ⇒ String
iOS deep link, for example, exampleApp://content/page.
-
#ios_app_store_id ⇒ Fixnum
iOS app store ID.
-
#origin_id ⇒ String
Origin ID which can be any sequence of letters and digits.
-
#origin_name ⇒ String
Origin name, for example, London.
-
#similar_destination_ids ⇒ Array<String>
Similar destination IDs, for example, PAR,LON.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicFlightsAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonDynamicFlightsAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicFlightsAsset
Returns a new instance of GoogleAdsSearchads360V23CommonDynamicFlightsAsset.
4276 4277 4278 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4276 def initialize(**args) update!(**args) end |
Instance Attribute Details
#android_app_link ⇒ String
Android deep link, for example, android-app://com.example.android/http/example.
com/gizmos?1234.
Corresponds to the JSON property androidAppLink
4191 4192 4193 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4191 def android_app_link @android_app_link end |
#custom_mapping ⇒ String
A custom field which can be multiple key to values mapping separated by
delimiters (",", "|" and ":"), in the forms of ": , , ... , | : , ... , | ... |
: , ... ," for example, wifi: most | aircraft: 320, 77W | flights: 42 |
legroom: 32".
Corresponds to the JSON property customMapping
4199 4200 4201 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4199 def custom_mapping @custom_mapping end |
#destination_id ⇒ String
Required. Destination ID which can be any sequence of letters and digits, and
must be unique and match the values of remarketing tag. Required.
Corresponds to the JSON property destinationId
4205 4206 4207 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4205 def destination_id @destination_id end |
#destination_name ⇒ String
Destination name, for example, Paris.
Corresponds to the JSON property destinationName
4210 4211 4212 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4210 def destination_name @destination_name end |
#flight_description ⇒ String
Required. Flight description, for example, Book your ticket. Required.
Corresponds to the JSON property flightDescription
4215 4216 4217 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4215 def flight_description @flight_description end |
#flight_price ⇒ String
Flight price which can be number followed by the alphabetic currency code, ISO
4217 standard. Use '.' as the decimal mark, for example, 100.00 USD.
Corresponds to the JSON property flightPrice
4221 4222 4223 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4221 def flight_price @flight_price end |
#flight_sale_price ⇒ String
Flight sale price which can be number followed by the alphabetic currency code,
ISO 4217 standard. Use '.' as the decimal mark, for example, 80.00 USD. Must
be less than the 'flight_price' field.
Corresponds to the JSON property flightSalePrice
4228 4229 4230 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4228 def flight_sale_price @flight_sale_price end |
#formatted_price ⇒ String
Formatted price which can be any characters. If set, this attribute will be
used instead of 'price', for example, Starting at $100.00.
Corresponds to the JSON property formattedPrice
4234 4235 4236 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4234 def formatted_price @formatted_price end |
#formatted_sale_price ⇒ String
Formatted sale price which can be any characters. If set, this attribute will
be used instead of 'sale price', for example, On sale for $80.00.
Corresponds to the JSON property formattedSalePrice
4240 4241 4242 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4240 def formatted_sale_price @formatted_sale_price end |
#image_url ⇒ String
Image URL, for example, http://www.example.com/image.png. The image will not
be uploaded as image asset.
Corresponds to the JSON property imageUrl
4246 4247 4248 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4246 def image_url @image_url end |
#ios_app_link ⇒ String
iOS deep link, for example, exampleApp://content/page.
Corresponds to the JSON property iosAppLink
4251 4252 4253 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4251 def ios_app_link @ios_app_link end |
#ios_app_store_id ⇒ Fixnum
iOS app store ID. This is used to check if the user has the app installed on
their device before deep linking. If this field is set, then the ios_app_link
field must also be present.
Corresponds to the JSON property iosAppStoreId
4258 4259 4260 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4258 def ios_app_store_id @ios_app_store_id end |
#origin_id ⇒ String
Origin ID which can be any sequence of letters and digits. The ID sequence (
destination ID + origin ID) must be unique.
Corresponds to the JSON property originId
4264 4265 4266 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4264 def origin_id @origin_id end |
#origin_name ⇒ String
Origin name, for example, London.
Corresponds to the JSON property originName
4269 4270 4271 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4269 def origin_name @origin_name end |
#similar_destination_ids ⇒ Array<String>
Similar destination IDs, for example, PAR,LON.
Corresponds to the JSON property similarDestinationIds
4274 4275 4276 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4274 def similar_destination_ids @similar_destination_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 4297 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4281 def update!(**args) @android_app_link = args[:android_app_link] if args.key?(:android_app_link) @custom_mapping = args[:custom_mapping] if args.key?(:custom_mapping) @destination_id = args[:destination_id] if args.key?(:destination_id) @destination_name = args[:destination_name] if args.key?(:destination_name) @flight_description = args[:flight_description] if args.key?(:flight_description) @flight_price = args[:flight_price] if args.key?(:flight_price) @flight_sale_price = args[:flight_sale_price] if args.key?(:flight_sale_price) @formatted_price = args[:formatted_price] if args.key?(:formatted_price) @formatted_sale_price = args[:formatted_sale_price] if args.key?(:formatted_sale_price) @image_url = args[:image_url] if args.key?(:image_url) @ios_app_link = args[:ios_app_link] if args.key?(:ios_app_link) @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id) @origin_id = args[:origin_id] if args.key?(:origin_id) @origin_name = args[:origin_name] if args.key?(:origin_name) @similar_destination_ids = args[:similar_destination_ids] if args.key?(:similar_destination_ids) end |