Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicFlightsAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A dynamic flights asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicFlightsAsset

Returns a new instance of GoogleAdsSearchads360V23CommonDynamicFlightsAsset.



4216
4217
4218
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Android deep link, for example, android-app://com.example.android/http/example. com/gizmos?1234. Corresponds to the JSON property androidAppLink

Returns:

  • (String)


4131
4132
4133
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4131

def android_app_link
  @android_app_link
end

#custom_mappingString

A custom field which can be multiple key to values mapping separated by delimiters (",", "|" and ":"), in the forms of ": , , ... , | : , ... , | ... | : , ... ," for example, wifi: most | aircraft: 320, 77W | flights: 42 | legroom: 32". Corresponds to the JSON property customMapping

Returns:

  • (String)


4139
4140
4141
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4139

def custom_mapping
  @custom_mapping
end

#destination_idString

Required. Destination ID which can be any sequence of letters and digits, and must be unique and match the values of remarketing tag. Required. Corresponds to the JSON property destinationId

Returns:

  • (String)


4145
4146
4147
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4145

def destination_id
  @destination_id
end

#destination_nameString

Destination name, for example, Paris. Corresponds to the JSON property destinationName

Returns:

  • (String)


4150
4151
4152
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4150

def destination_name
  @destination_name
end

#flight_descriptionString

Required. Flight description, for example, Book your ticket. Required. Corresponds to the JSON property flightDescription

Returns:

  • (String)


4155
4156
4157
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4155

def flight_description
  @flight_description
end

#flight_priceString

Flight price which can be number followed by the alphabetic currency code, ISO 4217 standard. Use '.' as the decimal mark, for example, 100.00 USD. Corresponds to the JSON property flightPrice

Returns:

  • (String)


4161
4162
4163
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4161

def flight_price
  @flight_price
end

#flight_sale_priceString

Flight sale price which can be number followed by the alphabetic currency code, ISO 4217 standard. Use '.' as the decimal mark, for example, 80.00 USD. Must be less than the 'flight_price' field. Corresponds to the JSON property flightSalePrice

Returns:

  • (String)


4168
4169
4170
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4168

def flight_sale_price
  @flight_sale_price
end

#formatted_priceString

Formatted price which can be any characters. If set, this attribute will be used instead of 'price', for example, Starting at $100.00. Corresponds to the JSON property formattedPrice

Returns:

  • (String)


4174
4175
4176
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4174

def formatted_price
  @formatted_price
end

#formatted_sale_priceString

Formatted sale price which can be any characters. If set, this attribute will be used instead of 'sale price', for example, On sale for $80.00. Corresponds to the JSON property formattedSalePrice

Returns:

  • (String)


4180
4181
4182
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4180

def formatted_sale_price
  @formatted_sale_price
end

#image_urlString

Image URL, for example, http://www.example.com/image.png. The image will not be uploaded as image asset. Corresponds to the JSON property imageUrl

Returns:

  • (String)


4186
4187
4188
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4186

def image_url
  @image_url
end

iOS deep link, for example, exampleApp://content/page. Corresponds to the JSON property iosAppLink

Returns:

  • (String)


4191
4192
4193
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4191

def ios_app_link
  @ios_app_link
end

#ios_app_store_idFixnum

iOS app store ID. This is used to check if the user has the app installed on their device before deep linking. If this field is set, then the ios_app_link field must also be present. Corresponds to the JSON property iosAppStoreId

Returns:

  • (Fixnum)


4198
4199
4200
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4198

def ios_app_store_id
  @ios_app_store_id
end

#origin_idString

Origin ID which can be any sequence of letters and digits. The ID sequence ( destination ID + origin ID) must be unique. Corresponds to the JSON property originId

Returns:

  • (String)


4204
4205
4206
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4204

def origin_id
  @origin_id
end

#origin_nameString

Origin name, for example, London. Corresponds to the JSON property originName

Returns:

  • (String)


4209
4210
4211
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4209

def origin_name
  @origin_name
end

#similar_destination_idsArray<String>

Similar destination IDs, for example, PAR,LON. Corresponds to the JSON property similarDestinationIds

Returns:

  • (Array<String>)


4214
4215
4216
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4214

def similar_destination_ids
  @similar_destination_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4221
4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4221

def update!(**args)
  @android_app_link = args[:android_app_link] if args.key?(:android_app_link)
  @custom_mapping = args[:custom_mapping] if args.key?(:custom_mapping)
  @destination_id = args[:destination_id] if args.key?(:destination_id)
  @destination_name = args[:destination_name] if args.key?(:destination_name)
  @flight_description = args[:flight_description] if args.key?(:flight_description)
  @flight_price = args[:flight_price] if args.key?(:flight_price)
  @flight_sale_price = args[:flight_sale_price] if args.key?(:flight_sale_price)
  @formatted_price = args[:formatted_price] if args.key?(:formatted_price)
  @formatted_sale_price = args[:formatted_sale_price] if args.key?(:formatted_sale_price)
  @image_url = args[:image_url] if args.key?(:image_url)
  @ios_app_link = args[:ios_app_link] if args.key?(:ios_app_link)
  @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id)
  @origin_id = args[:origin_id] if args.key?(:origin_id)
  @origin_name = args[:origin_name] if args.key?(:origin_name)
  @similar_destination_ids = args[:similar_destination_ids] if args.key?(:similar_destination_ids)
end