Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicHotelsAndRentalsAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicHotelsAndRentalsAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A dynamic hotels and rentals asset.
Instance Attribute Summary collapse
-
#address ⇒ String
Address which can be specified in one of the following formats.
-
#android_app_link ⇒ String
Android deep link, for example, android-app://com.example.android/http/example.
-
#category ⇒ String
Category, for example, Hotel suite.
-
#contextual_keywords ⇒ Array<String>
Contextual keywords, for example, Mountain View "Hotels", South Bay hotels.
-
#description ⇒ String
Description, for example, Close to SJC Airport.
-
#destination_name ⇒ String
Destination name, for example, Downtown Mountain View.
-
#formatted_price ⇒ String
Formatted price which can be any characters.
-
#formatted_sale_price ⇒ String
Formatted sale price which can be any characters.
-
#image_url ⇒ String
Image URL, for example, http://www.example.com/image.png.
-
#ios_app_link ⇒ String
iOS deep link, for example, exampleApp://content/page.
-
#ios_app_store_id ⇒ Fixnum
iOS app store ID.
-
#price ⇒ String
Price which can be number followed by the alphabetic currency code, ISO 4217 standard.
-
#property_id ⇒ String
Required.
-
#property_name ⇒ String
Required.
-
#sale_price ⇒ String
ISO 4217 standard.
-
#similar_property_ids ⇒ Array<String>
Similar property IDs.
-
#star_rating ⇒ Fixnum
Star rating.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicHotelsAndRentalsAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonDynamicHotelsAndRentalsAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicHotelsAndRentalsAsset
Returns a new instance of GoogleAdsSearchads360V23CommonDynamicHotelsAndRentalsAsset.
4401 4402 4403 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Address which can be specified in one of the following formats. (1) City,
state, code, country, for example, Mountain View, CA, USA. (2) Full address,
for example, 123 Boulevard St, Mountain View, CA 94043. (3) Latitude-longitude
in the DDD format, for example, 41.40338, 2.17403
Corresponds to the JSON property address
4310 4311 4312 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4310 def address @address end |
#android_app_link ⇒ String
Android deep link, for example, android-app://com.example.android/http/example.
com/gizmos?1234.
Corresponds to the JSON property androidAppLink
4316 4317 4318 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4316 def android_app_link @android_app_link end |
#category ⇒ String
Category, for example, Hotel suite.
Corresponds to the JSON property category
4321 4322 4323 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4321 def category @category end |
#contextual_keywords ⇒ Array<String>
Contextual keywords, for example, Mountain View "Hotels", South Bay hotels.
Corresponds to the JSON property contextualKeywords
4326 4327 4328 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4326 def contextual_keywords @contextual_keywords end |
#description ⇒ String
Description, for example, Close to SJC Airport.
Corresponds to the JSON property description
4331 4332 4333 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4331 def description @description end |
#destination_name ⇒ String
Destination name, for example, Downtown Mountain View.
Corresponds to the JSON property destinationName
4336 4337 4338 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4336 def destination_name @destination_name end |
#formatted_price ⇒ String
Formatted price which can be any characters. If set, this attribute will be
used instead of 'price', for example, Starting at $100.00.
Corresponds to the JSON property formattedPrice
4342 4343 4344 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4342 def formatted_price @formatted_price end |
#formatted_sale_price ⇒ String
Formatted sale price which can be any characters. If set, this attribute will
be used instead of 'sale price', for example, On sale for $80.00.
Corresponds to the JSON property formattedSalePrice
4348 4349 4350 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4348 def formatted_sale_price @formatted_sale_price end |
#image_url ⇒ String
Image URL, for example, http://www.example.com/image.png. The image will not
be uploaded as image asset.
Corresponds to the JSON property imageUrl
4354 4355 4356 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4354 def image_url @image_url end |
#ios_app_link ⇒ String
iOS deep link, for example, exampleApp://content/page.
Corresponds to the JSON property iosAppLink
4359 4360 4361 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4359 def ios_app_link @ios_app_link end |
#ios_app_store_id ⇒ Fixnum
iOS app store ID. This is used to check if the user has the app installed on
their device before deep linking. If this field is set, then the ios_app_link
field must also be present.
Corresponds to the JSON property iosAppStoreId
4366 4367 4368 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4366 def ios_app_store_id @ios_app_store_id end |
#price ⇒ String
Price which can be number followed by the alphabetic currency code, ISO 4217
standard. Use '.' as the decimal mark, for example, 100.00 USD.
Corresponds to the JSON property price
4372 4373 4374 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4372 def price @price end |
#property_id ⇒ String
Required. Property ID which can be any sequence of letters and digits, and
must be unique and match the values of remarketing tag. Required.
Corresponds to the JSON property propertyId
4378 4379 4380 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4378 def property_id @property_id end |
#property_name ⇒ String
Required. Property name, for example, Mountain View Hotel. Required.
Corresponds to the JSON property propertyName
4383 4384 4385 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4383 def property_name @property_name end |
#sale_price ⇒ String
ISO 4217 standard. Use '.' as the decimal mark, for example, 80.00 USD. Must
be less than the 'price' field.
Corresponds to the JSON property salePrice
4389 4390 4391 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4389 def sale_price @sale_price end |
#similar_property_ids ⇒ Array<String>
Similar property IDs.
Corresponds to the JSON property similarPropertyIds
4394 4395 4396 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4394 def similar_property_ids @similar_property_ids end |
#star_rating ⇒ Fixnum
Star rating. Must be a number between 1 to 5, inclusive.
Corresponds to the JSON property starRating
4399 4400 4401 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4399 def @star_rating end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 4417 4418 4419 4420 4421 4422 4423 4424 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4406 def update!(**args) @address = args[:address] if args.key?(:address) @android_app_link = args[:android_app_link] if args.key?(:android_app_link) @category = args[:category] if args.key?(:category) @contextual_keywords = args[:contextual_keywords] if args.key?(:contextual_keywords) @description = args[:description] if args.key?(:description) @destination_name = args[:destination_name] if args.key?(:destination_name) @formatted_price = args[:formatted_price] if args.key?(:formatted_price) @formatted_sale_price = args[:formatted_sale_price] if args.key?(:formatted_sale_price) @image_url = args[:image_url] if args.key?(:image_url) @ios_app_link = args[:ios_app_link] if args.key?(:ios_app_link) @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id) @price = args[:price] if args.key?(:price) @property_id = args[:property_id] if args.key?(:property_id) @property_name = args[:property_name] if args.key?(:property_name) @sale_price = args[:sale_price] if args.key?(:sale_price) @similar_property_ids = args[:similar_property_ids] if args.key?(:similar_property_ids) @star_rating = args[:star_rating] if args.key?(:star_rating) end |