Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicJobsAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicJobsAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A dynamic jobs asset.
Instance Attribute Summary collapse
-
#address ⇒ String
Address which can be specified in one of the following formats.
-
#android_app_link ⇒ String
Android deep link, for example, android-app://com.example.android/http/example.
-
#contextual_keywords ⇒ Array<String>
Contextual keywords, for example, Software engineering job.
-
#description ⇒ String
Description, for example, Apply your technical skills.
-
#image_url ⇒ String
Image URL, for example, http://www.example.com/image.png.
-
#ios_app_link ⇒ String
iOS deep link, for example, exampleApp://content/page.
-
#ios_app_store_id ⇒ Fixnum
iOS app store ID.
-
#job_category ⇒ String
Job category, for example, Technical.
-
#job_id ⇒ String
Required.
-
#job_subtitle ⇒ String
Job subtitle, for example, Level II.
-
#job_title ⇒ String
Required.
-
#location_id ⇒ String
Location ID which can be any sequence of letters and digits.
-
#salary ⇒ String
Salary, for example, $100,000.
-
#similar_job_ids ⇒ Array<String>
Similar job IDs, for example, 1275.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicJobsAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonDynamicJobsAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicJobsAsset
Returns a new instance of GoogleAdsSearchads360V23CommonDynamicJobsAsset.
4510 4511 4512 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4510 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Address which can be specified in one of the following formats. (1) City,
state, code, country, for example, Mountain View, CA, USA. (2) Full address,
for example, 123 Boulevard St, Mountain View, CA 94043. (3) Latitude-longitude
in the DDD format, for example, 41.40338, 2.17403.
Corresponds to the JSON property address
4437 4438 4439 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4437 def address @address end |
#android_app_link ⇒ String
Android deep link, for example, android-app://com.example.android/http/example.
com/gizmos?1234.
Corresponds to the JSON property androidAppLink
4443 4444 4445 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4443 def android_app_link @android_app_link end |
#contextual_keywords ⇒ Array<String>
Contextual keywords, for example, Software engineering job.
Corresponds to the JSON property contextualKeywords
4448 4449 4450 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4448 def contextual_keywords @contextual_keywords end |
#description ⇒ String
Description, for example, Apply your technical skills.
Corresponds to the JSON property description
4453 4454 4455 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4453 def description @description end |
#image_url ⇒ String
Image URL, for example, http://www.example.com/image.png. The image will not
be uploaded as image asset.
Corresponds to the JSON property imageUrl
4459 4460 4461 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4459 def image_url @image_url end |
#ios_app_link ⇒ String
iOS deep link, for example, exampleApp://content/page.
Corresponds to the JSON property iosAppLink
4464 4465 4466 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4464 def ios_app_link @ios_app_link end |
#ios_app_store_id ⇒ Fixnum
iOS app store ID. This is used to check if the user has the app installed on
their device before deep linking. If this field is set, then the ios_app_link
field must also be present.
Corresponds to the JSON property iosAppStoreId
4471 4472 4473 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4471 def ios_app_store_id @ios_app_store_id end |
#job_category ⇒ String
Job category, for example, Technical.
Corresponds to the JSON property jobCategory
4476 4477 4478 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4476 def job_category @job_category end |
#job_id ⇒ String
Required. Job ID which can be any sequence of letters and digits, and must be
unique and match the values of remarketing tag. Required.
Corresponds to the JSON property jobId
4482 4483 4484 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4482 def job_id @job_id end |
#job_subtitle ⇒ String
Job subtitle, for example, Level II.
Corresponds to the JSON property jobSubtitle
4487 4488 4489 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4487 def job_subtitle @job_subtitle end |
#job_title ⇒ String
Required. Job title, for example, Software engineer. Required.
Corresponds to the JSON property jobTitle
4492 4493 4494 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4492 def job_title @job_title end |
#location_id ⇒ String
Location ID which can be any sequence of letters and digits. The ID sequence (
job ID + location ID) must be unique.
Corresponds to the JSON property locationId
4498 4499 4500 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4498 def location_id @location_id end |
#salary ⇒ String
Salary, for example, $100,000.
Corresponds to the JSON property salary
4503 4504 4505 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4503 def salary @salary end |
#similar_job_ids ⇒ Array<String>
Similar job IDs, for example, 1275.
Corresponds to the JSON property similarJobIds
4508 4509 4510 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4508 def similar_job_ids @similar_job_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4515 4516 4517 4518 4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4515 def update!(**args) @address = args[:address] if args.key?(:address) @android_app_link = args[:android_app_link] if args.key?(:android_app_link) @contextual_keywords = args[:contextual_keywords] if args.key?(:contextual_keywords) @description = args[:description] if args.key?(:description) @image_url = args[:image_url] if args.key?(:image_url) @ios_app_link = args[:ios_app_link] if args.key?(:ios_app_link) @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id) @job_category = args[:job_category] if args.key?(:job_category) @job_id = args[:job_id] if args.key?(:job_id) @job_subtitle = args[:job_subtitle] if args.key?(:job_subtitle) @job_title = args[:job_title] if args.key?(:job_title) @location_id = args[:location_id] if args.key?(:location_id) @salary = args[:salary] if args.key?(:salary) @similar_job_ids = args[:similar_job_ids] if args.key?(:similar_job_ids) end |