Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicJobsAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A dynamic jobs asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicJobsAsset

Returns a new instance of GoogleAdsSearchads360V23CommonDynamicJobsAsset.



4450
4451
4452
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4450

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Address which can be specified in one of the following formats. (1) City, state, code, country, for example, Mountain View, CA, USA. (2) Full address, for example, 123 Boulevard St, Mountain View, CA 94043. (3) Latitude-longitude in the DDD format, for example, 41.40338, 2.17403. Corresponds to the JSON property address

Returns:

  • (String)


4377
4378
4379
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4377

def address
  @address
end

Android deep link, for example, android-app://com.example.android/http/example. com/gizmos?1234. Corresponds to the JSON property androidAppLink

Returns:

  • (String)


4383
4384
4385
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4383

def android_app_link
  @android_app_link
end

#contextual_keywordsArray<String>

Contextual keywords, for example, Software engineering job. Corresponds to the JSON property contextualKeywords

Returns:

  • (Array<String>)


4388
4389
4390
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4388

def contextual_keywords
  @contextual_keywords
end

#descriptionString

Description, for example, Apply your technical skills. Corresponds to the JSON property description

Returns:

  • (String)


4393
4394
4395
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4393

def description
  @description
end

#image_urlString

Image URL, for example, http://www.example.com/image.png. The image will not be uploaded as image asset. Corresponds to the JSON property imageUrl

Returns:

  • (String)


4399
4400
4401
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4399

def image_url
  @image_url
end

iOS deep link, for example, exampleApp://content/page. Corresponds to the JSON property iosAppLink

Returns:

  • (String)


4404
4405
4406
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4404

def ios_app_link
  @ios_app_link
end

#ios_app_store_idFixnum

iOS app store ID. This is used to check if the user has the app installed on their device before deep linking. If this field is set, then the ios_app_link field must also be present. Corresponds to the JSON property iosAppStoreId

Returns:

  • (Fixnum)


4411
4412
4413
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4411

def ios_app_store_id
  @ios_app_store_id
end

#job_categoryString

Job category, for example, Technical. Corresponds to the JSON property jobCategory

Returns:

  • (String)


4416
4417
4418
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4416

def job_category
  @job_category
end

#job_idString

Required. Job ID which can be any sequence of letters and digits, and must be unique and match the values of remarketing tag. Required. Corresponds to the JSON property jobId

Returns:

  • (String)


4422
4423
4424
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4422

def job_id
  @job_id
end

#job_subtitleString

Job subtitle, for example, Level II. Corresponds to the JSON property jobSubtitle

Returns:

  • (String)


4427
4428
4429
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4427

def job_subtitle
  @job_subtitle
end

#job_titleString

Required. Job title, for example, Software engineer. Required. Corresponds to the JSON property jobTitle

Returns:

  • (String)


4432
4433
4434
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4432

def job_title
  @job_title
end

#location_idString

Location ID which can be any sequence of letters and digits. The ID sequence ( job ID + location ID) must be unique. Corresponds to the JSON property locationId

Returns:

  • (String)


4438
4439
4440
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4438

def location_id
  @location_id
end

#salaryString

Salary, for example, $100,000. Corresponds to the JSON property salary

Returns:

  • (String)


4443
4444
4445
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4443

def salary
  @salary
end

#similar_job_idsArray<String>

Similar job IDs, for example, 1275. Corresponds to the JSON property similarJobIds

Returns:

  • (Array<String>)


4448
4449
4450
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4448

def similar_job_ids
  @similar_job_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
4466
4467
4468
4469
4470
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4455

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @android_app_link = args[:android_app_link] if args.key?(:android_app_link)
  @contextual_keywords = args[:contextual_keywords] if args.key?(:contextual_keywords)
  @description = args[:description] if args.key?(:description)
  @image_url = args[:image_url] if args.key?(:image_url)
  @ios_app_link = args[:ios_app_link] if args.key?(:ios_app_link)
  @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id)
  @job_category = args[:job_category] if args.key?(:job_category)
  @job_id = args[:job_id] if args.key?(:job_id)
  @job_subtitle = args[:job_subtitle] if args.key?(:job_subtitle)
  @job_title = args[:job_title] if args.key?(:job_title)
  @location_id = args[:location_id] if args.key?(:location_id)
  @salary = args[:salary] if args.key?(:salary)
  @similar_job_ids = args[:similar_job_ids] if args.key?(:similar_job_ids)
end