Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicLocalAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A dynamic local asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicLocalAsset

Returns a new instance of GoogleAdsSearchads360V23CommonDynamicLocalAsset.



4570
4571
4572
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Address which can be specified in one of the following formats. (1) City, state, code, country, for example, Mountain View, CA, USA. (2) Full address, for example, 123 Boulevard St, Mountain View, CA 94043. (3) Latitude-longitude in the DDD format, for example, 41.40338, 2.17403. Corresponds to the JSON property address

Returns:

  • (String)


4483
4484
4485
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4483

def address
  @address
end

Android deep link, for example, android-app://com.example.android/http/example. com/gizmos?1234. Corresponds to the JSON property androidAppLink

Returns:

  • (String)


4489
4490
4491
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4489

def android_app_link
  @android_app_link
end

#categoryString

Category, for example, Food. Corresponds to the JSON property category

Returns:

  • (String)


4494
4495
4496
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4494

def category
  @category
end

#contextual_keywordsArray<String>

Contextual keywords, for example, Save groceries coupons. Corresponds to the JSON property contextualKeywords

Returns:

  • (Array<String>)


4499
4500
4501
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4499

def contextual_keywords
  @contextual_keywords
end

#deal_idString

Required. Deal ID which can be any sequence of letters and digits, and must be unique and match the values of remarketing tag. Required. Corresponds to the JSON property dealId

Returns:

  • (String)


4505
4506
4507
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4505

def deal_id
  @deal_id
end

#deal_nameString

Required. Deal name, for example, 50% off at Mountain View Grocers. Required. Corresponds to the JSON property dealName

Returns:

  • (String)


4510
4511
4512
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4510

def deal_name
  @deal_name
end

#descriptionString

Description, for example, Save on your weekly bill. Corresponds to the JSON property description

Returns:

  • (String)


4515
4516
4517
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4515

def description
  @description
end

#formatted_priceString

Formatted price which can be any characters. If set, this attribute will be used instead of 'price', for example, Starting at $100.00. Corresponds to the JSON property formattedPrice

Returns:

  • (String)


4521
4522
4523
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4521

def formatted_price
  @formatted_price
end

#formatted_sale_priceString

Formatted sale price which can be any characters. If set, this attribute will be used instead of 'sale price', for example, On sale for $80.00. Corresponds to the JSON property formattedSalePrice

Returns:

  • (String)


4527
4528
4529
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4527

def formatted_sale_price
  @formatted_sale_price
end

#image_urlString

Image URL, for example, http://www.example.com/image.png. The image will not be uploaded as image asset. Corresponds to the JSON property imageUrl

Returns:

  • (String)


4533
4534
4535
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4533

def image_url
  @image_url
end

iOS deep link, for example, exampleApp://content/page. Corresponds to the JSON property iosAppLink

Returns:

  • (String)


4538
4539
4540
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4538

def ios_app_link
  @ios_app_link
end

#ios_app_store_idFixnum

iOS app store ID. This is used to check if the user has the app installed on their device before deep linking. If this field is set, then the ios_app_link field must also be present. Corresponds to the JSON property iosAppStoreId

Returns:

  • (Fixnum)


4545
4546
4547
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4545

def ios_app_store_id
  @ios_app_store_id
end

#priceString

Price which can be a number followed by the alphabetic currency code, ISO 4217 standard. Use '.' as the decimal mark, for example, 100.00 USD. Corresponds to the JSON property price

Returns:

  • (String)


4551
4552
4553
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4551

def price
  @price
end

#sale_priceString

Sale price which can be number followed by the alphabetic currency code, ISO 4217 standard. Use '.' as the decimal mark, for example, 80.00 USD. Must be less than the 'price' field. Corresponds to the JSON property salePrice

Returns:

  • (String)


4558
4559
4560
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4558

def sale_price
  @sale_price
end

#similar_deal_idsArray<String>

Similar deal IDs, for example, 1275. Corresponds to the JSON property similarDealIds

Returns:

  • (Array<String>)


4563
4564
4565
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4563

def similar_deal_ids
  @similar_deal_ids
end

#subtitleString

Subtitle, for example, Groceries. Corresponds to the JSON property subtitle

Returns:

  • (String)


4568
4569
4570
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4568

def subtitle
  @subtitle
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4575
4576
4577
4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4575

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @android_app_link = args[:android_app_link] if args.key?(:android_app_link)
  @category = args[:category] if args.key?(:category)
  @contextual_keywords = args[:contextual_keywords] if args.key?(:contextual_keywords)
  @deal_id = args[:deal_id] if args.key?(:deal_id)
  @deal_name = args[:deal_name] if args.key?(:deal_name)
  @description = args[:description] if args.key?(:description)
  @formatted_price = args[:formatted_price] if args.key?(:formatted_price)
  @formatted_sale_price = args[:formatted_sale_price] if args.key?(:formatted_sale_price)
  @image_url = args[:image_url] if args.key?(:image_url)
  @ios_app_link = args[:ios_app_link] if args.key?(:ios_app_link)
  @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id)
  @price = args[:price] if args.key?(:price)
  @sale_price = args[:sale_price] if args.key?(:sale_price)
  @similar_deal_ids = args[:similar_deal_ids] if args.key?(:similar_deal_ids)
  @subtitle = args[:subtitle] if args.key?(:subtitle)
end