Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicRealEstateAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicRealEstateAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A dynamic real estate asset.
Instance Attribute Summary collapse
-
#address ⇒ String
Address which can be specified in one of the following formats.
-
#android_app_link ⇒ String
Android deep link, for example, android-app://com.example.android/http/example.
-
#city_name ⇒ String
City name, for example, Mountain View, California.
-
#contextual_keywords ⇒ Array<String>
Contextual keywords, for example, For sale; Houses for sale.
-
#description ⇒ String
Description, for example, 3 beds, 2 baths, 1568 sq.
-
#formatted_price ⇒ String
Formatted price which can be any characters.
-
#image_url ⇒ String
Image URL, for example, http://www.example.com/image.png.
-
#ios_app_link ⇒ String
iOS deep link, for example, exampleApp://content/page.
-
#ios_app_store_id ⇒ Fixnum
iOS app store ID.
-
#listing_id ⇒ String
Required.
-
#listing_name ⇒ String
Required.
-
#listing_type ⇒ String
Listing type, for example, For sale.
-
#price ⇒ String
Price which can be number followed by the alphabetic currency code, ISO 4217 standard.
-
#property_type ⇒ String
Property type, for example, House.
-
#similar_listing_ids ⇒ Array<String>
Similar listing IDs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicRealEstateAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonDynamicRealEstateAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicRealEstateAsset
Returns a new instance of GoogleAdsSearchads360V23CommonDynamicRealEstateAsset.
4684 4685 4686 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4684 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Address which can be specified in one of the following formats. (1) City,
state, code, country, for example, Mountain View, CA, USA. (2) Full address,
for example, 123 Boulevard St, Mountain View, CA 94043. (3) Latitude-longitude
in the DDD format, for example, 41.40338, 2.17403
Corresponds to the JSON property address
4605 4606 4607 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4605 def address @address end |
#android_app_link ⇒ String
Android deep link, for example, android-app://com.example.android/http/example.
com/gizmos?1234.
Corresponds to the JSON property androidAppLink
4611 4612 4613 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4611 def android_app_link @android_app_link end |
#city_name ⇒ String
City name, for example, Mountain View, California.
Corresponds to the JSON property cityName
4616 4617 4618 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4616 def city_name @city_name end |
#contextual_keywords ⇒ Array<String>
Contextual keywords, for example, For sale; Houses for sale.
Corresponds to the JSON property contextualKeywords
4621 4622 4623 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4621 def contextual_keywords @contextual_keywords end |
#description ⇒ String
Description, for example, 3 beds, 2 baths, 1568 sq. ft.
Corresponds to the JSON property description
4626 4627 4628 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4626 def description @description end |
#formatted_price ⇒ String
Formatted price which can be any characters. If set, this attribute will be
used instead of 'price', for example, Starting at $200,000.00.
Corresponds to the JSON property formattedPrice
4632 4633 4634 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4632 def formatted_price @formatted_price end |
#image_url ⇒ String
Image URL, for example, http://www.example.com/image.png. The image will not
be uploaded as image asset.
Corresponds to the JSON property imageUrl
4638 4639 4640 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4638 def image_url @image_url end |
#ios_app_link ⇒ String
iOS deep link, for example, exampleApp://content/page.
Corresponds to the JSON property iosAppLink
4643 4644 4645 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4643 def ios_app_link @ios_app_link end |
#ios_app_store_id ⇒ Fixnum
iOS app store ID. This is used to check if the user has the app installed on
their device before deep linking. If this field is set, then the ios_app_link
field must also be present.
Corresponds to the JSON property iosAppStoreId
4650 4651 4652 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4650 def ios_app_store_id @ios_app_store_id end |
#listing_id ⇒ String
Required. Listing ID which can be any sequence of letters and digits, and must
be unique and match the values of remarketing tag. Required.
Corresponds to the JSON property listingId
4656 4657 4658 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4656 def listing_id @listing_id end |
#listing_name ⇒ String
Required. Listing name, for example, Boulevard Bungalow. Required.
Corresponds to the JSON property listingName
4661 4662 4663 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4661 def listing_name @listing_name end |
#listing_type ⇒ String
Listing type, for example, For sale.
Corresponds to the JSON property listingType
4666 4667 4668 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4666 def listing_type @listing_type end |
#price ⇒ String
Price which can be number followed by the alphabetic currency code, ISO 4217
standard. Use '.' as the decimal mark, for example, 200,000.00 USD.
Corresponds to the JSON property price
4672 4673 4674 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4672 def price @price end |
#property_type ⇒ String
Property type, for example, House.
Corresponds to the JSON property propertyType
4677 4678 4679 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4677 def property_type @property_type end |
#similar_listing_ids ⇒ Array<String>
Similar listing IDs.
Corresponds to the JSON property similarListingIds
4682 4683 4684 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4682 def similar_listing_ids @similar_listing_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4689 4690 4691 4692 4693 4694 4695 4696 4697 4698 4699 4700 4701 4702 4703 4704 4705 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4689 def update!(**args) @address = args[:address] if args.key?(:address) @android_app_link = args[:android_app_link] if args.key?(:android_app_link) @city_name = args[:city_name] if args.key?(:city_name) @contextual_keywords = args[:contextual_keywords] if args.key?(:contextual_keywords) @description = args[:description] if args.key?(:description) @formatted_price = args[:formatted_price] if args.key?(:formatted_price) @image_url = args[:image_url] if args.key?(:image_url) @ios_app_link = args[:ios_app_link] if args.key?(:ios_app_link) @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id) @listing_id = args[:listing_id] if args.key?(:listing_id) @listing_name = args[:listing_name] if args.key?(:listing_name) @listing_type = args[:listing_type] if args.key?(:listing_type) @price = args[:price] if args.key?(:price) @property_type = args[:property_type] if args.key?(:property_type) @similar_listing_ids = args[:similar_listing_ids] if args.key?(:similar_listing_ids) end |