Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicTravelAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A dynamic travel asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonDynamicTravelAsset

Returns a new instance of GoogleAdsSearchads360V23CommonDynamicTravelAsset.



4811
4812
4813
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Android deep link, for example, android-app://com.example.android/http/example. com/gizmos?1234. Corresponds to the JSON property androidAppLink

Returns:

  • (String)


4716
4717
4718
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4716

def android_app_link
  @android_app_link
end

#categoryString

Category, for example, Express. Corresponds to the JSON property category

Returns:

  • (String)


4721
4722
4723
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4721

def category
  @category
end

#contextual_keywordsArray<String>

Contextual keywords, for example, Paris trains. Corresponds to the JSON property contextualKeywords

Returns:

  • (Array<String>)


4726
4727
4728
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4726

def contextual_keywords
  @contextual_keywords
end

#destination_addressString

Destination address which can be specified in one of the following formats. (1) City, state, code, country, for example, Mountain View, CA, USA. (2) Full address, for example, 123 Boulevard St, Mountain View, CA 94043. (3) Latitude- longitude in the DDD format, for example, 41.40338, 2.17403. Corresponds to the JSON property destinationAddress

Returns:

  • (String)


4734
4735
4736
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4734

def destination_address
  @destination_address
end

#destination_idString

Required. Destination ID which can be any sequence of letters and digits, and must be unique and match the values of remarketing tag. Required. Corresponds to the JSON property destinationId

Returns:

  • (String)


4740
4741
4742
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4740

def destination_id
  @destination_id
end

#destination_nameString

Destination name, for example, Paris. Corresponds to the JSON property destinationName

Returns:

  • (String)


4745
4746
4747
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4745

def destination_name
  @destination_name
end

#formatted_priceString

Formatted price which can be any characters. If set, this attribute will be used instead of 'price', for example, Starting at $100.00. Corresponds to the JSON property formattedPrice

Returns:

  • (String)


4751
4752
4753
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4751

def formatted_price
  @formatted_price
end

#formatted_sale_priceString

Formatted sale price which can be any characters. If set, this attribute will be used instead of 'sale price', for example, On sale for $80.00. Corresponds to the JSON property formattedSalePrice

Returns:

  • (String)


4757
4758
4759
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4757

def formatted_sale_price
  @formatted_sale_price
end

#image_urlString

Image URL, for example, http://www.example.com/image.png. The image will not be uploaded as image asset. Corresponds to the JSON property imageUrl

Returns:

  • (String)


4763
4764
4765
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4763

def image_url
  @image_url
end

iOS deep link, for example, exampleApp://content/page. Corresponds to the JSON property iosAppLink

Returns:

  • (String)


4768
4769
4770
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4768

def ios_app_link
  @ios_app_link
end

#ios_app_store_idFixnum

iOS app store ID. This is used to check if the user has the app installed on their device before deep linking. If this field is set, then the ios_app_link field must also be present. Corresponds to the JSON property iosAppStoreId

Returns:

  • (Fixnum)


4775
4776
4777
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4775

def ios_app_store_id
  @ios_app_store_id
end

#origin_idString

Origin ID which can be any sequence of letters and digits. The ID sequence ( destination ID + origin ID) must be unique. Corresponds to the JSON property originId

Returns:

  • (String)


4781
4782
4783
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4781

def origin_id
  @origin_id
end

#origin_nameString

Origin name, for example, London. Corresponds to the JSON property originName

Returns:

  • (String)


4786
4787
4788
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4786

def origin_name
  @origin_name
end

#priceString

Price which can be a number followed by the alphabetic currency code, ISO 4217 standard. Use '.' as the decimal mark, for example, 100.00 USD. Corresponds to the JSON property price

Returns:

  • (String)


4792
4793
4794
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4792

def price
  @price
end

#sale_priceString

Sale price which can be a number followed by the alphabetic currency code, ISO 4217 standard. Use '.' as the decimal mark, for example, 80.00 USD. Must be less than the 'price' field. Corresponds to the JSON property salePrice

Returns:

  • (String)


4799
4800
4801
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4799

def sale_price
  @sale_price
end

#similar_destination_idsArray<String>

Similar destination IDs, for example, NYC. Corresponds to the JSON property similarDestinationIds

Returns:

  • (Array<String>)


4804
4805
4806
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4804

def similar_destination_ids
  @similar_destination_ids
end

#titleString

Required. Title, for example, Book your train ticket. Required. Corresponds to the JSON property title

Returns:

  • (String)


4809
4810
4811
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4809

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4816
4817
4818
4819
4820
4821
4822
4823
4824
4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
# File 'lib/google/apis/searchads360_v23/classes.rb', line 4816

def update!(**args)
  @android_app_link = args[:android_app_link] if args.key?(:android_app_link)
  @category = args[:category] if args.key?(:category)
  @contextual_keywords = args[:contextual_keywords] if args.key?(:contextual_keywords)
  @destination_address = args[:destination_address] if args.key?(:destination_address)
  @destination_id = args[:destination_id] if args.key?(:destination_id)
  @destination_name = args[:destination_name] if args.key?(:destination_name)
  @formatted_price = args[:formatted_price] if args.key?(:formatted_price)
  @formatted_sale_price = args[:formatted_sale_price] if args.key?(:formatted_sale_price)
  @image_url = args[:image_url] if args.key?(:image_url)
  @ios_app_link = args[:ios_app_link] if args.key?(:ios_app_link)
  @ios_app_store_id = args[:ios_app_store_id] if args.key?(:ios_app_store_id)
  @origin_id = args[:origin_id] if args.key?(:origin_id)
  @origin_name = args[:origin_name] if args.key?(:origin_name)
  @price = args[:price] if args.key?(:price)
  @sale_price = args[:sale_price] if args.key?(:sale_price)
  @similar_destination_ids = args[:similar_destination_ids] if args.key?(:similar_destination_ids)
  @title = args[:title] if args.key?(:title)
end