Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFlexibleRuleOperandInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Flexible rule that wraps the common rule and a lookback window.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonFlexibleRuleOperandInfo

Returns a new instance of GoogleAdsSearchads360V23CommonFlexibleRuleOperandInfo.



5090
5091
5092
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5090

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lookback_window_daysFixnum

Lookback window for this rule in days. From now until X days ago. Corresponds to the JSON property lookbackWindowDays

Returns:

  • (Fixnum)


5082
5083
5084
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5082

def lookback_window_days
  @lookback_window_days
end

#ruleGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleInfo

A client defined rule based on custom parameters sent by web sites or uploaded by the advertiser. Corresponds to the JSON property rule



5088
5089
5090
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5088

def rule
  @rule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5095
5096
5097
5098
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5095

def update!(**args)
  @lookback_window_days = args[:lookback_window_days] if args.key?(:lookback_window_days)
  @rule = args[:rule] if args.key?(:rule)
end