Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFlexibleRuleUserListInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFlexibleRuleUserListInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Flexible rule representation of visitors with one or multiple actions. The flexible user list is defined by two lists of operands – inclusive_operands and exclusive_operands; each operand represents a set of users based on actions they took in a given timeframe. These lists of operands are combined with the AND_NOT operator, so that users represented by the inclusive operands are included in the user list, minus the users represented by the exclusive operands.
Instance Attribute Summary collapse
-
#exclusive_operands ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFlexibleRuleOperandInfo>
Rules representing users that should be excluded from the user list.
-
#inclusive_operands ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFlexibleRuleOperandInfo>
Rules representing users that should be included in the user list.
-
#inclusive_rule_operator ⇒ String
Operator that defines how the inclusive operands are combined.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonFlexibleRuleUserListInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonFlexibleRuleUserListInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonFlexibleRuleUserListInfo
Returns a new instance of GoogleAdsSearchads360V23CommonFlexibleRuleUserListInfo.
5129 5130 5131 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5129 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclusive_operands ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFlexibleRuleOperandInfo>
Rules representing users that should be excluded from the user list. These are
located on the right side of the AND_NOT operator, and joined together by OR.
Corresponds to the JSON property exclusiveOperands
5115 5116 5117 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5115 def exclusive_operands @exclusive_operands end |
#inclusive_operands ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFlexibleRuleOperandInfo>
Rules representing users that should be included in the user list. These are
located on the left side of the AND_NOT operator, and joined together by
either AND/OR as specified by the inclusive_rule_operator.
Corresponds to the JSON property inclusiveOperands
5122 5123 5124 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5122 def inclusive_operands @inclusive_operands end |
#inclusive_rule_operator ⇒ String
Operator that defines how the inclusive operands are combined.
Corresponds to the JSON property inclusiveRuleOperator
5127 5128 5129 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5127 def inclusive_rule_operator @inclusive_rule_operator end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5134 5135 5136 5137 5138 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5134 def update!(**args) @exclusive_operands = args[:exclusive_operands] if args.key?(:exclusive_operands) @inclusive_operands = args[:inclusive_operands] if args.key?(:inclusive_operands) @inclusive_rule_operator = args[:inclusive_rule_operator] if args.key?(:inclusive_rule_operator) end |