Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFrequencyCapEntry
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFrequencyCapEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A rule specifying the maximum number of times an ad (or some set of ads) can be shown to a user over a particular time period.
Instance Attribute Summary collapse
-
#cap ⇒ Fixnum
Maximum number of events allowed during the time range by this cap.
-
#key ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFrequencyCapKey
A group of fields used as keys for a frequency cap.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonFrequencyCapEntry
constructor
A new instance of GoogleAdsSearchads360V23CommonFrequencyCapEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonFrequencyCapEntry
Returns a new instance of GoogleAdsSearchads360V23CommonFrequencyCapEntry.
5217 5218 5219 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cap ⇒ Fixnum
Maximum number of events allowed during the time range by this cap.
Corresponds to the JSON property cap
5209 5210 5211 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5209 def cap @cap end |
#key ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFrequencyCapKey
A group of fields used as keys for a frequency cap. There can be no more than
one frequency cap with the same key.
Corresponds to the JSON property key
5215 5216 5217 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5215 def key @key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5222 5223 5224 5225 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5222 def update!(**args) @cap = args[:cap] if args.key?(:cap) @key = args[:key] if args.key?(:key) end |