Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHistoricalMetricsOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Historical metrics options.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonHistoricalMetricsOptions

Returns a new instance of GoogleAdsSearchads360V23CommonHistoricalMetricsOptions.



5294
5295
5296
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5294

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_average_cpcBoolean Also known as: include_average_cpc?

Indicates whether to include average cost per click value. Average CPC is provided only for legacy support. Corresponds to the JSON property includeAverageCpc

Returns:

  • (Boolean)


5285
5286
5287
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5285

def include_average_cpc
  @include_average_cpc
end

#year_month_rangeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYearMonthRange

The year month range inclusive of the start and end months. Eg: A year month range to represent Jan 2020 would be: (Jan 2020, Jan 2020). Corresponds to the JSON property yearMonthRange



5292
5293
5294
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5292

def year_month_range
  @year_month_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5299
5300
5301
5302
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5299

def update!(**args)
  @include_average_cpc = args[:include_average_cpc] if args.key?(:include_average_cpc)
  @year_month_range = args[:year_month_range] if args.key?(:year_month_range)
end