Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelAdvanceBookingWindowInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelAdvanceBookingWindowInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Criterion for number of days prior to the stay the booking is being made.
Instance Attribute Summary collapse
-
#max_days ⇒ Fixnum
High end of the number of days prior to the stay.
-
#min_days ⇒ Fixnum
Low end of the number of days prior to the stay.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonHotelAdvanceBookingWindowInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonHotelAdvanceBookingWindowInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonHotelAdvanceBookingWindowInfo
Returns a new instance of GoogleAdsSearchads360V23CommonHotelAdvanceBookingWindowInfo.
5332 5333 5334 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5332 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_days ⇒ Fixnum
High end of the number of days prior to the stay.
Corresponds to the JSON property maxDays
5325 5326 5327 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5325 def max_days @max_days end |
#min_days ⇒ Fixnum
Low end of the number of days prior to the stay.
Corresponds to the JSON property minDays
5330 5331 5332 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5330 def min_days @min_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5337 5338 5339 5340 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5337 def update!(**args) @max_days = args[:max_days] if args.key?(:max_days) @min_days = args[:min_days] if args.key?(:min_days) end |