Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelLengthOfStayInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Criterion for length of hotel stay in nights.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonHotelLengthOfStayInfo

Returns a new instance of GoogleAdsSearchads360V23CommonHotelLengthOfStayInfo.



5523
5524
5525
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5523

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_nightsFixnum

High end of the number of nights in the stay. Corresponds to the JSON property maxNights

Returns:

  • (Fixnum)


5516
5517
5518
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5516

def max_nights
  @max_nights
end

#min_nightsFixnum

Low end of the number of nights in the stay. Corresponds to the JSON property minNights

Returns:

  • (Fixnum)


5521
5522
5523
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5521

def min_nights
  @min_nights
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5528
5529
5530
5531
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5528

def update!(**args)
  @max_nights = args[:max_nights] if args.key?(:max_nights)
  @min_nights = args[:min_nights] if args.key?(:min_nights)
end