Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelPropertyAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelPropertyAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A hotel property asset.
Instance Attribute Summary collapse
-
#hotel_address ⇒ String
Address of the hotel.
-
#hotel_name ⇒ String
Name of the hotel.
-
#place_id ⇒ String
Place IDs uniquely identify a place in the Google Places database and on Google Maps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonHotelPropertyAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonHotelPropertyAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonHotelPropertyAsset
Returns a new instance of GoogleAdsSearchads360V23CommonHotelPropertyAsset.
5555 5556 5557 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5555 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hotel_address ⇒ String
Address of the hotel. Read-only.
Corresponds to the JSON property hotelAddress
5541 5542 5543 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5541 def hotel_address @hotel_address end |
#hotel_name ⇒ String
Name of the hotel. Read-only.
Corresponds to the JSON property hotelName
5546 5547 5548 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5546 def hotel_name @hotel_name end |
#place_id ⇒ String
Place IDs uniquely identify a place in the Google Places database and on
Google Maps. See https://developers.google.com/places/web-service/place-id to
learn more.
Corresponds to the JSON property placeId
5553 5554 5555 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5553 def place_id @place_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5560 5561 5562 5563 5564 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5560 def update!(**args) @hotel_address = args[:hotel_address] if args.key?(:hotel_address) @hotel_name = args[:hotel_name] if args.key?(:hotel_name) @place_id = args[:place_id] if args.key?(:place_id) end |