Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonImageAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonImageAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An Image asset.
Instance Attribute Summary collapse
-
#data ⇒ String
The raw bytes data of an image.
-
#file_size ⇒ Fixnum
File size of the image asset in bytes.
-
#full_size ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonImageDimension
Metadata for an image at a certain size, either original or resized.
-
#mime_type ⇒ String
MIME type of the image asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonImageAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonImageAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonImageAsset
Returns a new instance of GoogleAdsSearchads360V23CommonImageAsset.
5718 5719 5720 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5718 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ String
The raw bytes data of an image. This field is mutate only.
Corresponds to the JSON property data
NOTE: Values are automatically base64 encoded/decoded in the client library.
5701 5702 5703 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5701 def data @data end |
#file_size ⇒ Fixnum
File size of the image asset in bytes.
Corresponds to the JSON property fileSize
5706 5707 5708 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5706 def file_size @file_size end |
#full_size ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonImageDimension
Metadata for an image at a certain size, either original or resized.
Corresponds to the JSON property fullSize
5711 5712 5713 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5711 def full_size @full_size end |
#mime_type ⇒ String
MIME type of the image asset.
Corresponds to the JSON property mimeType
5716 5717 5718 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5716 def mime_type @mime_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5723 5724 5725 5726 5727 5728 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5723 def update!(**args) @data = args[:data] if args.key?(:data) @file_size = args[:file_size] if args.key?(:file_size) @full_size = args[:full_size] if args.key?(:full_size) @mime_type = args[:mime_type] if args.key?(:mime_type) end |