Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonImageDimension

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Metadata for an image at a certain size, either original or resized.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonImageDimension

Returns a new instance of GoogleAdsSearchads360V23CommonImageDimension.



5750
5751
5752
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5750

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#height_pixelsFixnum

Height of the image. Corresponds to the JSON property heightPixels

Returns:

  • (Fixnum)


5738
5739
5740
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5738

def height_pixels
  @height_pixels
end

#urlString

A URL that returns the image with this height and width. Corresponds to the JSON property url

Returns:

  • (String)


5743
5744
5745
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5743

def url
  @url
end

#width_pixelsFixnum

Width of the image. Corresponds to the JSON property widthPixels

Returns:

  • (Fixnum)


5748
5749
5750
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5748

def width_pixels
  @width_pixels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5755
5756
5757
5758
5759
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5755

def update!(**args)
  @height_pixels = args[:height_pixels] if args.key?(:height_pixels)
  @url = args[:url] if args.key?(:url)
  @width_pixels = args[:width_pixels] if args.key?(:width_pixels)
end