Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonItemAttribute
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonItemAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Item attributes of the transaction.
Instance Attribute Summary collapse
-
#country_code ⇒ String
Common Locale Data Repository (CLDR) territory code of the country associated with the feed where your items are uploaded.
-
#item_id ⇒ String
A unique identifier of a product.
-
#language_code ⇒ String
ISO 639-1 code of the language associated with the feed where your items are uploaded.
-
#merchant_id ⇒ Fixnum
ID of the Merchant Center Account.
-
#quantity ⇒ Fixnum
The number of items sold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonItemAttribute
constructor
A new instance of GoogleAdsSearchads360V23CommonItemAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonItemAttribute
Returns a new instance of GoogleAdsSearchads360V23CommonItemAttribute.
5924 5925 5926 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5924 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_code ⇒ String
Common Locale Data Repository (CLDR) territory code of the country associated
with the feed where your items are uploaded. See https://developers.google.com/
google-ads/api/reference/data/codes-formats#country-codes for more information.
This information is useful to differentiate product information in cases
where a product (identified by item_id) is associated with multiple countries.
Corresponds to the JSON property countryCode
5898 5899 5900 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5898 def country_code @country_code end |
#item_id ⇒ String
A unique identifier of a product. It must be the exact same Merchant Center
Item ID you use in your Google Merchant Center for this product. Required.
Corresponds to the JSON property itemId
5904 5905 5906 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5904 def item_id @item_id end |
#language_code ⇒ String
ISO 639-1 code of the language associated with the feed where your items are
uploaded. This information is useful to differentiate product information in
cases where a product (identified by item_id) is associated with multiple
languages.
Corresponds to the JSON property languageCode
5912 5913 5914 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5912 def language_code @language_code end |
#merchant_id ⇒ Fixnum
ID of the Merchant Center Account. Required.
Corresponds to the JSON property merchantId
5917 5918 5919 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5917 def merchant_id @merchant_id end |
#quantity ⇒ Fixnum
The number of items sold. Defaults to 1 if not set.
Corresponds to the JSON property quantity
5922 5923 5924 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5922 def quantity @quantity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5929 5930 5931 5932 5933 5934 5935 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5929 def update!(**args) @country_code = args[:country_code] if args.key?(:country_code) @item_id = args[:item_id] if args.key?(:item_id) @language_code = args[:language_code] if args.key?(:language_code) @merchant_id = args[:merchant_id] if args.key?(:merchant_id) @quantity = args[:quantity] if args.key?(:quantity) end |