Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonItemAttribute
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonItemAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Item attributes of the transaction.
Instance Attribute Summary collapse
-
#country_code ⇒ String
Common Locale Data Repository (CLDR) territory code of the country associated with the feed where your items are uploaded.
-
#item_id ⇒ String
A unique identifier of a product.
-
#language_code ⇒ String
ISO 639-1 code of the language associated with the feed where your items are uploaded.
-
#merchant_id ⇒ Fixnum
ID of the Merchant Center Account.
-
#quantity ⇒ Fixnum
The number of items sold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonItemAttribute
constructor
A new instance of GoogleAdsSearchads360V23CommonItemAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonItemAttribute
Returns a new instance of GoogleAdsSearchads360V23CommonItemAttribute.
5864 5865 5866 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5864 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_code ⇒ String
Common Locale Data Repository (CLDR) territory code of the country associated
with the feed where your items are uploaded. See https://developers.google.com/
google-ads/api/reference/data/codes-formats#country-codes for more information.
This information is useful to differentiate product information in cases
where a product (identified by item_id) is associated with multiple countries.
Corresponds to the JSON property countryCode
5838 5839 5840 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5838 def country_code @country_code end |
#item_id ⇒ String
A unique identifier of a product. It must be the exact same Merchant Center
Item ID you use in your Google Merchant Center for this product. Required.
Corresponds to the JSON property itemId
5844 5845 5846 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5844 def item_id @item_id end |
#language_code ⇒ String
ISO 639-1 code of the language associated with the feed where your items are
uploaded. This information is useful to differentiate product information in
cases where a product (identified by item_id) is associated with multiple
languages.
Corresponds to the JSON property languageCode
5852 5853 5854 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5852 def language_code @language_code end |
#merchant_id ⇒ Fixnum
ID of the Merchant Center Account. Required.
Corresponds to the JSON property merchantId
5857 5858 5859 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5857 def merchant_id @merchant_id end |
#quantity ⇒ Fixnum
The number of items sold. Defaults to 1 if not set.
Corresponds to the JSON property quantity
5862 5863 5864 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5862 def quantity @quantity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5869 5870 5871 5872 5873 5874 5875 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 5869 def update!(**args) @country_code = args[:country_code] if args.key?(:country_code) @item_id = args[:item_id] if args.key?(:item_id) @language_code = args[:language_code] if args.key?(:language_code) @merchant_id = args[:merchant_id] if args.key?(:merchant_id) @quantity = args[:quantity] if args.key?(:quantity) end |