Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Historical metrics specific to the targeting options selected. Targeting options include geographies, network, and so on. Refer to https://support. google.com/google-ads/answer/3022575 for more details.
Instance Attribute Summary collapse
-
#average_cpc_micros ⇒ Fixnum
Average Cost Per Click in micros for the keyword.
-
#avg_monthly_searches ⇒ Fixnum
Approximate number of monthly searches on this query, averaged for the past 12 months.
-
#competition ⇒ String
The competition level for the query.
-
#competition_index ⇒ Fixnum
The competition index for the query in the range [0, 100].
-
#high_top_of_page_bid_micros ⇒ Fixnum
Top of page bid high range (80th percentile) in micros for the keyword.
-
#low_top_of_page_bid_micros ⇒ Fixnum
Top of page bid low range (20th percentile) in micros for the keyword.
-
#monthly_search_volumes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMonthlySearchVolume>
Approximate number of searches on this query for the past twelve months.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics
constructor
A new instance of GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics
Returns a new instance of GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics.
6143 6144 6145 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6143 def initialize(**args) update!(**args) end |
Instance Attribute Details
#average_cpc_micros ⇒ Fixnum
Average Cost Per Click in micros for the keyword.
Corresponds to the JSON property averageCpcMicros
6107 6108 6109 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6107 def average_cpc_micros @average_cpc_micros end |
#avg_monthly_searches ⇒ Fixnum
Approximate number of monthly searches on this query, averaged for the past 12
months.
Corresponds to the JSON property avgMonthlySearches
6113 6114 6115 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6113 def avg_monthly_searches @avg_monthly_searches end |
#competition ⇒ String
The competition level for the query.
Corresponds to the JSON property competition
6118 6119 6120 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6118 def competition @competition end |
#competition_index ⇒ Fixnum
The competition index for the query in the range [0, 100]. Shows how
competitive ad placement is for a keyword. The level of competition from 0-100
is determined by the number of ad slots filled divided by the total number of
ad slots available. If not enough data is available, null is returned.
Corresponds to the JSON property competitionIndex
6126 6127 6128 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6126 def competition_index @competition_index end |
#high_top_of_page_bid_micros ⇒ Fixnum
Top of page bid high range (80th percentile) in micros for the keyword.
Corresponds to the JSON property highTopOfPageBidMicros
6131 6132 6133 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6131 def high_top_of_page_bid_micros @high_top_of_page_bid_micros end |
#low_top_of_page_bid_micros ⇒ Fixnum
Top of page bid low range (20th percentile) in micros for the keyword.
Corresponds to the JSON property lowTopOfPageBidMicros
6136 6137 6138 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6136 def low_top_of_page_bid_micros @low_top_of_page_bid_micros end |
#monthly_search_volumes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMonthlySearchVolume>
Approximate number of searches on this query for the past twelve months.
Corresponds to the JSON property monthlySearchVolumes
6141 6142 6143 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6141 def monthly_search_volumes @monthly_search_volumes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6148 6149 6150 6151 6152 6153 6154 6155 6156 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6148 def update!(**args) @average_cpc_micros = args[:average_cpc_micros] if args.key?(:average_cpc_micros) @avg_monthly_searches = args[:avg_monthly_searches] if args.key?(:avg_monthly_searches) @competition = args[:competition] if args.key?(:competition) @competition_index = args[:competition_index] if args.key?(:competition_index) @high_top_of_page_bid_micros = args[:high_top_of_page_bid_micros] if args.key?(:high_top_of_page_bid_micros) @low_top_of_page_bid_micros = args[:low_top_of_page_bid_micros] if args.key?(:low_top_of_page_bid_micros) @monthly_search_volumes = args[:monthly_search_volumes] if args.key?(:monthly_search_volumes) end |