Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Historical metrics specific to the targeting options selected. Targeting options include geographies, network, and so on. Refer to https://support. google.com/google-ads/answer/3022575 for more details.
Instance Attribute Summary collapse
-
#average_cpc_micros ⇒ Fixnum
Average Cost Per Click in micros for the keyword.
-
#avg_monthly_searches ⇒ Fixnum
Approximate number of monthly searches on this query, averaged for the past 12 months.
-
#competition ⇒ String
The competition level for the query.
-
#competition_index ⇒ Fixnum
The competition index for the query in the range [0, 100].
-
#high_top_of_page_bid_micros ⇒ Fixnum
Top of page bid high range (80th percentile) in micros for the keyword.
-
#low_top_of_page_bid_micros ⇒ Fixnum
Top of page bid low range (20th percentile) in micros for the keyword.
-
#monthly_search_volumes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMonthlySearchVolume>
Approximate number of searches on this query for the past twelve months.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics
constructor
A new instance of GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics
Returns a new instance of GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics.
6083 6084 6085 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6083 def initialize(**args) update!(**args) end |
Instance Attribute Details
#average_cpc_micros ⇒ Fixnum
Average Cost Per Click in micros for the keyword.
Corresponds to the JSON property averageCpcMicros
6047 6048 6049 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6047 def average_cpc_micros @average_cpc_micros end |
#avg_monthly_searches ⇒ Fixnum
Approximate number of monthly searches on this query, averaged for the past 12
months.
Corresponds to the JSON property avgMonthlySearches
6053 6054 6055 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6053 def avg_monthly_searches @avg_monthly_searches end |
#competition ⇒ String
The competition level for the query.
Corresponds to the JSON property competition
6058 6059 6060 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6058 def competition @competition end |
#competition_index ⇒ Fixnum
The competition index for the query in the range [0, 100]. Shows how
competitive ad placement is for a keyword. The level of competition from 0-100
is determined by the number of ad slots filled divided by the total number of
ad slots available. If not enough data is available, null is returned.
Corresponds to the JSON property competitionIndex
6066 6067 6068 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6066 def competition_index @competition_index end |
#high_top_of_page_bid_micros ⇒ Fixnum
Top of page bid high range (80th percentile) in micros for the keyword.
Corresponds to the JSON property highTopOfPageBidMicros
6071 6072 6073 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6071 def high_top_of_page_bid_micros @high_top_of_page_bid_micros end |
#low_top_of_page_bid_micros ⇒ Fixnum
Top of page bid low range (20th percentile) in micros for the keyword.
Corresponds to the JSON property lowTopOfPageBidMicros
6076 6077 6078 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6076 def low_top_of_page_bid_micros @low_top_of_page_bid_micros end |
#monthly_search_volumes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMonthlySearchVolume>
Approximate number of searches on this query for the past twelve months.
Corresponds to the JSON property monthlySearchVolumes
6081 6082 6083 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6081 def monthly_search_volumes @monthly_search_volumes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6088 6089 6090 6091 6092 6093 6094 6095 6096 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6088 def update!(**args) @average_cpc_micros = args[:average_cpc_micros] if args.key?(:average_cpc_micros) @avg_monthly_searches = args[:avg_monthly_searches] if args.key?(:avg_monthly_searches) @competition = args[:competition] if args.key?(:competition) @competition_index = args[:competition_index] if args.key?(:competition_index) @high_top_of_page_bid_micros = args[:high_top_of_page_bid_micros] if args.key?(:high_top_of_page_bid_micros) @low_top_of_page_bid_micros = args[:low_top_of_page_bid_micros] if args.key?(:low_top_of_page_bid_micros) @monthly_search_volumes = args[:monthly_search_volumes] if args.key?(:monthly_search_volumes) end |