Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordThemeInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordThemeInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Smart Campaign keyword theme.
Instance Attribute Summary collapse
-
#free_form_keyword_theme ⇒ String
Free-form text to be matched to a Smart Campaign keyword theme constant on a best-effort basis.
-
#keyword_theme_constant ⇒ String
The resource name of a Smart Campaign keyword theme constant.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonKeywordThemeInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonKeywordThemeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonKeywordThemeInfo
Returns a new instance of GoogleAdsSearchads360V23CommonKeywordThemeInfo.
6175 6176 6177 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#free_form_keyword_theme ⇒ String
Free-form text to be matched to a Smart Campaign keyword theme constant on a
best-effort basis.
Corresponds to the JSON property freeFormKeywordTheme
6167 6168 6169 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6167 def free_form_keyword_theme @free_form_keyword_theme end |
#keyword_theme_constant ⇒ String
The resource name of a Smart Campaign keyword theme constant.
keywordThemeConstants/keyword_theme_id~sub_keyword_theme_id`
Corresponds to the JSON propertykeywordThemeConstant`
6173 6174 6175 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6173 def keyword_theme_constant @keyword_theme_constant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6180 6181 6182 6183 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6180 def update!(**args) @free_form_keyword_theme = args[:free_form_keyword_theme] if args.key?(:free_form_keyword_theme) @keyword_theme_constant = args[:keyword_theme_constant] if args.key?(:keyword_theme_constant) end |