Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordThemeInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordThemeInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Smart Campaign keyword theme.
Instance Attribute Summary collapse
-
#free_form_keyword_theme ⇒ String
Free-form text to be matched to a Smart Campaign keyword theme constant on a best-effort basis.
-
#keyword_theme_constant ⇒ String
The resource name of a Smart Campaign keyword theme constant.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonKeywordThemeInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonKeywordThemeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonKeywordThemeInfo
Returns a new instance of GoogleAdsSearchads360V23CommonKeywordThemeInfo.
6115 6116 6117 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#free_form_keyword_theme ⇒ String
Free-form text to be matched to a Smart Campaign keyword theme constant on a
best-effort basis.
Corresponds to the JSON property freeFormKeywordTheme
6107 6108 6109 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6107 def free_form_keyword_theme @free_form_keyword_theme end |
#keyword_theme_constant ⇒ String
The resource name of a Smart Campaign keyword theme constant.
keywordThemeConstants/keyword_theme_id~sub_keyword_theme_id`
Corresponds to the JSON propertykeywordThemeConstant`
6113 6114 6115 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6113 def keyword_theme_constant @keyword_theme_constant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6120 6121 6122 6123 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6120 def update!(**args) @free_form_keyword_theme = args[:free_form_keyword_theme] if args.key?(:free_form_keyword_theme) @keyword_theme_constant = args[:keyword_theme_constant] if args.key?(:keyword_theme_constant) end |