Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLeadFormCustomQuestionField
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLeadFormCustomQuestionField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
One custom question input field instance within a form.
Instance Attribute Summary collapse
-
#custom_question_text ⇒ String
The exact custom question field text (for example, "What kind of vehicle do you have?").
-
#has_location_answer ⇒ Boolean
(also: #has_location_answer?)
Answer configuration for location question.
-
#single_choice_answers ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLeadFormSingleChoiceAnswers
Defines possible answers for a single choice question, usually presented as a single-choice drop-down list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLeadFormCustomQuestionField
constructor
A new instance of GoogleAdsSearchads360V23CommonLeadFormCustomQuestionField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLeadFormCustomQuestionField
Returns a new instance of GoogleAdsSearchads360V23CommonLeadFormCustomQuestionField.
6311 6312 6313 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6311 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_question_text ⇒ String
The exact custom question field text (for example, "What kind of vehicle do
you have?").
Corresponds to the JSON property customQuestionText
6293 6294 6295 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6293 def custom_question_text @custom_question_text end |
#has_location_answer ⇒ Boolean Also known as: has_location_answer?
Answer configuration for location question. If true, campaign/account level
location data (state, city, business name etc) will be rendered on the Lead
Form. Starting V13.1, has_location_answer can only be set for "What is your
preferred dealership?" question, for advertisers with Location Assets setup at
campaign/account level.
Corresponds to the JSON property hasLocationAnswer
6302 6303 6304 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6302 def has_location_answer @has_location_answer end |
#single_choice_answers ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLeadFormSingleChoiceAnswers
Defines possible answers for a single choice question, usually presented as a
single-choice drop-down list.
Corresponds to the JSON property singleChoiceAnswers
6309 6310 6311 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6309 def single_choice_answers @single_choice_answers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6316 6317 6318 6319 6320 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6316 def update!(**args) @custom_question_text = args[:custom_question_text] if args.key?(:custom_question_text) @has_location_answer = args[:has_location_answer] if args.key?(:has_location_answer) @single_choice_answers = args[:single_choice_answers] if args.key?(:single_choice_answers) end |