Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLeadFormDeliveryMethod

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A configuration of how leads are delivered to the advertiser.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLeadFormDeliveryMethod

Returns a new instance of GoogleAdsSearchads360V23CommonLeadFormDeliveryMethod.



6334
6335
6336
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#webhookGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebhookDelivery

Google notifies the advertiser of leads by making HTTP calls to an endpoint they specify. The requests contain JSON matching a schema that Google publishes as part of form ads documentation. Corresponds to the JSON property webhook



6332
6333
6334
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6332

def webhook
  @webhook
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6339
6340
6341
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6339

def update!(**args)
  @webhook = args[:webhook] if args.key?(:webhook)
end