Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A legacy app install ad that only can be used by a few select customers.
Instance Attribute Summary collapse
-
#app_id ⇒ String
The ID of the mobile app.
-
#app_store ⇒ String
The app store the mobile app is available in.
-
#description1 ⇒ String
The first description line of the ad.
-
#description2 ⇒ String
The second description line of the ad.
-
#headline ⇒ String
The headline of the ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo
Returns a new instance of GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo.
6492 6493 6494 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ String
The ID of the mobile app.
Corresponds to the JSON property appId
6470 6471 6472 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6470 def app_id @app_id end |
#app_store ⇒ String
The app store the mobile app is available in.
Corresponds to the JSON property appStore
6475 6476 6477 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6475 def app_store @app_store end |
#description1 ⇒ String
The first description line of the ad.
Corresponds to the JSON property description1
6480 6481 6482 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6480 def description1 @description1 end |
#description2 ⇒ String
The second description line of the ad.
Corresponds to the JSON property description2
6485 6486 6487 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6485 def description2 @description2 end |
#headline ⇒ String
The headline of the ad.
Corresponds to the JSON property headline
6490 6491 6492 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6490 def headline @headline end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6497 6498 6499 6500 6501 6502 6503 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6497 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @app_store = args[:app_store] if args.key?(:app_store) @description1 = args[:description1] if args.key?(:description1) @description2 = args[:description2] if args.key?(:description2) @headline = args[:headline] if args.key?(:headline) end |