Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A legacy app install ad that only can be used by a few select customers.
Instance Attribute Summary collapse
-
#app_id ⇒ String
The ID of the mobile app.
-
#app_store ⇒ String
The app store the mobile app is available in.
-
#description1 ⇒ String
The first description line of the ad.
-
#description2 ⇒ String
The second description line of the ad.
-
#headline ⇒ String
The headline of the ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo
Returns a new instance of GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo.
6432 6433 6434 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6432 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ String
The ID of the mobile app.
Corresponds to the JSON property appId
6410 6411 6412 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6410 def app_id @app_id end |
#app_store ⇒ String
The app store the mobile app is available in.
Corresponds to the JSON property appStore
6415 6416 6417 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6415 def app_store @app_store end |
#description1 ⇒ String
The first description line of the ad.
Corresponds to the JSON property description1
6420 6421 6422 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6420 def description1 @description1 end |
#description2 ⇒ String
The second description line of the ad.
Corresponds to the JSON property description2
6425 6426 6427 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6425 def description2 @description2 end |
#headline ⇒ String
The headline of the ad.
Corresponds to the JSON property headline
6430 6431 6432 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6430 def headline @headline end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6437 6438 6439 6440 6441 6442 6443 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6437 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @app_store = args[:app_store] if args.key?(:app_store) @description1 = args[:description1] if args.key?(:description1) @description2 = args[:description2] if args.key?(:description2) @headline = args[:headline] if args.key?(:headline) end |