Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLegacyResponsiveDisplayAdInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLegacyResponsiveDisplayAdInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A legacy responsive display ad. Ads of this type are labeled 'Responsive ads' in the Google Ads UI.
Instance Attribute Summary collapse
-
#accent_color ⇒ String
The accent color of the ad in hexadecimal, for example, #ffffff for white.
-
#allow_flexible_color ⇒ Boolean
(also: #allow_flexible_color?)
Advertiser's consent to allow flexible color.
-
#business_name ⇒ String
The business name in the ad.
-
#call_to_action_text ⇒ String
The call-to-action text for the ad.
-
#description ⇒ String
The description of the ad.
-
#format_setting ⇒ String
Specifies which format the ad will be served in.
-
#logo_image ⇒ String
The MediaFile resource name of the logo image used in the ad.
-
#long_headline ⇒ String
The long version of the ad's headline.
-
#main_color ⇒ String
The main color of the ad in hexadecimal, for example, #ffffff for white.
-
#marketing_image ⇒ String
The MediaFile resource name of the marketing image used in the ad.
-
#price_prefix ⇒ String
Prefix before price.
-
#promo_text ⇒ String
Promotion text used for dynamic formats of responsive ads.
-
#short_headline ⇒ String
The short version of the ad's headline.
-
#square_logo_image ⇒ String
The MediaFile resource name of the square logo image used in the ad.
-
#square_marketing_image ⇒ String
The MediaFile resource name of the square marketing image used in the ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLegacyResponsiveDisplayAdInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonLegacyResponsiveDisplayAdInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLegacyResponsiveDisplayAdInfo
Returns a new instance of GoogleAdsSearchads360V23CommonLegacyResponsiveDisplayAdInfo.
6533 6534 6535 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accent_color ⇒ String
The accent color of the ad in hexadecimal, for example, #ffffff for white. If
one of main_color and accent_color is set, the other is required as well.
Corresponds to the JSON property accentColor
6455 6456 6457 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6455 def accent_color @accent_color end |
#allow_flexible_color ⇒ Boolean Also known as: allow_flexible_color?
Advertiser's consent to allow flexible color. When true, the ad may be served
with different color if necessary. When false, the ad will be served with the
specified colors or a neutral color. The default value is true. Must be true
if main_color and accent_color are not set.
Corresponds to the JSON property allowFlexibleColor
6463 6464 6465 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6463 def allow_flexible_color @allow_flexible_color end |
#business_name ⇒ String
The business name in the ad.
Corresponds to the JSON property businessName
6469 6470 6471 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6469 def business_name @business_name end |
#call_to_action_text ⇒ String
The call-to-action text for the ad.
Corresponds to the JSON property callToActionText
6474 6475 6476 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6474 def call_to_action_text @call_to_action_text end |
#description ⇒ String
The description of the ad.
Corresponds to the JSON property description
6479 6480 6481 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6479 def description @description end |
#format_setting ⇒ String
Specifies which format the ad will be served in. Default is ALL_FORMATS.
Corresponds to the JSON property formatSetting
6484 6485 6486 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6484 def format_setting @format_setting end |
#logo_image ⇒ String
The MediaFile resource name of the logo image used in the ad.
Corresponds to the JSON property logoImage
6489 6490 6491 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6489 def logo_image @logo_image end |
#long_headline ⇒ String
The long version of the ad's headline.
Corresponds to the JSON property longHeadline
6494 6495 6496 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6494 def long_headline @long_headline end |
#main_color ⇒ String
The main color of the ad in hexadecimal, for example, #ffffff for white. If
one of main_color and accent_color is set, the other is required as well.
Corresponds to the JSON property mainColor
6500 6501 6502 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6500 def main_color @main_color end |
#marketing_image ⇒ String
The MediaFile resource name of the marketing image used in the ad.
Corresponds to the JSON property marketingImage
6505 6506 6507 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6505 def marketing_image @marketing_image end |
#price_prefix ⇒ String
Prefix before price. For example, 'as low as'.
Corresponds to the JSON property pricePrefix
6510 6511 6512 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6510 def price_prefix @price_prefix end |
#promo_text ⇒ String
Promotion text used for dynamic formats of responsive ads. For example 'Free
two-day shipping'.
Corresponds to the JSON property promoText
6516 6517 6518 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6516 def promo_text @promo_text end |
#short_headline ⇒ String
The short version of the ad's headline.
Corresponds to the JSON property shortHeadline
6521 6522 6523 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6521 def short_headline @short_headline end |
#square_logo_image ⇒ String
The MediaFile resource name of the square logo image used in the ad.
Corresponds to the JSON property squareLogoImage
6526 6527 6528 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6526 def square_logo_image @square_logo_image end |
#square_marketing_image ⇒ String
The MediaFile resource name of the square marketing image used in the ad.
Corresponds to the JSON property squareMarketingImage
6531 6532 6533 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6531 def square_marketing_image @square_marketing_image end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6538 def update!(**args) @accent_color = args[:accent_color] if args.key?(:accent_color) @allow_flexible_color = args[:allow_flexible_color] if args.key?(:allow_flexible_color) @business_name = args[:business_name] if args.key?(:business_name) @call_to_action_text = args[:call_to_action_text] if args.key?(:call_to_action_text) @description = args[:description] if args.key?(:description) @format_setting = args[:format_setting] if args.key?(:format_setting) @logo_image = args[:logo_image] if args.key?(:logo_image) @long_headline = args[:long_headline] if args.key?(:long_headline) @main_color = args[:main_color] if args.key?(:main_color) @marketing_image = args[:marketing_image] if args.key?(:marketing_image) @price_prefix = args[:price_prefix] if args.key?(:price_prefix) @promo_text = args[:promo_text] if args.key?(:promo_text) @short_headline = args[:short_headline] if args.key?(:short_headline) @square_logo_image = args[:square_logo_image] if args.key?(:square_logo_image) @square_marketing_image = args[:square_marketing_image] if args.key?(:square_marketing_image) end |