Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLifecycleGoalValueSettings
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLifecycleGoalValueSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Lifecycle goal value settings.
Instance Attribute Summary collapse
-
#high_lifetime_value ⇒ Float
High lifetime value of the lifecycle goal.
-
#value ⇒ Float
Value of the lifecycle goal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLifecycleGoalValueSettings
constructor
A new instance of GoogleAdsSearchads360V23CommonLifecycleGoalValueSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLifecycleGoalValueSettings
Returns a new instance of GoogleAdsSearchads360V23CommonLifecycleGoalValueSettings.
6674 6675 6676 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#high_lifetime_value ⇒ Float
High lifetime value of the lifecycle goal. For example, for customer
acquisition goal, high lifetime value is the incremental conversion value for
new customers who are of high value. High lifetime value should be greater
than value, if set.
Corresponds to the JSON property highLifetimeValue
6665 6666 6667 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6665 def high_lifetime_value @high_lifetime_value end |
#value ⇒ Float
Value of the lifecycle goal. For example, for customer acquisition goal, value
is the incremental conversion value for new customers who are not of high
value.
Corresponds to the JSON property value
6672 6673 6674 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6672 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6679 6680 6681 6682 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6679 def update!(**args) @high_lifetime_value = args[:high_lifetime_value] if args.key?(:high_lifetime_value) @value = args[:value] if args.key?(:value) end |