Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLineupAttributeMetadata
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLineupAttributeMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Metadata associated with a Lineup attribute.
Instance Attribute Summary collapse
-
#channel_count_lower_bound ⇒ Fixnum
The lower end of a range containing the number of channels in the lineup.
-
#channel_count_upper_bound ⇒ Fixnum
The upper end of a range containing the number of channels in the lineup.
-
#inventory_country ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo
A location criterion.
-
#median_monthly_inventory ⇒ Fixnum
The median number of impressions per month on this lineup.
-
#sample_channels ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLineupAttributeMetadataSampleChannel>
Examples of channels that are included in the lineup.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLineupAttributeMetadata
constructor
A new instance of GoogleAdsSearchads360V23CommonLineupAttributeMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLineupAttributeMetadata
Returns a new instance of GoogleAdsSearchads360V23CommonLineupAttributeMetadata.
6654 6655 6656 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6654 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_count_lower_bound ⇒ Fixnum
The lower end of a range containing the number of channels in the lineup.
Corresponds to the JSON property channelCountLowerBound
6632 6633 6634 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6632 def channel_count_lower_bound @channel_count_lower_bound end |
#channel_count_upper_bound ⇒ Fixnum
The upper end of a range containing the number of channels in the lineup.
Corresponds to the JSON property channelCountUpperBound
6637 6638 6639 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6637 def channel_count_upper_bound @channel_count_upper_bound end |
#inventory_country ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo
A location criterion.
Corresponds to the JSON property inventoryCountry
6642 6643 6644 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6642 def inventory_country @inventory_country end |
#median_monthly_inventory ⇒ Fixnum
The median number of impressions per month on this lineup.
Corresponds to the JSON property medianMonthlyInventory
6647 6648 6649 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6647 def median_monthly_inventory @median_monthly_inventory end |
#sample_channels ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLineupAttributeMetadataSampleChannel>
Examples of channels that are included in the lineup.
Corresponds to the JSON property sampleChannels
6652 6653 6654 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6652 def sample_channels @sample_channels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6659 6660 6661 6662 6663 6664 6665 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6659 def update!(**args) @channel_count_lower_bound = args[:channel_count_lower_bound] if args.key?(:channel_count_lower_bound) @channel_count_upper_bound = args[:channel_count_upper_bound] if args.key?(:channel_count_upper_bound) @inventory_country = args[:inventory_country] if args.key?(:inventory_country) @median_monthly_inventory = args[:median_monthly_inventory] if args.key?(:median_monthly_inventory) @sample_channels = args[:sample_channels] if args.key?(:sample_channels) end |