Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingDimensionInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingDimensionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Listing dimensions for listing group criterion.
Instance Attribute Summary collapse
-
#activity_city ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityCityInfo
The city where the travel activity is available.
-
#activity_country ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityCountryInfo
The country where the travel activity is available.
-
#activity_id ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityIdInfo
Advertiser-specific activity ID.
-
#activity_rating ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityRatingInfo
Rating of the activity as a number 1 to 5, where 5 is the best.
-
#activity_state ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityStateInfo
The state where the travel activity is available.
-
#hotel_city ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCityInfo
City the hotel is located in.
-
#hotel_class ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelClassInfo
Class of the hotel as a number of stars 1 to 5.
-
#hotel_country_region ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCountryRegionInfo
Country or Region the hotel is located in.
-
#hotel_id ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelIdInfo
Advertiser-specific hotel ID.
-
#hotel_state ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelStateInfo
State the hotel is located in.
-
#product_brand ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductBrandInfo
Brand of the product.
-
#product_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductCategoryInfo
Category of a product offer.
-
#product_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductChannelInfo
Locality of a product offer.
-
#product_channel_exclusivity ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductChannelExclusivityInfo
Availability of a product offer.
-
#product_condition ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductConditionInfo
Condition of a product offer.
-
#product_custom_attribute ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductCustomAttributeInfo
Custom attribute of a product offer.
-
#product_grouping ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductGroupingInfo
Grouping of a product offer.
-
#product_item_id ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductItemIdInfo
Item id of a product offer.
-
#product_labels ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductLabelsInfo
Labels of a product offer.
-
#product_legacy_condition ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductLegacyConditionInfo
Legacy condition of a product offer.
-
#product_type ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductTypeInfo
Type of a product offer.
-
#product_type_full ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductTypeFullInfo
Full type of a product offer.
-
#unknown_listing_dimension ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnknownListingDimensionInfo
Unknown listing dimension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonListingDimensionInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonListingDimensionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonListingDimensionInfo
Returns a new instance of GoogleAdsSearchads360V23CommonListingDimensionInfo.
6851 6852 6853 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6851 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activity_city ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityCityInfo
The city where the travel activity is available.
Corresponds to the JSON property activityCity
6735 6736 6737 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6735 def activity_city @activity_city end |
#activity_country ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityCountryInfo
The country where the travel activity is available.
Corresponds to the JSON property activityCountry
6740 6741 6742 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6740 def activity_country @activity_country end |
#activity_id ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityIdInfo
Advertiser-specific activity ID.
Corresponds to the JSON property activityId
6745 6746 6747 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6745 def activity_id @activity_id end |
#activity_rating ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityRatingInfo
Rating of the activity as a number 1 to 5, where 5 is the best.
Corresponds to the JSON property activityRating
6750 6751 6752 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6750 def @activity_rating end |
#activity_state ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityStateInfo
The state where the travel activity is available.
Corresponds to the JSON property activityState
6755 6756 6757 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6755 def activity_state @activity_state end |
#hotel_city ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCityInfo
City the hotel is located in.
Corresponds to the JSON property hotelCity
6760 6761 6762 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6760 def hotel_city @hotel_city end |
#hotel_class ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelClassInfo
Class of the hotel as a number of stars 1 to 5.
Corresponds to the JSON property hotelClass
6765 6766 6767 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6765 def hotel_class @hotel_class end |
#hotel_country_region ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCountryRegionInfo
Country or Region the hotel is located in.
Corresponds to the JSON property hotelCountryRegion
6770 6771 6772 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6770 def hotel_country_region @hotel_country_region end |
#hotel_id ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelIdInfo
Advertiser-specific hotel ID.
Corresponds to the JSON property hotelId
6775 6776 6777 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6775 def hotel_id @hotel_id end |
#hotel_state ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelStateInfo
State the hotel is located in.
Corresponds to the JSON property hotelState
6780 6781 6782 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6780 def hotel_state @hotel_state end |
#product_brand ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductBrandInfo
Brand of the product.
Corresponds to the JSON property productBrand
6785 6786 6787 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6785 def product_brand @product_brand end |
#product_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductCategoryInfo
Category of a product offer.
Corresponds to the JSON property productCategory
6790 6791 6792 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6790 def product_category @product_category end |
#product_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductChannelInfo
Locality of a product offer.
Corresponds to the JSON property productChannel
6795 6796 6797 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6795 def product_channel @product_channel end |
#product_channel_exclusivity ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductChannelExclusivityInfo
Availability of a product offer.
Corresponds to the JSON property productChannelExclusivity
6800 6801 6802 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6800 def product_channel_exclusivity @product_channel_exclusivity end |
#product_condition ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductConditionInfo
Condition of a product offer.
Corresponds to the JSON property productCondition
6805 6806 6807 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6805 def product_condition @product_condition end |
#product_custom_attribute ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductCustomAttributeInfo
Custom attribute of a product offer.
Corresponds to the JSON property productCustomAttribute
6810 6811 6812 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6810 def product_custom_attribute @product_custom_attribute end |
#product_grouping ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductGroupingInfo
Grouping of a product offer. This listing dimension is deprecated and it is
supported only in Display campaigns.
Corresponds to the JSON property productGrouping
6816 6817 6818 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6816 def product_grouping @product_grouping end |
#product_item_id ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductItemIdInfo
Item id of a product offer.
Corresponds to the JSON property productItemId
6821 6822 6823 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6821 def product_item_id @product_item_id end |
#product_labels ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductLabelsInfo
Labels of a product offer. This listing dimension is deprecated and it is
supported only in Display campaigns.
Corresponds to the JSON property productLabels
6827 6828 6829 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6827 def product_labels @product_labels end |
#product_legacy_condition ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductLegacyConditionInfo
Legacy condition of a product offer. This listing dimension is deprecated and
it is supported only in Display campaigns.
Corresponds to the JSON property productLegacyCondition
6833 6834 6835 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6833 def product_legacy_condition @product_legacy_condition end |
#product_type ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductTypeInfo
Type of a product offer.
Corresponds to the JSON property productType
6838 6839 6840 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6838 def product_type @product_type end |
#product_type_full ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductTypeFullInfo
Full type of a product offer. This listing dimension is deprecated and it is
supported only in Display campaigns.
Corresponds to the JSON property productTypeFull
6844 6845 6846 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6844 def product_type_full @product_type_full end |
#unknown_listing_dimension ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnknownListingDimensionInfo
Unknown listing dimension.
Corresponds to the JSON property unknownListingDimension
6849 6850 6851 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6849 def unknown_listing_dimension @unknown_listing_dimension end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 6879 6880 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6856 def update!(**args) @activity_city = args[:activity_city] if args.key?(:activity_city) @activity_country = args[:activity_country] if args.key?(:activity_country) @activity_id = args[:activity_id] if args.key?(:activity_id) @activity_rating = args[:activity_rating] if args.key?(:activity_rating) @activity_state = args[:activity_state] if args.key?(:activity_state) @hotel_city = args[:hotel_city] if args.key?(:hotel_city) @hotel_class = args[:hotel_class] if args.key?(:hotel_class) @hotel_country_region = args[:hotel_country_region] if args.key?(:hotel_country_region) @hotel_id = args[:hotel_id] if args.key?(:hotel_id) @hotel_state = args[:hotel_state] if args.key?(:hotel_state) @product_brand = args[:product_brand] if args.key?(:product_brand) @product_category = args[:product_category] if args.key?(:product_category) @product_channel = args[:product_channel] if args.key?(:product_channel) @product_channel_exclusivity = args[:product_channel_exclusivity] if args.key?(:product_channel_exclusivity) @product_condition = args[:product_condition] if args.key?(:product_condition) @product_custom_attribute = args[:product_custom_attribute] if args.key?(:product_custom_attribute) @product_grouping = args[:product_grouping] if args.key?(:product_grouping) @product_item_id = args[:product_item_id] if args.key?(:product_item_id) @product_labels = args[:product_labels] if args.key?(:product_labels) @product_legacy_condition = args[:product_legacy_condition] if args.key?(:product_legacy_condition) @product_type = args[:product_type] if args.key?(:product_type) @product_type_full = args[:product_type_full] if args.key?(:product_type_full) @unknown_listing_dimension = args[:unknown_listing_dimension] if args.key?(:unknown_listing_dimension) end |