Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingDimensionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Listing dimensions for listing group criterion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonListingDimensionInfo

Returns a new instance of GoogleAdsSearchads360V23CommonListingDimensionInfo.



6791
6792
6793
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6791

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activity_cityGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityCityInfo

The city where the travel activity is available. Corresponds to the JSON property activityCity



6675
6676
6677
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6675

def activity_city
  @activity_city
end

#activity_countryGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityCountryInfo

The country where the travel activity is available. Corresponds to the JSON property activityCountry



6680
6681
6682
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6680

def activity_country
  @activity_country
end

#activity_idGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityIdInfo

Advertiser-specific activity ID. Corresponds to the JSON property activityId



6685
6686
6687
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6685

def activity_id
  @activity_id
end

#activity_ratingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityRatingInfo

Rating of the activity as a number 1 to 5, where 5 is the best. Corresponds to the JSON property activityRating



6690
6691
6692
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6690

def activity_rating
  @activity_rating
end

#activity_stateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonActivityStateInfo

The state where the travel activity is available. Corresponds to the JSON property activityState



6695
6696
6697
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6695

def activity_state
  @activity_state
end

#hotel_cityGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCityInfo

City the hotel is located in. Corresponds to the JSON property hotelCity



6700
6701
6702
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6700

def hotel_city
  @hotel_city
end

#hotel_classGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelClassInfo

Class of the hotel as a number of stars 1 to 5. Corresponds to the JSON property hotelClass



6705
6706
6707
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6705

def hotel_class
  @hotel_class
end

#hotel_country_regionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCountryRegionInfo

Country or Region the hotel is located in. Corresponds to the JSON property hotelCountryRegion



6710
6711
6712
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6710

def hotel_country_region
  @hotel_country_region
end

#hotel_idGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelIdInfo

Advertiser-specific hotel ID. Corresponds to the JSON property hotelId



6715
6716
6717
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6715

def hotel_id
  @hotel_id
end

#hotel_stateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelStateInfo

State the hotel is located in. Corresponds to the JSON property hotelState



6720
6721
6722
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6720

def hotel_state
  @hotel_state
end

#product_brandGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductBrandInfo

Brand of the product. Corresponds to the JSON property productBrand



6725
6726
6727
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6725

def product_brand
  @product_brand
end

#product_categoryGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductCategoryInfo

Category of a product offer. Corresponds to the JSON property productCategory



6730
6731
6732
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6730

def product_category
  @product_category
end

#product_channelGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductChannelInfo

Locality of a product offer. Corresponds to the JSON property productChannel



6735
6736
6737
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6735

def product_channel
  @product_channel
end

#product_channel_exclusivityGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductChannelExclusivityInfo

Availability of a product offer. Corresponds to the JSON property productChannelExclusivity



6740
6741
6742
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6740

def product_channel_exclusivity
  @product_channel_exclusivity
end

#product_conditionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductConditionInfo

Condition of a product offer. Corresponds to the JSON property productCondition



6745
6746
6747
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6745

def product_condition
  @product_condition
end

#product_custom_attributeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductCustomAttributeInfo

Custom attribute of a product offer. Corresponds to the JSON property productCustomAttribute



6750
6751
6752
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6750

def product_custom_attribute
  @product_custom_attribute
end

#product_groupingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductGroupingInfo

Grouping of a product offer. This listing dimension is deprecated and it is supported only in Display campaigns. Corresponds to the JSON property productGrouping



6756
6757
6758
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6756

def product_grouping
  @product_grouping
end

#product_item_idGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductItemIdInfo

Item id of a product offer. Corresponds to the JSON property productItemId



6761
6762
6763
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6761

def product_item_id
  @product_item_id
end

#product_labelsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductLabelsInfo

Labels of a product offer. This listing dimension is deprecated and it is supported only in Display campaigns. Corresponds to the JSON property productLabels



6767
6768
6769
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6767

def product_labels
  @product_labels
end

#product_legacy_conditionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductLegacyConditionInfo

Legacy condition of a product offer. This listing dimension is deprecated and it is supported only in Display campaigns. Corresponds to the JSON property productLegacyCondition



6773
6774
6775
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6773

def product_legacy_condition
  @product_legacy_condition
end

#product_typeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductTypeInfo

Type of a product offer. Corresponds to the JSON property productType



6778
6779
6780
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6778

def product_type
  @product_type
end

#product_type_fullGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProductTypeFullInfo

Full type of a product offer. This listing dimension is deprecated and it is supported only in Display campaigns. Corresponds to the JSON property productTypeFull



6784
6785
6786
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6784

def product_type_full
  @product_type_full
end

#unknown_listing_dimensionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnknownListingDimensionInfo

Unknown listing dimension. Corresponds to the JSON property unknownListingDimension



6789
6790
6791
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6789

def unknown_listing_dimension
  @unknown_listing_dimension
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6796
6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6796

def update!(**args)
  @activity_city = args[:activity_city] if args.key?(:activity_city)
  @activity_country = args[:activity_country] if args.key?(:activity_country)
  @activity_id = args[:activity_id] if args.key?(:activity_id)
  @activity_rating = args[:activity_rating] if args.key?(:activity_rating)
  @activity_state = args[:activity_state] if args.key?(:activity_state)
  @hotel_city = args[:hotel_city] if args.key?(:hotel_city)
  @hotel_class = args[:hotel_class] if args.key?(:hotel_class)
  @hotel_country_region = args[:hotel_country_region] if args.key?(:hotel_country_region)
  @hotel_id = args[:hotel_id] if args.key?(:hotel_id)
  @hotel_state = args[:hotel_state] if args.key?(:hotel_state)
  @product_brand = args[:product_brand] if args.key?(:product_brand)
  @product_category = args[:product_category] if args.key?(:product_category)
  @product_channel = args[:product_channel] if args.key?(:product_channel)
  @product_channel_exclusivity = args[:product_channel_exclusivity] if args.key?(:product_channel_exclusivity)
  @product_condition = args[:product_condition] if args.key?(:product_condition)
  @product_custom_attribute = args[:product_custom_attribute] if args.key?(:product_custom_attribute)
  @product_grouping = args[:product_grouping] if args.key?(:product_grouping)
  @product_item_id = args[:product_item_id] if args.key?(:product_item_id)
  @product_labels = args[:product_labels] if args.key?(:product_labels)
  @product_legacy_condition = args[:product_legacy_condition] if args.key?(:product_legacy_condition)
  @product_type = args[:product_type] if args.key?(:product_type)
  @product_type_full = args[:product_type_full] if args.key?(:product_type_full)
  @unknown_listing_dimension = args[:unknown_listing_dimension] if args.key?(:unknown_listing_dimension)
end