Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalServicesDocumentReadOnly

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Local Services Document with read only accessible data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLocalServicesDocumentReadOnly

Returns a new instance of GoogleAdsSearchads360V23CommonLocalServicesDocumentReadOnly.



7001
7002
7003
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_urlString

URL to access an already uploaded Local Services document. Corresponds to the JSON property documentUrl

Returns:

  • (String)


6999
7000
7001
# File 'lib/google/apis/searchads360_v23/classes.rb', line 6999

def document_url
  @document_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7006
7007
7008
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7006

def update!(**args)
  @document_url = args[:document_url] if args.key?(:document_url)
end