Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A location asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLocationAsset

Returns a new instance of GoogleAdsSearchads360V23CommonLocationAsset.



7038
7039
7040
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7038

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_profile_locationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileLocation>

The list of business locations for the customer. This will only be returned if the Location Asset is syncing from the Business Profile account. It is possible to have multiple Business Profile listings under the same account that point to the same Place ID. Corresponds to the JSON property businessProfileLocations



7021
7022
7023
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7021

def business_profile_locations
  @business_profile_locations
end

#location_ownership_typeString

The type of location ownership. If the type is BUSINESS_OWNER, it will be served as a location extension. If the type is AFFILIATE, it will be served as an affiliate location. Corresponds to the JSON property locationOwnershipType

Returns:

  • (String)


7028
7029
7030
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7028

def location_ownership_type
  @location_ownership_type
end

#place_idString

Place IDs uniquely identify a place in the Google Places database and on Google Maps. This field is unique for a given customer ID and asset type. See https://developers.google.com/places/web-service/place-id to learn more about Place ID. Corresponds to the JSON property placeId

Returns:

  • (String)


7036
7037
7038
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7036

def place_id
  @place_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7043
7044
7045
7046
7047
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7043

def update!(**args)
  @business_profile_locations = args[:business_profile_locations] if args.key?(:business_profile_locations)
  @location_ownership_type = args[:location_ownership_type] if args.key?(:location_ownership_type)
  @place_id = args[:place_id] if args.key?(:place_id)
end