Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationGroupInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationGroupInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A radius around a list of locations specified through a feed.
Instance Attribute Summary collapse
-
#enable_customer_level_location_asset_set ⇒ Boolean
(also: #enable_customer_level_location_asset_set?)
Denotes that the latest customer level asset set is used for targeting.
-
#feed_item_sets ⇒ Array<String>
FeedItemSets whose FeedItems are targeted.
-
#geo_target_constants ⇒ Array<String>
Geo target constant(s) restricting the scope of the geographic area within the feed.
-
#location_group_asset_sets ⇒ Array<String>
AssetSets whose Assets are targeted.
-
#radius ⇒ Fixnum
Distance in units specifying the radius around targeted locations.
-
#radius_units ⇒ String
Unit of the radius.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLocationGroupInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonLocationGroupInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLocationGroupInfo
Returns a new instance of GoogleAdsSearchads360V23CommonLocationGroupInfo.
7120 7121 7122 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_customer_level_location_asset_set ⇒ Boolean Also known as: enable_customer_level_location_asset_set?
Denotes that the latest customer level asset set is used for targeting. Used
with radius and radius_units. Cannot be used with feed, geo target constants
or feed item sets. When using asset sets, either this field or
location_group_asset_sets should be specified. Both cannot be used at the same
time. This can only be set in CREATE operations.
Corresponds to the JSON property enableCustomerLevelLocationAssetSet
7080 7081 7082 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7080 def enable_customer_level_location_asset_set @enable_customer_level_location_asset_set end |
#feed_item_sets ⇒ Array<String>
FeedItemSets whose FeedItems are targeted. If multiple IDs are specified, then
all items that appear in at least one set are targeted. This field cannot be
used with geo_target_constants. This is optional and can only be set in CREATE
operations.
Corresponds to the JSON property feedItemSets
7089 7090 7091 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7089 def feed_item_sets @feed_item_sets end |
#geo_target_constants ⇒ Array<String>
Geo target constant(s) restricting the scope of the geographic area within the
feed. Currently only one geo target constant is allowed.
Corresponds to the JSON property geoTargetConstants
7095 7096 7097 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7095 def geo_target_constants @geo_target_constants end |
#location_group_asset_sets ⇒ Array<String>
AssetSets whose Assets are targeted. If multiple IDs are specified, then all
items that appear in at least one set are targeted. This field cannot be used
with feed, geo target constants or feed item sets. When using asset sets,
either this field or enable_customer_level_location_asset_set should be
specified. Both cannot be used at the same time. This can only be set in
CREATE operations.
Corresponds to the JSON property locationGroupAssetSets
7105 7106 7107 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7105 def location_group_asset_sets @location_group_asset_sets end |
#radius ⇒ Fixnum
Distance in units specifying the radius around targeted locations. This is
required and must be set in CREATE operations.
Corresponds to the JSON property radius
7111 7112 7113 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7111 def radius @radius end |
#radius_units ⇒ String
Unit of the radius. Miles and meters are supported for geo target constants.
Milli miles and meters are supported for feed item sets. This is required and
must be set in CREATE operations.
Corresponds to the JSON property radiusUnits
7118 7119 7120 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7118 def radius_units @radius_units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7125 7126 7127 7128 7129 7130 7131 7132 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7125 def update!(**args) @enable_customer_level_location_asset_set = args[:enable_customer_level_location_asset_set] if args.key?(:enable_customer_level_location_asset_set) @feed_item_sets = args[:feed_item_sets] if args.key?(:feed_item_sets) @geo_target_constants = args[:geo_target_constants] if args.key?(:geo_target_constants) @location_group_asset_sets = args[:location_group_asset_sets] if args.key?(:location_group_asset_sets) @radius = args[:radius] if args.key?(:radius) @radius_units = args[:radius_units] if args.key?(:radius_units) end |