Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationSet
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Data related to location set. One of the Google Business Profile (previously known as Google My Business) data, Chain data, and map location data need to be specified.
Instance Attribute Summary collapse
-
#business_profile_location_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileLocationSet
Data used to configure a location set populated from Google Business Profile locations.
-
#chain_location_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonChainSet
Data used to configure a location set populated with the specified chains.
-
#location_ownership_type ⇒ String
Required.
-
#maps_location_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMapsLocationSet
Wrapper for multiple maps location sync data Corresponds to the JSON property
mapsLocationSet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLocationSet
constructor
A new instance of GoogleAdsSearchads360V23CommonLocationSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLocationSet
Returns a new instance of GoogleAdsSearchads360V23CommonLocationSet.
7243 7244 7245 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_profile_location_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileLocationSet
Data used to configure a location set populated from Google Business Profile
locations. Different types of filters are AND'ed together, if they are
specified.
Corresponds to the JSON property businessProfileLocationSet
7225 7226 7227 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7225 def business_profile_location_set @business_profile_location_set end |
#chain_location_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonChainSet
Data used to configure a location set populated with the specified chains.
Corresponds to the JSON property chainLocationSet
7230 7231 7232 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7230 def chain_location_set @chain_location_set end |
#location_ownership_type ⇒ String
Required. Immutable. Location Ownership Type (owned location or affiliate
location).
Corresponds to the JSON property locationOwnershipType
7236 7237 7238 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7236 def location_ownership_type @location_ownership_type end |
#maps_location_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMapsLocationSet
Wrapper for multiple maps location sync data
Corresponds to the JSON property mapsLocationSet
7241 7242 7243 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7241 def maps_location_set @maps_location_set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7248 7249 7250 7251 7252 7253 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7248 def update!(**args) @business_profile_location_set = args[:business_profile_location_set] if args.key?(:business_profile_location_set) @chain_location_set = args[:chain_location_set] if args.key?(:chain_location_set) @location_ownership_type = args[:location_ownership_type] if args.key?(:location_ownership_type) @maps_location_set = args[:maps_location_set] if args.key?(:maps_location_set) end |