Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLogicalUserListOperandInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Operand of logical user list that consists of a user list.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLogicalUserListOperandInfo

Returns a new instance of GoogleAdsSearchads360V23CommonLogicalUserListOperandInfo.



7226
7227
7228
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7226

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#user_listString

Resource name of a user list as an operand. Corresponds to the JSON property userList

Returns:

  • (String)


7224
7225
7226
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7224

def user_list
  @user_list
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7231
7232
7233
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7231

def update!(**args)
  @user_list = args[:user_list] if args.key?(:user_list)
end