Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLookalikeUserListInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLookalikeUserListInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
LookalikeUserlist, composed of users similar to those of a configurable seed ( set of UserLists)
Instance Attribute Summary collapse
-
#country_codes ⇒ Array<String>
Countries targeted by the Lookalike.
-
#expansion_level ⇒ String
Expansion level, reflecting the size of the lookalike audience Corresponds to the JSON property
expansionLevel. -
#seed_user_list_ids ⇒ Array<Fixnum>
Seed UserList ID from which this list is derived, provided by user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLookalikeUserListInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonLookalikeUserListInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonLookalikeUserListInfo
Returns a new instance of GoogleAdsSearchads360V23CommonLookalikeUserListInfo.
7257 7258 7259 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7257 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_codes ⇒ Array<String>
Countries targeted by the Lookalike. Two-letter country code as defined by ISO-
3166
Corresponds to the JSON property countryCodes
7245 7246 7247 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7245 def country_codes @country_codes end |
#expansion_level ⇒ String
Expansion level, reflecting the size of the lookalike audience
Corresponds to the JSON property expansionLevel
7250 7251 7252 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7250 def expansion_level @expansion_level end |
#seed_user_list_ids ⇒ Array<Fixnum>
Seed UserList ID from which this list is derived, provided by user.
Corresponds to the JSON property seedUserListIds
7255 7256 7257 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7255 def seed_user_list_ids @seed_user_list_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7262 7263 7264 7265 7266 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7262 def update!(**args) @country_codes = args[:country_codes] if args.key?(:country_codes) @expansion_level = args[:expansion_level] if args.key?(:expansion_level) @seed_user_list_ids = args[:seed_user_list_ids] if args.key?(:seed_user_list_ids) end |