Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMaximizeConversionValue
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMaximizeConversionValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An automated bidding strategy to help get the most conversion value for your campaigns while spending your budget.
Instance Attribute Summary collapse
-
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy.
-
#cpc_bid_floor_micros ⇒ Fixnum
Minimum bid limit that can be set by the bid strategy.
-
#target_roas ⇒ Float
The target return on ad spend (ROAS) option.
-
#target_roas_tolerance_percent_millis ⇒ Fixnum
The percent of ROAS(return on advertising spend) degradation tolerance allowed to increase traffic diversity and conversion volume, specified in millis (for example, 10,000 = 10%).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonMaximizeConversionValue
constructor
A new instance of GoogleAdsSearchads360V23CommonMaximizeConversionValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonMaximizeConversionValue
Returns a new instance of GoogleAdsSearchads360V23CommonMaximizeConversionValue.
7463 7464 7465 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy. The limit applies to
all keywords managed by the strategy. Mutable for portfolio bidding strategies
only.
Corresponds to the JSON property cpcBidCeilingMicros
7437 7438 7439 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7437 def cpc_bid_ceiling_micros @cpc_bid_ceiling_micros end |
#cpc_bid_floor_micros ⇒ Fixnum
Minimum bid limit that can be set by the bid strategy. The limit applies to
all keywords managed by the strategy. Mutable for portfolio bidding strategies
only.
Corresponds to the JSON property cpcBidFloorMicros
7444 7445 7446 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7444 def cpc_bid_floor_micros @cpc_bid_floor_micros end |
#target_roas ⇒ Float
The target return on ad spend (ROAS) option. If set, the bid strategy will
maximize revenue while averaging the target return on ad spend. If the target
ROAS is high, the bid strategy may not be able to spend the full budget. If
the target ROAS is not set, the bid strategy will aim to achieve the highest
possible ROAS for the budget.
Corresponds to the JSON property targetRoas
7453 7454 7455 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7453 def target_roas @target_roas end |
#target_roas_tolerance_percent_millis ⇒ Fixnum
The percent of ROAS(return on advertising spend) degradation tolerance allowed
to increase traffic diversity and conversion volume, specified in millis (for
example, 10,000 = 10%). A value of 10,000 means that the advertiser can expect
ROAS degradation of up to 10% of the specified target ROAS.
Corresponds to the JSON property targetRoasTolerancePercentMillis
7461 7462 7463 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7461 def target_roas_tolerance_percent_millis @target_roas_tolerance_percent_millis end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7468 7469 7470 7471 7472 7473 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7468 def update!(**args) @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros) @cpc_bid_floor_micros = args[:cpc_bid_floor_micros] if args.key?(:cpc_bid_floor_micros) @target_roas = args[:target_roas] if args.key?(:target_roas) @target_roas_tolerance_percent_millis = args[:target_roas_tolerance_percent_millis] if args.key?(:target_roas_tolerance_percent_millis) end |