Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMaximizeConversions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An automated bidding strategy to help get the most conversions for your campaigns while spending your budget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonMaximizeConversions

Returns a new instance of GoogleAdsSearchads360V23CommonMaximizeConversions.



7445
7446
7447
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7445

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpc_bid_ceiling_microsFixnum

Maximum bid limit that can be set by the bid strategy. The limit applies to all keywords managed by the strategy. Mutable for portfolio bidding strategies only. Corresponds to the JSON property cpcBidCeilingMicros

Returns:

  • (Fixnum)


7426
7427
7428
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7426

def cpc_bid_ceiling_micros
  @cpc_bid_ceiling_micros
end

#cpc_bid_floor_microsFixnum

Minimum bid limit that can be set by the bid strategy. The limit applies to all keywords managed by the strategy. Mutable for portfolio bidding strategies only. Corresponds to the JSON property cpcBidFloorMicros

Returns:

  • (Fixnum)


7433
7434
7435
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7433

def cpc_bid_floor_micros
  @cpc_bid_floor_micros
end

#target_cpa_microsFixnum

The target cost-per-action (CPA) option. This is the average amount that you would like to spend per conversion action specified in micro units of the bidding strategy's currency. If set, the bid strategy will get as many conversions as possible at or below the target cost-per-action. If the target CPA is not set, the bid strategy will aim to achieve the lowest possible CPA given the budget. Corresponds to the JSON property targetCpaMicros

Returns:

  • (Fixnum)


7443
7444
7445
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7443

def target_cpa_micros
  @target_cpa_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7450
7451
7452
7453
7454
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7450

def update!(**args)
  @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros)
  @cpc_bid_floor_micros = args[:cpc_bid_floor_micros] if args.key?(:cpc_bid_floor_micros)
  @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros)
end