Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMediaBundleAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMediaBundleAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A MediaBundle asset.
Instance Attribute Summary collapse
-
#data ⇒ String
Media bundle (ZIP file) asset data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonMediaBundleAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonMediaBundleAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonMediaBundleAsset
Returns a new instance of GoogleAdsSearchads360V23CommonMediaBundleAsset.
7530 7531 7532 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ String
Media bundle (ZIP file) asset data. The format of the uploaded ZIP file
depends on the ad field where it will be used. For more information on the
format, see the documentation of the ad field where you plan on using the
MediaBundleAsset. This field is mutate only.
Corresponds to the JSON property data
NOTE: Values are automatically base64 encoded/decoded in the client library.
7528 7529 7530 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7528 def data @data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7535 7536 7537 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7535 def update!(**args) @data = args[:data] if args.key?(:data) end |