Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMediaBundleAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMediaBundleAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A MediaBundle asset.
Instance Attribute Summary collapse
-
#data ⇒ String
Media bundle (ZIP file) asset data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonMediaBundleAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonMediaBundleAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonMediaBundleAsset
Returns a new instance of GoogleAdsSearchads360V23CommonMediaBundleAsset.
7470 7471 7472 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ String
Media bundle (ZIP file) asset data. The format of the uploaded ZIP file
depends on the ad field where it will be used. For more information on the
format, see the documentation of the ad field where you plan on using the
MediaBundleAsset. This field is mutate only.
Corresponds to the JSON property data
NOTE: Values are automatically base64 encoded/decoded in the client library.
7468 7469 7470 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7468 def data @data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7475 7476 7477 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 7475 def update!(**args) @data = args[:data] if args.key?(:data) end |