Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An asset representing a mobile app.
Instance Attribute Summary collapse
-
#app_id ⇒ String
Required.
-
#app_store ⇒ String
Required.
-
#end_date ⇒ String
Last date of when this asset is effective and still serving, in yyyy-MM-dd format.
-
#link_text ⇒ String
Required.
-
#start_date ⇒ String
Start date of when this asset is effective and can begin serving, in yyyy-MM- dd format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonMobileAppAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonMobileAppAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonMobileAppAsset
Returns a new instance of GoogleAdsSearchads360V23CommonMobileAppAsset.
8565 8566 8567 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ String
Required. A string that uniquely identifies a mobile application. It should
just contain the platform native id, like "com.android.ebay" for Android or "
12345689" for iOS.
Corresponds to the JSON property appId
8540 8541 8542 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8540 def app_id @app_id end |
#app_store ⇒ String
Required. The application store that distributes this specific app.
Corresponds to the JSON property appStore
8545 8546 8547 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8545 def app_store @app_store end |
#end_date ⇒ String
Last date of when this asset is effective and still serving, in yyyy-MM-dd
format.
Corresponds to the JSON property endDate
8551 8552 8553 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8551 def end_date @end_date end |
#link_text ⇒ String
Required. The visible text displayed when the link is rendered in an ad. The
length of this string should be between 1 and 25, inclusive.
Corresponds to the JSON property linkText
8557 8558 8559 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8557 def link_text @link_text end |
#start_date ⇒ String
Start date of when this asset is effective and can begin serving, in yyyy-MM-
dd format.
Corresponds to the JSON property startDate
8563 8564 8565 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8563 def start_date @start_date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8570 8571 8572 8573 8574 8575 8576 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8570 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @app_store = args[:app_store] if args.key?(:app_store) @end_date = args[:end_date] if args.key?(:end_date) @link_text = args[:link_text] if args.key?(:link_text) @start_date = args[:start_date] if args.key?(:start_date) end |