Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonNegativeKeywordListInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Negative Keyword List criterion. Represents a shared set of negative keywords that can be excluded at the account-level. Only one negative keyword list criterion can be attached per account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonNegativeKeywordListInfo

Returns a new instance of GoogleAdsSearchads360V23CommonNegativeKeywordListInfo.



8722
8723
8724
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8722

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#shared_setString

The NegativeKeywordListInfo shared set resource name. Corresponds to the JSON property sharedSet

Returns:

  • (String)


8720
8721
8722
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8720

def shared_set
  @shared_set
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8727
8728
8729
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8727

def update!(**args)
  @shared_set = args[:shared_set] if args.key?(:shared_set)
end