Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonNegativeKeywordListInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonNegativeKeywordListInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Negative Keyword List criterion. Represents a shared set of negative keywords that can be excluded at the account-level. Only one negative keyword list criterion can be attached per account.
Instance Attribute Summary collapse
-
#shared_set ⇒ String
The NegativeKeywordListInfo shared set resource name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonNegativeKeywordListInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonNegativeKeywordListInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonNegativeKeywordListInfo
Returns a new instance of GoogleAdsSearchads360V23CommonNegativeKeywordListInfo.
8714 8715 8716 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8714 def initialize(**args) update!(**args) end |
Instance Attribute Details
#shared_set ⇒ String
The NegativeKeywordListInfo shared set resource name.
Corresponds to the JSON property sharedSet
8712 8713 8714 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8712 def shared_set @shared_set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8719 8720 8721 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8719 def update!(**args) @shared_set = args[:shared_set] if args.key?(:shared_set) end |