Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonOfflineUserAddressInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonOfflineUserAddressInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Address identifier of offline data.
Instance Attribute Summary collapse
-
#city ⇒ String
City of the address.
-
#country_code ⇒ String
2-letter country code in ISO-3166-1 alpha-2 of the user's address.
-
#hashed_first_name ⇒ String
First name of the user, which is hashed as SHA-256 after normalized (Lowercase all characters; Remove any extra spaces before, after, and in between).
-
#hashed_last_name ⇒ String
Last name of the user, which is hashed as SHA-256 after normalized (lower case only and no punctuation).
-
#hashed_street_address ⇒ String
The street address of the user hashed using SHA-256 hash function after normalization (lower case only).
-
#postal_code ⇒ String
Postal code of the user's address.
-
#state ⇒ String
State code of the address.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonOfflineUserAddressInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonOfflineUserAddressInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonOfflineUserAddressInfo
Returns a new instance of GoogleAdsSearchads360V23CommonOfflineUserAddressInfo.
8835 8836 8837 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8835 def initialize(**args) update!(**args) end |
Instance Attribute Details
#city ⇒ String
City of the address. Only accepted for Store Sales.
Corresponds to the JSON property city
8799 8800 8801 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8799 def city @city end |
#country_code ⇒ String
2-letter country code in ISO-3166-1 alpha-2 of the user's address.
Corresponds to the JSON property countryCode
8804 8805 8806 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8804 def country_code @country_code end |
#hashed_first_name ⇒ String
First name of the user, which is hashed as SHA-256 after normalized (Lowercase
all characters; Remove any extra spaces before, after, and in between).
Corresponds to the JSON property hashedFirstName
8810 8811 8812 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8810 def hashed_first_name @hashed_first_name end |
#hashed_last_name ⇒ String
Last name of the user, which is hashed as SHA-256 after normalized (lower case
only and no punctuation).
Corresponds to the JSON property hashedLastName
8816 8817 8818 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8816 def hashed_last_name @hashed_last_name end |
#hashed_street_address ⇒ String
The street address of the user hashed using SHA-256 hash function after
normalization (lower case only). Only accepted for
ConversionAdjustmentUploadService.
Corresponds to the JSON property hashedStreetAddress
8823 8824 8825 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8823 def hashed_street_address @hashed_street_address end |
#postal_code ⇒ String
Postal code of the user's address.
Corresponds to the JSON property postalCode
8828 8829 8830 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8828 def postal_code @postal_code end |
#state ⇒ String
State code of the address. Only accepted for Store Sales.
Corresponds to the JSON property state
8833 8834 8835 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8833 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8840 8841 8842 8843 8844 8845 8846 8847 8848 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8840 def update!(**args) @city = args[:city] if args.key?(:city) @country_code = args[:country_code] if args.key?(:country_code) @hashed_first_name = args[:hashed_first_name] if args.key?(:hashed_first_name) @hashed_last_name = args[:hashed_last_name] if args.key?(:hashed_last_name) @hashed_street_address = args[:hashed_street_address] if args.key?(:hashed_street_address) @postal_code = args[:postal_code] if args.key?(:postal_code) @state = args[:state] if args.key?(:state) end |