Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonOfflineUserAddressInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Address identifier of offline data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonOfflineUserAddressInfo

Returns a new instance of GoogleAdsSearchads360V23CommonOfflineUserAddressInfo.



8775
8776
8777
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8775

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cityString

City of the address. Only accepted for Store Sales. Corresponds to the JSON property city

Returns:

  • (String)


8739
8740
8741
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8739

def city
  @city
end

#country_codeString

2-letter country code in ISO-3166-1 alpha-2 of the user's address. Corresponds to the JSON property countryCode

Returns:

  • (String)


8744
8745
8746
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8744

def country_code
  @country_code
end

#hashed_first_nameString

First name of the user, which is hashed as SHA-256 after normalized (Lowercase all characters; Remove any extra spaces before, after, and in between). Corresponds to the JSON property hashedFirstName

Returns:

  • (String)


8750
8751
8752
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8750

def hashed_first_name
  @hashed_first_name
end

#hashed_last_nameString

Last name of the user, which is hashed as SHA-256 after normalized (lower case only and no punctuation). Corresponds to the JSON property hashedLastName

Returns:

  • (String)


8756
8757
8758
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8756

def hashed_last_name
  @hashed_last_name
end

#hashed_street_addressString

The street address of the user hashed using SHA-256 hash function after normalization (lower case only). Only accepted for ConversionAdjustmentUploadService. Corresponds to the JSON property hashedStreetAddress

Returns:

  • (String)


8763
8764
8765
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8763

def hashed_street_address
  @hashed_street_address
end

#postal_codeString

Postal code of the user's address. Corresponds to the JSON property postalCode

Returns:

  • (String)


8768
8769
8770
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8768

def postal_code
  @postal_code
end

#stateString

State code of the address. Only accepted for Store Sales. Corresponds to the JSON property state

Returns:

  • (String)


8773
8774
8775
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8773

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8780
8781
8782
8783
8784
8785
8786
8787
8788
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8780

def update!(**args)
  @city = args[:city] if args.key?(:city)
  @country_code = args[:country_code] if args.key?(:country_code)
  @hashed_first_name = args[:hashed_first_name] if args.key?(:hashed_first_name)
  @hashed_last_name = args[:hashed_last_name] if args.key?(:hashed_last_name)
  @hashed_street_address = args[:hashed_street_address] if args.key?(:hashed_street_address)
  @postal_code = args[:postal_code] if args.key?(:postal_code)
  @state = args[:state] if args.key?(:state)
end