Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonOfflineUserAddressInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonOfflineUserAddressInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Address identifier of offline data.
Instance Attribute Summary collapse
-
#city ⇒ String
City of the address.
-
#country_code ⇒ String
2-letter country code in ISO-3166-1 alpha-2 of the user's address.
-
#hashed_first_name ⇒ String
First name of the user, which is hashed as SHA-256 after normalized (Lowercase all characters; Remove any extra spaces before, after, and in between).
-
#hashed_last_name ⇒ String
Last name of the user, which is hashed as SHA-256 after normalized (lower case only and no punctuation).
-
#hashed_street_address ⇒ String
The street address of the user hashed using SHA-256 hash function after normalization (lower case only).
-
#postal_code ⇒ String
Postal code of the user's address.
-
#state ⇒ String
State code of the address.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonOfflineUserAddressInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonOfflineUserAddressInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonOfflineUserAddressInfo
Returns a new instance of GoogleAdsSearchads360V23CommonOfflineUserAddressInfo.
8767 8768 8769 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8767 def initialize(**args) update!(**args) end |
Instance Attribute Details
#city ⇒ String
City of the address. Only accepted for Store Sales.
Corresponds to the JSON property city
8731 8732 8733 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8731 def city @city end |
#country_code ⇒ String
2-letter country code in ISO-3166-1 alpha-2 of the user's address.
Corresponds to the JSON property countryCode
8736 8737 8738 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8736 def country_code @country_code end |
#hashed_first_name ⇒ String
First name of the user, which is hashed as SHA-256 after normalized (Lowercase
all characters; Remove any extra spaces before, after, and in between).
Corresponds to the JSON property hashedFirstName
8742 8743 8744 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8742 def hashed_first_name @hashed_first_name end |
#hashed_last_name ⇒ String
Last name of the user, which is hashed as SHA-256 after normalized (lower case
only and no punctuation).
Corresponds to the JSON property hashedLastName
8748 8749 8750 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8748 def hashed_last_name @hashed_last_name end |
#hashed_street_address ⇒ String
The street address of the user hashed using SHA-256 hash function after
normalization (lower case only). Only accepted for
ConversionAdjustmentUploadService.
Corresponds to the JSON property hashedStreetAddress
8755 8756 8757 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8755 def hashed_street_address @hashed_street_address end |
#postal_code ⇒ String
Postal code of the user's address.
Corresponds to the JSON property postalCode
8760 8761 8762 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8760 def postal_code @postal_code end |
#state ⇒ String
State code of the address. Only accepted for Store Sales.
Corresponds to the JSON property state
8765 8766 8767 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8765 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8772 8773 8774 8775 8776 8777 8778 8779 8780 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8772 def update!(**args) @city = args[:city] if args.key?(:city) @country_code = args[:country_code] if args.key?(:country_code) @hashed_first_name = args[:hashed_first_name] if args.key?(:hashed_first_name) @hashed_last_name = args[:hashed_last_name] if args.key?(:hashed_last_name) @hashed_street_address = args[:hashed_street_address] if args.key?(:hashed_street_address) @postal_code = args[:postal_code] if args.key?(:postal_code) @state = args[:state] if args.key?(:state) end |