Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPercentCpcBidSimulationPoint
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPercentCpcBidSimulationPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Projected metrics for a specific percent CPC amount. Only Hotel advertising channel type supports this field.
Instance Attribute Summary collapse
-
#biddable_conversions ⇒ Float
Projected number of biddable conversions.
-
#biddable_conversions_value ⇒ Float
Projected total value of biddable conversions in local currency.
-
#clicks ⇒ Fixnum
Projected number of clicks.
-
#cost_micros ⇒ Fixnum
Projected cost in micros.
-
#impressions ⇒ Fixnum
Projected number of impressions.
-
#percent_cpc_bid_micros ⇒ Fixnum
The simulated percent CPC upon which projected metrics are based.
-
#top_slot_impressions ⇒ Fixnum
Projected number of top slot impressions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPercentCpcBidSimulationPoint
constructor
A new instance of GoogleAdsSearchads360V23CommonPercentCpcBidSimulationPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPercentCpcBidSimulationPoint
Returns a new instance of GoogleAdsSearchads360V23CommonPercentCpcBidSimulationPoint.
8945 8946 8947 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8945 def initialize(**args) update!(**args) end |
Instance Attribute Details
#biddable_conversions ⇒ Float
Projected number of biddable conversions.
Corresponds to the JSON property biddableConversions
8911 8912 8913 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8911 def biddable_conversions @biddable_conversions end |
#biddable_conversions_value ⇒ Float
Projected total value of biddable conversions in local currency.
Corresponds to the JSON property biddableConversionsValue
8916 8917 8918 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8916 def biddable_conversions_value @biddable_conversions_value end |
#clicks ⇒ Fixnum
Projected number of clicks.
Corresponds to the JSON property clicks
8921 8922 8923 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8921 def clicks @clicks end |
#cost_micros ⇒ Fixnum
Projected cost in micros.
Corresponds to the JSON property costMicros
8926 8927 8928 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8926 def cost_micros @cost_micros end |
#impressions ⇒ Fixnum
Projected number of impressions.
Corresponds to the JSON property impressions
8931 8932 8933 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8931 def impressions @impressions end |
#percent_cpc_bid_micros ⇒ Fixnum
The simulated percent CPC upon which projected metrics are based. Percent CPC
expressed as fraction of the advertised price for some good or service. The
value stored here is 1,000,000 * [fraction].
Corresponds to the JSON property percentCpcBidMicros
8938 8939 8940 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8938 def percent_cpc_bid_micros @percent_cpc_bid_micros end |
#top_slot_impressions ⇒ Fixnum
Projected number of top slot impressions.
Corresponds to the JSON property topSlotImpressions
8943 8944 8945 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8943 def top_slot_impressions @top_slot_impressions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8950 8951 8952 8953 8954 8955 8956 8957 8958 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 8950 def update!(**args) @biddable_conversions = args[:biddable_conversions] if args.key?(:biddable_conversions) @biddable_conversions_value = args[:biddable_conversions_value] if args.key?(:biddable_conversions_value) @clicks = args[:clicks] if args.key?(:clicks) @cost_micros = args[:cost_micros] if args.key?(:cost_micros) @impressions = args[:impressions] if args.key?(:impressions) @percent_cpc_bid_micros = args[:percent_cpc_bid_micros] if args.key?(:percent_cpc_bid_micros) @top_slot_impressions = args[:top_slot_impressions] if args.key?(:top_slot_impressions) end |