Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicySummary
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicySummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Contains policy summary information.
Instance Attribute Summary collapse
-
#approval_status ⇒ String
The overall approval status, which is calculated based on the status of its individual policy topic entries.
-
#policy_topic_entries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry>
The list of policy findings.
-
#review_status ⇒ String
Where in the review process the resource is.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicySummary
constructor
A new instance of GoogleAdsSearchads360V23CommonPolicySummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicySummary
Returns a new instance of GoogleAdsSearchads360V23CommonPolicySummary.
9040 9041 9042 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9040 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval_status ⇒ String
The overall approval status, which is calculated based on the status of its
individual policy topic entries.
Corresponds to the JSON property approvalStatus
9028 9029 9030 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9028 def approval_status @approval_status end |
#policy_topic_entries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry>
The list of policy findings.
Corresponds to the JSON property policyTopicEntries
9033 9034 9035 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9033 def policy_topic_entries @policy_topic_entries end |
#review_status ⇒ String
Where in the review process the resource is.
Corresponds to the JSON property reviewStatus
9038 9039 9040 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9038 def review_status @review_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9045 9046 9047 9048 9049 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9045 def update!(**args) @approval_status = args[:approval_status] if args.key?(:approval_status) @policy_topic_entries = args[:policy_topic_entries] if args.key?(:policy_topic_entries) @review_status = args[:review_status] if args.key?(:review_status) end |