Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Describes the effect on serving that a policy topic entry will have.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicConstraint

Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicConstraint.



9077
9078
9079
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9077

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_domain_mismatch_in_country_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList

A list of countries where a resource's serving is constrained. Corresponds to the JSON property certificateDomainMismatchInCountryList



9059
9060
9061
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9059

def certificate_domain_mismatch_in_country_list
  @certificate_domain_mismatch_in_country_list
end

#certificate_missing_in_country_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList

A list of countries where a resource's serving is constrained. Corresponds to the JSON property certificateMissingInCountryList



9064
9065
9066
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9064

def certificate_missing_in_country_list
  @certificate_missing_in_country_list
end

#country_constraint_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraintList

A list of countries where a resource's serving is constrained. Corresponds to the JSON property countryConstraintList



9069
9070
9071
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9069

def country_constraint_list
  @country_constraint_list
end

#reseller_constraintGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintResellerConstraint

Indicates that a policy topic was constrained due to disapproval of the website for reseller purposes. Corresponds to the JSON property resellerConstraint



9075
9076
9077
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9075

def reseller_constraint
  @reseller_constraint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9082
9083
9084
9085
9086
9087
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9082

def update!(**args)
  @certificate_domain_mismatch_in_country_list = args[:certificate_domain_mismatch_in_country_list] if args.key?(:certificate_domain_mismatch_in_country_list)
  @certificate_missing_in_country_list = args[:certificate_missing_in_country_list] if args.key?(:certificate_missing_in_country_list)
  @country_constraint_list = args[:country_constraint_list] if args.key?(:country_constraint_list)
  @reseller_constraint = args[:reseller_constraint] if args.key?(:reseller_constraint)
end