Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Indicates that a resource's ability to serve in a particular country is constrained.
Instance Attribute Summary collapse
-
#country_criterion ⇒ String
Geo target constant resource name of the country in which serving is constrained.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint
constructor
A new instance of GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint
Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicConstraintCountryConstraint.
424 425 426 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 424 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_criterion ⇒ String
Geo target constant resource name of the country in which serving is
constrained.
Corresponds to the JSON property countryCriterion
422 423 424 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 422 def country_criterion @country_criterion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
429 430 431 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 429 def update!(**args) @country_criterion = args[:country_criterion] if args.key?(:country_criterion) end |