Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Policy finding attached to a resource (for example, alcohol policy associated with a site that sells alcohol). Each PolicyTopicEntry has a topic that indicates the specific ads policy the entry is about and a type to indicate the effect that the entry will have on serving. It may optionally have one or more evidences that indicate the reason for the finding. It may also optionally have one or more constraints that provide details about how serving may be restricted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicEntry

Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicEntry.



9125
9126
9127
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9125

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constraintsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicConstraint>

Indicates how serving of this resource may be affected (for example, not serving in a country). Corresponds to the JSON property constraints



9104
9105
9106
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9104

def constraints
  @constraints
end

#evidencesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidence>

Additional information that explains policy finding (for example, the brand name for a trademark finding). Corresponds to the JSON property evidences



9110
9111
9112
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9110

def evidences
  @evidences
end

#topicString

Policy topic this finding refers to. For example, "ALCOHOL", " TRADEMARKS_IN_AD_TEXT", or "DESTINATION_NOT_WORKING". The set of possible policy topics is not fixed for a particular API version and may change at any time. Corresponds to the JSON property topic

Returns:

  • (String)


9118
9119
9120
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9118

def topic
  @topic
end

#typeString

Describes the negative or positive effect this policy will have on serving. Corresponds to the JSON property type

Returns:

  • (String)


9123
9124
9125
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9123

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9130
9131
9132
9133
9134
9135
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9130

def update!(**args)
  @constraints = args[:constraints] if args.key?(:constraints)
  @evidences = args[:evidences] if args.key?(:evidences)
  @topic = args[:topic] if args.key?(:topic)
  @type = args[:type] if args.key?(:type)
end