Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidence
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Additional information that explains a policy finding.
Instance Attribute Summary collapse
-
#destination_mismatch ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationMismatch
Evidence of mismatches between the URLs of a resource.
-
#destination_not_working ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationNotWorking
Evidence details when the destination is returning an HTTP error code or isn't functional in all locations for commonly used devices.
-
#destination_text_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationTextList
A list of strings found in a destination page that caused a policy finding.
-
#language_code ⇒ String
The language the resource was detected to be written in.
-
#text_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceTextList
A list of fragments of text that violated a policy.
-
#website_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceWebsiteList
A list of websites that caused a policy finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicEvidence
constructor
A new instance of GoogleAdsSearchads360V23CommonPolicyTopicEvidence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicEvidence
Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicEvidence.
9245 9246 9247 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9245 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination_mismatch ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationMismatch
Evidence of mismatches between the URLs of a resource.
Corresponds to the JSON property destinationMismatch
9213 9214 9215 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9213 def destination_mismatch @destination_mismatch end |
#destination_not_working ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationNotWorking
Evidence details when the destination is returning an HTTP error code or isn't
functional in all locations for commonly used devices.
Corresponds to the JSON property destinationNotWorking
9219 9220 9221 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9219 def destination_not_working @destination_not_working end |
#destination_text_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationTextList
A list of strings found in a destination page that caused a policy finding.
Corresponds to the JSON property destinationTextList
9224 9225 9226 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9224 def destination_text_list @destination_text_list end |
#language_code ⇒ String
The language the resource was detected to be written in. This is an IETF
language tag such as "en-US".
Corresponds to the JSON property languageCode
9230 9231 9232 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9230 def language_code @language_code end |
#text_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceTextList
A list of fragments of text that violated a policy.
Corresponds to the JSON property textList
9235 9236 9237 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9235 def text_list @text_list end |
#website_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceWebsiteList
A list of websites that caused a policy finding. Used for
ONE_WEBSITE_PER_AD_GROUP policy topic, for example. In case there are more
than five websites, only the top five (those that appear in resources the most)
will be listed here.
Corresponds to the JSON property websiteList
9243 9244 9245 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9243 def website_list @website_list end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9250 9251 9252 9253 9254 9255 9256 9257 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9250 def update!(**args) @destination_mismatch = args[:destination_mismatch] if args.key?(:destination_mismatch) @destination_not_working = args[:destination_not_working] if args.key?(:destination_not_working) @destination_text_list = args[:destination_text_list] if args.key?(:destination_text_list) @language_code = args[:language_code] if args.key?(:language_code) @text_list = args[:text_list] if args.key?(:text_list) @website_list = args[:website_list] if args.key?(:website_list) end |