Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Additional information that explains a policy finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicEvidence

Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicEvidence.



9177
9178
9179
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9177

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_mismatchGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationMismatch

Evidence of mismatches between the URLs of a resource. Corresponds to the JSON property destinationMismatch



9145
9146
9147
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9145

def destination_mismatch
  @destination_mismatch
end

#destination_not_workingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationNotWorking

Evidence details when the destination is returning an HTTP error code or isn't functional in all locations for commonly used devices. Corresponds to the JSON property destinationNotWorking



9151
9152
9153
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9151

def destination_not_working
  @destination_not_working
end

#destination_text_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceDestinationTextList

A list of strings found in a destination page that caused a policy finding. Corresponds to the JSON property destinationTextList



9156
9157
9158
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9156

def destination_text_list
  @destination_text_list
end

#language_codeString

The language the resource was detected to be written in. This is an IETF language tag such as "en-US". Corresponds to the JSON property languageCode

Returns:

  • (String)


9162
9163
9164
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9162

def language_code
  @language_code
end

#text_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceTextList

A list of fragments of text that violated a policy. Corresponds to the JSON property textList



9167
9168
9169
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9167

def text_list
  @text_list
end

#website_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceWebsiteList

A list of websites that caused a policy finding. Used for ONE_WEBSITE_PER_AD_GROUP policy topic, for example. In case there are more than five websites, only the top five (those that appear in resources the most) will be listed here. Corresponds to the JSON property websiteList



9175
9176
9177
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9175

def website_list
  @website_list
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9182
9183
9184
9185
9186
9187
9188
9189
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9182

def update!(**args)
  @destination_mismatch = args[:destination_mismatch] if args.key?(:destination_mismatch)
  @destination_not_working = args[:destination_not_working] if args.key?(:destination_not_working)
  @destination_text_list = args[:destination_text_list] if args.key?(:destination_text_list)
  @language_code = args[:language_code] if args.key?(:language_code)
  @text_list = args[:text_list] if args.key?(:text_list)
  @website_list = args[:website_list] if args.key?(:website_list)
end