Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEvidenceWebsiteList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A list of websites that caused a policy finding. Used for ONE_WEBSITE_PER_AD_GROUP policy topic, for example. In case there are more than five websites, only the top five (those that appear in resources the most) will be listed here.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyTopicEvidenceWebsiteList

Returns a new instance of GoogleAdsSearchads360V23CommonPolicyTopicEvidenceWebsiteList.



587
588
589
# File 'lib/google/apis/searchads360_v23/classes.rb', line 587

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#websitesArray<String>

Websites that caused the policy finding. Corresponds to the JSON property websites

Returns:

  • (Array<String>)


585
586
587
# File 'lib/google/apis/searchads360_v23/classes.rb', line 585

def websites
  @websites
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



592
593
594
# File 'lib/google/apis/searchads360_v23/classes.rb', line 592

def update!(**args)
  @websites = args[:websites] if args.key?(:websites)
end