Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyViolationKey
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyViolationKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Key of the violation. The key is used for referring to a violation when filing an exemption request.
Instance Attribute Summary collapse
-
#policy_name ⇒ String
Unique ID of the violated policy.
-
#violating_text ⇒ String
The text that violates the policy if specified.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyViolationKey
constructor
A new instance of GoogleAdsSearchads360V23CommonPolicyViolationKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPolicyViolationKey
Returns a new instance of GoogleAdsSearchads360V23CommonPolicyViolationKey.
9248 9249 9250 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9248 def initialize(**args) update!(**args) end |
Instance Attribute Details
#policy_name ⇒ String
Unique ID of the violated policy.
Corresponds to the JSON property policyName
9238 9239 9240 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9238 def policy_name @policy_name end |
#violating_text ⇒ String
The text that violates the policy if specified. Otherwise, refers to the
policy in general (for example, when requesting to be exempt from the whole
policy). If not specified for criterion exemptions, the whole policy is
implied. Must be specified for ad exemptions.
Corresponds to the JSON property violatingText
9246 9247 9248 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9246 def violating_text @violating_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9253 9254 9255 9256 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9253 def update!(**args) @policy_name = args[:policy_name] if args.key?(:policy_name) @violating_text = args[:violating_text] if args.key?(:violating_text) end |