Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPriceOffering

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single price offering within a PriceAsset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPriceOffering

Returns a new instance of GoogleAdsSearchads360V23CommonPriceOffering.



9341
9342
9343
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Required. The description of the price offering. The length of this string should be between 1 and 25, inclusive. Corresponds to the JSON property description

Returns:

  • (String)


9313
9314
9315
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9313

def description
  @description
end

#final_mobile_urlString

The final mobile URL after all cross domain redirects. Corresponds to the JSON property finalMobileUrl

Returns:

  • (String)


9318
9319
9320
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9318

def final_mobile_url
  @final_mobile_url
end

#final_urlString

Required. The final URL after all cross domain redirects. Corresponds to the JSON property finalUrl

Returns:

  • (String)


9323
9324
9325
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9323

def final_url
  @final_url
end

#headerString

Required. The header of the price offering. The length of this string should be between 1 and 25, inclusive. Corresponds to the JSON property header

Returns:

  • (String)


9329
9330
9331
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9329

def header
  @header
end

#priceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMoney

Represents a price in a particular currency. Corresponds to the JSON property price



9334
9335
9336
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9334

def price
  @price
end

#unitString

The price unit of the price offering. Corresponds to the JSON property unit

Returns:

  • (String)


9339
9340
9341
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9339

def unit
  @unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9346
9347
9348
9349
9350
9351
9352
9353
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9346

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @header = args[:header] if args.key?(:header)
  @price = args[:price] if args.key?(:price)
  @unit = args[:unit] if args.key?(:unit)
end