Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPriceOffering

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single price offering within a PriceAsset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPriceOffering

Returns a new instance of GoogleAdsSearchads360V23CommonPriceOffering.



9333
9334
9335
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Required. The description of the price offering. The length of this string should be between 1 and 25, inclusive. Corresponds to the JSON property description

Returns:

  • (String)


9305
9306
9307
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9305

def description
  @description
end

#final_mobile_urlString

The final mobile URL after all cross domain redirects. Corresponds to the JSON property finalMobileUrl

Returns:

  • (String)


9310
9311
9312
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9310

def final_mobile_url
  @final_mobile_url
end

#final_urlString

Required. The final URL after all cross domain redirects. Corresponds to the JSON property finalUrl

Returns:

  • (String)


9315
9316
9317
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9315

def final_url
  @final_url
end

#headerString

Required. The header of the price offering. The length of this string should be between 1 and 25, inclusive. Corresponds to the JSON property header

Returns:

  • (String)


9321
9322
9323
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9321

def header
  @header
end

#priceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMoney

Represents a price in a particular currency. Corresponds to the JSON property price



9326
9327
9328
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9326

def price
  @price
end

#unitString

The price unit of the price offering. Corresponds to the JSON property unit

Returns:

  • (String)


9331
9332
9333
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9331

def unit
  @unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9338
9339
9340
9341
9342
9343
9344
9345
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9338

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @header = args[:header] if args.key?(:header)
  @price = args[:price] if args.key?(:price)
  @unit = args[:unit] if args.key?(:unit)
end