Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPromotionAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPromotionAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Promotion asset.
Instance Attribute Summary collapse
-
#ad_schedule_targets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>
List of non-overlapping schedules specifying all time intervals for which the asset may serve.
-
#discount_modifier ⇒ String
A modifier for qualification of the discount.
-
#end_date ⇒ String
Last date of when this asset is effective and still serving, in yyyy-MM-dd format.
-
#language_code ⇒ String
The language of the promotion.
-
#money_amount_off ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMoney
Represents a price in a particular currency.
-
#occasion ⇒ String
The occasion the promotion was intended for.
-
#orders_over_amount ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMoney
Represents a price in a particular currency.
-
#percent_off ⇒ Fixnum
Percentage off discount in the promotion.
-
#promotion_barcode_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPromotionBarcodeInfo
Barcode info to generate promotion barcode.
-
#promotion_code ⇒ String
A code the user should use in order to be eligible for the promotion.
-
#promotion_qr_code_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPromotionQrCodeInfo
QR code info to generate promotion QR code.
-
#promotion_target ⇒ String
Required.
-
#redemption_end_date ⇒ String
Last date of when the promotion is eligible to be redeemed, in yyyy-MM-dd format.
-
#redemption_start_date ⇒ String
Start date of when the promotion is eligible to be redeemed, in yyyy-MM-dd format.
-
#start_date ⇒ String
Start date of when this asset is effective and can begin serving, in yyyy-MM- dd format.
-
#terms_and_conditions_text ⇒ String
Terms and conditions of the promotion.
-
#terms_and_conditions_uri ⇒ String
URI to the terms and conditions of the promotion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPromotionAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonPromotionAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonPromotionAsset
Returns a new instance of GoogleAdsSearchads360V23CommonPromotionAsset.
9705 9706 9707 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_schedule_targets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>
List of non-overlapping schedules specifying all time intervals for which the
asset may serve. There can be a maximum of 6 schedules per day, 42 in total.
Corresponds to the JSON property adScheduleTargets
9616 9617 9618 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9616 def ad_schedule_targets @ad_schedule_targets end |
#discount_modifier ⇒ String
A modifier for qualification of the discount.
Corresponds to the JSON property discountModifier
9621 9622 9623 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9621 def discount_modifier @discount_modifier end |
#end_date ⇒ String
Last date of when this asset is effective and still serving, in yyyy-MM-dd
format.
Corresponds to the JSON property endDate
9627 9628 9629 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9627 def end_date @end_date end |
#language_code ⇒ String
The language of the promotion. Represented as BCP 47 language tag.
Corresponds to the JSON property languageCode
9632 9633 9634 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9632 def language_code @language_code end |
#money_amount_off ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMoney
Represents a price in a particular currency.
Corresponds to the JSON property moneyAmountOff
9637 9638 9639 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9637 def money_amount_off @money_amount_off end |
#occasion ⇒ String
The occasion the promotion was intended for. If an occasion is set, the
redemption window will need to fall within the date range associated with the
occasion.
Corresponds to the JSON property occasion
9644 9645 9646 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9644 def occasion @occasion end |
#orders_over_amount ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMoney
Represents a price in a particular currency.
Corresponds to the JSON property ordersOverAmount
9649 9650 9651 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9649 def orders_over_amount @orders_over_amount end |
#percent_off ⇒ Fixnum
Percentage off discount in the promotion. 1,000,000 = 100%. Either this or
money_amount_off is required.
Corresponds to the JSON property percentOff
9655 9656 9657 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9655 def percent_off @percent_off end |
#promotion_barcode_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPromotionBarcodeInfo
Barcode info to generate promotion barcode.
Corresponds to the JSON property promotionBarcodeInfo
9660 9661 9662 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9660 def @promotion_barcode_info end |
#promotion_code ⇒ String
A code the user should use in order to be eligible for the promotion.
Corresponds to the JSON property promotionCode
9665 9666 9667 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9665 def promotion_code @promotion_code end |
#promotion_qr_code_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPromotionQrCodeInfo
QR code info to generate promotion QR code.
Corresponds to the JSON property promotionQrCodeInfo
9670 9671 9672 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9670 def promotion_qr_code_info @promotion_qr_code_info end |
#promotion_target ⇒ String
Required. A freeform description of what the promotion is targeting.
Corresponds to the JSON property promotionTarget
9675 9676 9677 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9675 def promotion_target @promotion_target end |
#redemption_end_date ⇒ String
Last date of when the promotion is eligible to be redeemed, in yyyy-MM-dd
format.
Corresponds to the JSON property redemptionEndDate
9681 9682 9683 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9681 def redemption_end_date @redemption_end_date end |
#redemption_start_date ⇒ String
Start date of when the promotion is eligible to be redeemed, in yyyy-MM-dd
format.
Corresponds to the JSON property redemptionStartDate
9687 9688 9689 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9687 def redemption_start_date @redemption_start_date end |
#start_date ⇒ String
Start date of when this asset is effective and can begin serving, in yyyy-MM-
dd format.
Corresponds to the JSON property startDate
9693 9694 9695 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9693 def start_date @start_date end |
#terms_and_conditions_text ⇒ String
Terms and conditions of the promotion.
Corresponds to the JSON property termsAndConditionsText
9698 9699 9700 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9698 def terms_and_conditions_text @terms_and_conditions_text end |
#terms_and_conditions_uri ⇒ String
URI to the terms and conditions of the promotion.
Corresponds to the JSON property termsAndConditionsUri
9703 9704 9705 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9703 def terms_and_conditions_uri @terms_and_conditions_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9710 9711 9712 9713 9714 9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9710 def update!(**args) @ad_schedule_targets = args[:ad_schedule_targets] if args.key?(:ad_schedule_targets) @discount_modifier = args[:discount_modifier] if args.key?(:discount_modifier) @end_date = args[:end_date] if args.key?(:end_date) @language_code = args[:language_code] if args.key?(:language_code) @money_amount_off = args[:money_amount_off] if args.key?(:money_amount_off) @occasion = args[:occasion] if args.key?(:occasion) @orders_over_amount = args[:orders_over_amount] if args.key?(:orders_over_amount) @percent_off = args[:percent_off] if args.key?(:percent_off) @promotion_barcode_info = args[:promotion_barcode_info] if args.key?(:promotion_barcode_info) @promotion_code = args[:promotion_code] if args.key?(:promotion_code) @promotion_qr_code_info = args[:promotion_qr_code_info] if args.key?(:promotion_qr_code_info) @promotion_target = args[:promotion_target] if args.key?(:promotion_target) @redemption_end_date = args[:redemption_end_date] if args.key?(:redemption_end_date) @redemption_start_date = args[:redemption_start_date] if args.key?(:redemption_start_date) @start_date = args[:start_date] if args.key?(:start_date) @terms_and_conditions_text = args[:terms_and_conditions_text] if args.key?(:terms_and_conditions_text) @terms_and_conditions_uri = args[:terms_and_conditions_uri] if args.key?(:terms_and_conditions_uri) end |