Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProximityInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProximityInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Proximity criterion. The geo point and radius determine what geographical area is included. The address is a description of the geo point that does not affect ad serving. There are two ways to create a proximity. First, by setting an address and radius. The geo point will be automatically computed. Second, by setting a geo point and radius. The address is an optional label that won't be validated.
Instance Attribute Summary collapse
-
#address ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAddressInfo
Address for proximity criterion.
-
#geo_point ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGeoPointInfo
Geo point for proximity criterion.
-
#radius ⇒ Float
The radius of the proximity.
-
#radius_units ⇒ String
The unit of measurement of the radius.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonProximityInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonProximityInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonProximityInfo
Returns a new instance of GoogleAdsSearchads360V23CommonProximityInfo.
9796 9797 9798 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9796 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAddressInfo
Address for proximity criterion.
Corresponds to the JSON property address
9779 9780 9781 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9779 def address @address end |
#geo_point ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGeoPointInfo
Geo point for proximity criterion.
Corresponds to the JSON property geoPoint
9784 9785 9786 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9784 def geo_point @geo_point end |
#radius ⇒ Float
The radius of the proximity.
Corresponds to the JSON property radius
9789 9790 9791 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9789 def radius @radius end |
#radius_units ⇒ String
The unit of measurement of the radius. Default is KILOMETERS.
Corresponds to the JSON property radiusUnits
9794 9795 9796 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9794 def radius_units @radius_units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9801 9802 9803 9804 9805 9806 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9801 def update!(**args) @address = args[:address] if args.key?(:address) @geo_point = args[:geo_point] if args.key?(:geo_point) @radius = args[:radius] if args.key?(:radius) @radius_units = args[:radius_units] if args.key?(:radius_units) end |