Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveDisplayAdInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveDisplayAdInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A responsive display ad.
Instance Attribute Summary collapse
-
#accent_color ⇒ String
The accent color of the ad in hexadecimal, for example, #ffffff for white.
-
#allow_flexible_color ⇒ Boolean
(also: #allow_flexible_color?)
Advertiser's consent to allow flexible color.
-
#business_name ⇒ String
The advertiser/brand name.
-
#call_to_action_text ⇒ String
The call-to-action text for the ad.
-
#control_spec ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveDisplayAdControlSpec
Specification for various creative controls for a responsive display ad.
-
#descriptions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
Descriptive texts for the ad.
-
#format_setting ⇒ String
Specifies which format the ad will be served in.
-
#headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
Short format headlines for the ad.
-
#logo_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Logo images to be used in the ad.
-
#long_headline ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
-
#main_color ⇒ String
The main color of the ad in hexadecimal, for example, #ffffff for white.
-
#marketing_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Marketing images to be used in the ad.
-
#price_prefix ⇒ String
Prefix before price.
-
#promo_text ⇒ String
Promotion text used for dynamic formats of responsive ads.
-
#square_logo_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Square logo images to be used in the ad.
-
#square_marketing_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Square marketing images to be used in the ad.
-
#youtube_videos ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAsset>
Optional YouTube videos for the ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonResponsiveDisplayAdInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonResponsiveDisplayAdInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonResponsiveDisplayAdInfo
Returns a new instance of GoogleAdsSearchads360V23CommonResponsiveDisplayAdInfo.
9965 9966 9967 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9965 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accent_color ⇒ String
The accent color of the ad in hexadecimal, for example, #ffffff for white. If
one of main_color and accent_color is set, the other is required as well.
Corresponds to the JSON property accentColor
9865 9866 9867 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9865 def accent_color @accent_color end |
#allow_flexible_color ⇒ Boolean Also known as: allow_flexible_color?
Advertiser's consent to allow flexible color. When true, the ad may be served
with different color if necessary. When false, the ad will be served with the
specified colors or a neutral color. The default value is true. Must be true
if main_color and accent_color are not set.
Corresponds to the JSON property allowFlexibleColor
9873 9874 9875 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9873 def allow_flexible_color @allow_flexible_color end |
#business_name ⇒ String
The advertiser/brand name. Maximum display width is 25.
Corresponds to the JSON property businessName
9879 9880 9881 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9879 def business_name @business_name end |
#call_to_action_text ⇒ String
The call-to-action text for the ad. Maximum display width is 30.
Corresponds to the JSON property callToActionText
9884 9885 9886 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9884 def call_to_action_text @call_to_action_text end |
#control_spec ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveDisplayAdControlSpec
Specification for various creative controls for a responsive display ad.
Corresponds to the JSON property controlSpec
9889 9890 9891 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9889 def control_spec @control_spec end |
#descriptions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
Descriptive texts for the ad. The maximum length is 90 characters. At least 1
and max 5 headlines can be specified.
Corresponds to the JSON property descriptions
9895 9896 9897 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9895 def descriptions @descriptions end |
#format_setting ⇒ String
Specifies which format the ad will be served in. Default is ALL_FORMATS.
Corresponds to the JSON property formatSetting
9900 9901 9902 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9900 def format_setting @format_setting end |
#headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
Short format headlines for the ad. The maximum length is 30 characters. At
least 1 and max 5 headlines can be specified.
Corresponds to the JSON property headlines
9906 9907 9908 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9906 def headlines @headlines end |
#logo_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Logo images to be used in the ad. Valid image types are GIF, JPEG, and PNG.
The minimum size is 512x128 and the aspect ratio must be 4:1 (+-1%). Combined
with square_logo_images, the maximum is 5.
Corresponds to the JSON property logoImages
9913 9914 9915 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9913 def logo_images @logo_images end |
#long_headline ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset
A text asset used inside an ad.
Corresponds to the JSON property longHeadline
9918 9919 9920 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9918 def long_headline @long_headline end |
#main_color ⇒ String
The main color of the ad in hexadecimal, for example, #ffffff for white. If
one of main_color and accent_color is set, the other is required as well.
Corresponds to the JSON property mainColor
9924 9925 9926 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9924 def main_color @main_color end |
#marketing_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Marketing images to be used in the ad. Valid image types are GIF, JPEG, and
PNG. The minimum size is 600x314 and the aspect ratio must be 1.91:1 (+-1%).
At least one marketing_image is required. Combined with
square_marketing_images, the maximum is 15.
Corresponds to the JSON property marketingImages
9932 9933 9934 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9932 def marketing_images @marketing_images end |
#price_prefix ⇒ String
Prefix before price. For example, 'as low as'.
Corresponds to the JSON property pricePrefix
9937 9938 9939 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9937 def price_prefix @price_prefix end |
#promo_text ⇒ String
Promotion text used for dynamic formats of responsive ads. For example 'Free
two-day shipping'.
Corresponds to the JSON property promoText
9943 9944 9945 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9943 def promo_text @promo_text end |
#square_logo_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Square logo images to be used in the ad. Valid image types are GIF, JPEG, and
PNG. The minimum size is 128x128 and the aspect ratio must be 1:1 (+-1%).
Combined with logo_images, the maximum is 5.
Corresponds to the JSON property squareLogoImages
9950 9951 9952 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9950 def square_logo_images @square_logo_images end |
#square_marketing_images ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdImageAsset>
Square marketing images to be used in the ad. Valid image types are GIF, JPEG,
and PNG. The minimum size is 300x300 and the aspect ratio must be 1:1 (+-1%).
At least one square marketing_image is required. Combined with
marketing_images, the maximum is 15.
Corresponds to the JSON property squareMarketingImages
9958 9959 9960 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9958 def square_marketing_images @square_marketing_images end |
#youtube_videos ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdVideoAsset>
Optional YouTube videos for the ad. A maximum of 5 videos can be specified.
Corresponds to the JSON property youtubeVideos
9963 9964 9965 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9963 def youtube_videos @youtube_videos end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 9986 9987 9988 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 9970 def update!(**args) @accent_color = args[:accent_color] if args.key?(:accent_color) @allow_flexible_color = args[:allow_flexible_color] if args.key?(:allow_flexible_color) @business_name = args[:business_name] if args.key?(:business_name) @call_to_action_text = args[:call_to_action_text] if args.key?(:call_to_action_text) @control_spec = args[:control_spec] if args.key?(:control_spec) @descriptions = args[:descriptions] if args.key?(:descriptions) @format_setting = args[:format_setting] if args.key?(:format_setting) @headlines = args[:headlines] if args.key?(:headlines) @logo_images = args[:logo_images] if args.key?(:logo_images) @long_headline = args[:long_headline] if args.key?(:long_headline) @main_color = args[:main_color] if args.key?(:main_color) @marketing_images = args[:marketing_images] if args.key?(:marketing_images) @price_prefix = args[:price_prefix] if args.key?(:price_prefix) @promo_text = args[:promo_text] if args.key?(:promo_text) @square_logo_images = args[:square_logo_images] if args.key?(:square_logo_images) @square_marketing_images = args[:square_marketing_images] if args.key?(:square_marketing_images) @youtube_videos = args[:youtube_videos] if args.key?(:youtube_videos) end |