Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveSearchAdInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveSearchAdInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A responsive search ad. Responsive search ads let you create an ad that adapts to show more text, and more relevant messages, to your customers. Enter multiple headlines and descriptions when creating a responsive search ad, and over time, Google Ads will automatically test different combinations and learn which combinations perform best. By adapting your ad's content to more closely match potential customers' search terms, responsive search ads may improve your campaign's performance. More information at https://support.google.com/ google-ads/answer/7684791
Instance Attribute Summary collapse
-
#descriptions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets for descriptions.
-
#headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets for headlines.
-
#path1 ⇒ String
First part of text that can be appended to the URL in the ad.
-
#path2 ⇒ String
Second part of text that can be appended to the URL in the ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonResponsiveSearchAdInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonResponsiveSearchAdInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonResponsiveSearchAdInfo
Returns a new instance of GoogleAdsSearchads360V23CommonResponsiveSearchAdInfo.
10025 10026 10027 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#descriptions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets for descriptions. When the ad serves the descriptions will
be selected from this list.
Corresponds to the JSON property descriptions
10006 10007 10008 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10006 def descriptions @descriptions end |
#headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets for headlines. When the ad serves the headlines will be
selected from this list.
Corresponds to the JSON property headlines
10012 10013 10014 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10012 def headlines @headlines end |
#path1 ⇒ String
First part of text that can be appended to the URL in the ad.
Corresponds to the JSON property path1
10017 10018 10019 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10017 def path1 @path1 end |
#path2 ⇒ String
Second part of text that can be appended to the URL in the ad. This field can
only be set when path1 is also set.
Corresponds to the JSON property path2
10023 10024 10025 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10023 def path2 @path2 end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10030 10031 10032 10033 10034 10035 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10030 def update!(**args) @descriptions = args[:descriptions] if args.key?(:descriptions) @headlines = args[:headlines] if args.key?(:headlines) @path1 = args[:path1] if args.key?(:path1) @path2 = args[:path2] if args.key?(:path2) end |