Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonRuleBasedUserListInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Representation of a userlist that is generated by a rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonRuleBasedUserListInfo

Returns a new instance of GoogleAdsSearchads360V23CommonRuleBasedUserListInfo.



10064
10065
10066
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#flexible_rule_user_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFlexibleRuleUserListInfo

Flexible rule representation of visitors with one or multiple actions. The flexible user list is defined by two lists of operands – inclusive_operands and exclusive_operands; each operand represents a set of users based on actions they took in a given timeframe. These lists of operands are combined with the AND_NOT operator, so that users represented by the inclusive operands are included in the user list, minus the users represented by the exclusive operands. Corresponds to the JSON property flexibleRuleUserList



10051
10052
10053
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10051

def flexible_rule_user_list
  @flexible_rule_user_list
end

#prepopulation_statusString

The status of pre-population. The field is default to NONE if not set which means the previous users will not be considered. If set to REQUESTED, past site visitors or app users who match the list definition will be included in the list (works on the Display Network only). This will only add past users from within the last 30 days, depending on the list's membership duration and the date when the remarketing tag is added. The status will be updated to FINISHED once request is processed, or FAILED if the request fails. Corresponds to the JSON property prepopulationStatus

Returns:

  • (String)


10062
10063
10064
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10062

def prepopulation_status
  @prepopulation_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10069
10070
10071
10072
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10069

def update!(**args)
  @flexible_rule_user_list = args[:flexible_rule_user_list] if args.key?(:flexible_rule_user_list)
  @prepopulation_status = args[:prepopulation_status] if args.key?(:prepopulation_status)
end