Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchThemeInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchThemeInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Search Theme criterion only on Performance Max campaign. Represents a keyword-like advertiser input.
Instance Attribute Summary collapse
-
#text ⇒ String
Each Search Theme has a value of a simple string, like keywords.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSearchThemeInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonSearchThemeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSearchThemeInfo
Returns a new instance of GoogleAdsSearchads360V23CommonSearchThemeInfo.
10294 10295 10296 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10294 def initialize(**args) update!(**args) end |
Instance Attribute Details
#text ⇒ String
Each Search Theme has a value of a simple string, like keywords. There are
limits on overall length, allowed characters, and number of words.
Corresponds to the JSON property text
10292 10293 10294 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10292 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10299 10300 10301 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10299 def update!(**args) @text = args[:text] if args.key?(:text) end |