Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSegments

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Segment only fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSegments

Returns a new instance of GoogleAdsSearchads360V23CommonSegments.



10693
10694
10695
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10693

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_format_typeString

Ad Format type. Corresponds to the JSON property adFormatType

Returns:

  • (String)


10311
10312
10313
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10311

def ad_format_type
  @ad_format_type
end

#ad_network_typeString

Ad network type. Corresponds to the JSON property adNetworkType

Returns:

  • (String)


10316
10317
10318
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10316

def ad_network_type
  @ad_network_type
end

#asset_interaction_targetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetInteractionTarget

An AssetInteractionTarget segment. Corresponds to the JSON property assetInteractionTarget



10321
10322
10323
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10321

def asset_interaction_target
  @asset_interaction_target
end

#conversion_actionString

Resource name of the conversion action. Corresponds to the JSON property conversionAction

Returns:

  • (String)


10326
10327
10328
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10326

def conversion_action
  @conversion_action
end

#conversion_action_categoryString

Conversion action category. Corresponds to the JSON property conversionActionCategory

Returns:

  • (String)


10331
10332
10333
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10331

def conversion_action_category
  @conversion_action_category
end

#conversion_action_nameString

Conversion action name. Corresponds to the JSON property conversionActionName

Returns:

  • (String)


10336
10337
10338
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10336

def conversion_action_name
  @conversion_action_name
end

#conversion_custom_dimensionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonValue>

The conversion custom dimensions. Corresponds to the JSON property conversionCustomDimensions



10341
10342
10343
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10341

def conversion_custom_dimensions
  @conversion_custom_dimensions
end

#dateString

Date to which metrics apply. yyyy-MM-dd format, for example, 2018-04-17. Corresponds to the JSON property date

Returns:

  • (String)


10346
10347
10348
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10346

def date
  @date
end

#day_of_weekString

Day of the week, for example, MONDAY. Corresponds to the JSON property dayOfWeek

Returns:

  • (String)


10351
10352
10353
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10351

def day_of_week
  @day_of_week
end

#deviceString

Device to which metrics apply. Corresponds to the JSON property device

Returns:

  • (String)


10356
10357
10358
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10356

def device
  @device
end

#geo_target_cityString

Resource name of the geo target constant that represents a city. Corresponds to the JSON property geoTargetCity

Returns:

  • (String)


10361
10362
10363
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10361

def geo_target_city
  @geo_target_city
end

#geo_target_countryString

Resource name of the geo target constant that represents a country. Corresponds to the JSON property geoTargetCountry

Returns:

  • (String)


10366
10367
10368
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10366

def geo_target_country
  @geo_target_country
end

#geo_target_metroString

Resource name of the geo target constant that represents a metro. Corresponds to the JSON property geoTargetMetro

Returns:

  • (String)


10371
10372
10373
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10371

def geo_target_metro
  @geo_target_metro
end

#geo_target_postal_codeString

Resource name of the geo target constant that represents a postal code. Corresponds to the JSON property geoTargetPostalCode

Returns:

  • (String)


10376
10377
10378
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10376

def geo_target_postal_code
  @geo_target_postal_code
end

#geo_target_regionString

Resource name of the geo target constant that represents a region. Corresponds to the JSON property geoTargetRegion

Returns:

  • (String)


10381
10382
10383
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10381

def geo_target_region
  @geo_target_region
end

#hourFixnum

Hour of day as a number between 0 and 23, inclusive. Corresponds to the JSON property hour

Returns:

  • (Fixnum)


10386
10387
10388
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10386

def hour
  @hour
end

#keywordGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeyword

A Keyword criterion segment. Corresponds to the JSON property keyword



10391
10392
10393
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10391

def keyword
  @keyword
end

#mobile_device_platformString

Mobile device platform to which metrics apply. Corresponds to the JSON property mobileDevicePlatform

Returns:

  • (String)


10396
10397
10398
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10396

def mobile_device_platform
  @mobile_device_platform
end

#monthString

Month as represented by the date of the first day of a month. Formatted as yyyy-MM-dd. Corresponds to the JSON property month

Returns:

  • (String)


10402
10403
10404
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10402

def month
  @month
end

#product_bidding_category_level1String

Bidding category (level 1) of the product. Corresponds to the JSON property productBiddingCategoryLevel1

Returns:

  • (String)


10407
10408
10409
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10407

def product_bidding_category_level1
  @product_bidding_category_level1
end

#product_bidding_category_level2String

Bidding category (level 2) of the product. Corresponds to the JSON property productBiddingCategoryLevel2

Returns:

  • (String)


10412
10413
10414
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10412

def product_bidding_category_level2
  @product_bidding_category_level2
end

#product_bidding_category_level3String

Bidding category (level 3) of the product. Corresponds to the JSON property productBiddingCategoryLevel3

Returns:

  • (String)


10417
10418
10419
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10417

def product_bidding_category_level3
  @product_bidding_category_level3
end

#product_bidding_category_level4String

Bidding category (level 4) of the product. Corresponds to the JSON property productBiddingCategoryLevel4

Returns:

  • (String)


10422
10423
10424
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10422

def product_bidding_category_level4
  @product_bidding_category_level4
end

#product_bidding_category_level5String

Bidding category (level 5) of the product. Corresponds to the JSON property productBiddingCategoryLevel5

Returns:

  • (String)


10427
10428
10429
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10427

def product_bidding_category_level5
  @product_bidding_category_level5
end

#product_brandString

Brand of the product. Corresponds to the JSON property productBrand

Returns:

  • (String)


10432
10433
10434
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10432

def product_brand
  @product_brand
end

#product_channelString

Channel of the product. Corresponds to the JSON property productChannel

Returns:

  • (String)


10437
10438
10439
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10437

def product_channel
  @product_channel
end

#product_channel_exclusivityString

Channel exclusivity of the product. Corresponds to the JSON property productChannelExclusivity

Returns:

  • (String)


10442
10443
10444
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10442

def product_channel_exclusivity
  @product_channel_exclusivity
end

#product_conditionString

Condition of the product. Corresponds to the JSON property productCondition

Returns:

  • (String)


10447
10448
10449
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10447

def product_condition
  @product_condition
end

#product_countryString

Resource name of the geo target constant for the country of sale of the product. Corresponds to the JSON property productCountry

Returns:

  • (String)


10453
10454
10455
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10453

def product_country
  @product_country
end

#product_custom_attribute0String

Custom attribute 0 of the product. Corresponds to the JSON property productCustomAttribute0

Returns:

  • (String)


10458
10459
10460
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10458

def product_custom_attribute0
  @product_custom_attribute0
end

#product_custom_attribute1String

Custom attribute 1 of the product. Corresponds to the JSON property productCustomAttribute1

Returns:

  • (String)


10463
10464
10465
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10463

def product_custom_attribute1
  @product_custom_attribute1
end

#product_custom_attribute2String

Custom attribute 2 of the product. Corresponds to the JSON property productCustomAttribute2

Returns:

  • (String)


10468
10469
10470
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10468

def product_custom_attribute2
  @product_custom_attribute2
end

#product_custom_attribute3String

Custom attribute 3 of the product. Corresponds to the JSON property productCustomAttribute3

Returns:

  • (String)


10473
10474
10475
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10473

def product_custom_attribute3
  @product_custom_attribute3
end

#product_custom_attribute4String

Custom attribute 4 of the product. Corresponds to the JSON property productCustomAttribute4

Returns:

  • (String)


10478
10479
10480
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10478

def product_custom_attribute4
  @product_custom_attribute4
end

#product_item_idString

Item ID of the product. Corresponds to the JSON property productItemId

Returns:

  • (String)


10483
10484
10485
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10483

def product_item_id
  @product_item_id
end

#product_languageString

Resource name of the language constant for the language of the product. Corresponds to the JSON property productLanguage

Returns:

  • (String)


10488
10489
10490
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10488

def product_language
  @product_language
end

#product_sold_bidding_category_level1String

Bidding category (level 1) of the product sold. Corresponds to the JSON property productSoldBiddingCategoryLevel1

Returns:

  • (String)


10493
10494
10495
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10493

def product_sold_bidding_category_level1
  @product_sold_bidding_category_level1
end

#product_sold_bidding_category_level2String

Bidding category (level 2) of the product sold. Corresponds to the JSON property productSoldBiddingCategoryLevel2

Returns:

  • (String)


10498
10499
10500
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10498

def product_sold_bidding_category_level2
  @product_sold_bidding_category_level2
end

#product_sold_bidding_category_level3String

Bidding category (level 3) of the product sold. Corresponds to the JSON property productSoldBiddingCategoryLevel3

Returns:

  • (String)


10503
10504
10505
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10503

def product_sold_bidding_category_level3
  @product_sold_bidding_category_level3
end

#product_sold_bidding_category_level4String

Bidding category (level 4) of the product sold. Corresponds to the JSON property productSoldBiddingCategoryLevel4

Returns:

  • (String)


10508
10509
10510
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10508

def product_sold_bidding_category_level4
  @product_sold_bidding_category_level4
end

#product_sold_bidding_category_level5String

Bidding category (level 5) of the product sold. Corresponds to the JSON property productSoldBiddingCategoryLevel5

Returns:

  • (String)


10513
10514
10515
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10513

def product_sold_bidding_category_level5
  @product_sold_bidding_category_level5
end

#product_sold_brandString

Brand of the product sold. Corresponds to the JSON property productSoldBrand

Returns:

  • (String)


10518
10519
10520
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10518

def product_sold_brand
  @product_sold_brand
end

#product_sold_conditionString

Condition of the product sold. Corresponds to the JSON property productSoldCondition

Returns:

  • (String)


10523
10524
10525
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10523

def product_sold_condition
  @product_sold_condition
end

#product_sold_custom_attribute0String

Custom attribute 0 of the product sold. Corresponds to the JSON property productSoldCustomAttribute0

Returns:

  • (String)


10528
10529
10530
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10528

def product_sold_custom_attribute0
  @product_sold_custom_attribute0
end

#product_sold_custom_attribute1String

Custom attribute 1 of the product sold. Corresponds to the JSON property productSoldCustomAttribute1

Returns:

  • (String)


10533
10534
10535
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10533

def product_sold_custom_attribute1
  @product_sold_custom_attribute1
end

#product_sold_custom_attribute2String

Custom attribute 2 of the product sold. Corresponds to the JSON property productSoldCustomAttribute2

Returns:

  • (String)


10538
10539
10540
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10538

def product_sold_custom_attribute2
  @product_sold_custom_attribute2
end

#product_sold_custom_attribute3String

Custom attribute 3 of the product sold. Corresponds to the JSON property productSoldCustomAttribute3

Returns:

  • (String)


10543
10544
10545
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10543

def product_sold_custom_attribute3
  @product_sold_custom_attribute3
end

#product_sold_custom_attribute4String

Custom attribute 4 of the product sold. Corresponds to the JSON property productSoldCustomAttribute4

Returns:

  • (String)


10548
10549
10550
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10548

def product_sold_custom_attribute4
  @product_sold_custom_attribute4
end

#product_sold_item_idString

Item ID of the product sold. Corresponds to the JSON property productSoldItemId

Returns:

  • (String)


10553
10554
10555
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10553

def product_sold_item_id
  @product_sold_item_id
end

#product_sold_titleString

Title of the product sold. Corresponds to the JSON property productSoldTitle

Returns:

  • (String)


10558
10559
10560
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10558

def product_sold_title
  @product_sold_title
end

#product_sold_type_l1String

Type (level 1) of the product sold. Corresponds to the JSON property productSoldTypeL1

Returns:

  • (String)


10563
10564
10565
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10563

def product_sold_type_l1
  @product_sold_type_l1
end

#product_sold_type_l2String

Type (level 2) of the product sold. Corresponds to the JSON property productSoldTypeL2

Returns:

  • (String)


10568
10569
10570
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10568

def product_sold_type_l2
  @product_sold_type_l2
end

#product_sold_type_l3String

Type (level 3) of the product sold. Corresponds to the JSON property productSoldTypeL3

Returns:

  • (String)


10573
10574
10575
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10573

def product_sold_type_l3
  @product_sold_type_l3
end

#product_sold_type_l4String

Type (level 4) of the product sold. Corresponds to the JSON property productSoldTypeL4

Returns:

  • (String)


10578
10579
10580
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10578

def product_sold_type_l4
  @product_sold_type_l4
end

#product_sold_type_l5String

Type (level 5) of the product sold. Corresponds to the JSON property productSoldTypeL5

Returns:

  • (String)


10583
10584
10585
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10583

def product_sold_type_l5
  @product_sold_type_l5
end

#product_store_idString

Store ID of the product. Corresponds to the JSON property productStoreId

Returns:

  • (String)


10588
10589
10590
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10588

def product_store_id
  @product_store_id
end

#product_titleString

Title of the product. Corresponds to the JSON property productTitle

Returns:

  • (String)


10593
10594
10595
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10593

def product_title
  @product_title
end

#product_type_l1String

Type (level 1) of the product. Corresponds to the JSON property productTypeL1

Returns:

  • (String)


10598
10599
10600
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10598

def product_type_l1
  @product_type_l1
end

#product_type_l2String

Type (level 2) of the product. Corresponds to the JSON property productTypeL2

Returns:

  • (String)


10603
10604
10605
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10603

def product_type_l2
  @product_type_l2
end

#product_type_l3String

Type (level 3) of the product. Corresponds to the JSON property productTypeL3

Returns:

  • (String)


10608
10609
10610
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10608

def product_type_l3
  @product_type_l3
end

#product_type_l4String

Type (level 4) of the product. Corresponds to the JSON property productTypeL4

Returns:

  • (String)


10613
10614
10615
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10613

def product_type_l4
  @product_type_l4
end

#product_type_l5String

Type (level 5) of the product. Corresponds to the JSON property productTypeL5

Returns:

  • (String)


10618
10619
10620
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10618

def product_type_l5
  @product_type_l5
end

#quarterString

Quarter as represented by the date of the first day of a quarter. Uses the calendar year for quarters, for example, the second quarter of 2018 starts on 2018-04-01. Formatted as yyyy-MM-dd. Corresponds to the JSON property quarter

Returns:

  • (String)


10625
10626
10627
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10625

def quarter
  @quarter
end

#raw_event_conversion_dimensionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonValue>

The raw event conversion dimensions. Corresponds to the JSON property rawEventConversionDimensions



10630
10631
10632
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10630

def raw_event_conversion_dimensions
  @raw_event_conversion_dimensions
end

#vertical_ads_event_participant_display_namesString

The display names of participants in an event listing, like performers, speakers, or teams. Corresponds to the JSON property verticalAdsEventParticipantDisplayNames

Returns:

  • (String)


10636
10637
10638
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10636

def vertical_ads_event_participant_display_names
  @vertical_ads_event_participant_display_names
end

#vertical_ads_hotel_classFixnum

The class of the hotel. Generally in the range of 1 to 5 stars, but fully customizable in the hotel feed. Corresponds to the JSON property verticalAdsHotelClass

Returns:

  • (Fixnum)


10642
10643
10644
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10642

def vertical_ads_hotel_class
  @vertical_ads_hotel_class
end

#vertical_ads_listingString

The listing associated with a listing impression, click or conversion. Corresponds to the JSON property verticalAdsListing

Returns:

  • (String)


10647
10648
10649
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10647

def vertical_ads_listing
  @vertical_ads_listing
end

#vertical_ads_listing_brandString

The brand associated with a specific listing within a Vertical Ads context, for example, the brand of a car rental, a vacation home, or an event. Corresponds to the JSON property verticalAdsListingBrand

Returns:

  • (String)


10653
10654
10655
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10653

def vertical_ads_listing_brand
  @vertical_ads_listing_brand
end

#vertical_ads_listing_cityString

The city where the vertical ads listing is located. Corresponds to the JSON property verticalAdsListingCity

Returns:

  • (String)


10658
10659
10660
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10658

def vertical_ads_listing_city
  @vertical_ads_listing_city
end

#vertical_ads_listing_countryString

The country where the vertical ads listing is located. Corresponds to the JSON property verticalAdsListingCountry

Returns:

  • (String)


10663
10664
10665
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10663

def vertical_ads_listing_country
  @vertical_ads_listing_country
end

#vertical_ads_listing_regionString

The region where the vertical ads listing is located. Corresponds to the JSON property verticalAdsListingRegion

Returns:

  • (String)


10668
10669
10670
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10668

def vertical_ads_listing_region
  @vertical_ads_listing_region
end

#vertical_ads_partner_accountFixnum

A specific partner account within a Partner Center (for example, Hotel Center) that supplies inventory feed data for Vertical Ads. Corresponds to the JSON property verticalAdsPartnerAccount

Returns:

  • (Fixnum)


10674
10675
10676
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10674

def 
  @vertical_ads_partner_account
end

#vertical_ads_verticalString

Type of vertical ad, such as Vacation Rentals, Car Rentals, or Events, used to categorize and segment data in the context of Vertical Ads. Corresponds to the JSON property verticalAdsVertical

Returns:

  • (String)


10680
10681
10682
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10680

def vertical_ads_vertical
  @vertical_ads_vertical
end

#weekString

Week as defined as Monday through Sunday, and represented by the date of Monday. Formatted as yyyy-MM-dd. Corresponds to the JSON property week

Returns:

  • (String)


10686
10687
10688
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10686

def week
  @week
end

#yearFixnum

Year, formatted as yyyy. Corresponds to the JSON property year

Returns:

  • (Fixnum)


10691
10692
10693
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10691

def year
  @year
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10698
10699
10700
10701
10702
10703
10704
10705
10706
10707
10708
10709
10710
10711
10712
10713
10714
10715
10716
10717
10718
10719
10720
10721
10722
10723
10724
10725
10726
10727
10728
10729
10730
10731
10732
10733
10734
10735
10736
10737
10738
10739
10740
10741
10742
10743
10744
10745
10746
10747
10748
10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
10764
10765
10766
10767
10768
10769
10770
10771
10772
10773
10774
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10698

def update!(**args)
  @ad_format_type = args[:ad_format_type] if args.key?(:ad_format_type)
  @ad_network_type = args[:ad_network_type] if args.key?(:ad_network_type)
  @asset_interaction_target = args[:asset_interaction_target] if args.key?(:asset_interaction_target)
  @conversion_action = args[:conversion_action] if args.key?(:conversion_action)
  @conversion_action_category = args[:conversion_action_category] if args.key?(:conversion_action_category)
  @conversion_action_name = args[:conversion_action_name] if args.key?(:conversion_action_name)
  @conversion_custom_dimensions = args[:conversion_custom_dimensions] if args.key?(:conversion_custom_dimensions)
  @date = args[:date] if args.key?(:date)
  @day_of_week = args[:day_of_week] if args.key?(:day_of_week)
  @device = args[:device] if args.key?(:device)
  @geo_target_city = args[:geo_target_city] if args.key?(:geo_target_city)
  @geo_target_country = args[:geo_target_country] if args.key?(:geo_target_country)
  @geo_target_metro = args[:geo_target_metro] if args.key?(:geo_target_metro)
  @geo_target_postal_code = args[:geo_target_postal_code] if args.key?(:geo_target_postal_code)
  @geo_target_region = args[:geo_target_region] if args.key?(:geo_target_region)
  @hour = args[:hour] if args.key?(:hour)
  @keyword = args[:keyword] if args.key?(:keyword)
  @mobile_device_platform = args[:mobile_device_platform] if args.key?(:mobile_device_platform)
  @month = args[:month] if args.key?(:month)
  @product_bidding_category_level1 = args[:product_bidding_category_level1] if args.key?(:product_bidding_category_level1)
  @product_bidding_category_level2 = args[:product_bidding_category_level2] if args.key?(:product_bidding_category_level2)
  @product_bidding_category_level3 = args[:product_bidding_category_level3] if args.key?(:product_bidding_category_level3)
  @product_bidding_category_level4 = args[:product_bidding_category_level4] if args.key?(:product_bidding_category_level4)
  @product_bidding_category_level5 = args[:product_bidding_category_level5] if args.key?(:product_bidding_category_level5)
  @product_brand = args[:product_brand] if args.key?(:product_brand)
  @product_channel = args[:product_channel] if args.key?(:product_channel)
  @product_channel_exclusivity = args[:product_channel_exclusivity] if args.key?(:product_channel_exclusivity)
  @product_condition = args[:product_condition] if args.key?(:product_condition)
  @product_country = args[:product_country] if args.key?(:product_country)
  @product_custom_attribute0 = args[:product_custom_attribute0] if args.key?(:product_custom_attribute0)
  @product_custom_attribute1 = args[:product_custom_attribute1] if args.key?(:product_custom_attribute1)
  @product_custom_attribute2 = args[:product_custom_attribute2] if args.key?(:product_custom_attribute2)
  @product_custom_attribute3 = args[:product_custom_attribute3] if args.key?(:product_custom_attribute3)
  @product_custom_attribute4 = args[:product_custom_attribute4] if args.key?(:product_custom_attribute4)
  @product_item_id = args[:product_item_id] if args.key?(:product_item_id)
  @product_language = args[:product_language] if args.key?(:product_language)
  @product_sold_bidding_category_level1 = args[:product_sold_bidding_category_level1] if args.key?(:product_sold_bidding_category_level1)
  @product_sold_bidding_category_level2 = args[:product_sold_bidding_category_level2] if args.key?(:product_sold_bidding_category_level2)
  @product_sold_bidding_category_level3 = args[:product_sold_bidding_category_level3] if args.key?(:product_sold_bidding_category_level3)
  @product_sold_bidding_category_level4 = args[:product_sold_bidding_category_level4] if args.key?(:product_sold_bidding_category_level4)
  @product_sold_bidding_category_level5 = args[:product_sold_bidding_category_level5] if args.key?(:product_sold_bidding_category_level5)
  @product_sold_brand = args[:product_sold_brand] if args.key?(:product_sold_brand)
  @product_sold_condition = args[:product_sold_condition] if args.key?(:product_sold_condition)
  @product_sold_custom_attribute0 = args[:product_sold_custom_attribute0] if args.key?(:product_sold_custom_attribute0)
  @product_sold_custom_attribute1 = args[:product_sold_custom_attribute1] if args.key?(:product_sold_custom_attribute1)
  @product_sold_custom_attribute2 = args[:product_sold_custom_attribute2] if args.key?(:product_sold_custom_attribute2)
  @product_sold_custom_attribute3 = args[:product_sold_custom_attribute3] if args.key?(:product_sold_custom_attribute3)
  @product_sold_custom_attribute4 = args[:product_sold_custom_attribute4] if args.key?(:product_sold_custom_attribute4)
  @product_sold_item_id = args[:product_sold_item_id] if args.key?(:product_sold_item_id)
  @product_sold_title = args[:product_sold_title] if args.key?(:product_sold_title)
  @product_sold_type_l1 = args[:product_sold_type_l1] if args.key?(:product_sold_type_l1)
  @product_sold_type_l2 = args[:product_sold_type_l2] if args.key?(:product_sold_type_l2)
  @product_sold_type_l3 = args[:product_sold_type_l3] if args.key?(:product_sold_type_l3)
  @product_sold_type_l4 = args[:product_sold_type_l4] if args.key?(:product_sold_type_l4)
  @product_sold_type_l5 = args[:product_sold_type_l5] if args.key?(:product_sold_type_l5)
  @product_store_id = args[:product_store_id] if args.key?(:product_store_id)
  @product_title = args[:product_title] if args.key?(:product_title)
  @product_type_l1 = args[:product_type_l1] if args.key?(:product_type_l1)
  @product_type_l2 = args[:product_type_l2] if args.key?(:product_type_l2)
  @product_type_l3 = args[:product_type_l3] if args.key?(:product_type_l3)
  @product_type_l4 = args[:product_type_l4] if args.key?(:product_type_l4)
  @product_type_l5 = args[:product_type_l5] if args.key?(:product_type_l5)
  @quarter = args[:quarter] if args.key?(:quarter)
  @raw_event_conversion_dimensions = args[:raw_event_conversion_dimensions] if args.key?(:raw_event_conversion_dimensions)
  @vertical_ads_event_participant_display_names = args[:vertical_ads_event_participant_display_names] if args.key?(:vertical_ads_event_participant_display_names)
  @vertical_ads_hotel_class = args[:vertical_ads_hotel_class] if args.key?(:vertical_ads_hotel_class)
  @vertical_ads_listing = args[:vertical_ads_listing] if args.key?(:vertical_ads_listing)
  @vertical_ads_listing_brand = args[:vertical_ads_listing_brand] if args.key?(:vertical_ads_listing_brand)
  @vertical_ads_listing_city = args[:vertical_ads_listing_city] if args.key?(:vertical_ads_listing_city)
  @vertical_ads_listing_country = args[:vertical_ads_listing_country] if args.key?(:vertical_ads_listing_country)
  @vertical_ads_listing_region = args[:vertical_ads_listing_region] if args.key?(:vertical_ads_listing_region)
  @vertical_ads_partner_account = args[:vertical_ads_partner_account] if args.key?(:vertical_ads_partner_account)
  @vertical_ads_vertical = args[:vertical_ads_vertical] if args.key?(:vertical_ads_vertical)
  @week = args[:week] if args.key?(:week)
  @year = args[:year] if args.key?(:year)
end