Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSegments
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSegments
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Segment only fields.
Instance Attribute Summary collapse
-
#ad_format_type ⇒ String
Ad Format type.
-
#ad_network_type ⇒ String
Ad network type.
-
#asset_interaction_target ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetInteractionTarget
An AssetInteractionTarget segment.
-
#conversion_action ⇒ String
Resource name of the conversion action.
-
#conversion_action_category ⇒ String
Conversion action category.
-
#conversion_action_name ⇒ String
Conversion action name.
-
#conversion_custom_dimensions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonValue>
The conversion custom dimensions.
-
#date ⇒ String
Date to which metrics apply.
-
#day_of_week ⇒ String
Day of the week, for example, MONDAY.
-
#device ⇒ String
Device to which metrics apply.
-
#geo_target_city ⇒ String
Resource name of the geo target constant that represents a city.
-
#geo_target_country ⇒ String
Resource name of the geo target constant that represents a country.
-
#geo_target_metro ⇒ String
Resource name of the geo target constant that represents a metro.
-
#geo_target_postal_code ⇒ String
Resource name of the geo target constant that represents a postal code.
-
#geo_target_region ⇒ String
Resource name of the geo target constant that represents a region.
-
#hour ⇒ Fixnum
Hour of day as a number between 0 and 23, inclusive.
-
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeyword
A Keyword criterion segment.
-
#month ⇒ String
Month as represented by the date of the first day of a month.
-
#product_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product.
-
#product_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product.
-
#product_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product.
-
#product_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product.
-
#product_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product.
-
#product_brand ⇒ String
Brand of the product.
-
#product_channel ⇒ String
Channel of the product.
-
#product_channel_exclusivity ⇒ String
Channel exclusivity of the product.
-
#product_condition ⇒ String
Condition of the product.
-
#product_country ⇒ String
Resource name of the geo target constant for the country of sale of the product.
-
#product_custom_attribute0 ⇒ String
Custom attribute 0 of the product.
-
#product_custom_attribute1 ⇒ String
Custom attribute 1 of the product.
-
#product_custom_attribute2 ⇒ String
Custom attribute 2 of the product.
-
#product_custom_attribute3 ⇒ String
Custom attribute 3 of the product.
-
#product_custom_attribute4 ⇒ String
Custom attribute 4 of the product.
-
#product_item_id ⇒ String
Item ID of the product.
-
#product_language ⇒ String
Resource name of the language constant for the language of the product.
-
#product_sold_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product sold.
-
#product_sold_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product sold.
-
#product_sold_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product sold.
-
#product_sold_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product sold.
-
#product_sold_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product sold.
-
#product_sold_brand ⇒ String
Brand of the product sold.
-
#product_sold_condition ⇒ String
Condition of the product sold.
-
#product_sold_custom_attribute0 ⇒ String
Custom attribute 0 of the product sold.
-
#product_sold_custom_attribute1 ⇒ String
Custom attribute 1 of the product sold.
-
#product_sold_custom_attribute2 ⇒ String
Custom attribute 2 of the product sold.
-
#product_sold_custom_attribute3 ⇒ String
Custom attribute 3 of the product sold.
-
#product_sold_custom_attribute4 ⇒ String
Custom attribute 4 of the product sold.
-
#product_sold_item_id ⇒ String
Item ID of the product sold.
-
#product_sold_title ⇒ String
Title of the product sold.
-
#product_sold_type_l1 ⇒ String
Type (level 1) of the product sold.
-
#product_sold_type_l2 ⇒ String
Type (level 2) of the product sold.
-
#product_sold_type_l3 ⇒ String
Type (level 3) of the product sold.
-
#product_sold_type_l4 ⇒ String
Type (level 4) of the product sold.
-
#product_sold_type_l5 ⇒ String
Type (level 5) of the product sold.
-
#product_store_id ⇒ String
Store ID of the product.
-
#product_title ⇒ String
Title of the product.
-
#product_type_l1 ⇒ String
Type (level 1) of the product.
-
#product_type_l2 ⇒ String
Type (level 2) of the product.
-
#product_type_l3 ⇒ String
Type (level 3) of the product.
-
#product_type_l4 ⇒ String
Type (level 4) of the product.
-
#product_type_l5 ⇒ String
Type (level 5) of the product.
-
#quarter ⇒ String
Quarter as represented by the date of the first day of a quarter.
-
#raw_event_conversion_dimensions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonValue>
The raw event conversion dimensions.
-
#vertical_ads_event_participant_display_names ⇒ String
The display names of participants in an event listing, like performers, speakers, or teams.
-
#vertical_ads_hotel_class ⇒ Fixnum
The class of the hotel.
-
#vertical_ads_listing ⇒ String
The listing associated with a listing impression, click or conversion.
-
#vertical_ads_listing_brand ⇒ String
The brand associated with a specific listing within a Vertical Ads context, for example, the brand of a car rental, a vacation home, or an event.
-
#vertical_ads_listing_city ⇒ String
The city where the vertical ads listing is located.
-
#vertical_ads_listing_country ⇒ String
The country where the vertical ads listing is located.
-
#vertical_ads_listing_region ⇒ String
The region where the vertical ads listing is located.
-
#vertical_ads_partner_account ⇒ Fixnum
A specific partner account within a Partner Center (for example, Hotel Center) that supplies inventory feed data for Vertical Ads.
-
#vertical_ads_vertical ⇒ String
Type of vertical ad, such as Vacation Rentals, Car Rentals, or Events, used to categorize and segment data in the context of Vertical Ads.
-
#week ⇒ String
Week as defined as Monday through Sunday, and represented by the date of Monday.
-
#year ⇒ Fixnum
Year, formatted as yyyy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSegments
constructor
A new instance of GoogleAdsSearchads360V23CommonSegments.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSegments
Returns a new instance of GoogleAdsSearchads360V23CommonSegments.
10679 10680 10681 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10679 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_format_type ⇒ String
Ad Format type.
Corresponds to the JSON property adFormatType
10302 10303 10304 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10302 def ad_format_type @ad_format_type end |
#ad_network_type ⇒ String
Ad network type.
Corresponds to the JSON property adNetworkType
10307 10308 10309 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10307 def ad_network_type @ad_network_type end |
#asset_interaction_target ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetInteractionTarget
An AssetInteractionTarget segment.
Corresponds to the JSON property assetInteractionTarget
10312 10313 10314 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10312 def asset_interaction_target @asset_interaction_target end |
#conversion_action ⇒ String
Resource name of the conversion action.
Corresponds to the JSON property conversionAction
10317 10318 10319 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10317 def conversion_action @conversion_action end |
#conversion_action_category ⇒ String
Conversion action category.
Corresponds to the JSON property conversionActionCategory
10322 10323 10324 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10322 def conversion_action_category @conversion_action_category end |
#conversion_action_name ⇒ String
Conversion action name.
Corresponds to the JSON property conversionActionName
10327 10328 10329 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10327 def conversion_action_name @conversion_action_name end |
#conversion_custom_dimensions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonValue>
The conversion custom dimensions.
Corresponds to the JSON property conversionCustomDimensions
10332 10333 10334 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10332 def conversion_custom_dimensions @conversion_custom_dimensions end |
#date ⇒ String
Date to which metrics apply. yyyy-MM-dd format, for example, 2018-04-17.
Corresponds to the JSON property date
10337 10338 10339 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10337 def date @date end |
#day_of_week ⇒ String
Day of the week, for example, MONDAY.
Corresponds to the JSON property dayOfWeek
10342 10343 10344 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10342 def day_of_week @day_of_week end |
#device ⇒ String
Device to which metrics apply.
Corresponds to the JSON property device
10347 10348 10349 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10347 def device @device end |
#geo_target_city ⇒ String
Resource name of the geo target constant that represents a city.
Corresponds to the JSON property geoTargetCity
10352 10353 10354 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10352 def geo_target_city @geo_target_city end |
#geo_target_country ⇒ String
Resource name of the geo target constant that represents a country.
Corresponds to the JSON property geoTargetCountry
10357 10358 10359 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10357 def geo_target_country @geo_target_country end |
#geo_target_metro ⇒ String
Resource name of the geo target constant that represents a metro.
Corresponds to the JSON property geoTargetMetro
10362 10363 10364 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10362 def geo_target_metro @geo_target_metro end |
#geo_target_postal_code ⇒ String
Resource name of the geo target constant that represents a postal code.
Corresponds to the JSON property geoTargetPostalCode
10367 10368 10369 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10367 def geo_target_postal_code @geo_target_postal_code end |
#geo_target_region ⇒ String
Resource name of the geo target constant that represents a region.
Corresponds to the JSON property geoTargetRegion
10372 10373 10374 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10372 def geo_target_region @geo_target_region end |
#hour ⇒ Fixnum
Hour of day as a number between 0 and 23, inclusive.
Corresponds to the JSON property hour
10377 10378 10379 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10377 def hour @hour end |
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeyword
A Keyword criterion segment.
Corresponds to the JSON property keyword
10382 10383 10384 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10382 def keyword @keyword end |
#month ⇒ String
Month as represented by the date of the first day of a month. Formatted as
yyyy-MM-dd.
Corresponds to the JSON property month
10388 10389 10390 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10388 def month @month end |
#product_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product.
Corresponds to the JSON property productBiddingCategoryLevel1
10393 10394 10395 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10393 def product_bidding_category_level1 @product_bidding_category_level1 end |
#product_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product.
Corresponds to the JSON property productBiddingCategoryLevel2
10398 10399 10400 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10398 def product_bidding_category_level2 @product_bidding_category_level2 end |
#product_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product.
Corresponds to the JSON property productBiddingCategoryLevel3
10403 10404 10405 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10403 def product_bidding_category_level3 @product_bidding_category_level3 end |
#product_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product.
Corresponds to the JSON property productBiddingCategoryLevel4
10408 10409 10410 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10408 def product_bidding_category_level4 @product_bidding_category_level4 end |
#product_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product.
Corresponds to the JSON property productBiddingCategoryLevel5
10413 10414 10415 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10413 def product_bidding_category_level5 @product_bidding_category_level5 end |
#product_brand ⇒ String
Brand of the product.
Corresponds to the JSON property productBrand
10418 10419 10420 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10418 def product_brand @product_brand end |
#product_channel ⇒ String
Channel of the product.
Corresponds to the JSON property productChannel
10423 10424 10425 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10423 def product_channel @product_channel end |
#product_channel_exclusivity ⇒ String
Channel exclusivity of the product.
Corresponds to the JSON property productChannelExclusivity
10428 10429 10430 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10428 def product_channel_exclusivity @product_channel_exclusivity end |
#product_condition ⇒ String
Condition of the product.
Corresponds to the JSON property productCondition
10433 10434 10435 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10433 def product_condition @product_condition end |
#product_country ⇒ String
Resource name of the geo target constant for the country of sale of the
product.
Corresponds to the JSON property productCountry
10439 10440 10441 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10439 def product_country @product_country end |
#product_custom_attribute0 ⇒ String
Custom attribute 0 of the product.
Corresponds to the JSON property productCustomAttribute0
10444 10445 10446 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10444 def product_custom_attribute0 @product_custom_attribute0 end |
#product_custom_attribute1 ⇒ String
Custom attribute 1 of the product.
Corresponds to the JSON property productCustomAttribute1
10449 10450 10451 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10449 def product_custom_attribute1 @product_custom_attribute1 end |
#product_custom_attribute2 ⇒ String
Custom attribute 2 of the product.
Corresponds to the JSON property productCustomAttribute2
10454 10455 10456 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10454 def product_custom_attribute2 @product_custom_attribute2 end |
#product_custom_attribute3 ⇒ String
Custom attribute 3 of the product.
Corresponds to the JSON property productCustomAttribute3
10459 10460 10461 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10459 def product_custom_attribute3 @product_custom_attribute3 end |
#product_custom_attribute4 ⇒ String
Custom attribute 4 of the product.
Corresponds to the JSON property productCustomAttribute4
10464 10465 10466 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10464 def product_custom_attribute4 @product_custom_attribute4 end |
#product_item_id ⇒ String
Item ID of the product.
Corresponds to the JSON property productItemId
10469 10470 10471 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10469 def product_item_id @product_item_id end |
#product_language ⇒ String
Resource name of the language constant for the language of the product.
Corresponds to the JSON property productLanguage
10474 10475 10476 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10474 def product_language @product_language end |
#product_sold_bidding_category_level1 ⇒ String
Bidding category (level 1) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel1
10479 10480 10481 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10479 def product_sold_bidding_category_level1 @product_sold_bidding_category_level1 end |
#product_sold_bidding_category_level2 ⇒ String
Bidding category (level 2) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel2
10484 10485 10486 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10484 def product_sold_bidding_category_level2 @product_sold_bidding_category_level2 end |
#product_sold_bidding_category_level3 ⇒ String
Bidding category (level 3) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel3
10489 10490 10491 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10489 def product_sold_bidding_category_level3 @product_sold_bidding_category_level3 end |
#product_sold_bidding_category_level4 ⇒ String
Bidding category (level 4) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel4
10494 10495 10496 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10494 def product_sold_bidding_category_level4 @product_sold_bidding_category_level4 end |
#product_sold_bidding_category_level5 ⇒ String
Bidding category (level 5) of the product sold.
Corresponds to the JSON property productSoldBiddingCategoryLevel5
10499 10500 10501 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10499 def product_sold_bidding_category_level5 @product_sold_bidding_category_level5 end |
#product_sold_brand ⇒ String
Brand of the product sold.
Corresponds to the JSON property productSoldBrand
10504 10505 10506 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10504 def product_sold_brand @product_sold_brand end |
#product_sold_condition ⇒ String
Condition of the product sold.
Corresponds to the JSON property productSoldCondition
10509 10510 10511 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10509 def product_sold_condition @product_sold_condition end |
#product_sold_custom_attribute0 ⇒ String
Custom attribute 0 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute0
10514 10515 10516 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10514 def product_sold_custom_attribute0 @product_sold_custom_attribute0 end |
#product_sold_custom_attribute1 ⇒ String
Custom attribute 1 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute1
10519 10520 10521 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10519 def product_sold_custom_attribute1 @product_sold_custom_attribute1 end |
#product_sold_custom_attribute2 ⇒ String
Custom attribute 2 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute2
10524 10525 10526 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10524 def product_sold_custom_attribute2 @product_sold_custom_attribute2 end |
#product_sold_custom_attribute3 ⇒ String
Custom attribute 3 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute3
10529 10530 10531 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10529 def product_sold_custom_attribute3 @product_sold_custom_attribute3 end |
#product_sold_custom_attribute4 ⇒ String
Custom attribute 4 of the product sold.
Corresponds to the JSON property productSoldCustomAttribute4
10534 10535 10536 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10534 def product_sold_custom_attribute4 @product_sold_custom_attribute4 end |
#product_sold_item_id ⇒ String
Item ID of the product sold.
Corresponds to the JSON property productSoldItemId
10539 10540 10541 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10539 def product_sold_item_id @product_sold_item_id end |
#product_sold_title ⇒ String
Title of the product sold.
Corresponds to the JSON property productSoldTitle
10544 10545 10546 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10544 def product_sold_title @product_sold_title end |
#product_sold_type_l1 ⇒ String
Type (level 1) of the product sold.
Corresponds to the JSON property productSoldTypeL1
10549 10550 10551 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10549 def product_sold_type_l1 @product_sold_type_l1 end |
#product_sold_type_l2 ⇒ String
Type (level 2) of the product sold.
Corresponds to the JSON property productSoldTypeL2
10554 10555 10556 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10554 def product_sold_type_l2 @product_sold_type_l2 end |
#product_sold_type_l3 ⇒ String
Type (level 3) of the product sold.
Corresponds to the JSON property productSoldTypeL3
10559 10560 10561 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10559 def product_sold_type_l3 @product_sold_type_l3 end |
#product_sold_type_l4 ⇒ String
Type (level 4) of the product sold.
Corresponds to the JSON property productSoldTypeL4
10564 10565 10566 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10564 def product_sold_type_l4 @product_sold_type_l4 end |
#product_sold_type_l5 ⇒ String
Type (level 5) of the product sold.
Corresponds to the JSON property productSoldTypeL5
10569 10570 10571 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10569 def product_sold_type_l5 @product_sold_type_l5 end |
#product_store_id ⇒ String
Store ID of the product.
Corresponds to the JSON property productStoreId
10574 10575 10576 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10574 def product_store_id @product_store_id end |
#product_title ⇒ String
Title of the product.
Corresponds to the JSON property productTitle
10579 10580 10581 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10579 def product_title @product_title end |
#product_type_l1 ⇒ String
Type (level 1) of the product.
Corresponds to the JSON property productTypeL1
10584 10585 10586 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10584 def product_type_l1 @product_type_l1 end |
#product_type_l2 ⇒ String
Type (level 2) of the product.
Corresponds to the JSON property productTypeL2
10589 10590 10591 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10589 def product_type_l2 @product_type_l2 end |
#product_type_l3 ⇒ String
Type (level 3) of the product.
Corresponds to the JSON property productTypeL3
10594 10595 10596 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10594 def product_type_l3 @product_type_l3 end |
#product_type_l4 ⇒ String
Type (level 4) of the product.
Corresponds to the JSON property productTypeL4
10599 10600 10601 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10599 def product_type_l4 @product_type_l4 end |
#product_type_l5 ⇒ String
Type (level 5) of the product.
Corresponds to the JSON property productTypeL5
10604 10605 10606 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10604 def product_type_l5 @product_type_l5 end |
#quarter ⇒ String
Quarter as represented by the date of the first day of a quarter. Uses the
calendar year for quarters, for example, the second quarter of 2018 starts on
2018-04-01. Formatted as yyyy-MM-dd.
Corresponds to the JSON property quarter
10611 10612 10613 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10611 def quarter @quarter end |
#raw_event_conversion_dimensions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonValue>
The raw event conversion dimensions.
Corresponds to the JSON property rawEventConversionDimensions
10616 10617 10618 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10616 def raw_event_conversion_dimensions @raw_event_conversion_dimensions end |
#vertical_ads_event_participant_display_names ⇒ String
The display names of participants in an event listing, like performers,
speakers, or teams.
Corresponds to the JSON property verticalAdsEventParticipantDisplayNames
10622 10623 10624 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10622 def vertical_ads_event_participant_display_names @vertical_ads_event_participant_display_names end |
#vertical_ads_hotel_class ⇒ Fixnum
The class of the hotel. Generally in the range of 1 to 5 stars, but fully
customizable in the hotel feed.
Corresponds to the JSON property verticalAdsHotelClass
10628 10629 10630 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10628 def vertical_ads_hotel_class @vertical_ads_hotel_class end |
#vertical_ads_listing ⇒ String
The listing associated with a listing impression, click or conversion.
Corresponds to the JSON property verticalAdsListing
10633 10634 10635 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10633 def vertical_ads_listing @vertical_ads_listing end |
#vertical_ads_listing_brand ⇒ String
The brand associated with a specific listing within a Vertical Ads context,
for example, the brand of a car rental, a vacation home, or an event.
Corresponds to the JSON property verticalAdsListingBrand
10639 10640 10641 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10639 def vertical_ads_listing_brand @vertical_ads_listing_brand end |
#vertical_ads_listing_city ⇒ String
The city where the vertical ads listing is located.
Corresponds to the JSON property verticalAdsListingCity
10644 10645 10646 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10644 def vertical_ads_listing_city @vertical_ads_listing_city end |
#vertical_ads_listing_country ⇒ String
The country where the vertical ads listing is located.
Corresponds to the JSON property verticalAdsListingCountry
10649 10650 10651 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10649 def vertical_ads_listing_country @vertical_ads_listing_country end |
#vertical_ads_listing_region ⇒ String
The region where the vertical ads listing is located.
Corresponds to the JSON property verticalAdsListingRegion
10654 10655 10656 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10654 def vertical_ads_listing_region @vertical_ads_listing_region end |
#vertical_ads_partner_account ⇒ Fixnum
A specific partner account within a Partner Center (for example, Hotel Center)
that supplies inventory feed data for Vertical Ads.
Corresponds to the JSON property verticalAdsPartnerAccount
10660 10661 10662 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10660 def vertical_ads_partner_account @vertical_ads_partner_account end |
#vertical_ads_vertical ⇒ String
Type of vertical ad, such as Vacation Rentals, Car Rentals, or Events, used to
categorize and segment data in the context of Vertical Ads.
Corresponds to the JSON property verticalAdsVertical
10666 10667 10668 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10666 def vertical_ads_vertical @vertical_ads_vertical end |
#week ⇒ String
Week as defined as Monday through Sunday, and represented by the date of
Monday. Formatted as yyyy-MM-dd.
Corresponds to the JSON property week
10672 10673 10674 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10672 def week @week end |
#year ⇒ Fixnum
Year, formatted as yyyy.
Corresponds to the JSON property year
10677 10678 10679 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10677 def year @year end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10684 10685 10686 10687 10688 10689 10690 10691 10692 10693 10694 10695 10696 10697 10698 10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 10717 10718 10719 10720 10721 10722 10723 10724 10725 10726 10727 10728 10729 10730 10731 10732 10733 10734 10735 10736 10737 10738 10739 10740 10741 10742 10743 10744 10745 10746 10747 10748 10749 10750 10751 10752 10753 10754 10755 10756 10757 10758 10759 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10684 def update!(**args) @ad_format_type = args[:ad_format_type] if args.key?(:ad_format_type) @ad_network_type = args[:ad_network_type] if args.key?(:ad_network_type) @asset_interaction_target = args[:asset_interaction_target] if args.key?(:asset_interaction_target) @conversion_action = args[:conversion_action] if args.key?(:conversion_action) @conversion_action_category = args[:conversion_action_category] if args.key?(:conversion_action_category) @conversion_action_name = args[:conversion_action_name] if args.key?(:conversion_action_name) @conversion_custom_dimensions = args[:conversion_custom_dimensions] if args.key?(:conversion_custom_dimensions) @date = args[:date] if args.key?(:date) @day_of_week = args[:day_of_week] if args.key?(:day_of_week) @device = args[:device] if args.key?(:device) @geo_target_city = args[:geo_target_city] if args.key?(:geo_target_city) @geo_target_country = args[:geo_target_country] if args.key?(:geo_target_country) @geo_target_metro = args[:geo_target_metro] if args.key?(:geo_target_metro) @geo_target_postal_code = args[:geo_target_postal_code] if args.key?(:geo_target_postal_code) @geo_target_region = args[:geo_target_region] if args.key?(:geo_target_region) @hour = args[:hour] if args.key?(:hour) @keyword = args[:keyword] if args.key?(:keyword) @month = args[:month] if args.key?(:month) @product_bidding_category_level1 = args[:product_bidding_category_level1] if args.key?(:product_bidding_category_level1) @product_bidding_category_level2 = args[:product_bidding_category_level2] if args.key?(:product_bidding_category_level2) @product_bidding_category_level3 = args[:product_bidding_category_level3] if args.key?(:product_bidding_category_level3) @product_bidding_category_level4 = args[:product_bidding_category_level4] if args.key?(:product_bidding_category_level4) @product_bidding_category_level5 = args[:product_bidding_category_level5] if args.key?(:product_bidding_category_level5) @product_brand = args[:product_brand] if args.key?(:product_brand) @product_channel = args[:product_channel] if args.key?(:product_channel) @product_channel_exclusivity = args[:product_channel_exclusivity] if args.key?(:product_channel_exclusivity) @product_condition = args[:product_condition] if args.key?(:product_condition) @product_country = args[:product_country] if args.key?(:product_country) @product_custom_attribute0 = args[:product_custom_attribute0] if args.key?(:product_custom_attribute0) @product_custom_attribute1 = args[:product_custom_attribute1] if args.key?(:product_custom_attribute1) @product_custom_attribute2 = args[:product_custom_attribute2] if args.key?(:product_custom_attribute2) @product_custom_attribute3 = args[:product_custom_attribute3] if args.key?(:product_custom_attribute3) @product_custom_attribute4 = args[:product_custom_attribute4] if args.key?(:product_custom_attribute4) @product_item_id = args[:product_item_id] if args.key?(:product_item_id) @product_language = args[:product_language] if args.key?(:product_language) @product_sold_bidding_category_level1 = args[:product_sold_bidding_category_level1] if args.key?(:product_sold_bidding_category_level1) @product_sold_bidding_category_level2 = args[:product_sold_bidding_category_level2] if args.key?(:product_sold_bidding_category_level2) @product_sold_bidding_category_level3 = args[:product_sold_bidding_category_level3] if args.key?(:product_sold_bidding_category_level3) @product_sold_bidding_category_level4 = args[:product_sold_bidding_category_level4] if args.key?(:product_sold_bidding_category_level4) @product_sold_bidding_category_level5 = args[:product_sold_bidding_category_level5] if args.key?(:product_sold_bidding_category_level5) @product_sold_brand = args[:product_sold_brand] if args.key?(:product_sold_brand) @product_sold_condition = args[:product_sold_condition] if args.key?(:product_sold_condition) @product_sold_custom_attribute0 = args[:product_sold_custom_attribute0] if args.key?(:product_sold_custom_attribute0) @product_sold_custom_attribute1 = args[:product_sold_custom_attribute1] if args.key?(:product_sold_custom_attribute1) @product_sold_custom_attribute2 = args[:product_sold_custom_attribute2] if args.key?(:product_sold_custom_attribute2) @product_sold_custom_attribute3 = args[:product_sold_custom_attribute3] if args.key?(:product_sold_custom_attribute3) @product_sold_custom_attribute4 = args[:product_sold_custom_attribute4] if args.key?(:product_sold_custom_attribute4) @product_sold_item_id = args[:product_sold_item_id] if args.key?(:product_sold_item_id) @product_sold_title = args[:product_sold_title] if args.key?(:product_sold_title) @product_sold_type_l1 = args[:product_sold_type_l1] if args.key?(:product_sold_type_l1) @product_sold_type_l2 = args[:product_sold_type_l2] if args.key?(:product_sold_type_l2) @product_sold_type_l3 = args[:product_sold_type_l3] if args.key?(:product_sold_type_l3) @product_sold_type_l4 = args[:product_sold_type_l4] if args.key?(:product_sold_type_l4) @product_sold_type_l5 = args[:product_sold_type_l5] if args.key?(:product_sold_type_l5) @product_store_id = args[:product_store_id] if args.key?(:product_store_id) @product_title = args[:product_title] if args.key?(:product_title) @product_type_l1 = args[:product_type_l1] if args.key?(:product_type_l1) @product_type_l2 = args[:product_type_l2] if args.key?(:product_type_l2) @product_type_l3 = args[:product_type_l3] if args.key?(:product_type_l3) @product_type_l4 = args[:product_type_l4] if args.key?(:product_type_l4) @product_type_l5 = args[:product_type_l5] if args.key?(:product_type_l5) @quarter = args[:quarter] if args.key?(:quarter) @raw_event_conversion_dimensions = args[:raw_event_conversion_dimensions] if args.key?(:raw_event_conversion_dimensions) @vertical_ads_event_participant_display_names = args[:vertical_ads_event_participant_display_names] if args.key?(:vertical_ads_event_participant_display_names) @vertical_ads_hotel_class = args[:vertical_ads_hotel_class] if args.key?(:vertical_ads_hotel_class) @vertical_ads_listing = args[:vertical_ads_listing] if args.key?(:vertical_ads_listing) @vertical_ads_listing_brand = args[:vertical_ads_listing_brand] if args.key?(:vertical_ads_listing_brand) @vertical_ads_listing_city = args[:vertical_ads_listing_city] if args.key?(:vertical_ads_listing_city) @vertical_ads_listing_country = args[:vertical_ads_listing_country] if args.key?(:vertical_ads_listing_country) @vertical_ads_listing_region = args[:vertical_ads_listing_region] if args.key?(:vertical_ads_listing_region) @vertical_ads_partner_account = args[:vertical_ads_partner_account] if args.key?(:vertical_ads_partner_account) @vertical_ads_vertical = args[:vertical_ads_vertical] if args.key?(:vertical_ads_vertical) @week = args[:week] if args.key?(:week) @year = args[:year] if args.key?(:year) end |