Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSitelinkAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSitelinkAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Sitelink asset.
Instance Attribute Summary collapse
-
#ad_schedule_targets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>
List of non-overlapping schedules specifying all time intervals for which the asset may serve.
-
#description1 ⇒ String
First line of the description for the sitelink.
-
#description2 ⇒ String
Second line of the description for the sitelink.
-
#end_date ⇒ String
Last date of when this asset is effective and still serving, in yyyy-MM-dd format.
-
#link_text ⇒ String
Required.
-
#start_date ⇒ String
Start date of when this asset is effective and can begin serving, in yyyy-MM- dd format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSitelinkAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonSitelinkAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSitelinkAsset
Returns a new instance of GoogleAdsSearchads360V23CommonSitelinkAsset.
10905 10906 10907 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10905 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_schedule_targets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>
List of non-overlapping schedules specifying all time intervals for which the
asset may serve. There can be a maximum of 6 schedules per day, 42 in total.
Corresponds to the JSON property adScheduleTargets
10873 10874 10875 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10873 def ad_schedule_targets @ad_schedule_targets end |
#description1 ⇒ String
First line of the description for the sitelink. If set, the length should be
between 1 and 35, inclusive, and description2 must also be set.
Corresponds to the JSON property description1
10879 10880 10881 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10879 def description1 @description1 end |
#description2 ⇒ String
Second line of the description for the sitelink. If set, the length should be
between 1 and 35, inclusive, and description1 must also be set.
Corresponds to the JSON property description2
10885 10886 10887 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10885 def description2 @description2 end |
#end_date ⇒ String
Last date of when this asset is effective and still serving, in yyyy-MM-dd
format.
Corresponds to the JSON property endDate
10891 10892 10893 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10891 def end_date @end_date end |
#link_text ⇒ String
Required. URL display text for the sitelink. The length of this string should
be between 1 and 25, inclusive.
Corresponds to the JSON property linkText
10897 10898 10899 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10897 def link_text @link_text end |
#start_date ⇒ String
Start date of when this asset is effective and can begin serving, in yyyy-MM-
dd format.
Corresponds to the JSON property startDate
10903 10904 10905 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10903 def start_date @start_date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10910 10911 10912 10913 10914 10915 10916 10917 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10910 def update!(**args) @ad_schedule_targets = args[:ad_schedule_targets] if args.key?(:ad_schedule_targets) @description1 = args[:description1] if args.key?(:description1) @description2 = args[:description2] if args.key?(:description2) @end_date = args[:end_date] if args.key?(:end_date) @link_text = args[:link_text] if args.key?(:link_text) @start_date = args[:start_date] if args.key?(:start_date) end |