Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSitelinkAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSitelinkAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Sitelink asset.
Instance Attribute Summary collapse
-
#ad_schedule_targets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>
List of non-overlapping schedules specifying all time intervals for which the asset may serve.
-
#description1 ⇒ String
First line of the description for the sitelink.
-
#description2 ⇒ String
Second line of the description for the sitelink.
-
#end_date ⇒ String
Last date of when this asset is effective and still serving, in yyyy-MM-dd format.
-
#link_text ⇒ String
Required.
-
#start_date ⇒ String
Start date of when this asset is effective and can begin serving, in yyyy-MM- dd format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSitelinkAsset
constructor
A new instance of GoogleAdsSearchads360V23CommonSitelinkAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSitelinkAsset
Returns a new instance of GoogleAdsSearchads360V23CommonSitelinkAsset.
10890 10891 10892 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10890 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_schedule_targets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>
List of non-overlapping schedules specifying all time intervals for which the
asset may serve. There can be a maximum of 6 schedules per day, 42 in total.
Corresponds to the JSON property adScheduleTargets
10858 10859 10860 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10858 def ad_schedule_targets @ad_schedule_targets end |
#description1 ⇒ String
First line of the description for the sitelink. If set, the length should be
between 1 and 35, inclusive, and description2 must also be set.
Corresponds to the JSON property description1
10864 10865 10866 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10864 def description1 @description1 end |
#description2 ⇒ String
Second line of the description for the sitelink. If set, the length should be
between 1 and 35, inclusive, and description1 must also be set.
Corresponds to the JSON property description2
10870 10871 10872 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10870 def description2 @description2 end |
#end_date ⇒ String
Last date of when this asset is effective and still serving, in yyyy-MM-dd
format.
Corresponds to the JSON property endDate
10876 10877 10878 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10876 def end_date @end_date end |
#link_text ⇒ String
Required. URL display text for the sitelink. The length of this string should
be between 1 and 25, inclusive.
Corresponds to the JSON property linkText
10882 10883 10884 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10882 def link_text @link_text end |
#start_date ⇒ String
Start date of when this asset is effective and can begin serving, in yyyy-MM-
dd format.
Corresponds to the JSON property startDate
10888 10889 10890 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10888 def start_date @start_date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10895 10896 10897 10898 10899 10900 10901 10902 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10895 def update!(**args) @ad_schedule_targets = args[:ad_schedule_targets] if args.key?(:ad_schedule_targets) @description1 = args[:description1] if args.key?(:description1) @description2 = args[:description2] if args.key?(:description2) @end_date = args[:end_date] if args.key?(:end_date) @link_text = args[:link_text] if args.key?(:link_text) @start_date = args[:start_date] if args.key?(:start_date) end |