Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSitelinkFeedItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a sitelink.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSitelinkFeedItem

Returns a new instance of GoogleAdsSearchads360V23CommonSitelinkFeedItem.



10956
10957
10958
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#final_mobile_urlsArray<String>

A list of possible final mobile URLs after all cross domain redirects. Corresponds to the JSON property finalMobileUrls

Returns:

  • (Array<String>)


10912
10913
10914
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10912

def final_mobile_urls
  @final_mobile_urls
end

#final_url_suffixString

Final URL suffix to be appended to landing page URLs served with parallel tracking. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


10918
10919
10920
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10918

def final_url_suffix
  @final_url_suffix
end

#final_urlsArray<String>

A list of possible final URLs after all cross domain redirects. Corresponds to the JSON property finalUrls

Returns:

  • (Array<String>)


10923
10924
10925
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10923

def final_urls
  @final_urls
end

#line1String

First line of the description for the sitelink. If this value is set, line2 must also be set. The length of this string should be between 0 and 35, inclusive. Corresponds to the JSON property line1

Returns:

  • (String)


10930
10931
10932
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10930

def line1
  @line1
end

#line2String

Second line of the description for the sitelink. If this value is set, line1 must also be set. The length of this string should be between 0 and 35, inclusive. Corresponds to the JSON property line2

Returns:

  • (String)


10937
10938
10939
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10937

def line2
  @line2
end

URL display text for the sitelink. The length of this string should be between 1 and 25, inclusive. Corresponds to the JSON property linkText

Returns:

  • (String)


10943
10944
10945
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10943

def link_text
  @link_text
end

#tracking_url_templateString

URL template for constructing a tracking URL. Corresponds to the JSON property trackingUrlTemplate

Returns:

  • (String)


10948
10949
10950
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10948

def tracking_url_template
  @tracking_url_template
end

#url_custom_parametersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>

A list of mappings to be used for substituting URL custom parameter tags in the tracking_url_template, final_urls, and/or final_mobile_urls. Corresponds to the JSON property urlCustomParameters



10954
10955
10956
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10954

def url_custom_parameters
  @url_custom_parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10961
10962
10963
10964
10965
10966
10967
10968
10969
10970
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10961

def update!(**args)
  @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @final_urls = args[:final_urls] if args.key?(:final_urls)
  @line1 = args[:line1] if args.key?(:line1)
  @line2 = args[:line2] if args.key?(:line2)
  @link_text = args[:link_text] if args.key?(:link_text)
  @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template)
  @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters)
end