Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSmartCampaignAdInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSmartCampaignAdInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Smart campaign ad.
Instance Attribute Summary collapse
-
#descriptions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets, each of which corresponds to a description when the ad serves.
-
#headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets, each of which corresponds to a headline when the ad serves.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSmartCampaignAdInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonSmartCampaignAdInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSmartCampaignAdInfo
Returns a new instance of GoogleAdsSearchads360V23CommonSmartCampaignAdInfo.
10989 10990 10991 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10989 def initialize(**args) update!(**args) end |
Instance Attribute Details
#descriptions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets, each of which corresponds to a description when the ad
serves. This list consists of a minimum of 2 and up to 4 text assets.
Corresponds to the JSON property descriptions
10981 10982 10983 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10981 def descriptions @descriptions end |
#headlines ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdTextAsset>
List of text assets, each of which corresponds to a headline when the ad
serves. This list consists of a minimum of 3 and up to 15 text assets.
Corresponds to the JSON property headlines
10987 10988 10989 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10987 def headlines @headlines end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10994 10995 10996 10997 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 10994 def update!(**args) @descriptions = args[:descriptions] if args.key?(:descriptions) @headlines = args[:headlines] if args.key?(:headlines) end |