Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStoreSalesMetadata
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStoreSalesMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Metadata for Store Sales Direct.
Instance Attribute Summary collapse
-
#custom_key ⇒ String
Name of the store sales custom variable key.
-
#loyalty_fraction ⇒ Float
This is the fraction of all transactions that are identifiable (for example, associated with any form of customer information).
-
#third_party_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStoreSalesThirdPartyMetadata
Metadata for a third party Store Sales.
-
#transaction_upload_fraction ⇒ Float
This is the ratio of sales being uploaded compared to the overall sales that can be associated with a customer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonStoreSalesMetadata
constructor
A new instance of GoogleAdsSearchads360V23CommonStoreSalesMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonStoreSalesMetadata
Returns a new instance of GoogleAdsSearchads360V23CommonStoreSalesMetadata.
11052 11053 11054 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11052 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_key ⇒ String
Name of the store sales custom variable key. A predefined key that can be
applied to the transaction and then later used for custom segmentation in
reporting. Accessible only to customers on the allow-list.
Corresponds to the JSON property customKey
11028 11029 11030 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11028 def custom_key @custom_key end |
#loyalty_fraction ⇒ Float
This is the fraction of all transactions that are identifiable (for example,
associated with any form of customer information). Required. The fraction
needs to be between 0 and 1 (excluding 0).
Corresponds to the JSON property loyaltyFraction
11035 11036 11037 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11035 def loyalty_fraction @loyalty_fraction end |
#third_party_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStoreSalesThirdPartyMetadata
Metadata for a third party Store Sales. This product is only for customers on
the allow-list. Contact your Google business development representative for
details on the upload configuration.
Corresponds to the JSON property thirdPartyMetadata
11042 11043 11044 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11042 def @third_party_metadata end |
#transaction_upload_fraction ⇒ Float
This is the ratio of sales being uploaded compared to the overall sales that
can be associated with a customer. Required. The fraction needs to be between
0 and 1 (excluding 0). For example, if you upload half the sales that you are
able to associate with a customer, this would be 0.5.
Corresponds to the JSON property transactionUploadFraction
11050 11051 11052 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11050 def transaction_upload_fraction @transaction_upload_fraction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11057 11058 11059 11060 11061 11062 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11057 def update!(**args) @custom_key = args[:custom_key] if args.key?(:custom_key) @loyalty_fraction = args[:loyalty_fraction] if args.key?(:loyalty_fraction) @third_party_metadata = args[:third_party_metadata] if args.key?(:third_party_metadata) @transaction_upload_fraction = args[:transaction_upload_fraction] if args.key?(:transaction_upload_fraction) end |