Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStoreSalesThirdPartyMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Metadata for a third party Store Sales. This product is only for customers on the allow-list. Contact your Google business development representative for details on the upload configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonStoreSalesThirdPartyMetadata

Returns a new instance of GoogleAdsSearchads360V23CommonStoreSalesThirdPartyMetadata.



11107
11108
11109
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11107

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_upload_date_timeString

Time the advertiser uploaded the data to the partner. Required. The format is " YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34:30" Corresponds to the JSON property advertiserUploadDateTime

Returns:

  • (String)


11075
11076
11077
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11075

def advertiser_upload_date_time
  @advertiser_upload_date_time
end

#bridge_map_version_idString

Version of partner IDs to be used for uploads. Required. Corresponds to the JSON property bridgeMapVersionId

Returns:

  • (String)


11080
11081
11082
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11080

def bridge_map_version_id
  @bridge_map_version_id
end

#partner_idFixnum

ID of the third party partner updating the transaction feed. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


11085
11086
11087
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11085

def partner_id
  @partner_id
end

#partner_match_fractionFloat

The fraction of valid transactions that are matched to a third party assigned user ID on the partner side. Required. The fraction needs to be between 0 and 1 (excluding 0). Corresponds to the JSON property partnerMatchFraction

Returns:

  • (Float)


11092
11093
11094
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11092

def partner_match_fraction
  @partner_match_fraction
end

#partner_upload_fractionFloat

The fraction of valid transactions that are uploaded by the partner to Google. Required. The fraction needs to be between 0 and 1 (excluding 0). Corresponds to the JSON property partnerUploadFraction

Returns:

  • (Float)


11098
11099
11100
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11098

def partner_upload_fraction
  @partner_upload_fraction
end

#valid_transaction_fractionFloat

The fraction of transactions that are valid. Invalid transactions may include invalid formats or values. Required. The fraction needs to be between 0 and 1 ( excluding 0). Corresponds to the JSON property validTransactionFraction

Returns:

  • (Float)


11105
11106
11107
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11105

def valid_transaction_fraction
  @valid_transaction_fraction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11112
11113
11114
11115
11116
11117
11118
11119
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11112

def update!(**args)
  @advertiser_upload_date_time = args[:advertiser_upload_date_time] if args.key?(:advertiser_upload_date_time)
  @bridge_map_version_id = args[:bridge_map_version_id] if args.key?(:bridge_map_version_id)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @partner_match_fraction = args[:partner_match_fraction] if args.key?(:partner_match_fraction)
  @partner_upload_fraction = args[:partner_upload_fraction] if args.key?(:partner_upload_fraction)
  @valid_transaction_fraction = args[:valid_transaction_fraction] if args.key?(:valid_transaction_fraction)
end