Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStructuredSnippetAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Structured Snippet asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonStructuredSnippetAsset

Returns a new instance of GoogleAdsSearchads360V23CommonStructuredSnippetAsset.



11140
11141
11142
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11140

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#headerString

Required. The header of the snippet. This string should be one of the predefined values at https://developers.google.com/google-ads/api/reference/ data/structured-snippet-headers Corresponds to the JSON property header

Returns:

  • (String)


11131
11132
11133
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11131

def header
  @header
end

#valuesArray<String>

Required. The values in the snippet. The size of this collection should be between 3 and 10, inclusive. The length of each value should be between 1 and 25 characters, inclusive. Corresponds to the JSON property values

Returns:

  • (Array<String>)


11138
11139
11140
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11138

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11145
11146
11147
11148
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11145

def update!(**args)
  @header = args[:header] if args.key?(:header)
  @values = args[:values] if args.key?(:values)
end