Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSyntheticContentAttestation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSyntheticContentAttestation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents an attestation about synthetic content from a single source.
Instance Attribute Summary collapse
-
#source ⇒ String
The source of the synthetic content attestation.
-
#status ⇒ String
Indicates whether the content is considered synthetic by this source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSyntheticContentAttestation
constructor
A new instance of GoogleAdsSearchads360V23CommonSyntheticContentAttestation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSyntheticContentAttestation
Returns a new instance of GoogleAdsSearchads360V23CommonSyntheticContentAttestation.
11180 11181 11182 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11180 def initialize(**args) update!(**args) end |
Instance Attribute Details
#source ⇒ String
The source of the synthetic content attestation.
Corresponds to the JSON property source
11173 11174 11175 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11173 def source @source end |
#status ⇒ String
Indicates whether the content is considered synthetic by this source.
Corresponds to the JSON property status
11178 11179 11180 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11178 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11185 11186 11187 11188 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11185 def update!(**args) @source = args[:source] if args.key?(:source) @status = args[:status] if args.key?(:status) end |