Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSyntheticContentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Container for synthetic content attestations from different sources, such as the advertiser and Google systems.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonSyntheticContentInfo

Returns a new instance of GoogleAdsSearchads360V23CommonSyntheticContentInfo.



11206
11207
11208
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_attestationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSyntheticContentAttestation

Represents an attestation about synthetic content from a single source. Corresponds to the JSON property advertiserAttestation



11199
11200
11201
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11199

def advertiser_attestation
  @advertiser_attestation
end

#system_attestationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSyntheticContentAttestation

Represents an attestation about synthetic content from a single source. Corresponds to the JSON property systemAttestation



11204
11205
11206
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11204

def system_attestation
  @system_attestation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11211
11212
11213
11214
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11211

def update!(**args)
  @advertiser_attestation = args[:advertiser_attestation] if args.key?(:advertiser_attestation)
  @system_attestation = args[:system_attestation] if args.key?(:system_attestation)
end