Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpa
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpa
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set.
Instance Attribute Summary collapse
-
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy.
-
#cpc_bid_floor_micros ⇒ Fixnum
Minimum bid limit that can be set by the bid strategy.
-
#target_cpa_micros ⇒ Fixnum
Average CPA target.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetCpa
constructor
A new instance of GoogleAdsSearchads360V23CommonTargetCpa.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetCpa
Returns a new instance of GoogleAdsSearchads360V23CommonTargetCpa.
11216 11217 11218 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11216 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy. The limit applies to
all keywords managed by the strategy. This should only be set for portfolio
bid strategies.
Corresponds to the JSON property cpcBidCeilingMicros
11201 11202 11203 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11201 def cpc_bid_ceiling_micros @cpc_bid_ceiling_micros end |
#cpc_bid_floor_micros ⇒ Fixnum
Minimum bid limit that can be set by the bid strategy. The limit applies to
all keywords managed by the strategy. This should only be set for portfolio
bid strategies.
Corresponds to the JSON property cpcBidFloorMicros
11208 11209 11210 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11208 def cpc_bid_floor_micros @cpc_bid_floor_micros end |
#target_cpa_micros ⇒ Fixnum
Average CPA target. This target should be greater than or equal to minimum
billable unit based on the currency for the account.
Corresponds to the JSON property targetCpaMicros
11214 11215 11216 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11214 def target_cpa_micros @target_cpa_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11221 11222 11223 11224 11225 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11221 def update!(**args) @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros) @cpc_bid_floor_micros = args[:cpc_bid_floor_micros] if args.key?(:cpc_bid_floor_micros) @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros) end |