Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpaSimulationPoint
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpaSimulationPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Projected metrics for a specific target CPA amount.
Instance Attribute Summary collapse
-
#app_installs ⇒ Float
Projected number of app installs.
-
#biddable_conversions ⇒ Float
Projected number of biddable conversions.
-
#biddable_conversions_value ⇒ Float
Projected total value of biddable conversions.
-
#clicks ⇒ Fixnum
Projected number of clicks.
-
#cost_micros ⇒ Fixnum
Projected cost in micros.
-
#impressions ⇒ Fixnum
Projected number of impressions.
-
#in_app_actions ⇒ Float
Projected number of in-app actions.
-
#interactions ⇒ Fixnum
Projected number of interactions.
-
#required_budget_amount_micros ⇒ Fixnum
Projected required daily budget that the advertiser must set in order to receive the estimated traffic, in micros of advertiser currency.
-
#target_cpa_micros ⇒ Fixnum
The simulated target CPA upon which projected metrics are based.
-
#target_cpa_scaling_modifier ⇒ Float
The simulated scaling modifier upon which projected metrics are based.
-
#top_slot_impressions ⇒ Fixnum
Projected number of top slot impressions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetCpaSimulationPoint
constructor
A new instance of GoogleAdsSearchads360V23CommonTargetCpaSimulationPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetCpaSimulationPoint
Returns a new instance of GoogleAdsSearchads360V23CommonTargetCpaSimulationPoint.
11296 11297 11298 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11296 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_installs ⇒ Float
Projected number of app installs.
Corresponds to the JSON property appInstalls
11235 11236 11237 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11235 def app_installs @app_installs end |
#biddable_conversions ⇒ Float
Projected number of biddable conversions.
Corresponds to the JSON property biddableConversions
11240 11241 11242 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11240 def biddable_conversions @biddable_conversions end |
#biddable_conversions_value ⇒ Float
Projected total value of biddable conversions.
Corresponds to the JSON property biddableConversionsValue
11245 11246 11247 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11245 def biddable_conversions_value @biddable_conversions_value end |
#clicks ⇒ Fixnum
Projected number of clicks.
Corresponds to the JSON property clicks
11250 11251 11252 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11250 def clicks @clicks end |
#cost_micros ⇒ Fixnum
Projected cost in micros.
Corresponds to the JSON property costMicros
11255 11256 11257 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11255 def cost_micros @cost_micros end |
#impressions ⇒ Fixnum
Projected number of impressions.
Corresponds to the JSON property impressions
11260 11261 11262 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11260 def impressions @impressions end |
#in_app_actions ⇒ Float
Projected number of in-app actions.
Corresponds to the JSON property inAppActions
11265 11266 11267 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11265 def in_app_actions @in_app_actions end |
#interactions ⇒ Fixnum
Projected number of interactions. Only discovery advertising channel type
supports this field.
Corresponds to the JSON property interactions
11271 11272 11273 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11271 def interactions @interactions end |
#required_budget_amount_micros ⇒ Fixnum
Projected required daily budget that the advertiser must set in order to
receive the estimated traffic, in micros of advertiser currency.
Corresponds to the JSON property requiredBudgetAmountMicros
11277 11278 11279 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11277 def required_budget_amount_micros @required_budget_amount_micros end |
#target_cpa_micros ⇒ Fixnum
The simulated target CPA upon which projected metrics are based.
Corresponds to the JSON property targetCpaMicros
11282 11283 11284 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11282 def target_cpa_micros @target_cpa_micros end |
#target_cpa_scaling_modifier ⇒ Float
The simulated scaling modifier upon which projected metrics are based. All CPA
targets relevant to the simulated entity are scaled by this modifier.
Corresponds to the JSON property targetCpaScalingModifier
11288 11289 11290 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11288 def target_cpa_scaling_modifier @target_cpa_scaling_modifier end |
#top_slot_impressions ⇒ Fixnum
Projected number of top slot impressions. Only search advertising channel type
supports this field.
Corresponds to the JSON property topSlotImpressions
11294 11295 11296 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11294 def top_slot_impressions @top_slot_impressions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11301 11302 11303 11304 11305 11306 11307 11308 11309 11310 11311 11312 11313 11314 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11301 def update!(**args) @app_installs = args[:app_installs] if args.key?(:app_installs) @biddable_conversions = args[:biddable_conversions] if args.key?(:biddable_conversions) @biddable_conversions_value = args[:biddable_conversions_value] if args.key?(:biddable_conversions_value) @clicks = args[:clicks] if args.key?(:clicks) @cost_micros = args[:cost_micros] if args.key?(:cost_micros) @impressions = args[:impressions] if args.key?(:impressions) @in_app_actions = args[:in_app_actions] if args.key?(:in_app_actions) @interactions = args[:interactions] if args.key?(:interactions) @required_budget_amount_micros = args[:required_budget_amount_micros] if args.key?(:required_budget_amount_micros) @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros) @target_cpa_scaling_modifier = args[:target_cpa_scaling_modifier] if args.key?(:target_cpa_scaling_modifier) @top_slot_impressions = args[:top_slot_impressions] if args.key?(:top_slot_impressions) end |