Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpc
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpc
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An automated bidding strategy that sets bids to help get as many clicks as possible at the target cost-per-click (CPC) you set.
Instance Attribute Summary collapse
-
#target_cpc_micros ⇒ Fixnum
Average CPC target.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetCpc
constructor
A new instance of GoogleAdsSearchads360V23CommonTargetCpc.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetCpc
Returns a new instance of GoogleAdsSearchads360V23CommonTargetCpc.
11347 11348 11349 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11347 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_cpc_micros ⇒ Fixnum
Average CPC target. This target should be greater than or equal to minimum
billable unit based on the currency for the account.
Corresponds to the JSON property targetCpcMicros
11345 11346 11347 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11345 def target_cpc_micros @target_cpc_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11352 11353 11354 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11352 def update!(**args) @target_cpc_micros = args[:target_cpc_micros] if args.key?(:target_cpc_micros) end |