Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Projected metrics for a specific target impression share value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPoint

Returns a new instance of GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPoint.



11466
11467
11468
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#absolute_top_impressionsFixnum

Projected number of absolute top impressions. Only search advertising channel type supports this field. Corresponds to the JSON property absoluteTopImpressions

Returns:

  • (Fixnum)


11414
11415
11416
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11414

def absolute_top_impressions
  @absolute_top_impressions
end

#biddable_conversionsFloat

Projected number of biddable conversions. Corresponds to the JSON property biddableConversions

Returns:

  • (Float)


11419
11420
11421
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11419

def biddable_conversions
  @biddable_conversions
end

#biddable_conversions_valueFloat

Projected total value of biddable conversions. Corresponds to the JSON property biddableConversionsValue

Returns:

  • (Float)


11424
11425
11426
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11424

def biddable_conversions_value
  @biddable_conversions_value
end

#clicksFixnum

Projected number of clicks. Corresponds to the JSON property clicks

Returns:

  • (Fixnum)


11429
11430
11431
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11429

def clicks
  @clicks
end

#cost_microsFixnum

Projected cost in micros. Corresponds to the JSON property costMicros

Returns:

  • (Fixnum)


11434
11435
11436
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11434

def cost_micros
  @cost_micros
end

#impressionsFixnum

Projected number of impressions. Corresponds to the JSON property impressions

Returns:

  • (Fixnum)


11439
11440
11441
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11439

def impressions
  @impressions
end

#required_budget_amount_microsFixnum

Projected required daily budget that the advertiser must set in order to receive the estimated traffic, in micros of advertiser currency. Corresponds to the JSON property requiredBudgetAmountMicros

Returns:

  • (Fixnum)


11445
11446
11447
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11445

def required_budget_amount_micros
  @required_budget_amount_micros
end

#required_cpc_bid_ceiling_microsFixnum

Projected required daily cpc bid ceiling that the advertiser must set to realize this simulation, in micros of the advertiser currency. Corresponds to the JSON property requiredCpcBidCeilingMicros

Returns:

  • (Fixnum)


11451
11452
11453
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11451

def required_cpc_bid_ceiling_micros
  @required_cpc_bid_ceiling_micros
end

#target_impression_share_microsFixnum

The simulated target impression share value (in micros) upon which projected metrics are based. For example, 10% impression share, which is equal to 0.1, is stored as 100_000. This value is validated and will not exceed 1M (100%). Corresponds to the JSON property targetImpressionShareMicros

Returns:

  • (Fixnum)


11458
11459
11460
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11458

def target_impression_share_micros
  @target_impression_share_micros
end

#top_slot_impressionsFixnum

Projected number of top slot impressions. Only search advertising channel type supports this field. Corresponds to the JSON property topSlotImpressions

Returns:

  • (Fixnum)


11464
11465
11466
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11464

def top_slot_impressions
  @top_slot_impressions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11471

def update!(**args)
  @absolute_top_impressions = args[:absolute_top_impressions] if args.key?(:absolute_top_impressions)
  @biddable_conversions = args[:biddable_conversions] if args.key?(:biddable_conversions)
  @biddable_conversions_value = args[:biddable_conversions_value] if args.key?(:biddable_conversions_value)
  @clicks = args[:clicks] if args.key?(:clicks)
  @cost_micros = args[:cost_micros] if args.key?(:cost_micros)
  @impressions = args[:impressions] if args.key?(:impressions)
  @required_budget_amount_micros = args[:required_budget_amount_micros] if args.key?(:required_budget_amount_micros)
  @required_cpc_bid_ceiling_micros = args[:required_cpc_bid_ceiling_micros] if args.key?(:required_cpc_bid_ceiling_micros)
  @target_impression_share_micros = args[:target_impression_share_micros] if args.key?(:target_impression_share_micros)
  @top_slot_impressions = args[:top_slot_impressions] if args.key?(:top_slot_impressions)
end