Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPointList
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPointList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A container for simulation points for simulations of type TARGET_IMPRESSION_SHARE.
Instance Attribute Summary collapse
-
#points ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPoint>
Projected metrics for a specific target impression share value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPointList
constructor
A new instance of GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPointList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPointList
Returns a new instance of GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPointList.
11495 11496 11497 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11495 def initialize(**args) update!(**args) end |
Instance Attribute Details
#points ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPoint>
Projected metrics for a specific target impression share value.
Corresponds to the JSON property points
11493 11494 11495 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11493 def points @points end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11500 11501 11502 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11500 def update!(**args) @points = args[:points] if args.key?(:points) end |