Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoas
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoas
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS).
Instance Attribute Summary collapse
-
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy.
-
#cpc_bid_floor_micros ⇒ Fixnum
Minimum bid limit that can be set by the bid strategy.
-
#target_roas ⇒ Float
Required.
-
#target_roas_tolerance_percent_millis ⇒ Fixnum
The percent of ROAS(return on advertising spend) degradation tolerance allowed to increase traffic diversity and conversion volume, specified in millis (for example, 10,000 = 10%).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetRoas
constructor
A new instance of GoogleAdsSearchads360V23CommonTargetRoas.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetRoas
Returns a new instance of GoogleAdsSearchads360V23CommonTargetRoas.
11661 11662 11663 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11661 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy. The limit applies to
all keywords managed by the strategy. This should only be set for portfolio
bid strategies.
Corresponds to the JSON property cpcBidCeilingMicros
11637 11638 11639 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11637 def cpc_bid_ceiling_micros @cpc_bid_ceiling_micros end |
#cpc_bid_floor_micros ⇒ Fixnum
Minimum bid limit that can be set by the bid strategy. The limit applies to
all keywords managed by the strategy. This should only be set for portfolio
bid strategies.
Corresponds to the JSON property cpcBidFloorMicros
11644 11645 11646 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11644 def cpc_bid_floor_micros @cpc_bid_floor_micros end |
#target_roas ⇒ Float
Required. The chosen revenue (based on conversion data) per unit of spend.
Value must be between 0.01 and 1000.0, inclusive.
Corresponds to the JSON property targetRoas
11650 11651 11652 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11650 def target_roas @target_roas end |
#target_roas_tolerance_percent_millis ⇒ Fixnum
The percent of ROAS(return on advertising spend) degradation tolerance allowed
to increase traffic diversity and conversion volume, specified in millis (for
example, 10,000 = 10%). A value of 10,000 means that the advertiser can expect
ROAS degradation of up to 10% of the specified target ROAS. This field is only
mutable for portfolio bidding strategies.
Corresponds to the JSON property targetRoasTolerancePercentMillis
11659 11660 11661 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11659 def target_roas_tolerance_percent_millis @target_roas_tolerance_percent_millis end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11666 11667 11668 11669 11670 11671 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11666 def update!(**args) @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros) @cpc_bid_floor_micros = args[:cpc_bid_floor_micros] if args.key?(:cpc_bid_floor_micros) @target_roas = args[:target_roas] if args.key?(:target_roas) @target_roas_tolerance_percent_millis = args[:target_roas_tolerance_percent_millis] if args.key?(:target_roas_tolerance_percent_millis) end |