Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoas

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetRoas

Returns a new instance of GoogleAdsSearchads360V23CommonTargetRoas.



11595
11596
11597
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpc_bid_ceiling_microsFixnum

Maximum bid limit that can be set by the bid strategy. The limit applies to all keywords managed by the strategy. This should only be set for portfolio bid strategies. Corresponds to the JSON property cpcBidCeilingMicros

Returns:

  • (Fixnum)


11571
11572
11573
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11571

def cpc_bid_ceiling_micros
  @cpc_bid_ceiling_micros
end

#cpc_bid_floor_microsFixnum

Minimum bid limit that can be set by the bid strategy. The limit applies to all keywords managed by the strategy. This should only be set for portfolio bid strategies. Corresponds to the JSON property cpcBidFloorMicros

Returns:

  • (Fixnum)


11578
11579
11580
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11578

def cpc_bid_floor_micros
  @cpc_bid_floor_micros
end

#target_roasFloat

Required. The chosen revenue (based on conversion data) per unit of spend. Value must be between 0.01 and 1000.0, inclusive. Corresponds to the JSON property targetRoas

Returns:

  • (Float)


11584
11585
11586
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11584

def target_roas
  @target_roas
end

#target_roas_tolerance_percent_millisFixnum

The percent of ROAS(return on advertising spend) degradation tolerance allowed to increase traffic diversity and conversion volume, specified in millis (for example, 10,000 = 10%). A value of 10,000 means that the advertiser can expect ROAS degradation of up to 10% of the specified target ROAS. This field is only mutable for portfolio bidding strategies. Corresponds to the JSON property targetRoasTolerancePercentMillis

Returns:

  • (Fixnum)


11593
11594
11595
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11593

def target_roas_tolerance_percent_millis
  @target_roas_tolerance_percent_millis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11600
11601
11602
11603
11604
11605
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11600

def update!(**args)
  @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros)
  @cpc_bid_floor_micros = args[:cpc_bid_floor_micros] if args.key?(:cpc_bid_floor_micros)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
  @target_roas_tolerance_percent_millis = args[:target_roas_tolerance_percent_millis] if args.key?(:target_roas_tolerance_percent_millis)
end