Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoasSimulationPoint
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoasSimulationPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Projected metrics for a specific target ROAS amount.
Instance Attribute Summary collapse
-
#biddable_conversions ⇒ Float
Projected number of biddable conversions.
-
#biddable_conversions_value ⇒ Float
Projected total value of biddable conversions.
-
#clicks ⇒ Fixnum
Projected number of clicks.
-
#cost_micros ⇒ Fixnum
Projected cost in micros.
-
#impressions ⇒ Fixnum
Projected number of impressions.
-
#required_budget_amount_micros ⇒ Fixnum
Projected required daily budget that the advertiser must set in order to receive the estimated traffic, in micros of advertiser currency.
-
#target_roas ⇒ Float
The simulated target ROAS upon which projected metrics are based.
-
#top_slot_impressions ⇒ Fixnum
Projected number of top slot impressions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetRoasSimulationPoint
constructor
A new instance of GoogleAdsSearchads360V23CommonTargetRoasSimulationPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetRoasSimulationPoint
Returns a new instance of GoogleAdsSearchads360V23CommonTargetRoasSimulationPoint.
11654 11655 11656 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11654 def initialize(**args) update!(**args) end |
Instance Attribute Details
#biddable_conversions ⇒ Float
Projected number of biddable conversions.
Corresponds to the JSON property biddableConversions
11615 11616 11617 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11615 def biddable_conversions @biddable_conversions end |
#biddable_conversions_value ⇒ Float
Projected total value of biddable conversions.
Corresponds to the JSON property biddableConversionsValue
11620 11621 11622 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11620 def biddable_conversions_value @biddable_conversions_value end |
#clicks ⇒ Fixnum
Projected number of clicks.
Corresponds to the JSON property clicks
11625 11626 11627 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11625 def clicks @clicks end |
#cost_micros ⇒ Fixnum
Projected cost in micros.
Corresponds to the JSON property costMicros
11630 11631 11632 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11630 def cost_micros @cost_micros end |
#impressions ⇒ Fixnum
Projected number of impressions.
Corresponds to the JSON property impressions
11635 11636 11637 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11635 def impressions @impressions end |
#required_budget_amount_micros ⇒ Fixnum
Projected required daily budget that the advertiser must set in order to
receive the estimated traffic, in micros of advertiser currency.
Corresponds to the JSON property requiredBudgetAmountMicros
11641 11642 11643 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11641 def required_budget_amount_micros @required_budget_amount_micros end |
#target_roas ⇒ Float
The simulated target ROAS upon which projected metrics are based.
Corresponds to the JSON property targetRoas
11646 11647 11648 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11646 def target_roas @target_roas end |
#top_slot_impressions ⇒ Fixnum
Projected number of top slot impressions. Only Search advertising channel type
supports this field.
Corresponds to the JSON property topSlotImpressions
11652 11653 11654 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11652 def top_slot_impressions @top_slot_impressions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11659 11660 11661 11662 11663 11664 11665 11666 11667 11668 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11659 def update!(**args) @biddable_conversions = args[:biddable_conversions] if args.key?(:biddable_conversions) @biddable_conversions_value = args[:biddable_conversions_value] if args.key?(:biddable_conversions_value) @clicks = args[:clicks] if args.key?(:clicks) @cost_micros = args[:cost_micros] if args.key?(:cost_micros) @impressions = args[:impressions] if args.key?(:impressions) @required_budget_amount_micros = args[:required_budget_amount_micros] if args.key?(:required_budget_amount_micros) @target_roas = args[:target_roas] if args.key?(:target_roas) @top_slot_impressions = args[:top_slot_impressions] if args.key?(:top_slot_impressions) end |