Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetSpend
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetSpend
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An automated bid strategy that sets your bids to help get as many clicks as possible within your budget.
Instance Attribute Summary collapse
-
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy.
-
#target_spend_micros ⇒ Fixnum
Deprecated: The spend target under which to maximize clicks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetSpend
constructor
A new instance of GoogleAdsSearchads360V23CommonTargetSpend.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetSpend
Returns a new instance of GoogleAdsSearchads360V23CommonTargetSpend.
11711 11712 11713 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpc_bid_ceiling_micros ⇒ Fixnum
Maximum bid limit that can be set by the bid strategy. The limit applies to
all keywords managed by the strategy.
Corresponds to the JSON property cpcBidCeilingMicros
11699 11700 11701 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11699 def cpc_bid_ceiling_micros @cpc_bid_ceiling_micros end |
#target_spend_micros ⇒ Fixnum
Deprecated: The spend target under which to maximize clicks. A TargetSpend
bidder will attempt to spend the smaller of this value or the natural
throttling spend amount. If not specified, the budget is used as the spend
target. This field is deprecated and should no longer be used. See https://ads-
developers.googleblog.com/2020/05/reminder-about-sunset-creation-of.html for
details.
Corresponds to the JSON property targetSpendMicros
11709 11710 11711 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11709 def target_spend_micros @target_spend_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11716 11717 11718 11719 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11716 def update!(**args) @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros) @target_spend_micros = args[:target_spend_micros] if args.key?(:target_spend_micros) end |