Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetingSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Settings for the targeting-related features, at the campaign and ad group levels. For more details about the targeting setting, visit https://support. google.com/google-ads/answer/7365594

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetingSetting

Returns a new instance of GoogleAdsSearchads360V23CommonTargetingSetting.



11807
11808
11809
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_restriction_operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRestrictionOperation>

The list of operations changing the target restrictions. Adding a target restriction with a targeting dimension that already exists causes the existing target restriction to be replaced with the new value. Corresponds to the JSON property targetRestrictionOperations



11799
11800
11801
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11799

def target_restriction_operations
  @target_restriction_operations
end

#target_restrictionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRestriction>

The per-targeting-dimension setting to restrict the reach of your campaign or ad group. Corresponds to the JSON property targetRestrictions



11805
11806
11807
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11805

def target_restrictions
  @target_restrictions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11812
11813
11814
11815
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11812

def update!(**args)
  @target_restriction_operations = args[:target_restriction_operations] if args.key?(:target_restriction_operations)
  @target_restrictions = args[:target_restrictions] if args.key?(:target_restrictions)
end