Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetingSetting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetingSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Settings for the targeting-related features, at the campaign and ad group levels. For more details about the targeting setting, visit https://support. google.com/google-ads/answer/7365594
Instance Attribute Summary collapse
-
#target_restriction_operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRestrictionOperation>
The list of operations changing the target restrictions.
-
#target_restrictions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRestriction>
The per-targeting-dimension setting to restrict the reach of your campaign or ad group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetingSetting
constructor
A new instance of GoogleAdsSearchads360V23CommonTargetingSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTargetingSetting
Returns a new instance of GoogleAdsSearchads360V23CommonTargetingSetting.
11741 11742 11743 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11741 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_restriction_operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRestrictionOperation>
The list of operations changing the target restrictions. Adding a target
restriction with a targeting dimension that already exists causes the existing
target restriction to be replaced with the new value.
Corresponds to the JSON property targetRestrictionOperations
11733 11734 11735 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11733 def target_restriction_operations @target_restriction_operations end |
#target_restrictions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRestriction>
The per-targeting-dimension setting to restrict the reach of your campaign or
ad group.
Corresponds to the JSON property targetRestrictions
11739 11740 11741 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11739 def target_restrictions @target_restrictions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11746 11747 11748 11749 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11746 def update!(**args) @target_restriction_operations = args[:target_restriction_operations] if args.key?(:target_restriction_operations) @target_restrictions = args[:target_restrictions] if args.key?(:target_restrictions) end |