Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTopicInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTopicInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A topic criterion. Use topics to target or exclude placements in the Google Display Network based on the category into which the placement falls (for example, "Pets & Animals/Pets/Dogs").
Instance Attribute Summary collapse
-
#path ⇒ Array<String>
The category to target or exclude.
-
#topic_constant ⇒ String
The Topic Constant resource name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTopicInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonTopicInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTopicInfo
Returns a new instance of GoogleAdsSearchads360V23CommonTopicInfo.
11875 11876 11877 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11875 def initialize(**args) update!(**args) end |
Instance Attribute Details
#path ⇒ Array<String>
The category to target or exclude. Each subsequent element in the array
describes a more specific sub-category. For example, "Pets & Animals", "Pets",
"Dogs" represents the "Pets & Animals/Pets/Dogs" category.
Corresponds to the JSON property path
11868 11869 11870 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11868 def path @path end |
#topic_constant ⇒ String
The Topic Constant resource name.
Corresponds to the JSON property topicConstant
11873 11874 11875 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11873 def topic_constant @topic_constant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11880 11881 11882 11883 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11880 def update!(**args) @path = args[:path] if args.key?(:path) @topic_constant = args[:topic_constant] if args.key?(:topic_constant) end |