Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTransactionAttribute
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTransactionAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Attribute of the store sales transaction.
Instance Attribute Summary collapse
-
#conversion_action ⇒ String
The resource name of conversion action to report conversions to.
-
#currency_code ⇒ String
Transaction currency code.
-
#custom_value ⇒ String
Value of the custom variable for each transaction.
-
#item_attribute ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonItemAttribute
Item attributes of the transaction.
-
#order_id ⇒ String
Transaction order id.
-
#store_attribute ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStoreAttribute
Store attributes of the transaction.
-
#transaction_amount_micros ⇒ Float
Transaction amount in micros.
-
#transaction_date_time ⇒ String
Timestamp when transaction occurred.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTransactionAttribute
constructor
A new instance of GoogleAdsSearchads360V23CommonTransactionAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTransactionAttribute
Returns a new instance of GoogleAdsSearchads360V23CommonTransactionAttribute.
12064 12065 12066 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12064 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_action ⇒ String
The resource name of conversion action to report conversions to. Required.
Corresponds to the JSON property conversionAction
12019 12020 12021 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12019 def conversion_action @conversion_action end |
#currency_code ⇒ String
Transaction currency code. ISO 4217 three-letter code is used. Required.
Corresponds to the JSON property currencyCode
12024 12025 12026 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12024 def currency_code @currency_code end |
#custom_value ⇒ String
Value of the custom variable for each transaction. Allowed only if a custom
key is provided in the store sales metadata.
Corresponds to the JSON property customValue
12030 12031 12032 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12030 def custom_value @custom_value end |
#item_attribute ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonItemAttribute
Item attributes of the transaction.
Corresponds to the JSON property itemAttribute
12035 12036 12037 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12035 def item_attribute @item_attribute end |
#order_id ⇒ String
Transaction order id. Useful to group transactions which are part of the same
order.
Corresponds to the JSON property orderId
12041 12042 12043 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12041 def order_id @order_id end |
#store_attribute ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStoreAttribute
Store attributes of the transaction.
Corresponds to the JSON property storeAttribute
12046 12047 12048 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12046 def store_attribute @store_attribute end |
#transaction_amount_micros ⇒ Float
Transaction amount in micros. Required. Transaction amount in micros needs to
be greater than 1000. If item Attributes are provided, it represents the total
value of the items, after multiplying the unit price per item by the quantity
provided in the ItemAttributes.
Corresponds to the JSON property transactionAmountMicros
12054 12055 12056 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12054 def transaction_amount_micros @transaction_amount_micros end |
#transaction_date_time ⇒ String
Timestamp when transaction occurred. Required. The format is "YYYY-MM-DD HH:MM:
SS[+/-HH:MM]", where [+/-HH:MM] is an optional timezone offset from UTC. If
the offset is absent, the API will use the account's timezone as default.
Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34:30+03:00"
Corresponds to the JSON property transactionDateTime
12062 12063 12064 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12062 def transaction_date_time @transaction_date_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12069 12070 12071 12072 12073 12074 12075 12076 12077 12078 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12069 def update!(**args) @conversion_action = args[:conversion_action] if args.key?(:conversion_action) @currency_code = args[:currency_code] if args.key?(:currency_code) @custom_value = args[:custom_value] if args.key?(:custom_value) @item_attribute = args[:item_attribute] if args.key?(:item_attribute) @order_id = args[:order_id] if args.key?(:order_id) @store_attribute = args[:store_attribute] if args.key?(:store_attribute) @transaction_amount_micros = args[:transaction_amount_micros] if args.key?(:transaction_amount_micros) @transaction_date_time = args[:transaction_date_time] if args.key?(:transaction_date_time) end |