Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTransactionAttribute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Attribute of the store sales transaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonTransactionAttribute

Returns a new instance of GoogleAdsSearchads360V23CommonTransactionAttribute.



11938
11939
11940
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11938

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversion_actionString

The resource name of conversion action to report conversions to. Required. Corresponds to the JSON property conversionAction

Returns:

  • (String)


11893
11894
11895
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11893

def conversion_action
  @conversion_action
end

#currency_codeString

Transaction currency code. ISO 4217 three-letter code is used. Required. Corresponds to the JSON property currencyCode

Returns:

  • (String)


11898
11899
11900
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11898

def currency_code
  @currency_code
end

#custom_valueString

Value of the custom variable for each transaction. Allowed only if a custom key is provided in the store sales metadata. Corresponds to the JSON property customValue

Returns:

  • (String)


11904
11905
11906
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11904

def custom_value
  @custom_value
end

#item_attributeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonItemAttribute

Item attributes of the transaction. Corresponds to the JSON property itemAttribute



11909
11910
11911
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11909

def item_attribute
  @item_attribute
end

#order_idString

Transaction order id. Useful to group transactions which are part of the same order. Corresponds to the JSON property orderId

Returns:

  • (String)


11915
11916
11917
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11915

def order_id
  @order_id
end

#store_attributeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStoreAttribute

Store attributes of the transaction. Corresponds to the JSON property storeAttribute



11920
11921
11922
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11920

def store_attribute
  @store_attribute
end

#transaction_amount_microsFloat

Transaction amount in micros. Required. Transaction amount in micros needs to be greater than 1000. If item Attributes are provided, it represents the total value of the items, after multiplying the unit price per item by the quantity provided in the ItemAttributes. Corresponds to the JSON property transactionAmountMicros

Returns:

  • (Float)


11928
11929
11930
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11928

def transaction_amount_micros
  @transaction_amount_micros
end

#transaction_date_timeString

Timestamp when transaction occurred. Required. The format is "YYYY-MM-DD HH:MM: SS[+/-HH:MM]", where [+/-HH:MM] is an optional timezone offset from UTC. If the offset is absent, the API will use the account's timezone as default. Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34:30+03:00" Corresponds to the JSON property transactionDateTime

Returns:

  • (String)


11936
11937
11938
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11936

def transaction_date_time
  @transaction_date_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11943
11944
11945
11946
11947
11948
11949
11950
11951
11952
# File 'lib/google/apis/searchads360_v23/classes.rb', line 11943

def update!(**args)
  @conversion_action = args[:conversion_action] if args.key?(:conversion_action)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @custom_value = args[:custom_value] if args.key?(:custom_value)
  @item_attribute = args[:item_attribute] if args.key?(:item_attribute)
  @order_id = args[:order_id] if args.key?(:order_id)
  @store_attribute = args[:store_attribute] if args.key?(:store_attribute)
  @transaction_amount_micros = args[:transaction_amount_micros] if args.key?(:transaction_amount_micros)
  @transaction_date_time = args[:transaction_date_time] if args.key?(:transaction_date_time)
end