Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedCalloutAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A unified callout asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUnifiedCalloutAsset

Returns a new instance of GoogleAdsSearchads360V23CommonUnifiedCalloutAsset.



12088
12089
12090
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12088

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_schedule_targetsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>

List of non-overlapping schedules specifying all time intervals for which the asset may serve. There can be a maximum of 6 schedules per day, 42 in total. Corresponds to the JSON property adScheduleTargets



12062
12063
12064
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12062

def ad_schedule_targets
  @ad_schedule_targets
end

#callout_textString

The callout text. The length of this string should be between 1 and 25, inclusive. Corresponds to the JSON property calloutText

Returns:

  • (String)


12068
12069
12070
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12068

def callout_text
  @callout_text
end

#end_dateString

Last date of when this asset is effective and still serving, in yyyy-MM-dd format. Corresponds to the JSON property endDate

Returns:

  • (String)


12074
12075
12076
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12074

def end_date
  @end_date
end

#start_dateString

Start date of when this asset is effective and can begin serving, in yyyy-MM- dd format. Corresponds to the JSON property startDate

Returns:

  • (String)


12080
12081
12082
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12080

def start_date
  @start_date
end

#use_searcher_time_zoneBoolean Also known as: use_searcher_time_zone?

Whether to show the asset in search user's time zone. Applies to Microsoft Ads. Corresponds to the JSON property useSearcherTimeZone

Returns:

  • (Boolean)


12085
12086
12087
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12085

def use_searcher_time_zone
  @use_searcher_time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12093
12094
12095
12096
12097
12098
12099
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12093

def update!(**args)
  @ad_schedule_targets = args[:ad_schedule_targets] if args.key?(:ad_schedule_targets)
  @callout_text = args[:callout_text] if args.key?(:callout_text)
  @end_date = args[:end_date] if args.key?(:end_date)
  @start_date = args[:start_date] if args.key?(:start_date)
  @use_searcher_time_zone = args[:use_searcher_time_zone] if args.key?(:use_searcher_time_zone)
end