Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedSitelinkAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A unified sitelink asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUnifiedSitelinkAsset

Returns a new instance of GoogleAdsSearchads360V23CommonUnifiedSitelinkAsset.



12226
12227
12228
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12226

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_schedule_targetsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>

List of non-overlapping schedules specifying all time intervals for which the asset may serve. There can be a maximum of 6 schedules per day, 42 in total. Corresponds to the JSON property adScheduleTargets



12174
12175
12176
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12174

def ad_schedule_targets
  @ad_schedule_targets
end

#description1String

First line of the description for the sitelink. If set, the length should be between 1 and 35, inclusive, and description2 must also be set. Corresponds to the JSON property description1

Returns:

  • (String)


12180
12181
12182
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12180

def description1
  @description1
end

#description2String

Second line of the description for the sitelink. If set, the length should be between 1 and 35, inclusive, and description1 must also be set. Corresponds to the JSON property description2

Returns:

  • (String)


12186
12187
12188
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12186

def description2
  @description2
end

#end_dateString

Last date of when this asset is effective and still serving, in yyyy-MM-dd format. Corresponds to the JSON property endDate

Returns:

  • (String)


12192
12193
12194
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12192

def end_date
  @end_date
end

URL display text for the sitelink. The length of this string should be between 1 and 25, inclusive. Corresponds to the JSON property linkText

Returns:

  • (String)


12198
12199
12200
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12198

def link_text
  @link_text
end

#mobile_preferredBoolean Also known as: mobile_preferred?

Whether the preference is for the sitelink asset to be displayed on mobile devices. Applies to Microsoft Ads. Corresponds to the JSON property mobilePreferred

Returns:

  • (Boolean)


12204
12205
12206
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12204

def mobile_preferred
  @mobile_preferred
end

#start_dateString

Start date of when this asset is effective and can begin serving, in yyyy-MM- dd format. Corresponds to the JSON property startDate

Returns:

  • (String)


12211
12212
12213
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12211

def start_date
  @start_date
end

#tracking_idFixnum

ID used for tracking clicks for the sitelink asset. This is a Yahoo! Japan only field. Corresponds to the JSON property trackingId

Returns:

  • (Fixnum)


12217
12218
12219
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12217

def tracking_id
  @tracking_id
end

#use_searcher_time_zoneBoolean Also known as: use_searcher_time_zone?

Whether to show the sitelink asset in search user's time zone. Applies to Microsoft Ads. Corresponds to the JSON property useSearcherTimeZone

Returns:

  • (Boolean)


12223
12224
12225
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12223

def use_searcher_time_zone
  @use_searcher_time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12231
12232
12233
12234
12235
12236
12237
12238
12239
12240
12241
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12231

def update!(**args)
  @ad_schedule_targets = args[:ad_schedule_targets] if args.key?(:ad_schedule_targets)
  @description1 = args[:description1] if args.key?(:description1)
  @description2 = args[:description2] if args.key?(:description2)
  @end_date = args[:end_date] if args.key?(:end_date)
  @link_text = args[:link_text] if args.key?(:link_text)
  @mobile_preferred = args[:mobile_preferred] if args.key?(:mobile_preferred)
  @start_date = args[:start_date] if args.key?(:start_date)
  @tracking_id = args[:tracking_id] if args.key?(:tracking_id)
  @use_searcher_time_zone = args[:use_searcher_time_zone] if args.key?(:use_searcher_time_zone)
end