Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserAttribute
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
User attribute, can only be used with CUSTOMER_MATCH_WITH_ATTRIBUTES job type.
Instance Attribute Summary collapse
-
#acquisition_date_time ⇒ String
Timestamp when the user was acquired.
-
#average_purchase_count ⇒ Fixnum
Advertiser defined average number of purchases that are made by the user in a 30 day period.
-
#average_purchase_value_micros ⇒ Fixnum
Advertiser defined average purchase value in micros for the user.
-
#event_attribute ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonEventAttribute>
Optional.
-
#first_purchase_date_time ⇒ String
Optional.
-
#last_purchase_date_time ⇒ String
Timestamp of the last purchase made by the user.
-
#lifecycle_stage ⇒ String
Optional.
-
#lifetime_value_bucket ⇒ Fixnum
Advertiser defined lifetime value bucket for the user.
-
#lifetime_value_micros ⇒ Fixnum
Advertiser defined lifetime value for the user.
-
#shopping_loyalty ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonShoppingLoyalty
The shopping loyalty related data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserAttribute
constructor
A new instance of GoogleAdsSearchads360V23CommonUserAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserAttribute
Returns a new instance of GoogleAdsSearchads360V23CommonUserAttribute.
12361 12362 12363 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12361 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acquisition_date_time ⇒ String
Timestamp when the user was acquired. The format is YYYY-MM-DD HH:MM:SS[+/-HH:
MM], where [+/-HH:MM] is an optional timezone offset from UTC. If the offset
is absent, the API will use the account's timezone as default.
Corresponds to the JSON property acquisitionDateTime
12303 12304 12305 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12303 def acquisition_date_time @acquisition_date_time end |
#average_purchase_count ⇒ Fixnum
Advertiser defined average number of purchases that are made by the user in a
30 day period.
Corresponds to the JSON property averagePurchaseCount
12309 12310 12311 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12309 def average_purchase_count @average_purchase_count end |
#average_purchase_value_micros ⇒ Fixnum
Advertiser defined average purchase value in micros for the user.
Corresponds to the JSON property averagePurchaseValueMicros
12314 12315 12316 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12314 def average_purchase_value_micros @average_purchase_value_micros end |
#event_attribute ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonEventAttribute>
Optional. Advertiser defined events and their attributes. All the values in
the nested fields are required. Currently this field is in beta.
Corresponds to the JSON property eventAttribute
12320 12321 12322 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12320 def event_attribute @event_attribute end |
#first_purchase_date_time ⇒ String
Optional. Timestamp of the first purchase made by the user. The format is YYYY-
MM-DD HH:MM:SS[+/-HH:MM], where [+/-HH:MM] is an optional timezone offset from
UTC. If the offset is absent, the API will use the account's timezone as
default.
Corresponds to the JSON property firstPurchaseDateTime
12328 12329 12330 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12328 def first_purchase_date_time @first_purchase_date_time end |
#last_purchase_date_time ⇒ String
Timestamp of the last purchase made by the user. The format is YYYY-MM-DD HH:
MM:SS[+/-HH:MM], where [+/-HH:MM] is an optional timezone offset from UTC. If
the offset is absent, the API will use the account's timezone as default.
Corresponds to the JSON property lastPurchaseDateTime
12335 12336 12337 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12335 def last_purchase_date_time @last_purchase_date_time end |
#lifecycle_stage ⇒ String
Optional. Advertiser defined lifecycle stage for the user. The accepted values
are "Lead", "Active" and "Churned".
Corresponds to the JSON property lifecycleStage
12341 12342 12343 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12341 def lifecycle_stage @lifecycle_stage end |
#lifetime_value_bucket ⇒ Fixnum
Advertiser defined lifetime value bucket for the user. The valid range for a
lifetime value bucket is from 1 (low) to 10 (high), except for remove
operation where 0 will also be accepted.
Corresponds to the JSON property lifetimeValueBucket
12348 12349 12350 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12348 def lifetime_value_bucket @lifetime_value_bucket end |
#lifetime_value_micros ⇒ Fixnum
Advertiser defined lifetime value for the user.
Corresponds to the JSON property lifetimeValueMicros
12353 12354 12355 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12353 def lifetime_value_micros @lifetime_value_micros end |
#shopping_loyalty ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonShoppingLoyalty
The shopping loyalty related data. Shopping utilizes this data to provide
users with a better experience. Accessible only to merchants on the allow-list.
Corresponds to the JSON property shoppingLoyalty
12359 12360 12361 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12359 def shopping_loyalty @shopping_loyalty end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12366 12367 12368 12369 12370 12371 12372 12373 12374 12375 12376 12377 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12366 def update!(**args) @acquisition_date_time = args[:acquisition_date_time] if args.key?(:acquisition_date_time) @average_purchase_count = args[:average_purchase_count] if args.key?(:average_purchase_count) @average_purchase_value_micros = args[:average_purchase_value_micros] if args.key?(:average_purchase_value_micros) @event_attribute = args[:event_attribute] if args.key?(:event_attribute) @first_purchase_date_time = args[:first_purchase_date_time] if args.key?(:first_purchase_date_time) @last_purchase_date_time = args[:last_purchase_date_time] if args.key?(:last_purchase_date_time) @lifecycle_stage = args[:lifecycle_stage] if args.key?(:lifecycle_stage) @lifetime_value_bucket = args[:lifetime_value_bucket] if args.key?(:lifetime_value_bucket) @lifetime_value_micros = args[:lifetime_value_micros] if args.key?(:lifetime_value_micros) @shopping_loyalty = args[:shopping_loyalty] if args.key?(:shopping_loyalty) end |