Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListDateRuleItemInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A rule item composed of a date operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListDateRuleItemInfo

Returns a new instance of GoogleAdsSearchads360V23CommonUserListDateRuleItemInfo.



12660
12661
12662
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12660

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#offset_in_daysFixnum

The relative date value of the right hand side denoted by number of days offset from now. The value field will override this field when both are present. Corresponds to the JSON property offsetInDays

Returns:

  • (Fixnum)


12645
12646
12647
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12645

def offset_in_days
  @offset_in_days
end

#operatorString

Date comparison operator. This field is required and must be populated when creating new date rule item. Corresponds to the JSON property operator

Returns:

  • (String)


12651
12652
12653
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12651

def operator
  @operator
end

#valueString

String representing date value to be compared with the rule variable. Supported date format is YYYY-MM-DD. Times are reported in the customer's time zone. Corresponds to the JSON property value

Returns:

  • (String)


12658
12659
12660
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12658

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12665
12666
12667
12668
12669
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12665

def update!(**args)
  @offset_in_days = args[:offset_in_days] if args.key?(:offset_in_days)
  @operator = args[:operator] if args.key?(:operator)
  @value = args[:value] if args.key?(:value)
end