Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListDateRuleItemInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A rule item composed of a date operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListDateRuleItemInfo

Returns a new instance of GoogleAdsSearchads360V23CommonUserListDateRuleItemInfo.



12594
12595
12596
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12594

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#offset_in_daysFixnum

The relative date value of the right hand side denoted by number of days offset from now. The value field will override this field when both are present. Corresponds to the JSON property offsetInDays

Returns:

  • (Fixnum)


12579
12580
12581
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12579

def offset_in_days
  @offset_in_days
end

#operatorString

Date comparison operator. This field is required and must be populated when creating new date rule item. Corresponds to the JSON property operator

Returns:

  • (String)


12585
12586
12587
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12585

def operator
  @operator
end

#valueString

String representing date value to be compared with the rule variable. Supported date format is YYYY-MM-DD. Times are reported in the customer's time zone. Corresponds to the JSON property value

Returns:

  • (String)


12592
12593
12594
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12592

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12599
12600
12601
12602
12603
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12599

def update!(**args)
  @offset_in_days = args[:offset_in_days] if args.key?(:offset_in_days)
  @operator = args[:operator] if args.key?(:operator)
  @value = args[:value] if args.key?(:value)
end