Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListNumberRuleItemInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListNumberRuleItemInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A rule item composed of a number operation.
Instance Attribute Summary collapse
-
#operator ⇒ String
Number comparison operator.
-
#value ⇒ Float
Number value to be compared with the variable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListNumberRuleItemInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonUserListNumberRuleItemInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListNumberRuleItemInfo
Returns a new instance of GoogleAdsSearchads360V23CommonUserListNumberRuleItemInfo.
12668 12669 12670 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operator ⇒ String
Number comparison operator. This field is required and must be populated when
creating a new number rule item.
Corresponds to the JSON property operator
12660 12661 12662 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12660 def operator @operator end |
#value ⇒ Float
Number value to be compared with the variable. This field is required and must
be populated when creating a new number rule item.
Corresponds to the JSON property value
12666 12667 12668 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12666 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12673 12674 12675 12676 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12673 def update!(**args) @operator = args[:operator] if args.key?(:operator) @value = args[:value] if args.key?(:value) end |