Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A client defined rule based on custom parameters sent by web sites or uploaded by the advertiser.
Instance Attribute Summary collapse
-
#rule_item_groups ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleItemGroupInfo>
List of rule item groups that defines this rule.
-
#rule_type ⇒ String
Rule type is used to determine how to group rule items.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListRuleInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonUserListRuleInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListRuleInfo
Returns a new instance of GoogleAdsSearchads360V23CommonUserListRuleInfo.
12824 12825 12826 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12824 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rule_item_groups ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleItemGroupInfo>
List of rule item groups that defines this rule. Rule item groups are grouped
together based on rule_type.
Corresponds to the JSON property ruleItemGroups
12814 12815 12816 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12814 def rule_item_groups @rule_item_groups end |
#rule_type ⇒ String
Rule type is used to determine how to group rule items. The default is OR of
ANDs (disjunctive normal form). That is, rule items will be ANDed together
within rule item groups and the groups themselves will be ORed together. OR of
ANDs is the only supported type for FlexibleRuleUserList.
Corresponds to the JSON property ruleType
12822 12823 12824 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12822 def rule_type @rule_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12829 12830 12831 12832 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12829 def update!(**args) @rule_item_groups = args[:rule_item_groups] if args.key?(:rule_item_groups) @rule_type = args[:rule_type] if args.key?(:rule_type) end |