Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A client defined rule based on custom parameters sent by web sites or uploaded by the advertiser.
Instance Attribute Summary collapse
-
#rule_item_groups ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleItemGroupInfo>
List of rule item groups that defines this rule.
-
#rule_type ⇒ String
Rule type is used to determine how to group rule items.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListRuleInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonUserListRuleInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListRuleInfo
Returns a new instance of GoogleAdsSearchads360V23CommonUserListRuleInfo.
12764 12765 12766 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12764 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rule_item_groups ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleItemGroupInfo>
List of rule item groups that defines this rule. Rule item groups are grouped
together based on rule_type.
Corresponds to the JSON property ruleItemGroups
12754 12755 12756 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12754 def rule_item_groups @rule_item_groups end |
#rule_type ⇒ String
Rule type is used to determine how to group rule items. The default is OR of
ANDs (disjunctive normal form). That is, rule items will be ANDed together
within rule item groups and the groups themselves will be ORed together. OR of
ANDs is the only supported type for FlexibleRuleUserList.
Corresponds to the JSON property ruleType
12762 12763 12764 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12762 def rule_type @rule_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12769 12770 12771 12772 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12769 def update!(**args) @rule_item_groups = args[:rule_item_groups] if args.key?(:rule_item_groups) @rule_type = args[:rule_type] if args.key?(:rule_type) end |