Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A client defined rule based on custom parameters sent by web sites or uploaded by the advertiser.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListRuleInfo

Returns a new instance of GoogleAdsSearchads360V23CommonUserListRuleInfo.



12698
12699
12700
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rule_item_groupsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleItemGroupInfo>

List of rule item groups that defines this rule. Rule item groups are grouped together based on rule_type. Corresponds to the JSON property ruleItemGroups



12688
12689
12690
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12688

def rule_item_groups
  @rule_item_groups
end

#rule_typeString

Rule type is used to determine how to group rule items. The default is OR of ANDs (disjunctive normal form). That is, rule items will be ANDed together within rule item groups and the groups themselves will be ORed together. OR of ANDs is the only supported type for FlexibleRuleUserList. Corresponds to the JSON property ruleType

Returns:

  • (String)


12696
12697
12698
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12696

def rule_type
  @rule_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12703
12704
12705
12706
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12703

def update!(**args)
  @rule_item_groups = args[:rule_item_groups] if args.key?(:rule_item_groups)
  @rule_type = args[:rule_type] if args.key?(:rule_type)
end