Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListRuleItemInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An atomic rule item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListRuleItemInfo

Returns a new instance of GoogleAdsSearchads360V23CommonUserListRuleItemInfo.



12757
12758
12759
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12757

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_rule_itemGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListDateRuleItemInfo

A rule item composed of a date operation. Corresponds to the JSON property dateRuleItem



12735
12736
12737
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12735

def date_rule_item
  @date_rule_item
end

#nameString

Rule variable name. It should match the corresponding key name fired by the pixel. A name must begin with US-ascii letters or underscore or UTF8 code that is greater than 127 and consist of US-ascii letters or digits or underscore or UTF8 code that is greater than 127. For websites, there are two built-in variable URL (name = 'url_') and referrer URL (name = 'ref_url_'). This field must be populated when creating a new rule item. Corresponds to the JSON property name

Returns:

  • (String)


12745
12746
12747
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12745

def name
  @name
end

#number_rule_itemGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListNumberRuleItemInfo

A rule item composed of a number operation. Corresponds to the JSON property numberRuleItem



12750
12751
12752
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12750

def number_rule_item
  @number_rule_item
end

#string_rule_itemGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo

A rule item composed of a string operation. Corresponds to the JSON property stringRuleItem



12755
12756
12757
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12755

def string_rule_item
  @string_rule_item
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12762
12763
12764
12765
12766
12767
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12762

def update!(**args)
  @date_rule_item = args[:date_rule_item] if args.key?(:date_rule_item)
  @name = args[:name] if args.key?(:name)
  @number_rule_item = args[:number_rule_item] if args.key?(:number_rule_item)
  @string_rule_item = args[:string_rule_item] if args.key?(:string_rule_item)
end