Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A rule item composed of a string operation.
Instance Attribute Summary collapse
-
#operator ⇒ String
String comparison operator.
-
#value ⇒ String
The right hand side of the string rule item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo
Returns a new instance of GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo.
12873 12874 12875 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12873 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operator ⇒ String
String comparison operator. This field is required and must be populated when
creating a new string rule item.
Corresponds to the JSON property operator
12863 12864 12865 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12863 def operator @operator end |
#value ⇒ String
The right hand side of the string rule item. For URLs or referrer URLs, the
value can not contain illegal URL chars such as newlines, quotes, tabs, or
parentheses. This field is required and must be populated when creating a new
string rule item.
Corresponds to the JSON property value
12871 12872 12873 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12871 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12878 12879 12880 12881 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12878 def update!(**args) @operator = args[:operator] if args.key?(:operator) @value = args[:value] if args.key?(:value) end |