Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A rule item composed of a string operation.
Instance Attribute Summary collapse
-
#operator ⇒ String
String comparison operator.
-
#value ⇒ String
The right hand side of the string rule item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo
Returns a new instance of GoogleAdsSearchads360V23CommonUserListStringRuleItemInfo.
12807 12808 12809 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12807 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operator ⇒ String
String comparison operator. This field is required and must be populated when
creating a new string rule item.
Corresponds to the JSON property operator
12797 12798 12799 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12797 def operator @operator end |
#value ⇒ String
The right hand side of the string rule item. For URLs or referrer URLs, the
value can not contain illegal URL chars such as newlines, quotes, tabs, or
parentheses. This field is required and must be populated when creating a new
string rule item.
Corresponds to the JSON property value
12805 12806 12807 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12805 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12812 12813 12814 12815 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12812 def update!(**args) @operator = args[:operator] if args.key?(:operator) @value = args[:value] if args.key?(:value) end |