Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A criterion to represent a single item group rule in Vertical Ads.
Instance Attribute Summary collapse
-
#city_criterion_id ⇒ String
The resource name of the Geo Target Constant for the city.
-
#country_criterion_id ⇒ String
The resource name of the Geo Target Constant for the country.
-
#hotel_class ⇒ Fixnum
Integer value specifying the class rating for a hotel.
-
#item_code ⇒ String
The id specifying a particular Vertical Ad listing.
-
#region_criterion_id ⇒ String
The resource name of the Geo Target Constant for the region.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo
Returns a new instance of GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo.
12958 12959 12960 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#city_criterion_id ⇒ String
The resource name of the Geo Target Constant for the city.
Corresponds to the JSON property cityCriterionId
12935 12936 12937 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12935 def city_criterion_id @city_criterion_id end |
#country_criterion_id ⇒ String
The resource name of the Geo Target Constant for the country.
Corresponds to the JSON property countryCriterionId
12940 12941 12942 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12940 def country_criterion_id @country_criterion_id end |
#hotel_class ⇒ Fixnum
Integer value specifying the class rating for a hotel. Ranges from 1 to 5
stars.
Corresponds to the JSON property hotelClass
12946 12947 12948 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12946 def hotel_class @hotel_class end |
#item_code ⇒ String
The id specifying a particular Vertical Ad listing.
Corresponds to the JSON property itemCode
12951 12952 12953 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12951 def item_code @item_code end |
#region_criterion_id ⇒ String
The resource name of the Geo Target Constant for the region.
Corresponds to the JSON property regionCriterionId
12956 12957 12958 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12956 def region_criterion_id @region_criterion_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12963 12964 12965 12966 12967 12968 12969 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12963 def update!(**args) @city_criterion_id = args[:city_criterion_id] if args.key?(:city_criterion_id) @country_criterion_id = args[:country_criterion_id] if args.key?(:country_criterion_id) @hotel_class = args[:hotel_class] if args.key?(:hotel_class) @item_code = args[:item_code] if args.key?(:item_code) @region_criterion_id = args[:region_criterion_id] if args.key?(:region_criterion_id) end |