Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A criterion to represent a single item group rule in Vertical Ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo

Returns a new instance of GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo.



12892
12893
12894
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#city_criterion_idString

The resource name of the Geo Target Constant for the city. Corresponds to the JSON property cityCriterionId

Returns:

  • (String)


12869
12870
12871
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12869

def city_criterion_id
  @city_criterion_id
end

#country_criterion_idString

The resource name of the Geo Target Constant for the country. Corresponds to the JSON property countryCriterionId

Returns:

  • (String)


12874
12875
12876
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12874

def country_criterion_id
  @country_criterion_id
end

#hotel_classFixnum

Integer value specifying the class rating for a hotel. Ranges from 1 to 5 stars. Corresponds to the JSON property hotelClass

Returns:

  • (Fixnum)


12880
12881
12882
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12880

def hotel_class
  @hotel_class
end

#item_codeString

The id specifying a particular Vertical Ad listing. Corresponds to the JSON property itemCode

Returns:

  • (String)


12885
12886
12887
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12885

def item_code
  @item_code
end

#region_criterion_idString

The resource name of the Geo Target Constant for the region. Corresponds to the JSON property regionCriterionId

Returns:

  • (String)


12890
12891
12892
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12890

def region_criterion_id
  @region_criterion_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12897
12898
12899
12900
12901
12902
12903
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12897

def update!(**args)
  @city_criterion_id = args[:city_criterion_id] if args.key?(:city_criterion_id)
  @country_criterion_id = args[:country_criterion_id] if args.key?(:country_criterion_id)
  @hotel_class = args[:hotel_class] if args.key?(:hotel_class)
  @item_code = args[:item_code] if args.key?(:item_code)
  @region_criterion_id = args[:region_criterion_id] if args.key?(:region_criterion_id)
end