Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleListInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleListInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A criterion for targeting a shared set of rules for item groups in Vertical Ads (e.g., for hotel ads).
Instance Attribute Summary collapse
-
#shared_set ⇒ String
The shared set resource name of the vertical ads item group rule list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleListInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleListInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleListInfo
Returns a new instance of GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleListInfo.
12982 12983 12984 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12982 def initialize(**args) update!(**args) end |
Instance Attribute Details
#shared_set ⇒ String
The shared set resource name of the vertical ads item group rule list.
Corresponds to the JSON property sharedSet
12980 12981 12982 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12980 def shared_set @shared_set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12987 12988 12989 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12987 def update!(**args) @shared_set = args[:shared_set] if args.key?(:shared_set) end |