Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleListInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A criterion for targeting a shared set of rules for item groups in Vertical Ads (e.g., for hotel ads).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleListInfo

Returns a new instance of GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleListInfo.



12916
12917
12918
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12916

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#shared_setString

The shared set resource name of the vertical ads item group rule list. Corresponds to the JSON property sharedSet

Returns:

  • (String)


12914
12915
12916
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12914

def shared_set
  @shared_set
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12921
12922
12923
# File 'lib/google/apis/searchads360_v23/classes.rb', line 12921

def update!(**args)
  @shared_set = args[:shared_set] if args.key?(:shared_set)
end