Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebhookDelivery
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebhookDelivery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Google notifies the advertiser of leads by making HTTP calls to an endpoint they specify. The requests contain JSON matching a schema that Google publishes as part of form ads documentation.
Instance Attribute Summary collapse
-
#advertiser_webhook_url ⇒ String
Webhook url specified by advertiser to send the lead.
-
#google_secret ⇒ String
Anti-spoofing secret set by the advertiser as part of the webhook payload.
-
#payload_schema_version ⇒ Fixnum
The schema version that this delivery instance will use.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonWebhookDelivery
constructor
A new instance of GoogleAdsSearchads360V23CommonWebhookDelivery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonWebhookDelivery
Returns a new instance of GoogleAdsSearchads360V23CommonWebhookDelivery.
13093 13094 13095 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13093 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_webhook_url ⇒ String
Webhook url specified by advertiser to send the lead.
Corresponds to the JSON property advertiserWebhookUrl
13081 13082 13083 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13081 def advertiser_webhook_url @advertiser_webhook_url end |
#google_secret ⇒ String
Anti-spoofing secret set by the advertiser as part of the webhook payload.
Corresponds to the JSON property googleSecret
13086 13087 13088 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13086 def google_secret @google_secret end |
#payload_schema_version ⇒ Fixnum
The schema version that this delivery instance will use.
Corresponds to the JSON property payloadSchemaVersion
13091 13092 13093 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13091 def payload_schema_version @payload_schema_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13098 13099 13100 13101 13102 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13098 def update!(**args) @advertiser_webhook_url = args[:advertiser_webhook_url] if args.key?(:advertiser_webhook_url) @google_secret = args[:google_secret] if args.key?(:google_secret) @payload_schema_version = args[:payload_schema_version] if args.key?(:payload_schema_version) end |