Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebhookDelivery
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebhookDelivery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Google notifies the advertiser of leads by making HTTP calls to an endpoint they specify. The requests contain JSON matching a schema that Google publishes as part of form ads documentation.
Instance Attribute Summary collapse
-
#advertiser_webhook_url ⇒ String
Webhook url specified by advertiser to send the lead.
-
#google_secret ⇒ String
Anti-spoofing secret set by the advertiser as part of the webhook payload.
-
#payload_schema_version ⇒ Fixnum
The schema version that this delivery instance will use.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonWebhookDelivery
constructor
A new instance of GoogleAdsSearchads360V23CommonWebhookDelivery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonWebhookDelivery
Returns a new instance of GoogleAdsSearchads360V23CommonWebhookDelivery.
13033 13034 13035 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_webhook_url ⇒ String
Webhook url specified by advertiser to send the lead.
Corresponds to the JSON property advertiserWebhookUrl
13021 13022 13023 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13021 def advertiser_webhook_url @advertiser_webhook_url end |
#google_secret ⇒ String
Anti-spoofing secret set by the advertiser as part of the webhook payload.
Corresponds to the JSON property googleSecret
13026 13027 13028 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13026 def google_secret @google_secret end |
#payload_schema_version ⇒ Fixnum
The schema version that this delivery instance will use.
Corresponds to the JSON property payloadSchemaVersion
13031 13032 13033 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13031 def payload_schema_version @payload_schema_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13038 13039 13040 13041 13042 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13038 def update!(**args) @advertiser_webhook_url = args[:advertiser_webhook_url] if args.key?(:advertiser_webhook_url) @google_secret = args[:google_secret] if args.key?(:google_secret) @payload_schema_version = args[:payload_schema_version] if args.key?(:payload_schema_version) end |