Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents a criterion for targeting webpages of an advertiser's website.
Instance Attribute Summary collapse
-
#conditions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageConditionInfo>
Conditions, or logical expressions, for webpage targeting.
-
#coverage_percentage ⇒ Float
Website criteria coverage percentage.
-
#criterion_name ⇒ String
The name of the criterion that is defined by this parameter.
-
#sample ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageSampleInfo
List of sample urls that match the website target Corresponds to the JSON property
sample.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonWebpageInfo
constructor
A new instance of GoogleAdsSearchads360V23CommonWebpageInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonWebpageInfo
Returns a new instance of GoogleAdsSearchads360V23CommonWebpageInfo.
13044 13045 13046 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13044 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageConditionInfo>
Conditions, or logical expressions, for webpage targeting. The list of webpage
targeting conditions are and-ed together when evaluated for targeting. An
empty list of conditions indicates all pages of the campaign's website are
targeted. This field is required for CREATE operations and is prohibited on
UPDATE operations.
Corresponds to the JSON property conditions
13021 13022 13023 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13021 def conditions @conditions end |
#coverage_percentage ⇒ Float
Website criteria coverage percentage. This is the computed percentage of
website coverage based on the website target, negative website target and
negative keywords in the ad group and campaign. For instance, when coverage
returns as 1, it indicates it has 100% coverage. This field is read-only.
Corresponds to the JSON property coveragePercentage
13029 13030 13031 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13029 def coverage_percentage @coverage_percentage end |
#criterion_name ⇒ String
The name of the criterion that is defined by this parameter. The name value
will be used for identifying, sorting and filtering criteria with this type of
parameters. This field is required for CREATE operations and is prohibited on
UPDATE operations.
Corresponds to the JSON property criterionName
13037 13038 13039 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13037 def criterion_name @criterion_name end |
#sample ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageSampleInfo
List of sample urls that match the website target
Corresponds to the JSON property sample
13042 13043 13044 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13042 def sample @sample end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13049 13050 13051 13052 13053 13054 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13049 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @coverage_percentage = args[:coverage_percentage] if args.key?(:coverage_percentage) @criterion_name = args[:criterion_name] if args.key?(:criterion_name) @sample = args[:sample] if args.key?(:sample) end |