Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonZaloBusinessMessageInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Zalo information to use for messaging.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23CommonZaloBusinessMessageInfo

Returns a new instance of GoogleAdsSearchads360V23CommonZaloBusinessMessageInfo.



13325
13326
13327
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_nameString

Custom name generated by the advertiser for their Zalo Account. These names will usually be registered brands or trademarks. Corresponds to the JSON property customName

Returns:

  • (String)


13318
13319
13320
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13318

def custom_name
  @custom_name
end

#oa_idFixnum

Zalo Official Account ID of the advertiser. Corresponds to the JSON property oaId

Returns:

  • (Fixnum)


13323
13324
13325
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13323

def oa_id
  @oa_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13330
13331
13332
13333
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13330

def update!(**args)
  @custom_name = args[:custom_name] if args.key?(:custom_name)
  @oa_id = args[:oa_id] if args.key?(:oa_id)
end