Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Error details for a budget below per-day minimum error.
Instance Attribute Summary collapse
-
#budget_per_day_minimum_micros ⇒ Fixnum
The minimum budget required by the campaign per day, in micros of the advertiser currency.
-
#currency_code ⇒ String
The advertiser's currency, represented as a three-letter ISO 4217 currency code (such as "USD").
-
#failed_budget_amount_micros ⇒ Fixnum
The budget amount value that was rejected as too low, in micros of the advertiser currency.
-
#failed_budget_total_amount_micros ⇒ Fixnum
The budget total_amount value that was rejected as too low, in micros of the advertiser currency.
-
#minimum_budget_amount_micros ⇒ Fixnum
The minimum value for the budget's amount field required by the campaign, in micros of the advertiser currency.
-
#minimum_budget_total_amount_micros ⇒ Fixnum
The minimum value for the budget's total_amount field required by the campaign given its configured start and end time, in micros of the advertiser currency.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails
constructor
A new instance of GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails
Returns a new instance of GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails.
13531 13532 13533 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#budget_per_day_minimum_micros ⇒ Fixnum
The minimum budget required by the campaign per day, in micros of the
advertiser currency. Applies to both daily and custom budgets.
Corresponds to the JSON property budgetPerDayMinimumMicros
13495 13496 13497 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13495 def budget_per_day_minimum_micros @budget_per_day_minimum_micros end |
#currency_code ⇒ String
The advertiser's currency, represented as a three-letter ISO 4217 currency
code (such as "USD").
Corresponds to the JSON property currencyCode
13501 13502 13503 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13501 def currency_code @currency_code end |
#failed_budget_amount_micros ⇒ Fixnum
The budget amount value that was rejected as too low, in micros of the
advertiser currency. Only set if this error is caused by the amount field
value.
Corresponds to the JSON property failedBudgetAmountMicros
13508 13509 13510 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13508 def failed_budget_amount_micros @failed_budget_amount_micros end |
#failed_budget_total_amount_micros ⇒ Fixnum
The budget total_amount value that was rejected as too low, in micros of the
advertiser currency. Only set if this error is caused by the total_amount
field value.
Corresponds to the JSON property failedBudgetTotalAmountMicros
13515 13516 13517 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13515 def failed_budget_total_amount_micros @failed_budget_total_amount_micros end |
#minimum_budget_amount_micros ⇒ Fixnum
The minimum value for the budget's amount field required by the campaign, in
micros of the advertiser currency. Only set if this error is caused by the
amount field value.
Corresponds to the JSON property minimumBudgetAmountMicros
13522 13523 13524 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13522 def minimum_budget_amount_micros @minimum_budget_amount_micros end |
#minimum_budget_total_amount_micros ⇒ Fixnum
The minimum value for the budget's total_amount field required by the campaign
given its configured start and end time, in micros of the advertiser currency.
Only set if this error is caused by the total_amount field value.
Corresponds to the JSON property minimumBudgetTotalAmountMicros
13529 13530 13531 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13529 def minimum_budget_total_amount_micros @minimum_budget_total_amount_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13536 13537 13538 13539 13540 13541 13542 13543 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13536 def update!(**args) @budget_per_day_minimum_micros = args[:budget_per_day_minimum_micros] if args.key?(:budget_per_day_minimum_micros) @currency_code = args[:currency_code] if args.key?(:currency_code) @failed_budget_amount_micros = args[:failed_budget_amount_micros] if args.key?(:failed_budget_amount_micros) @failed_budget_total_amount_micros = args[:failed_budget_total_amount_micros] if args.key?(:failed_budget_total_amount_micros) @minimum_budget_amount_micros = args[:minimum_budget_amount_micros] if args.key?(:minimum_budget_amount_micros) @minimum_budget_total_amount_micros = args[:minimum_budget_total_amount_micros] if args.key?(:minimum_budget_total_amount_micros) end |