Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Error details for a budget below per-day minimum error.
Instance Attribute Summary collapse
-
#budget_per_day_minimum_micros ⇒ Fixnum
The minimum budget required by the campaign per day, in micros of the advertiser currency.
-
#currency_code ⇒ String
The advertiser's currency, represented as a three-letter ISO 4217 currency code (such as "USD").
-
#failed_budget_amount_micros ⇒ Fixnum
The budget amount value that was rejected as too low, in micros of the advertiser currency.
-
#failed_budget_total_amount_micros ⇒ Fixnum
The budget total_amount value that was rejected as too low, in micros of the advertiser currency.
-
#minimum_budget_amount_micros ⇒ Fixnum
The minimum value for the budget's amount field required by the campaign, in micros of the advertiser currency.
-
#minimum_budget_total_amount_micros ⇒ Fixnum
The minimum value for the budget's total_amount field required by the campaign given its configured start and end time, in micros of the advertiser currency.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails
constructor
A new instance of GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails
Returns a new instance of GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails.
13471 13472 13473 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13471 def initialize(**args) update!(**args) end |
Instance Attribute Details
#budget_per_day_minimum_micros ⇒ Fixnum
The minimum budget required by the campaign per day, in micros of the
advertiser currency. Applies to both daily and custom budgets.
Corresponds to the JSON property budgetPerDayMinimumMicros
13435 13436 13437 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13435 def budget_per_day_minimum_micros @budget_per_day_minimum_micros end |
#currency_code ⇒ String
The advertiser's currency, represented as a three-letter ISO 4217 currency
code (such as "USD").
Corresponds to the JSON property currencyCode
13441 13442 13443 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13441 def currency_code @currency_code end |
#failed_budget_amount_micros ⇒ Fixnum
The budget amount value that was rejected as too low, in micros of the
advertiser currency. Only set if this error is caused by the amount field
value.
Corresponds to the JSON property failedBudgetAmountMicros
13448 13449 13450 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13448 def failed_budget_amount_micros @failed_budget_amount_micros end |
#failed_budget_total_amount_micros ⇒ Fixnum
The budget total_amount value that was rejected as too low, in micros of the
advertiser currency. Only set if this error is caused by the total_amount
field value.
Corresponds to the JSON property failedBudgetTotalAmountMicros
13455 13456 13457 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13455 def failed_budget_total_amount_micros @failed_budget_total_amount_micros end |
#minimum_budget_amount_micros ⇒ Fixnum
The minimum value for the budget's amount field required by the campaign, in
micros of the advertiser currency. Only set if this error is caused by the
amount field value.
Corresponds to the JSON property minimumBudgetAmountMicros
13462 13463 13464 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13462 def minimum_budget_amount_micros @minimum_budget_amount_micros end |
#minimum_budget_total_amount_micros ⇒ Fixnum
The minimum value for the budget's total_amount field required by the campaign
given its configured start and end time, in micros of the advertiser currency.
Only set if this error is caused by the total_amount field value.
Corresponds to the JSON property minimumBudgetTotalAmountMicros
13469 13470 13471 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13469 def minimum_budget_total_amount_micros @minimum_budget_total_amount_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13476 13477 13478 13479 13480 13481 13482 13483 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13476 def update!(**args) @budget_per_day_minimum_micros = args[:budget_per_day_minimum_micros] if args.key?(:budget_per_day_minimum_micros) @currency_code = args[:currency_code] if args.key?(:currency_code) @failed_budget_amount_micros = args[:failed_budget_amount_micros] if args.key?(:failed_budget_amount_micros) @failed_budget_total_amount_micros = args[:failed_budget_total_amount_micros] if args.key?(:failed_budget_total_amount_micros) @minimum_budget_amount_micros = args[:minimum_budget_amount_micros] if args.key?(:minimum_budget_amount_micros) @minimum_budget_total_amount_micros = args[:minimum_budget_total_amount_micros] if args.key?(:minimum_budget_total_amount_micros) end |