Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Error details for a budget below per-day minimum error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails

Returns a new instance of GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails.



13405
13406
13407
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13405

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_per_day_minimum_microsFixnum

The minimum budget required by the campaign per day, in micros of the advertiser currency. Applies to both daily and custom budgets. Corresponds to the JSON property budgetPerDayMinimumMicros

Returns:

  • (Fixnum)


13369
13370
13371
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13369

def budget_per_day_minimum_micros
  @budget_per_day_minimum_micros
end

#currency_codeString

The advertiser's currency, represented as a three-letter ISO 4217 currency code (such as "USD"). Corresponds to the JSON property currencyCode

Returns:

  • (String)


13375
13376
13377
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13375

def currency_code
  @currency_code
end

#failed_budget_amount_microsFixnum

The budget amount value that was rejected as too low, in micros of the advertiser currency. Only set if this error is caused by the amount field value. Corresponds to the JSON property failedBudgetAmountMicros

Returns:

  • (Fixnum)


13382
13383
13384
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13382

def failed_budget_amount_micros
  @failed_budget_amount_micros
end

#failed_budget_total_amount_microsFixnum

The budget total_amount value that was rejected as too low, in micros of the advertiser currency. Only set if this error is caused by the total_amount field value. Corresponds to the JSON property failedBudgetTotalAmountMicros

Returns:

  • (Fixnum)


13389
13390
13391
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13389

def failed_budget_total_amount_micros
  @failed_budget_total_amount_micros
end

#minimum_budget_amount_microsFixnum

The minimum value for the budget's amount field required by the campaign, in micros of the advertiser currency. Only set if this error is caused by the amount field value. Corresponds to the JSON property minimumBudgetAmountMicros

Returns:

  • (Fixnum)


13396
13397
13398
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13396

def minimum_budget_amount_micros
  @minimum_budget_amount_micros
end

#minimum_budget_total_amount_microsFixnum

The minimum value for the budget's total_amount field required by the campaign given its configured start and end time, in micros of the advertiser currency. Only set if this error is caused by the total_amount field value. Corresponds to the JSON property minimumBudgetTotalAmountMicros

Returns:

  • (Fixnum)


13403
13404
13405
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13403

def minimum_budget_total_amount_micros
  @minimum_budget_total_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13410
13411
13412
13413
13414
13415
13416
13417
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13410

def update!(**args)
  @budget_per_day_minimum_micros = args[:budget_per_day_minimum_micros] if args.key?(:budget_per_day_minimum_micros)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @failed_budget_amount_micros = args[:failed_budget_amount_micros] if args.key?(:failed_budget_amount_micros)
  @failed_budget_total_amount_micros = args[:failed_budget_total_amount_micros] if args.key?(:failed_budget_total_amount_micros)
  @minimum_budget_amount_micros = args[:minimum_budget_amount_micros] if args.key?(:minimum_budget_amount_micros)
  @minimum_budget_total_amount_micros = args[:minimum_budget_total_amount_micros] if args.key?(:minimum_budget_total_amount_micros)
end