Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorDetails
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Additional error details.
Instance Attribute Summary collapse
-
#budget_per_day_minimum_error_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails
Error details for a budget below per-day minimum error.
-
#policy_finding_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsPolicyFindingDetails
Error returned as part of a mutate response.
-
#policy_violation_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsPolicyViolationDetails
Error returned as part of a mutate response.
-
#quota_error_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsQuotaErrorDetails
Additional quota error details when there is QuotaError.
-
#resource_count_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsResourceCountDetails
Error details returned when an resource count limit was exceeded.
-
#unpublished_error_code ⇒ String
The error code that should have been returned, but wasn't.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsErrorDetails
constructor
A new instance of GoogleAdsSearchads360V23ErrorsErrorDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsErrorDetails
Returns a new instance of GoogleAdsSearchads360V23ErrorsErrorDetails.
14598 14599 14600 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14598 def initialize(**args) update!(**args) end |
Instance Attribute Details
#budget_per_day_minimum_error_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails
Error details for a budget below per-day minimum error.
Corresponds to the JSON property budgetPerDayMinimumErrorDetails
14568 14569 14570 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14568 def budget_per_day_minimum_error_details @budget_per_day_minimum_error_details end |
#policy_finding_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsPolicyFindingDetails
Error returned as part of a mutate response. This error indicates one or more
policy findings in the fields of a resource.
Corresponds to the JSON property policyFindingDetails
14574 14575 14576 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14574 def policy_finding_details @policy_finding_details end |
#policy_violation_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsPolicyViolationDetails
Error returned as part of a mutate response. This error indicates single
policy violation by some text in one of the fields.
Corresponds to the JSON property policyViolationDetails
14580 14581 14582 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14580 def policy_violation_details @policy_violation_details end |
#quota_error_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsQuotaErrorDetails
Additional quota error details when there is QuotaError.
Corresponds to the JSON property quotaErrorDetails
14585 14586 14587 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14585 def quota_error_details @quota_error_details end |
#resource_count_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsResourceCountDetails
Error details returned when an resource count limit was exceeded.
Corresponds to the JSON property resourceCountDetails
14590 14591 14592 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14590 def resource_count_details @resource_count_details end |
#unpublished_error_code ⇒ String
The error code that should have been returned, but wasn't. This is used when
the error code is not published in the client specified version.
Corresponds to the JSON property unpublishedErrorCode
14596 14597 14598 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14596 def unpublished_error_code @unpublished_error_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14603 14604 14605 14606 14607 14608 14609 14610 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14603 def update!(**args) @budget_per_day_minimum_error_details = args[:budget_per_day_minimum_error_details] if args.key?(:budget_per_day_minimum_error_details) @policy_finding_details = args[:policy_finding_details] if args.key?(:policy_finding_details) @policy_violation_details = args[:policy_violation_details] if args.key?(:policy_violation_details) @quota_error_details = args[:quota_error_details] if args.key?(:quota_error_details) @resource_count_details = args[:resource_count_details] if args.key?(:resource_count_details) @unpublished_error_code = args[:unpublished_error_code] if args.key?(:unpublished_error_code) end |