Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Additional error details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsErrorDetails

Returns a new instance of GoogleAdsSearchads360V23ErrorsErrorDetails.



14472
14473
14474
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14472

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_per_day_minimum_error_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsBudgetPerDayMinimumErrorDetails

Error details for a budget below per-day minimum error. Corresponds to the JSON property budgetPerDayMinimumErrorDetails



14442
14443
14444
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14442

def budget_per_day_minimum_error_details
  @budget_per_day_minimum_error_details
end

#policy_finding_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsPolicyFindingDetails

Error returned as part of a mutate response. This error indicates one or more policy findings in the fields of a resource. Corresponds to the JSON property policyFindingDetails



14448
14449
14450
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14448

def policy_finding_details
  @policy_finding_details
end

#policy_violation_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsPolicyViolationDetails

Error returned as part of a mutate response. This error indicates single policy violation by some text in one of the fields. Corresponds to the JSON property policyViolationDetails



14454
14455
14456
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14454

def policy_violation_details
  @policy_violation_details
end

#quota_error_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsQuotaErrorDetails

Additional quota error details when there is QuotaError. Corresponds to the JSON property quotaErrorDetails



14459
14460
14461
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14459

def quota_error_details
  @quota_error_details
end

#resource_count_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsResourceCountDetails

Error details returned when an resource count limit was exceeded. Corresponds to the JSON property resourceCountDetails



14464
14465
14466
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14464

def resource_count_details
  @resource_count_details
end

#unpublished_error_codeString

The error code that should have been returned, but wasn't. This is used when the error code is not published in the client specified version. Corresponds to the JSON property unpublishedErrorCode

Returns:

  • (String)


14470
14471
14472
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14470

def unpublished_error_code
  @unpublished_error_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14477
14478
14479
14480
14481
14482
14483
14484
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14477

def update!(**args)
  @budget_per_day_minimum_error_details = args[:budget_per_day_minimum_error_details] if args.key?(:budget_per_day_minimum_error_details)
  @policy_finding_details = args[:policy_finding_details] if args.key?(:policy_finding_details)
  @policy_violation_details = args[:policy_violation_details] if args.key?(:policy_violation_details)
  @quota_error_details = args[:quota_error_details] if args.key?(:quota_error_details)
  @resource_count_details = args[:resource_count_details] if args.key?(:resource_count_details)
  @unpublished_error_code = args[:unpublished_error_code] if args.key?(:unpublished_error_code)
end