Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Describes the part of the request proto that caused the error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsErrorLocation

Returns a new instance of GoogleAdsSearchads360V23ErrorsErrorLocation.



14496
14497
14498
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_path_elementsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement>

A field path that indicates which field was invalid in the request. Corresponds to the JSON property fieldPathElements



14494
14495
14496
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14494

def field_path_elements
  @field_path_elements
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14501
14502
14503
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14501

def update!(**args)
  @field_path_elements = args[:field_path_elements] if args.key?(:field_path_elements)
end