Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A part of a field path.
Instance Attribute Summary collapse
-
#field_name ⇒ String
The name of a field or a oneof Corresponds to the JSON property
fieldName. -
#index ⇒ Fixnum
If field_name is a repeated field, this is the element that failed Corresponds to the JSON property
index.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement
constructor
A new instance of GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement
Returns a new instance of GoogleAdsSearchads360V23ErrorsErrorLocationFieldPathElement.
13350 13351 13352 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13350 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_name ⇒ String
The name of a field or a oneof
Corresponds to the JSON property fieldName
13343 13344 13345 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13343 def field_name @field_name end |
#index ⇒ Fixnum
If field_name is a repeated field, this is the element that failed
Corresponds to the JSON property index
13348 13349 13350 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13348 def index @index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13355 13356 13357 13358 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 13355 def update!(**args) @field_name = args[:field_name] if args.key?(:field_name) @index = args[:index] if args.key?(:index) end |