Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ErrorsPolicyViolationDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Error returned as part of a mutate response. This error indicates single policy violation by some text in one of the fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ErrorsPolicyViolationDetails

Returns a new instance of GoogleAdsSearchads360V23ErrorsPolicyViolationDetails.



14555
14556
14557
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14555

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_policy_descriptionString

Human readable description of policy violation. Corresponds to the JSON property externalPolicyDescription

Returns:

  • (String)


14536
14537
14538
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14536

def external_policy_description
  @external_policy_description
end

#external_policy_nameString

Human readable name of the policy. Corresponds to the JSON property externalPolicyName

Returns:

  • (String)


14541
14542
14543
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14541

def external_policy_name
  @external_policy_name
end

#is_exemptibleBoolean Also known as: is_exemptible?

Whether user can file an exemption request for this violation. Corresponds to the JSON property isExemptible

Returns:

  • (Boolean)


14546
14547
14548
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14546

def is_exemptible
  @is_exemptible
end

#keyGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyViolationKey

Key of the violation. The key is used for referring to a violation when filing an exemption request. Corresponds to the JSON property key



14553
14554
14555
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14553

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14560
14561
14562
14563
14564
14565
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14560

def update!(**args)
  @external_policy_description = args[:external_policy_description] if args.key?(:external_policy_description)
  @external_policy_name = args[:external_policy_name] if args.key?(:external_policy_name)
  @is_exemptible = args[:is_exemptible] if args.key?(:is_exemptible)
  @key = args[:key] if args.key?(:key)
end