Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a view of BiddingStrategies owned by and shared with the customer. In contrast to BiddingStrategy, this resource includes strategies owned by managers of the customer and shared with this customer - in addition to strategies owned by this customer. This resource does not provide metrics and only exposes a limited subset of the BiddingStrategy attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategy

Returns a new instance of GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategy.



19160
19161
19162
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. The ID of the bidding strategy. Corresponds to the JSON property id

Returns:

  • (Fixnum)


19095
19096
19097
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19095

def id
  @id
end

#maximize_conversion_valueGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversionValue

An automated bidding strategy to help get the most conversion value for your campaigns while spending your budget. Corresponds to the JSON property maximizeConversionValue



19101
19102
19103
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19101

def maximize_conversion_value
  @maximize_conversion_value
end

#maximize_conversionsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversions

An automated bidding strategy to help get the most conversions for your campaigns while spending your budget. Corresponds to the JSON property maximizeConversions



19107
19108
19109
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19107

def maximize_conversions
  @maximize_conversions
end

#nameString

Output only. The name of the bidding strategy. Corresponds to the JSON property name

Returns:

  • (String)


19112
19113
19114
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19112

def name
  @name
end

#owner_customer_idFixnum

Output only. The ID of the Customer which owns the bidding strategy. Corresponds to the JSON property ownerCustomerId

Returns:

  • (Fixnum)


19117
19118
19119
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19117

def owner_customer_id
  @owner_customer_id
end

#owner_descriptive_nameString

Output only. descriptive_name of the Customer which owns the bidding strategy. Corresponds to the JSON property ownerDescriptiveName

Returns:

  • (String)


19122
19123
19124
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19122

def owner_descriptive_name
  @owner_descriptive_name
end

#resource_nameString

Output only. The resource name of the accessible bidding strategy. AccessibleBiddingStrategy resource names have the form: customers/ customer_id/accessibleBiddingStrategies/bidding_strategy_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


19129
19130
19131
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19129

def resource_name
  @resource_name
end

#target_cpaGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetCpa

An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set. Corresponds to the JSON property targetCpa



19135
19136
19137
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19135

def target_cpa
  @target_cpa
end

#target_impression_shareGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetImpressionShare

An automated bidding strategy that sets bids so that a certain percentage of search ads are shown at the top of the first page (or other targeted location). Corresponds to the JSON property targetImpressionShare



19141
19142
19143
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19141

def target_impression_share
  @target_impression_share
end

#target_roasGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetRoas

An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS). Corresponds to the JSON property targetRoas



19147
19148
19149
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19147

def target_roas
  @target_roas
end

#target_spendGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetSpend

An automated bid strategy that sets your bids to help get as many clicks as possible within your budget. Corresponds to the JSON property targetSpend



19153
19154
19155
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19153

def target_spend
  @target_spend
end

#typeString

Output only. The type of the bidding strategy. Corresponds to the JSON property type

Returns:

  • (String)


19158
19159
19160
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19158

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19165
19166
19167
19168
19169
19170
19171
19172
19173
19174
19175
19176
19177
19178
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19165

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @maximize_conversion_value = args[:maximize_conversion_value] if args.key?(:maximize_conversion_value)
  @maximize_conversions = args[:maximize_conversions] if args.key?(:maximize_conversions)
  @name = args[:name] if args.key?(:name)
  @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id)
  @owner_descriptive_name = args[:owner_descriptive_name] if args.key?(:owner_descriptive_name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @target_cpa = args[:target_cpa] if args.key?(:target_cpa)
  @target_impression_share = args[:target_impression_share] if args.key?(:target_impression_share)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
  @target_spend = args[:target_spend] if args.key?(:target_spend)
  @type = args[:type] if args.key?(:type)
end