Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversionValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An automated bidding strategy to help get the most conversion value for your campaigns while spending your budget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversionValue

Returns a new instance of GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyMaximizeConversionValue.



14793
14794
14795
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_roasFloat

Output only. The target return on ad spend (ROAS) option. If set, the bid strategy will maximize revenue while averaging the target return on ad spend. If the target ROAS is high, the bid strategy may not be able to spend the full budget. If the target ROAS is not set, the bid strategy will aim to achieve the highest possible ROAS for the budget. Corresponds to the JSON property targetRoas

Returns:

  • (Float)


14791
14792
14793
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14791

def target_roas
  @target_roas
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14798
14799
14800
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14798

def update!(**args)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
end