Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetCpa
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetCpa
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set.
Instance Attribute Summary collapse
-
#target_cpa_micros ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetCpa
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetCpa.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetCpa
Returns a new instance of GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetCpa.
14835 14836 14837 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14835 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_cpa_micros ⇒ Fixnum
Output only. Average CPA target. This target should be greater than or equal
to minimum billable unit based on the currency for the account.
Corresponds to the JSON property targetCpaMicros
14833 14834 14835 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14833 def target_cpa_micros @target_cpa_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14840 14841 14842 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14840 def update!(**args) @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros) end |