Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetCpa

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An automated bid strategy that sets bids to help get as many conversions as possible at the target cost-per-acquisition (CPA) you set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetCpa

Returns a new instance of GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetCpa.



14769
14770
14771
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_cpa_microsFixnum

Output only. Average CPA target. This target should be greater than or equal to minimum billable unit based on the currency for the account. Corresponds to the JSON property targetCpaMicros

Returns:

  • (Fixnum)


14767
14768
14769
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14767

def target_cpa_micros
  @target_cpa_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14774
14775
14776
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14774

def update!(**args)
  @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros)
end