Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetRoas
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetRoas
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An automated bidding strategy that helps you maximize revenue while averaging a specific target return on ad spend (ROAS).
Instance Attribute Summary collapse
-
#target_roas ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetRoas
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetRoas.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetRoas
Returns a new instance of GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetRoas.
14824 14825 14826 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14824 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_roas ⇒ Float
Output only. The chosen revenue (based on conversion data) per unit of spend.
Corresponds to the JSON property targetRoas
14822 14823 14824 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14822 def target_roas @target_roas end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14829 14830 14831 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14829 def update!(**args) @target_roas = args[:target_roas] if args.key?(:target_roas) end |