Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetSpend
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetSpend
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An automated bid strategy that sets your bids to help get as many clicks as possible within your budget.
Instance Attribute Summary collapse
-
#cpc_bid_ceiling_micros ⇒ Fixnum
Output only.
-
#target_spend_micros ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetSpend
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetSpend.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetSpend
Returns a new instance of GoogleAdsSearchads360V23ResourcesAccessibleBiddingStrategyTargetSpend.
14921 14922 14923 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpc_bid_ceiling_micros ⇒ Fixnum
Output only. Maximum bid limit that can be set by the bid strategy. The limit
applies to all keywords managed by the strategy.
Corresponds to the JSON property cpcBidCeilingMicros
14909 14910 14911 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14909 def cpc_bid_ceiling_micros @cpc_bid_ceiling_micros end |
#target_spend_micros ⇒ Fixnum
Output only. The spend target under which to maximize clicks. A TargetSpend
bidder will attempt to spend the smaller of this value or the natural
throttling spend amount. If not specified, the budget is used as the spend
target. This field is deprecated and should no longer be used. See https://ads-
developers.googleblog.com/2020/05/reminder-about-sunset-creation-of.html for
details.
Corresponds to the JSON property targetSpendMicros
14919 14920 14921 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14919 def target_spend_micros @target_spend_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14926 14927 14928 14929 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14926 def update!(**args) @cpc_bid_ceiling_micros = args[:cpc_bid_ceiling_micros] if args.key?(:cpc_bid_ceiling_micros) @target_spend_micros = args[:target_spend_micros] if args.key?(:target_spend_micros) end |