Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccountBudgetPendingAccountBudgetProposal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A pending proposal associated with the enclosing account-level budget, if applicable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccountBudgetPendingAccountBudgetProposal

Returns a new instance of GoogleAdsSearchads360V23ResourcesAccountBudgetPendingAccountBudgetProposal.



14932
14933
14934
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14932

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_budget_proposalString

Output only. The resource name of the proposal. AccountBudgetProposal resource names have the form: customers/customer_id/accountBudgetProposals/ account_budget_proposal_id` Corresponds to the JSON propertyaccountBudgetProposal`

Returns:

  • (String)


14876
14877
14878
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14876

def 
  @account_budget_proposal
end

#creation_date_timeString

Output only. The time when this account-level budget proposal was created. Formatted as yyyy-MM-dd HH:mm:ss. Corresponds to the JSON property creationDateTime

Returns:

  • (String)


14882
14883
14884
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14882

def creation_date_time
  @creation_date_time
end

#end_date_timeString

Output only. The end time in yyyy-MM-dd HH:mm:ss format. Corresponds to the JSON property endDateTime

Returns:

  • (String)


14887
14888
14889
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14887

def end_date_time
  @end_date_time
end

#end_time_typeString

Output only. The end time as a well-defined type, for example, FOREVER. Corresponds to the JSON property endTimeType

Returns:

  • (String)


14892
14893
14894
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14892

def end_time_type
  @end_time_type
end

#nameString

Output only. The name to assign to the account-level budget. Corresponds to the JSON property name

Returns:

  • (String)


14897
14898
14899
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14897

def name
  @name
end

#notesString

Output only. Notes associated with this budget. Corresponds to the JSON property notes

Returns:

  • (String)


14902
14903
14904
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14902

def notes
  @notes
end

#proposal_typeString

Output only. The type of this proposal, for example, END to end the budget associated with this proposal. Corresponds to the JSON property proposalType

Returns:

  • (String)


14908
14909
14910
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14908

def proposal_type
  @proposal_type
end

#purchase_order_numberString

Output only. A purchase order number is a value that helps users reference this budget in their monthly invoices. Corresponds to the JSON property purchaseOrderNumber

Returns:

  • (String)


14914
14915
14916
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14914

def purchase_order_number
  @purchase_order_number
end

#spending_limit_microsFixnum

Output only. The spending limit in micros. One million is equivalent to one unit. Corresponds to the JSON property spendingLimitMicros

Returns:

  • (Fixnum)


14920
14921
14922
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14920

def spending_limit_micros
  @spending_limit_micros
end

#spending_limit_typeString

Output only. The spending limit as a well-defined type, for example, INFINITE. Corresponds to the JSON property spendingLimitType

Returns:

  • (String)


14925
14926
14927
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14925

def spending_limit_type
  @spending_limit_type
end

#start_date_timeString

Output only. The start time in yyyy-MM-dd HH:mm:ss format. Corresponds to the JSON property startDateTime

Returns:

  • (String)


14930
14931
14932
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14930

def start_date_time
  @start_date_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14937
14938
14939
14940
14941
14942
14943
14944
14945
14946
14947
14948
14949
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14937

def update!(**args)
  @account_budget_proposal = args[:account_budget_proposal] if args.key?(:account_budget_proposal)
  @creation_date_time = args[:creation_date_time] if args.key?(:creation_date_time)
  @end_date_time = args[:end_date_time] if args.key?(:end_date_time)
  @end_time_type = args[:end_time_type] if args.key?(:end_time_type)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @proposal_type = args[:proposal_type] if args.key?(:proposal_type)
  @purchase_order_number = args[:purchase_order_number] if args.key?(:purchase_order_number)
  @spending_limit_micros = args[:spending_limit_micros] if args.key?(:spending_limit_micros)
  @spending_limit_type = args[:spending_limit_type] if args.key?(:spending_limit_type)
  @start_date_time = args[:start_date_time] if args.key?(:start_date_time)
end