Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccountBudgetProposal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An account-level budget proposal. All fields prefixed with 'proposed' may not necessarily be applied directly. For example, proposed spending limits may be adjusted before their application. This is true if the 'proposed' field has an 'approved' counterpart, for example, spending limits. Note that the proposal type (proposal_type) changes which fields are required and which must remain empty.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccountBudgetProposal

Returns a new instance of GoogleAdsSearchads360V23ResourcesAccountBudgetProposal.



19504
19505
19506
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_budgetString

Immutable. The resource name of the account-level budget associated with this proposal. Corresponds to the JSON property accountBudget

Returns:

  • (String)


19382
19383
19384
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19382

def 
  @account_budget
end

#approval_date_timeString

Output only. The date time when this account-level budget was approved, if applicable. Corresponds to the JSON property approvalDateTime

Returns:

  • (String)


19388
19389
19390
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19388

def approval_date_time
  @approval_date_time
end

#approved_end_date_timeString

Output only. The approved end date time in yyyy-mm-dd hh:mm:ss format. Corresponds to the JSON property approvedEndDateTime

Returns:

  • (String)


19393
19394
19395
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19393

def approved_end_date_time
  @approved_end_date_time
end

#approved_end_time_typeString

Output only. The approved end date time as a well-defined type, for example, FOREVER. Corresponds to the JSON property approvedEndTimeType

Returns:

  • (String)


19399
19400
19401
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19399

def approved_end_time_type
  @approved_end_time_type
end

#approved_spending_limit_microsFixnum

Output only. The approved spending limit in micros. One million is equivalent to one unit. Corresponds to the JSON property approvedSpendingLimitMicros

Returns:

  • (Fixnum)


19405
19406
19407
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19405

def approved_spending_limit_micros
  @approved_spending_limit_micros
end

#approved_spending_limit_typeString

Output only. The approved spending limit as a well-defined type, for example, INFINITE. Corresponds to the JSON property approvedSpendingLimitType

Returns:

  • (String)


19411
19412
19413
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19411

def approved_spending_limit_type
  @approved_spending_limit_type
end

#approved_start_date_timeString

Output only. The approved start date time in yyyy-mm-dd hh:mm:ss format. Corresponds to the JSON property approvedStartDateTime

Returns:

  • (String)


19416
19417
19418
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19416

def approved_start_date_time
  @approved_start_date_time
end

#billing_setupString

Immutable. The resource name of the billing setup associated with this proposal. Corresponds to the JSON property billingSetup

Returns:

  • (String)


19422
19423
19424
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19422

def billing_setup
  @billing_setup
end

#creation_date_timeString

Output only. The date time when this account-level budget proposal was created, which is not the same as its approval date time, if applicable. Corresponds to the JSON property creationDateTime

Returns:

  • (String)


19428
19429
19430
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19428

def creation_date_time
  @creation_date_time
end

#idFixnum

Output only. The ID of the proposal. Corresponds to the JSON property id

Returns:

  • (Fixnum)


19433
19434
19435
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19433

def id
  @id
end

#proposal_typeString

Immutable. The type of this proposal, for example, END to end the budget associated with this proposal. Corresponds to the JSON property proposalType

Returns:

  • (String)


19439
19440
19441
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19439

def proposal_type
  @proposal_type
end

#proposed_end_date_timeString

Immutable. The proposed end date time in yyyy-mm-dd hh:mm:ss format. Corresponds to the JSON property proposedEndDateTime

Returns:

  • (String)


19444
19445
19446
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19444

def proposed_end_date_time
  @proposed_end_date_time
end

#proposed_end_time_typeString

Immutable. The proposed end date time as a well-defined type, for example, FOREVER. Corresponds to the JSON property proposedEndTimeType

Returns:

  • (String)


19450
19451
19452
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19450

def proposed_end_time_type
  @proposed_end_time_type
end

#proposed_nameString

Immutable. The name to assign to the account-level budget. Corresponds to the JSON property proposedName

Returns:

  • (String)


19455
19456
19457
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19455

def proposed_name
  @proposed_name
end

#proposed_notesString

Immutable. Notes associated with this budget. Corresponds to the JSON property proposedNotes

Returns:

  • (String)


19460
19461
19462
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19460

def proposed_notes
  @proposed_notes
end

#proposed_purchase_order_numberString

Immutable. A purchase order number is a value that enables the user to help them reference this budget in their monthly invoices. Corresponds to the JSON property proposedPurchaseOrderNumber

Returns:

  • (String)


19466
19467
19468
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19466

def proposed_purchase_order_number
  @proposed_purchase_order_number
end

#proposed_spending_limit_microsFixnum

Immutable. The proposed spending limit in micros. One million is equivalent to one unit. Corresponds to the JSON property proposedSpendingLimitMicros

Returns:

  • (Fixnum)


19472
19473
19474
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19472

def proposed_spending_limit_micros
  @proposed_spending_limit_micros
end

#proposed_spending_limit_typeString

Immutable. The proposed spending limit as a well-defined type, for example, INFINITE. Corresponds to the JSON property proposedSpendingLimitType

Returns:

  • (String)


19478
19479
19480
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19478

def proposed_spending_limit_type
  @proposed_spending_limit_type
end

#proposed_start_date_timeString

Immutable. The proposed start date time in yyyy-mm-dd hh:mm:ss format. Corresponds to the JSON property proposedStartDateTime

Returns:

  • (String)


19483
19484
19485
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19483

def proposed_start_date_time
  @proposed_start_date_time
end

#proposed_start_time_typeString

Immutable. The proposed start date time as a well-defined type, for example, NOW. Corresponds to the JSON property proposedStartTimeType

Returns:

  • (String)


19489
19490
19491
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19489

def proposed_start_time_type
  @proposed_start_time_type
end

#resource_nameString

Immutable. The resource name of the proposal. AccountBudgetProposal resource names have the form: customers/customer_id/accountBudgetProposals/ account_budget_proposal_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


19496
19497
19498
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19496

def resource_name
  @resource_name
end

#statusString

Output only. The status of this proposal. When a new proposal is created, the status defaults to PENDING. Corresponds to the JSON property status

Returns:

  • (String)


19502
19503
19504
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19502

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19509
19510
19511
19512
19513
19514
19515
19516
19517
19518
19519
19520
19521
19522
19523
19524
19525
19526
19527
19528
19529
19530
19531
19532
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19509

def update!(**args)
  @account_budget = args[:account_budget] if args.key?(:account_budget)
  @approval_date_time = args[:approval_date_time] if args.key?(:approval_date_time)
  @approved_end_date_time = args[:approved_end_date_time] if args.key?(:approved_end_date_time)
  @approved_end_time_type = args[:approved_end_time_type] if args.key?(:approved_end_time_type)
  @approved_spending_limit_micros = args[:approved_spending_limit_micros] if args.key?(:approved_spending_limit_micros)
  @approved_spending_limit_type = args[:approved_spending_limit_type] if args.key?(:approved_spending_limit_type)
  @approved_start_date_time = args[:approved_start_date_time] if args.key?(:approved_start_date_time)
  @billing_setup = args[:billing_setup] if args.key?(:billing_setup)
  @creation_date_time = args[:creation_date_time] if args.key?(:creation_date_time)
  @id = args[:id] if args.key?(:id)
  @proposal_type = args[:proposal_type] if args.key?(:proposal_type)
  @proposed_end_date_time = args[:proposed_end_date_time] if args.key?(:proposed_end_date_time)
  @proposed_end_time_type = args[:proposed_end_time_type] if args.key?(:proposed_end_time_type)
  @proposed_name = args[:proposed_name] if args.key?(:proposed_name)
  @proposed_notes = args[:proposed_notes] if args.key?(:proposed_notes)
  @proposed_purchase_order_number = args[:proposed_purchase_order_number] if args.key?(:proposed_purchase_order_number)
  @proposed_spending_limit_micros = args[:proposed_spending_limit_micros] if args.key?(:proposed_spending_limit_micros)
  @proposed_spending_limit_type = args[:proposed_spending_limit_type] if args.key?(:proposed_spending_limit_type)
  @proposed_start_date_time = args[:proposed_start_date_time] if args.key?(:proposed_start_date_time)
  @proposed_start_time_type = args[:proposed_start_time_type] if args.key?(:proposed_start_time_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end