Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccountLink
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccountLink
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents the data sharing connection between a Google Ads account and another account
Instance Attribute Summary collapse
-
#account_link_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
The status of the link.
-
#third_party_app_analytics ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLinkIdentifier
The identifiers of a Third Party App Analytics Link.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccountLink
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAccountLink.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccountLink
Returns a new instance of GoogleAdsSearchads360V23ResourcesAccountLink.
19632 19633 19634 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19632 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_link_id ⇒ Fixnum
Output only. The ID of the link. This field is read only.
Corresponds to the JSON property accountLinkId
19609 19610 19611 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19609 def account_link_id @account_link_id end |
#resource_name ⇒ String
Immutable. Resource name of the account link. AccountLink resource names have
the form: customers/customer_id/accountLinks/account_link_id`
Corresponds to the JSON propertyresourceName`
19615 19616 19617 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19615 def resource_name @resource_name end |
#status ⇒ String
The status of the link.
Corresponds to the JSON property status
19620 19621 19622 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19620 def status @status end |
#third_party_app_analytics ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLinkIdentifier
The identifiers of a Third Party App Analytics Link.
Corresponds to the JSON property thirdPartyAppAnalytics
19625 19626 19627 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19625 def third_party_app_analytics @third_party_app_analytics end |
#type ⇒ String
Output only. The type of the linked account.
Corresponds to the JSON property type
19630 19631 19632 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19630 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19637 19638 19639 19640 19641 19642 19643 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19637 def update!(**args) @account_link_id = args[:account_link_id] if args.key?(:account_link_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @third_party_app_analytics = args[:third_party_app_analytics] if args.key?(:third_party_app_analytics) @type = args[:type] if args.key?(:type) end |