Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccountLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents the data sharing connection between a Google Ads account and another account

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAccountLink

Returns a new instance of GoogleAdsSearchads360V23ResourcesAccountLink.



19566
19567
19568
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19566

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Output only. The ID of the link. This field is read only. Corresponds to the JSON property accountLinkId

Returns:

  • (Fixnum)


19543
19544
19545
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19543

def 
  @account_link_id
end

#resource_nameString

Immutable. Resource name of the account link. AccountLink resource names have the form: customers/customer_id/accountLinks/account_link_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


19549
19550
19551
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19549

def resource_name
  @resource_name
end

#statusString

The status of the link. Corresponds to the JSON property status

Returns:

  • (String)


19554
19555
19556
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19554

def status
  @status
end

#third_party_app_analyticsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLinkIdentifier

The identifiers of a Third Party App Analytics Link. Corresponds to the JSON property thirdPartyAppAnalytics



19559
19560
19561
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19559

def third_party_app_analytics
  @third_party_app_analytics
end

#typeString

Output only. The type of the linked account. Corresponds to the JSON property type

Returns:

  • (String)


19564
19565
19566
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19564

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19571
19572
19573
19574
19575
19576
19577
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19571

def update!(**args)
  @account_link_id = args[:account_link_id] if args.key?(:account_link_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @third_party_app_analytics = args[:third_party_app_analytics] if args.key?(:third_party_app_analytics)
  @type = args[:type] if args.key?(:type)
end