Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAd
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An ad.
Instance Attribute Summary collapse
-
#added_by_google_ads ⇒ Boolean
(also: #added_by_google_ads?)
Output only.
-
#app_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppAdInfo
An app ad.
-
#app_engagement_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppEngagementAdInfo
App engagement ads allow you to write text encouraging a specific action in the app, like checking in, making a purchase, or booking a flight.
-
#app_pre_registration_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppPreRegistrationAdInfo
App pre-registration ads link to your app or game listing on Google Play, and can run on Google Play, on YouTube (in-stream only), and within other apps and mobile websites on the Display Network.
-
#demand_gen_carousel_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenCarouselAdInfo
A Demand Gen carousel ad.
-
#demand_gen_multi_asset_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenMultiAssetAdInfo
A Demand Gen multi asset ad.
-
#demand_gen_product_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenProductAdInfo
A Demand Gen product ad.
-
#demand_gen_video_responsive_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenVideoResponsiveAdInfo
A Demand Gen video responsive ad.
-
#device_preference ⇒ String
The device preference for the ad.
-
#display_upload_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDisplayUploadAdInfo
A generic type of display ad.
-
#display_url ⇒ String
The URL that appears in the ad description for some ad formats.
-
#expanded_dynamic_search_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonExpandedDynamicSearchAdInfo
An expanded dynamic search ad.
-
#expanded_text_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonExpandedTextAdInfo
An expanded text ad.
-
#final_app_urls ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFinalAppUrl>
A list of final app URLs that will be used on mobile if the user has the specific app installed.
-
#final_mobile_urls ⇒ Array<String>
The list of possible final mobile URLs after all cross-domain redirects for the ad.
-
#final_url_suffix ⇒ String
The suffix to use when constructing a final URL.
-
#final_urls ⇒ Array<String>
The list of possible final URLs after all cross-domain redirects for the ad.
-
#hotel_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelAdInfo
A hotel ad.
-
#id ⇒ Fixnum
Output only.
-
#image_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonImageAdInfo
An image ad.
-
#legacy_app_install_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo
A legacy app install ad that only can be used by a few select customers.
-
#legacy_responsive_display_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLegacyResponsiveDisplayAdInfo
A legacy responsive display ad.
-
#local_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalAdInfo
A local ad.
-
#name ⇒ String
Immutable.
-
#product_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360ProductAdInfo
A Search Ads 360 product ad.
-
#resource_name ⇒ String
Immutable.
-
#responsive_display_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveDisplayAdInfo
A responsive display ad.
-
#responsive_search_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveSearchAdInfo
A responsive search ad.
-
#search_ads360_expanded_dynamic_search_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360ExpandedDynamicSearchAdInfo
An expanded dynamic search ad.
-
#search_ads360_expanded_text_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360ExpandedTextAdInfo
A Search Ads 360 expanded text ad.
-
#search_ads360_responsive_search_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360ResponsiveSearchAdInfo
A Search Ads 360 responsive search ad.
-
#search_ads360_text_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360TextAdInfo
A Search Ads 360 text ad.
-
#shopping_comparison_listing_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonShoppingComparisonListingAdInfo
A Shopping Comparison Listing ad.
-
#shopping_product_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonShoppingProductAdInfo
A standard Shopping ad.
-
#shopping_smart_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonShoppingSmartAdInfo
A Smart Shopping ad.
-
#smart_campaign_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSmartCampaignAdInfo
A Smart campaign ad.
-
#system_managed_resource_source ⇒ String
Output only.
-
#text_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTextAdInfo
A text ad.
-
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
-
#travel_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTravelAdInfo
A travel ad.
-
#type ⇒ String
Output only.
-
#url_collections ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUrlCollection>
Additional URLs for the ad that are tagged with a unique identifier that can be referenced from other fields in the ad.
-
#url_custom_parameters ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>
The list of mappings that can be used to substitute custom parameter tags in a
tracking_url_template,final_urls, ormobile_final_urls.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAd
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAd
Returns a new instance of GoogleAdsSearchads360V23ResourcesAd.
19833 19834 19835 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19833 def initialize(**args) update!(**args) end |
Instance Attribute Details
#added_by_google_ads ⇒ Boolean Also known as: added_by_google_ads?
Output only. Indicates if this ad was automatically added by Google Ads and
not by a user. For example, this could happen when ads are automatically
created as suggestions for new ads based on knowledge of how existing ads are
performing.
Corresponds to the JSON property addedByGoogleAds
19590 19591 19592 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19590 def added_by_google_ads @added_by_google_ads end |
#app_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppAdInfo
An app ad.
Corresponds to the JSON property appAd
19596 19597 19598 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19596 def app_ad @app_ad end |
#app_engagement_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppEngagementAdInfo
App engagement ads allow you to write text encouraging a specific action in
the app, like checking in, making a purchase, or booking a flight. They allow
you to send users to a specific part of your app where they can find what they'
re looking for easier and faster.
Corresponds to the JSON property appEngagementAd
19604 19605 19606 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19604 def app_engagement_ad @app_engagement_ad end |
#app_pre_registration_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppPreRegistrationAdInfo
App pre-registration ads link to your app or game listing on Google Play, and
can run on Google Play, on YouTube (in-stream only), and within other apps and
mobile websites on the Display Network. It will help capture people's interest
in your app or game and generate an early install base for your app or game
before a launch.
Corresponds to the JSON property appPreRegistrationAd
19613 19614 19615 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19613 def app_pre_registration_ad @app_pre_registration_ad end |
#demand_gen_carousel_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenCarouselAdInfo
A Demand Gen carousel ad.
Corresponds to the JSON property demandGenCarouselAd
19618 19619 19620 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19618 def demand_gen_carousel_ad @demand_gen_carousel_ad end |
#demand_gen_multi_asset_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenMultiAssetAdInfo
A Demand Gen multi asset ad.
Corresponds to the JSON property demandGenMultiAssetAd
19623 19624 19625 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19623 def demand_gen_multi_asset_ad @demand_gen_multi_asset_ad end |
#demand_gen_product_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenProductAdInfo
A Demand Gen product ad.
Corresponds to the JSON property demandGenProductAd
19628 19629 19630 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19628 def demand_gen_product_ad @demand_gen_product_ad end |
#demand_gen_video_responsive_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenVideoResponsiveAdInfo
A Demand Gen video responsive ad.
Corresponds to the JSON property demandGenVideoResponsiveAd
19633 19634 19635 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19633 def demand_gen_video_responsive_ad @demand_gen_video_responsive_ad end |
#device_preference ⇒ String
The device preference for the ad. You can only specify a preference for mobile
devices. When this preference is set the ad will be preferred over other ads
when being displayed on a mobile device. The ad can still be displayed on
other device types, for example, if no other ads are available. If unspecified
(no device preference), all devices are targeted. This is only supported by
some ad types.
Corresponds to the JSON property devicePreference
19643 19644 19645 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19643 def device_preference @device_preference end |
#display_upload_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDisplayUploadAdInfo
A generic type of display ad. The exact ad format is controlled by the
display_upload_product_type field, which determines what kinds of data need
to be included with the ad.
Corresponds to the JSON property displayUploadAd
19650 19651 19652 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19650 def display_upload_ad @display_upload_ad end |
#display_url ⇒ String
The URL that appears in the ad description for some ad formats.
Corresponds to the JSON property displayUrl
19655 19656 19657 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19655 def display_url @display_url end |
#expanded_dynamic_search_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonExpandedDynamicSearchAdInfo
An expanded dynamic search ad.
Corresponds to the JSON property expandedDynamicSearchAd
19660 19661 19662 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19660 def @expanded_dynamic_search_ad end |
#expanded_text_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonExpandedTextAdInfo
An expanded text ad.
Corresponds to the JSON property expandedTextAd
19665 19666 19667 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19665 def @expanded_text_ad end |
#final_app_urls ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonFinalAppUrl>
A list of final app URLs that will be used on mobile if the user has the
specific app installed.
Corresponds to the JSON property finalAppUrls
19671 19672 19673 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19671 def final_app_urls @final_app_urls end |
#final_mobile_urls ⇒ Array<String>
The list of possible final mobile URLs after all cross-domain redirects for
the ad.
Corresponds to the JSON property finalMobileUrls
19677 19678 19679 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19677 def final_mobile_urls @final_mobile_urls end |
#final_url_suffix ⇒ String
The suffix to use when constructing a final URL.
Corresponds to the JSON property finalUrlSuffix
19682 19683 19684 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19682 def final_url_suffix @final_url_suffix end |
#final_urls ⇒ Array<String>
The list of possible final URLs after all cross-domain redirects for the ad.
Corresponds to the JSON property finalUrls
19687 19688 19689 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19687 def final_urls @final_urls end |
#hotel_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelAdInfo
A hotel ad.
Corresponds to the JSON property hotelAd
19692 19693 19694 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19692 def hotel_ad @hotel_ad end |
#id ⇒ Fixnum
Output only. The ID of the ad.
Corresponds to the JSON property id
19697 19698 19699 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19697 def id @id end |
#image_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonImageAdInfo
An image ad.
Corresponds to the JSON property imageAd
19702 19703 19704 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19702 def image_ad @image_ad end |
#legacy_app_install_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLegacyAppInstallAdInfo
A legacy app install ad that only can be used by a few select customers.
Corresponds to the JSON property legacyAppInstallAd
19707 19708 19709 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19707 def legacy_app_install_ad @legacy_app_install_ad end |
#legacy_responsive_display_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLegacyResponsiveDisplayAdInfo
A legacy responsive display ad. Ads of this type are labeled 'Responsive ads'
in the Google Ads UI.
Corresponds to the JSON property legacyResponsiveDisplayAd
19713 19714 19715 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19713 def legacy_responsive_display_ad @legacy_responsive_display_ad end |
#local_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalAdInfo
A local ad.
Corresponds to the JSON property localAd
19718 19719 19720 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19718 def local_ad @local_ad end |
#name ⇒ String
Immutable. The name of the ad. This is only used to be able to identify the ad.
It does not need to be unique and does not affect the served ad.
Corresponds to the JSON property name
19724 19725 19726 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19724 def name @name end |
#product_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360ProductAdInfo
A Search Ads 360 product ad.
Corresponds to the JSON property productAd
19729 19730 19731 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19729 def product_ad @product_ad end |
#resource_name ⇒ String
Immutable. The resource name of the ad. Ad resource names have the form:
customers/customer_id/ads/ad_id`
Corresponds to the JSON propertyresourceName`
19735 19736 19737 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19735 def resource_name @resource_name end |
#responsive_display_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveDisplayAdInfo
A responsive display ad.
Corresponds to the JSON property responsiveDisplayAd
19740 19741 19742 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19740 def responsive_display_ad @responsive_display_ad end |
#responsive_search_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonResponsiveSearchAdInfo
A responsive search ad. Responsive search ads let you create an ad that adapts
to show more text, and more relevant messages, to your customers. Enter
multiple headlines and descriptions when creating a responsive search ad, and
over time, Google Ads will automatically test different combinations and learn
which combinations perform best. By adapting your ad's content to more closely
match potential customers' search terms, responsive search ads may improve
your campaign's performance. More information at https://support.google.com/
google-ads/answer/7684791
Corresponds to the JSON property responsiveSearchAd
19752 19753 19754 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19752 def responsive_search_ad @responsive_search_ad end |
#search_ads360_expanded_dynamic_search_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360ExpandedDynamicSearchAdInfo
An expanded dynamic search ad.
Corresponds to the JSON property searchAds360ExpandedDynamicSearchAd
19757 19758 19759 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19757 def @search_ads360_expanded_dynamic_search_ad end |
#search_ads360_expanded_text_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360ExpandedTextAdInfo
A Search Ads 360 expanded text ad.
Corresponds to the JSON property searchAds360ExpandedTextAd
19762 19763 19764 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19762 def @search_ads360_expanded_text_ad end |
#search_ads360_responsive_search_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360ResponsiveSearchAdInfo
A Search Ads 360 responsive search ad.
Corresponds to the JSON property searchAds360ResponsiveSearchAd
19767 19768 19769 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19767 def search_ads360_responsive_search_ad @search_ads360_responsive_search_ad end |
#search_ads360_text_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchAds360TextAdInfo
A Search Ads 360 text ad.
Corresponds to the JSON property searchAds360TextAd
19772 19773 19774 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19772 def search_ads360_text_ad @search_ads360_text_ad end |
#shopping_comparison_listing_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonShoppingComparisonListingAdInfo
A Shopping Comparison Listing ad.
Corresponds to the JSON property shoppingComparisonListingAd
19777 19778 19779 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19777 def shopping_comparison_listing_ad @shopping_comparison_listing_ad end |
#shopping_product_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonShoppingProductAdInfo
A standard Shopping ad.
Corresponds to the JSON property shoppingProductAd
19782 19783 19784 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19782 def shopping_product_ad @shopping_product_ad end |
#shopping_smart_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonShoppingSmartAdInfo
A Smart Shopping ad.
Corresponds to the JSON property shoppingSmartAd
19787 19788 19789 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19787 def shopping_smart_ad @shopping_smart_ad end |
#smart_campaign_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSmartCampaignAdInfo
A Smart campaign ad.
Corresponds to the JSON property smartCampaignAd
19792 19793 19794 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19792 def smart_campaign_ad @smart_campaign_ad end |
#system_managed_resource_source ⇒ String
Output only. If this ad is system managed, then this field will indicate the
source. This field is read-only.
Corresponds to the JSON property systemManagedResourceSource
19798 19799 19800 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19798 def system_managed_resource_source @system_managed_resource_source end |
#text_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTextAdInfo
A text ad.
Corresponds to the JSON property textAd
19803 19804 19805 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19803 def text_ad @text_ad end |
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
Corresponds to the JSON property trackingUrlTemplate
19808 19809 19810 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19808 def tracking_url_template @tracking_url_template end |
#travel_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTravelAdInfo
A travel ad.
Corresponds to the JSON property travelAd
19813 19814 19815 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19813 def travel_ad @travel_ad end |
#type ⇒ String
Output only. The type of ad.
Corresponds to the JSON property type
19818 19819 19820 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19818 def type @type end |
#url_collections ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUrlCollection>
Additional URLs for the ad that are tagged with a unique identifier that can
be referenced from other fields in the ad.
Corresponds to the JSON property urlCollections
19824 19825 19826 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19824 def url_collections @url_collections end |
#url_custom_parameters ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>
The list of mappings that can be used to substitute custom parameter tags in a
tracking_url_template, final_urls, or mobile_final_urls. For mutates,
use url custom parameter operations.
Corresponds to the JSON property urlCustomParameters
19831 19832 19833 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19831 def url_custom_parameters @url_custom_parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19838 19839 19840 19841 19842 19843 19844 19845 19846 19847 19848 19849 19850 19851 19852 19853 19854 19855 19856 19857 19858 19859 19860 19861 19862 19863 19864 19865 19866 19867 19868 19869 19870 19871 19872 19873 19874 19875 19876 19877 19878 19879 19880 19881 19882 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19838 def update!(**args) @added_by_google_ads = args[:added_by_google_ads] if args.key?(:added_by_google_ads) @app_ad = args[:app_ad] if args.key?(:app_ad) @app_engagement_ad = args[:app_engagement_ad] if args.key?(:app_engagement_ad) @app_pre_registration_ad = args[:app_pre_registration_ad] if args.key?(:app_pre_registration_ad) @demand_gen_carousel_ad = args[:demand_gen_carousel_ad] if args.key?(:demand_gen_carousel_ad) @demand_gen_multi_asset_ad = args[:demand_gen_multi_asset_ad] if args.key?(:demand_gen_multi_asset_ad) @demand_gen_product_ad = args[:demand_gen_product_ad] if args.key?(:demand_gen_product_ad) @demand_gen_video_responsive_ad = args[:demand_gen_video_responsive_ad] if args.key?(:demand_gen_video_responsive_ad) @device_preference = args[:device_preference] if args.key?(:device_preference) @display_upload_ad = args[:display_upload_ad] if args.key?(:display_upload_ad) @display_url = args[:display_url] if args.key?(:display_url) @expanded_dynamic_search_ad = args[:expanded_dynamic_search_ad] if args.key?(:expanded_dynamic_search_ad) @expanded_text_ad = args[:expanded_text_ad] if args.key?(:expanded_text_ad) @final_app_urls = args[:final_app_urls] if args.key?(:final_app_urls) @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @final_urls = args[:final_urls] if args.key?(:final_urls) @hotel_ad = args[:hotel_ad] if args.key?(:hotel_ad) @id = args[:id] if args.key?(:id) @image_ad = args[:image_ad] if args.key?(:image_ad) @legacy_app_install_ad = args[:legacy_app_install_ad] if args.key?(:legacy_app_install_ad) @legacy_responsive_display_ad = args[:legacy_responsive_display_ad] if args.key?(:legacy_responsive_display_ad) @local_ad = args[:local_ad] if args.key?(:local_ad) @name = args[:name] if args.key?(:name) @product_ad = args[:product_ad] if args.key?(:product_ad) @resource_name = args[:resource_name] if args.key?(:resource_name) @responsive_display_ad = args[:responsive_display_ad] if args.key?(:responsive_display_ad) @responsive_search_ad = args[:responsive_search_ad] if args.key?(:responsive_search_ad) @search_ads360_expanded_dynamic_search_ad = args[:search_ads360_expanded_dynamic_search_ad] if args.key?(:search_ads360_expanded_dynamic_search_ad) @search_ads360_expanded_text_ad = args[:search_ads360_expanded_text_ad] if args.key?(:search_ads360_expanded_text_ad) @search_ads360_responsive_search_ad = args[:search_ads360_responsive_search_ad] if args.key?(:search_ads360_responsive_search_ad) @search_ads360_text_ad = args[:search_ads360_text_ad] if args.key?(:search_ads360_text_ad) @shopping_comparison_listing_ad = args[:shopping_comparison_listing_ad] if args.key?(:shopping_comparison_listing_ad) @shopping_product_ad = args[:shopping_product_ad] if args.key?(:shopping_product_ad) @shopping_smart_ad = args[:shopping_smart_ad] if args.key?(:shopping_smart_ad) @smart_campaign_ad = args[:smart_campaign_ad] if args.key?(:smart_campaign_ad) @system_managed_resource_source = args[:system_managed_resource_source] if args.key?(:system_managed_resource_source) @text_ad = args[:text_ad] if args.key?(:text_ad) @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template) @travel_ad = args[:travel_ad] if args.key?(:travel_ad) @type = args[:type] if args.key?(:type) @url_collections = args[:url_collections] if args.key?(:url_collections) @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters) end |