Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An ad group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroup

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroup.



20280
20281
20282
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20280

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_rotation_modeString

The ad rotation mode of the ad group. Corresponds to the JSON property adRotationMode

Returns:

  • (String)


19966
19967
19968
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19966

def ad_rotation_mode
  @ad_rotation_mode
end

#ai_max_ad_group_settingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAiMaxAdGroupSetting

Settings for AI Max feature in standard search adgroups. Corresponds to the JSON property aiMaxAdGroupSetting



19971
19972
19973
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19971

def ai_max_ad_group_setting
  @ai_max_ad_group_setting
end

#audience_settingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAudienceSetting

Settings for the audience targeting. Corresponds to the JSON property audienceSetting



19976
19977
19978
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19976

def audience_setting
  @audience_setting
end

#base_ad_groupString

Output only. For draft or experiment ad groups, this field is the resource name of the base ad group from which this ad group was created. If a draft or experiment ad group does not have a base ad group, then this field is null. For base ad groups, this field equals the ad group resource name. This field is read-only. Corresponds to the JSON property baseAdGroup

Returns:

  • (String)


19985
19986
19987
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19985

def base_ad_group
  @base_ad_group
end

#campaignString

Immutable. The campaign to which the ad group belongs. Corresponds to the JSON property campaign

Returns:

  • (String)


19990
19991
19992
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19990

def campaign
  @campaign
end

#cpc_bid_microsFixnum

The maximum CPC (cost-per-click) bid. This field is used when the ad group's effective bidding strategy is Manual CPC. This field is not applicable and will be ignored if the ad group's campaign is using a portfolio bidding strategy. Corresponds to the JSON property cpcBidMicros

Returns:

  • (Fixnum)


19998
19999
20000
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19998

def cpc_bid_micros
  @cpc_bid_micros
end

#cpm_bid_microsFixnum

The maximum CPM (cost-per-thousand viewable impressions) bid. Corresponds to the JSON property cpmBidMicros

Returns:

  • (Fixnum)


20003
20004
20005
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20003

def cpm_bid_micros
  @cpm_bid_micros
end

#cpv_bid_microsFixnum

The CPV (cost-per-view) bid. Corresponds to the JSON property cpvBidMicros

Returns:

  • (Fixnum)


20008
20009
20010
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20008

def cpv_bid_micros
  @cpv_bid_micros
end

#creation_timeString

Output only. The timestamp when this ad_group was created. The timestamp is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. Corresponds to the JSON property creationTime

Returns:

  • (String)


20014
20015
20016
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20014

def creation_time
  @creation_time
end

#demand_gen_ad_group_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettings

Settings for Demand Gen ad groups. Corresponds to the JSON property demandGenAdGroupSettings



20019
20020
20021
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20019

def demand_gen_ad_group_settings
  @demand_gen_ad_group_settings
end

#display_custom_bid_dimensionString

Lets advertisers specify a targeting dimension on which to place absolute bids. This is only applicable for campaigns that target only the display network and not search. Corresponds to the JSON property displayCustomBidDimension

Returns:

  • (String)


20026
20027
20028
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20026

def display_custom_bid_dimension
  @display_custom_bid_dimension
end

#effective_cpc_bid_microsFixnum

Output only. Value will be same as that of the CPC (cost-per-click) bid value when the bidding strategy is one of manual cpc, enhanced cpc, page one promoted or target outrank share, otherwise the value will be null. Corresponds to the JSON property effectiveCpcBidMicros

Returns:

  • (Fixnum)


20033
20034
20035
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20033

def effective_cpc_bid_micros
  @effective_cpc_bid_micros
end

#effective_labelsArray<String>

Output only. The resource names of effective labels attached to this ad group. An effective label is a label inherited or directly assigned to this ad group. Corresponds to the JSON property effectiveLabels

Returns:

  • (Array<String>)


20039
20040
20041
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20039

def effective_labels
  @effective_labels
end

#effective_target_cpa_microsFixnum

Output only. The effective target CPA (cost-per-acquisition). This field is read-only. Corresponds to the JSON property effectiveTargetCpaMicros

Returns:

  • (Fixnum)


20045
20046
20047
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20045

def effective_target_cpa_micros
  @effective_target_cpa_micros
end

#effective_target_cpa_sourceString

Output only. Source of the effective target CPA. This field is read-only. Corresponds to the JSON property effectiveTargetCpaSource

Returns:

  • (String)


20050
20051
20052
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20050

def effective_target_cpa_source
  @effective_target_cpa_source
end

#effective_target_cpcFixnum

Output only. The effective target CPC (cost-per-click). This field is read- only. Corresponds to the JSON property effectiveTargetCpc

Returns:

  • (Fixnum)


20056
20057
20058
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20056

def effective_target_cpc
  @effective_target_cpc
end

#effective_target_cpc_sourceString

Output only. Source of the effective target CPC. This field is read-only. Corresponds to the JSON property effectiveTargetCpcSource

Returns:

  • (String)


20061
20062
20063
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20061

def effective_target_cpc_source
  @effective_target_cpc_source
end

#effective_target_roasFloat

Output only. The effective target ROAS (return-on-ad-spend). This field is read-only. Corresponds to the JSON property effectiveTargetRoas

Returns:

  • (Float)


20067
20068
20069
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20067

def effective_target_roas
  @effective_target_roas
end

#effective_target_roas_sourceString

Output only. Source of the effective target ROAS. This field is read-only. Corresponds to the JSON property effectiveTargetRoasSource

Returns:

  • (String)


20072
20073
20074
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20072

def effective_target_roas_source
  @effective_target_roas_source
end

#end_dateString

Output only. Date when the ad group ends serving ads. By default, the ad group ends on the ad group's end date. If this field is set, then the ad group ends at the end of the specified date in the customer's time zone. This field is only available for Microsoft Advertising and Facebook gateway accounts. Format: YYYY-MM-DD Example: 2019-03-14 Corresponds to the JSON property endDate

Returns:

  • (String)


20081
20082
20083
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20081

def end_date
  @end_date
end

#engine_idString

Output only. ID of the ad group in the external engine account. This field is for non-Google Ads account only, for example, Yahoo Japan, Microsoft, Baidu etc. For Google Ads entity, use "ad_group.id" instead. Corresponds to the JSON property engineId

Returns:

  • (String)


20088
20089
20090
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20088

def engine_id
  @engine_id
end

#engine_statusString

Output only. The Engine Status for ad group. Corresponds to the JSON property engineStatus

Returns:

  • (String)


20093
20094
20095
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20093

def engine_status
  @engine_status
end

#exclude_demographic_expansionBoolean Also known as: exclude_demographic_expansion?

When this value is true, demographics will be excluded from the types of targeting which are expanded when optimized_targeting_enabled is true. When optimized_targeting_enabled is false, this field is ignored. Default is false. Corresponds to the JSON property excludeDemographicExpansion

Returns:

  • (Boolean)


20100
20101
20102
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20100

def exclude_demographic_expansion
  @exclude_demographic_expansion
end

#excluded_parent_asset_field_typesArray<String>

The asset field types that should be excluded from this ad group. Asset links with these field types will not be inherited by this ad group from the upper levels. Corresponds to the JSON property excludedParentAssetFieldTypes

Returns:

  • (Array<String>)


20108
20109
20110
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20108

def excluded_parent_asset_field_types
  @excluded_parent_asset_field_types
end

#excluded_parent_asset_set_typesArray<String>

The asset set types that should be excluded from this ad group. Asset set links with these types will not be inherited by this ad group from the upper levels. Location group types (GMB_DYNAMIC_LOCATION_GROUP, CHAIN_DYNAMIC_LOCATION_GROUP, and STATIC_LOCATION_GROUP) are child types of LOCATION_SYNC. Therefore, if LOCATION_SYNC is set for this field, all location group asset sets are not allowed to be linked to this ad group, and all Location Extension (LE) and Affiliate Location Extensions (ALE) will not be served under this ad group. Only LOCATION_SYNC is currently supported. Corresponds to the JSON property excludedParentAssetSetTypes

Returns:

  • (Array<String>)


20120
20121
20122
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20120

def excluded_parent_asset_set_types
  @excluded_parent_asset_set_types
end

#final_url_suffixString

URL template for appending params to Final URL. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


20125
20126
20127
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20125

def final_url_suffix
  @final_url_suffix
end

#fixed_cpm_microsFixnum

The fixed amount in micros that the advertiser pays for every thousand impressions of the ad. Corresponds to the JSON property fixedCpmMicros

Returns:

  • (Fixnum)


20131
20132
20133
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20131

def fixed_cpm_micros
  @fixed_cpm_micros
end

#idFixnum

Output only. The ID of the ad group. Corresponds to the JSON property id

Returns:

  • (Fixnum)


20136
20137
20138
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20136

def id
  @id
end

#labelsArray<String>

Output only. The resource names of labels attached to this ad group. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


20141
20142
20143
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20141

def labels
  @labels
end

#language_codeString

Output only. The language of the ads and keywords in an ad group. This field is only available for Microsoft Advertising accounts. More details: https:// docs.microsoft.com/en-us/advertising/guides/ad-languages?view=bingads-13# adlanguage Corresponds to the JSON property languageCode

Returns:

  • (String)


20149
20150
20151
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20149

def language_code
  @language_code
end

#last_modified_timeString

Output only. The datetime when this ad group was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


20155
20156
20157
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20155

def last_modified_time
  @last_modified_time
end

#nameString

The name of the ad group. This field is required and should not be empty when creating new ad groups. It must contain fewer than 255 UTF-8 full-width characters. It must not contain any null (code point 0x0), NL line feed (code point 0xA) or carriage return (code point 0xD) characters. Corresponds to the JSON property name

Returns:

  • (String)


20163
20164
20165
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20163

def name
  @name
end

#optimized_targeting_enabledBoolean Also known as: optimized_targeting_enabled?

True if optimized targeting is enabled. Optimized Targeting is the replacement for Audience Expansion. Corresponds to the JSON property optimizedTargetingEnabled

Returns:

  • (Boolean)


20169
20170
20171
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20169

def optimized_targeting_enabled
  @optimized_targeting_enabled
end

#percent_cpc_bid_microsFixnum

The percent cpc bid amount, expressed as a fraction of the advertised price for some good or service. The valid range for the fraction is [0,1) and the value stored here is 1,000,000 * [fraction]. Corresponds to the JSON property percentCpcBidMicros

Returns:

  • (Fixnum)


20177
20178
20179
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20177

def percent_cpc_bid_micros
  @percent_cpc_bid_micros
end

#primary_statusString

Output only. Provides aggregated view into why an ad group is not serving or not serving optimally. Corresponds to the JSON property primaryStatus

Returns:

  • (String)


20183
20184
20185
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20183

def primary_status
  @primary_status
end

#primary_status_reasonsArray<String>

Output only. Provides reasons for why an ad group is not serving or not serving optimally. Corresponds to the JSON property primaryStatusReasons

Returns:

  • (Array<String>)


20189
20190
20191
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20189

def primary_status_reasons
  @primary_status_reasons
end

#resource_nameString

Immutable. The resource name of the ad group. Ad group resource names have the form: customers/customer_id/adGroups/ad_group_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


20195
20196
20197
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20195

def resource_name
  @resource_name
end

#start_dateString

Output only. Date when this ad group starts serving ads. By default, the ad group starts now or the ad group's start date, whichever is later. If this field is set, then the ad group starts at the beginning of the specified date in the customer's time zone. This field is only available for Microsoft Advertising and Facebook gateway accounts. Format: YYYY-MM-DD Example: 2019-03- 14 Corresponds to the JSON property startDate

Returns:

  • (String)


20205
20206
20207
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20205

def start_date
  @start_date
end

#statusString

The status of the ad group. Corresponds to the JSON property status

Returns:

  • (String)


20210
20211
20212
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20210

def status
  @status
end

#target_cpa_microsFixnum

The target CPA (cost-per-acquisition). If the ad group's campaign bidding strategy is TargetCpa or MaximizeConversions (with its target_cpa field set), then this field overrides the target CPA specified in the campaign's bidding strategy. Otherwise, this value is ignored. Corresponds to the JSON property targetCpaMicros

Returns:

  • (Fixnum)


20218
20219
20220
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20218

def target_cpa_micros
  @target_cpa_micros
end

#target_cpc_microsFixnum

Average amount in micros that the advertiser is willing to pay for every ad click. Overrides the target CPC configured at the campaign level. Corresponds to the JSON property targetCpcMicros

Returns:

  • (Fixnum)


20224
20225
20226
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20224

def target_cpc_micros
  @target_cpc_micros
end

#target_cpm_microsFixnum

Average amount in micros that the advertiser is willing to pay for every thousand times the ad is shown. Corresponds to the JSON property targetCpmMicros

Returns:

  • (Fixnum)


20230
20231
20232
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20230

def target_cpm_micros
  @target_cpm_micros
end

#target_cpv_microsFixnum

Average amount in micros that the advertiser is willing to pay for every ad view. Corresponds to the JSON property targetCpvMicros

Returns:

  • (Fixnum)


20236
20237
20238
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20236

def target_cpv_micros
  @target_cpv_micros
end

#target_roasFloat

The target ROAS (return-on-ad-spend) for this ad group. This field lets you override the target ROAS specified in the campaign's bidding strategy, but only if the campaign is using a standard (not portfolio) TargetRoas strategy or a standard MaximizeConversionValue strategy with its target_roas field set. If the campaign is using a portfolio bidding strategy, this field cannot be set and attempting to do so will result in an error. For any other bidding strategies, this value is ignored. To see the actual target ROAS being used by the ad group, considering potential overrides, query the effective_target_roas and effective_target_roas_source fields. Corresponds to the JSON property targetRoas

Returns:

  • (Float)


20249
20250
20251
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20249

def target_roas
  @target_roas
end

#targeting_settingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetingSetting

Settings for the targeting-related features, at the campaign and ad group levels. For more details about the targeting setting, visit https://support. google.com/google-ads/answer/7365594 Corresponds to the JSON property targetingSetting



20256
20257
20258
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20256

def targeting_setting
  @targeting_setting
end

#tracking_url_templateString

The URL template for constructing a tracking URL. Corresponds to the JSON property trackingUrlTemplate

Returns:

  • (String)


20261
20262
20263
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20261

def tracking_url_template
  @tracking_url_template
end

#typeString

Immutable. The type of the ad group. Corresponds to the JSON property type

Returns:

  • (String)


20266
20267
20268
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20266

def type
  @type
end

#url_custom_parametersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>

The list of mappings used to substitute custom parameter tags in a tracking_url_template, final_urls, or mobile_final_urls. Corresponds to the JSON property urlCustomParameters



20272
20273
20274
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20272

def url_custom_parameters
  @url_custom_parameters
end

#vertical_ads_format_settingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupVerticalAdsFormatSetting

Vertical ads setting feature to enable/disable ad group format controls in search campaigns. Corresponds to the JSON property verticalAdsFormatSetting



20278
20279
20280
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20278

def vertical_ads_format_setting
  @vertical_ads_format_setting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20285
20286
20287
20288
20289
20290
20291
20292
20293
20294
20295
20296
20297
20298
20299
20300
20301
20302
20303
20304
20305
20306
20307
20308
20309
20310
20311
20312
20313
20314
20315
20316
20317
20318
20319
20320
20321
20322
20323
20324
20325
20326
20327
20328
20329
20330
20331
20332
20333
20334
20335
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20285

def update!(**args)
  @ad_rotation_mode = args[:ad_rotation_mode] if args.key?(:ad_rotation_mode)
  @ai_max_ad_group_setting = args[:ai_max_ad_group_setting] if args.key?(:ai_max_ad_group_setting)
  @audience_setting = args[:audience_setting] if args.key?(:audience_setting)
  @base_ad_group = args[:base_ad_group] if args.key?(:base_ad_group)
  @campaign = args[:campaign] if args.key?(:campaign)
  @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros)
  @cpm_bid_micros = args[:cpm_bid_micros] if args.key?(:cpm_bid_micros)
  @cpv_bid_micros = args[:cpv_bid_micros] if args.key?(:cpv_bid_micros)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @demand_gen_ad_group_settings = args[:demand_gen_ad_group_settings] if args.key?(:demand_gen_ad_group_settings)
  @display_custom_bid_dimension = args[:display_custom_bid_dimension] if args.key?(:display_custom_bid_dimension)
  @effective_cpc_bid_micros = args[:effective_cpc_bid_micros] if args.key?(:effective_cpc_bid_micros)
  @effective_labels = args[:effective_labels] if args.key?(:effective_labels)
  @effective_target_cpa_micros = args[:effective_target_cpa_micros] if args.key?(:effective_target_cpa_micros)
  @effective_target_cpa_source = args[:effective_target_cpa_source] if args.key?(:effective_target_cpa_source)
  @effective_target_cpc = args[:effective_target_cpc] if args.key?(:effective_target_cpc)
  @effective_target_cpc_source = args[:effective_target_cpc_source] if args.key?(:effective_target_cpc_source)
  @effective_target_roas = args[:effective_target_roas] if args.key?(:effective_target_roas)
  @effective_target_roas_source = args[:effective_target_roas_source] if args.key?(:effective_target_roas_source)
  @end_date = args[:end_date] if args.key?(:end_date)
  @engine_id = args[:engine_id] if args.key?(:engine_id)
  @engine_status = args[:engine_status] if args.key?(:engine_status)
  @exclude_demographic_expansion = args[:exclude_demographic_expansion] if args.key?(:exclude_demographic_expansion)
  @excluded_parent_asset_field_types = args[:excluded_parent_asset_field_types] if args.key?(:excluded_parent_asset_field_types)
  @excluded_parent_asset_set_types = args[:excluded_parent_asset_set_types] if args.key?(:excluded_parent_asset_set_types)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @fixed_cpm_micros = args[:fixed_cpm_micros] if args.key?(:fixed_cpm_micros)
  @id = args[:id] if args.key?(:id)
  @labels = args[:labels] if args.key?(:labels)
  @language_code = args[:language_code] if args.key?(:language_code)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @name = args[:name] if args.key?(:name)
  @optimized_targeting_enabled = args[:optimized_targeting_enabled] if args.key?(:optimized_targeting_enabled)
  @percent_cpc_bid_micros = args[:percent_cpc_bid_micros] if args.key?(:percent_cpc_bid_micros)
  @primary_status = args[:primary_status] if args.key?(:primary_status)
  @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @status = args[:status] if args.key?(:status)
  @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros)
  @target_cpc_micros = args[:target_cpc_micros] if args.key?(:target_cpc_micros)
  @target_cpm_micros = args[:target_cpm_micros] if args.key?(:target_cpm_micros)
  @target_cpv_micros = args[:target_cpv_micros] if args.key?(:target_cpv_micros)
  @target_roas = args[:target_roas] if args.key?(:target_roas)
  @targeting_setting = args[:targeting_setting] if args.key?(:targeting_setting)
  @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template)
  @type = args[:type] if args.key?(:type)
  @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters)
  @vertical_ads_format_setting = args[:vertical_ads_format_setting] if args.key?(:vertical_ads_format_setting)
end