Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An ad group.
Instance Attribute Summary collapse
-
#ad_rotation_mode ⇒ String
The ad rotation mode of the ad group.
-
#ai_max_ad_group_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAiMaxAdGroupSetting
Settings for AI Max feature in standard search adgroups.
-
#audience_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAudienceSetting
Settings for the audience targeting.
-
#base_ad_group ⇒ String
Output only.
-
#campaign ⇒ String
Immutable.
-
#cpc_bid_micros ⇒ Fixnum
The maximum CPC (cost-per-click) bid.
-
#cpm_bid_micros ⇒ Fixnum
The maximum CPM (cost-per-thousand viewable impressions) bid.
-
#cpv_bid_micros ⇒ Fixnum
The CPV (cost-per-view) bid.
-
#creation_time ⇒ String
Output only.
-
#demand_gen_ad_group_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettings
Settings for Demand Gen ad groups.
-
#display_custom_bid_dimension ⇒ String
Lets advertisers specify a targeting dimension on which to place absolute bids.
-
#effective_cpc_bid_micros ⇒ Fixnum
Output only.
-
#effective_labels ⇒ Array<String>
Output only.
-
#effective_target_cpa_micros ⇒ Fixnum
Output only.
-
#effective_target_cpa_source ⇒ String
Output only.
-
#effective_target_cpc ⇒ Fixnum
Output only.
-
#effective_target_cpc_source ⇒ String
Output only.
-
#effective_target_roas ⇒ Float
Output only.
-
#effective_target_roas_source ⇒ String
Output only.
-
#end_date ⇒ String
Output only.
-
#engine_id ⇒ String
Output only.
-
#engine_status ⇒ String
Output only.
-
#exclude_demographic_expansion ⇒ Boolean
(also: #exclude_demographic_expansion?)
When this value is true, demographics will be excluded from the types of targeting which are expanded when optimized_targeting_enabled is true.
-
#excluded_parent_asset_field_types ⇒ Array<String>
The asset field types that should be excluded from this ad group.
-
#excluded_parent_asset_set_types ⇒ Array<String>
The asset set types that should be excluded from this ad group.
-
#final_url_suffix ⇒ String
URL template for appending params to Final URL.
-
#fixed_cpm_micros ⇒ Fixnum
The fixed amount in micros that the advertiser pays for every thousand impressions of the ad.
-
#id ⇒ Fixnum
Output only.
-
#labels ⇒ Array<String>
Output only.
-
#language_code ⇒ String
Output only.
-
#last_modified_time ⇒ String
Output only.
-
#name ⇒ String
The name of the ad group.
-
#optimized_targeting_enabled ⇒ Boolean
(also: #optimized_targeting_enabled?)
True if optimized targeting is enabled.
-
#percent_cpc_bid_micros ⇒ Fixnum
The percent cpc bid amount, expressed as a fraction of the advertised price for some good or service.
-
#primary_status ⇒ String
Output only.
-
#primary_status_reasons ⇒ Array<String>
Output only.
-
#resource_name ⇒ String
Immutable.
-
#start_date ⇒ String
Output only.
-
#status ⇒ String
The status of the ad group.
-
#target_cpa_micros ⇒ Fixnum
The target CPA (cost-per-acquisition).
-
#target_cpc_micros ⇒ Fixnum
Average amount in micros that the advertiser is willing to pay for every ad click.
-
#target_cpm_micros ⇒ Fixnum
Average amount in micros that the advertiser is willing to pay for every thousand times the ad is shown.
-
#target_cpv_micros ⇒ Fixnum
Average amount in micros that the advertiser is willing to pay for every ad view.
-
#target_roas ⇒ Float
The target ROAS (return-on-ad-spend) for this ad group.
-
#targeting_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetingSetting
Settings for the targeting-related features, at the campaign and ad group levels.
-
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
-
#type ⇒ String
Immutable.
-
#url_custom_parameters ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>
The list of mappings used to substitute custom parameter tags in a
tracking_url_template,final_urls, ormobile_final_urls. -
#vertical_ads_format_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupVerticalAdsFormatSetting
Vertical ads setting feature to enable/disable ad group format controls in search campaigns.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroup
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroup
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroup.
20206 20207 20208 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_rotation_mode ⇒ String
The ad rotation mode of the ad group.
Corresponds to the JSON property adRotationMode
19892 19893 19894 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19892 def ad_rotation_mode @ad_rotation_mode end |
#ai_max_ad_group_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAiMaxAdGroupSetting
Settings for AI Max feature in standard search adgroups.
Corresponds to the JSON property aiMaxAdGroupSetting
19897 19898 19899 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19897 def ai_max_ad_group_setting @ai_max_ad_group_setting end |
#audience_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAudienceSetting
Settings for the audience targeting.
Corresponds to the JSON property audienceSetting
19902 19903 19904 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19902 def audience_setting @audience_setting end |
#base_ad_group ⇒ String
Output only. For draft or experiment ad groups, this field is the resource
name of the base ad group from which this ad group was created. If a draft or
experiment ad group does not have a base ad group, then this field is null.
For base ad groups, this field equals the ad group resource name. This field
is read-only.
Corresponds to the JSON property baseAdGroup
19911 19912 19913 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19911 def base_ad_group @base_ad_group end |
#campaign ⇒ String
Immutable. The campaign to which the ad group belongs.
Corresponds to the JSON property campaign
19916 19917 19918 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19916 def campaign @campaign end |
#cpc_bid_micros ⇒ Fixnum
The maximum CPC (cost-per-click) bid. This field is used when the ad group's
effective bidding strategy is Manual CPC. This field is not applicable and
will be ignored if the ad group's campaign is using a portfolio bidding
strategy.
Corresponds to the JSON property cpcBidMicros
19924 19925 19926 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19924 def cpc_bid_micros @cpc_bid_micros end |
#cpm_bid_micros ⇒ Fixnum
The maximum CPM (cost-per-thousand viewable impressions) bid.
Corresponds to the JSON property cpmBidMicros
19929 19930 19931 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19929 def cpm_bid_micros @cpm_bid_micros end |
#cpv_bid_micros ⇒ Fixnum
The CPV (cost-per-view) bid.
Corresponds to the JSON property cpvBidMicros
19934 19935 19936 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19934 def cpv_bid_micros @cpv_bid_micros end |
#creation_time ⇒ String
Output only. The timestamp when this ad_group was created. The timestamp is in
the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format.
Corresponds to the JSON property creationTime
19940 19941 19942 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19940 def creation_time @creation_time end |
#demand_gen_ad_group_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettings
Settings for Demand Gen ad groups.
Corresponds to the JSON property demandGenAdGroupSettings
19945 19946 19947 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19945 def demand_gen_ad_group_settings @demand_gen_ad_group_settings end |
#display_custom_bid_dimension ⇒ String
Lets advertisers specify a targeting dimension on which to place absolute bids.
This is only applicable for campaigns that target only the display network
and not search.
Corresponds to the JSON property displayCustomBidDimension
19952 19953 19954 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19952 def display_custom_bid_dimension @display_custom_bid_dimension end |
#effective_cpc_bid_micros ⇒ Fixnum
Output only. Value will be same as that of the CPC (cost-per-click) bid value
when the bidding strategy is one of manual cpc, enhanced cpc, page one
promoted or target outrank share, otherwise the value will be null.
Corresponds to the JSON property effectiveCpcBidMicros
19959 19960 19961 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19959 def effective_cpc_bid_micros @effective_cpc_bid_micros end |
#effective_labels ⇒ Array<String>
Output only. The resource names of effective labels attached to this ad group.
An effective label is a label inherited or directly assigned to this ad group.
Corresponds to the JSON property effectiveLabels
19965 19966 19967 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19965 def effective_labels @effective_labels end |
#effective_target_cpa_micros ⇒ Fixnum
Output only. The effective target CPA (cost-per-acquisition). This field is
read-only.
Corresponds to the JSON property effectiveTargetCpaMicros
19971 19972 19973 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19971 def effective_target_cpa_micros @effective_target_cpa_micros end |
#effective_target_cpa_source ⇒ String
Output only. Source of the effective target CPA. This field is read-only.
Corresponds to the JSON property effectiveTargetCpaSource
19976 19977 19978 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19976 def effective_target_cpa_source @effective_target_cpa_source end |
#effective_target_cpc ⇒ Fixnum
Output only. The effective target CPC (cost-per-click). This field is read-
only.
Corresponds to the JSON property effectiveTargetCpc
19982 19983 19984 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19982 def effective_target_cpc @effective_target_cpc end |
#effective_target_cpc_source ⇒ String
Output only. Source of the effective target CPC. This field is read-only.
Corresponds to the JSON property effectiveTargetCpcSource
19987 19988 19989 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19987 def effective_target_cpc_source @effective_target_cpc_source end |
#effective_target_roas ⇒ Float
Output only. The effective target ROAS (return-on-ad-spend). This field is
read-only.
Corresponds to the JSON property effectiveTargetRoas
19993 19994 19995 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19993 def effective_target_roas @effective_target_roas end |
#effective_target_roas_source ⇒ String
Output only. Source of the effective target ROAS. This field is read-only.
Corresponds to the JSON property effectiveTargetRoasSource
19998 19999 20000 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19998 def effective_target_roas_source @effective_target_roas_source end |
#end_date ⇒ String
Output only. Date when the ad group ends serving ads. By default, the ad group
ends on the ad group's end date. If this field is set, then the ad group ends
at the end of the specified date in the customer's time zone. This field is
only available for Microsoft Advertising and Facebook gateway accounts. Format:
YYYY-MM-DD Example: 2019-03-14
Corresponds to the JSON property endDate
20007 20008 20009 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20007 def end_date @end_date end |
#engine_id ⇒ String
Output only. ID of the ad group in the external engine account. This field is
for non-Google Ads account only, for example, Yahoo Japan, Microsoft, Baidu
etc. For Google Ads entity, use "ad_group.id" instead.
Corresponds to the JSON property engineId
20014 20015 20016 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20014 def engine_id @engine_id end |
#engine_status ⇒ String
Output only. The Engine Status for ad group.
Corresponds to the JSON property engineStatus
20019 20020 20021 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20019 def engine_status @engine_status end |
#exclude_demographic_expansion ⇒ Boolean Also known as: exclude_demographic_expansion?
When this value is true, demographics will be excluded from the types of
targeting which are expanded when optimized_targeting_enabled is true. When
optimized_targeting_enabled is false, this field is ignored. Default is false.
Corresponds to the JSON property excludeDemographicExpansion
20026 20027 20028 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20026 def exclude_demographic_expansion @exclude_demographic_expansion end |
#excluded_parent_asset_field_types ⇒ Array<String>
The asset field types that should be excluded from this ad group. Asset links
with these field types will not be inherited by this ad group from the upper
levels.
Corresponds to the JSON property excludedParentAssetFieldTypes
20034 20035 20036 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20034 def excluded_parent_asset_field_types @excluded_parent_asset_field_types end |
#excluded_parent_asset_set_types ⇒ Array<String>
The asset set types that should be excluded from this ad group. Asset set
links with these types will not be inherited by this ad group from the upper
levels. Location group types (GMB_DYNAMIC_LOCATION_GROUP,
CHAIN_DYNAMIC_LOCATION_GROUP, and STATIC_LOCATION_GROUP) are child types of
LOCATION_SYNC. Therefore, if LOCATION_SYNC is set for this field, all location
group asset sets are not allowed to be linked to this ad group, and all
Location Extension (LE) and Affiliate Location Extensions (ALE) will not be
served under this ad group. Only LOCATION_SYNC is currently supported.
Corresponds to the JSON property excludedParentAssetSetTypes
20046 20047 20048 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20046 def excluded_parent_asset_set_types @excluded_parent_asset_set_types end |
#final_url_suffix ⇒ String
URL template for appending params to Final URL.
Corresponds to the JSON property finalUrlSuffix
20051 20052 20053 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20051 def final_url_suffix @final_url_suffix end |
#fixed_cpm_micros ⇒ Fixnum
The fixed amount in micros that the advertiser pays for every thousand
impressions of the ad.
Corresponds to the JSON property fixedCpmMicros
20057 20058 20059 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20057 def fixed_cpm_micros @fixed_cpm_micros end |
#id ⇒ Fixnum
Output only. The ID of the ad group.
Corresponds to the JSON property id
20062 20063 20064 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20062 def id @id end |
#labels ⇒ Array<String>
Output only. The resource names of labels attached to this ad group.
Corresponds to the JSON property labels
20067 20068 20069 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20067 def labels @labels end |
#language_code ⇒ String
Output only. The language of the ads and keywords in an ad group. This field
is only available for Microsoft Advertising accounts. More details: https://
docs.microsoft.com/en-us/advertising/guides/ad-languages?view=bingads-13#
adlanguage
Corresponds to the JSON property languageCode
20075 20076 20077 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20075 def language_code @language_code end |
#last_modified_time ⇒ String
Output only. The datetime when this ad group was last modified. The datetime
is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format.
Corresponds to the JSON property lastModifiedTime
20081 20082 20083 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20081 def last_modified_time @last_modified_time end |
#name ⇒ String
The name of the ad group. This field is required and should not be empty when
creating new ad groups. It must contain fewer than 255 UTF-8 full-width
characters. It must not contain any null (code point 0x0), NL line feed (code
point 0xA) or carriage return (code point 0xD) characters.
Corresponds to the JSON property name
20089 20090 20091 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20089 def name @name end |
#optimized_targeting_enabled ⇒ Boolean Also known as: optimized_targeting_enabled?
True if optimized targeting is enabled. Optimized Targeting is the replacement
for Audience Expansion.
Corresponds to the JSON property optimizedTargetingEnabled
20095 20096 20097 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20095 def optimized_targeting_enabled @optimized_targeting_enabled end |
#percent_cpc_bid_micros ⇒ Fixnum
The percent cpc bid amount, expressed as a fraction of the advertised price
for some good or service. The valid range for the fraction is [0,1) and the
value stored here is 1,000,000 * [fraction].
Corresponds to the JSON property percentCpcBidMicros
20103 20104 20105 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20103 def percent_cpc_bid_micros @percent_cpc_bid_micros end |
#primary_status ⇒ String
Output only. Provides aggregated view into why an ad group is not serving or
not serving optimally.
Corresponds to the JSON property primaryStatus
20109 20110 20111 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20109 def primary_status @primary_status end |
#primary_status_reasons ⇒ Array<String>
Output only. Provides reasons for why an ad group is not serving or not
serving optimally.
Corresponds to the JSON property primaryStatusReasons
20115 20116 20117 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20115 def primary_status_reasons @primary_status_reasons end |
#resource_name ⇒ String
Immutable. The resource name of the ad group. Ad group resource names have the
form: customers/customer_id/adGroups/ad_group_id`
Corresponds to the JSON propertyresourceName`
20121 20122 20123 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20121 def resource_name @resource_name end |
#start_date ⇒ String
Output only. Date when this ad group starts serving ads. By default, the ad
group starts now or the ad group's start date, whichever is later. If this
field is set, then the ad group starts at the beginning of the specified date
in the customer's time zone. This field is only available for Microsoft
Advertising and Facebook gateway accounts. Format: YYYY-MM-DD Example: 2019-03-
14
Corresponds to the JSON property startDate
20131 20132 20133 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20131 def start_date @start_date end |
#status ⇒ String
The status of the ad group.
Corresponds to the JSON property status
20136 20137 20138 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20136 def status @status end |
#target_cpa_micros ⇒ Fixnum
The target CPA (cost-per-acquisition). If the ad group's campaign bidding
strategy is TargetCpa or MaximizeConversions (with its target_cpa field set),
then this field overrides the target CPA specified in the campaign's bidding
strategy. Otherwise, this value is ignored.
Corresponds to the JSON property targetCpaMicros
20144 20145 20146 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20144 def target_cpa_micros @target_cpa_micros end |
#target_cpc_micros ⇒ Fixnum
Average amount in micros that the advertiser is willing to pay for every ad
click. Overrides the target CPC configured at the campaign level.
Corresponds to the JSON property targetCpcMicros
20150 20151 20152 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20150 def target_cpc_micros @target_cpc_micros end |
#target_cpm_micros ⇒ Fixnum
Average amount in micros that the advertiser is willing to pay for every
thousand times the ad is shown.
Corresponds to the JSON property targetCpmMicros
20156 20157 20158 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20156 def target_cpm_micros @target_cpm_micros end |
#target_cpv_micros ⇒ Fixnum
Average amount in micros that the advertiser is willing to pay for every ad
view.
Corresponds to the JSON property targetCpvMicros
20162 20163 20164 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20162 def target_cpv_micros @target_cpv_micros end |
#target_roas ⇒ Float
The target ROAS (return-on-ad-spend) for this ad group. This field lets you
override the target ROAS specified in the campaign's bidding strategy, but
only if the campaign is using a standard (not portfolio) TargetRoas strategy
or a standard MaximizeConversionValue strategy with its target_roas field
set. If the campaign is using a portfolio bidding strategy, this field cannot
be set and attempting to do so will result in an error. For any other bidding
strategies, this value is ignored. To see the actual target ROAS being used by
the ad group, considering potential overrides, query the
effective_target_roas and effective_target_roas_source fields.
Corresponds to the JSON property targetRoas
20175 20176 20177 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20175 def target_roas @target_roas end |
#targeting_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetingSetting
Settings for the targeting-related features, at the campaign and ad group
levels. For more details about the targeting setting, visit https://support.
google.com/google-ads/answer/7365594
Corresponds to the JSON property targetingSetting
20182 20183 20184 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20182 def targeting_setting @targeting_setting end |
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
Corresponds to the JSON property trackingUrlTemplate
20187 20188 20189 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20187 def tracking_url_template @tracking_url_template end |
#type ⇒ String
Immutable. The type of the ad group.
Corresponds to the JSON property type
20192 20193 20194 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20192 def type @type end |
#url_custom_parameters ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>
The list of mappings used to substitute custom parameter tags in a
tracking_url_template, final_urls, or mobile_final_urls.
Corresponds to the JSON property urlCustomParameters
20198 20199 20200 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20198 def url_custom_parameters @url_custom_parameters end |
#vertical_ads_format_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupVerticalAdsFormatSetting
Vertical ads setting feature to enable/disable ad group format controls in
search campaigns.
Corresponds to the JSON property verticalAdsFormatSetting
20204 20205 20206 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20204 def vertical_ads_format_setting @vertical_ads_format_setting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20211 20212 20213 20214 20215 20216 20217 20218 20219 20220 20221 20222 20223 20224 20225 20226 20227 20228 20229 20230 20231 20232 20233 20234 20235 20236 20237 20238 20239 20240 20241 20242 20243 20244 20245 20246 20247 20248 20249 20250 20251 20252 20253 20254 20255 20256 20257 20258 20259 20260 20261 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20211 def update!(**args) @ad_rotation_mode = args[:ad_rotation_mode] if args.key?(:ad_rotation_mode) @ai_max_ad_group_setting = args[:ai_max_ad_group_setting] if args.key?(:ai_max_ad_group_setting) @audience_setting = args[:audience_setting] if args.key?(:audience_setting) @base_ad_group = args[:base_ad_group] if args.key?(:base_ad_group) @campaign = args[:campaign] if args.key?(:campaign) @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros) @cpm_bid_micros = args[:cpm_bid_micros] if args.key?(:cpm_bid_micros) @cpv_bid_micros = args[:cpv_bid_micros] if args.key?(:cpv_bid_micros) @creation_time = args[:creation_time] if args.key?(:creation_time) @demand_gen_ad_group_settings = args[:demand_gen_ad_group_settings] if args.key?(:demand_gen_ad_group_settings) @display_custom_bid_dimension = args[:display_custom_bid_dimension] if args.key?(:display_custom_bid_dimension) @effective_cpc_bid_micros = args[:effective_cpc_bid_micros] if args.key?(:effective_cpc_bid_micros) @effective_labels = args[:effective_labels] if args.key?(:effective_labels) @effective_target_cpa_micros = args[:effective_target_cpa_micros] if args.key?(:effective_target_cpa_micros) @effective_target_cpa_source = args[:effective_target_cpa_source] if args.key?(:effective_target_cpa_source) @effective_target_cpc = args[:effective_target_cpc] if args.key?(:effective_target_cpc) @effective_target_cpc_source = args[:effective_target_cpc_source] if args.key?(:effective_target_cpc_source) @effective_target_roas = args[:effective_target_roas] if args.key?(:effective_target_roas) @effective_target_roas_source = args[:effective_target_roas_source] if args.key?(:effective_target_roas_source) @end_date = args[:end_date] if args.key?(:end_date) @engine_id = args[:engine_id] if args.key?(:engine_id) @engine_status = args[:engine_status] if args.key?(:engine_status) @exclude_demographic_expansion = args[:exclude_demographic_expansion] if args.key?(:exclude_demographic_expansion) @excluded_parent_asset_field_types = args[:excluded_parent_asset_field_types] if args.key?(:excluded_parent_asset_field_types) @excluded_parent_asset_set_types = args[:excluded_parent_asset_set_types] if args.key?(:excluded_parent_asset_set_types) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @fixed_cpm_micros = args[:fixed_cpm_micros] if args.key?(:fixed_cpm_micros) @id = args[:id] if args.key?(:id) @labels = args[:labels] if args.key?(:labels) @language_code = args[:language_code] if args.key?(:language_code) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @name = args[:name] if args.key?(:name) @optimized_targeting_enabled = args[:optimized_targeting_enabled] if args.key?(:optimized_targeting_enabled) @percent_cpc_bid_micros = args[:percent_cpc_bid_micros] if args.key?(:percent_cpc_bid_micros) @primary_status = args[:primary_status] if args.key?(:primary_status) @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons) @resource_name = args[:resource_name] if args.key?(:resource_name) @start_date = args[:start_date] if args.key?(:start_date) @status = args[:status] if args.key?(:status) @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros) @target_cpc_micros = args[:target_cpc_micros] if args.key?(:target_cpc_micros) @target_cpm_micros = args[:target_cpm_micros] if args.key?(:target_cpm_micros) @target_cpv_micros = args[:target_cpv_micros] if args.key?(:target_cpv_micros) @target_roas = args[:target_roas] if args.key?(:target_roas) @targeting_setting = args[:targeting_setting] if args.key?(:targeting_setting) @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template) @type = args[:type] if args.key?(:type) @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters) @vertical_ads_format_setting = args[:vertical_ads_format_setting] if args.key?(:vertical_ads_format_setting) end |