Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An ad group ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAd

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAd.



20363
20364
20365
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_itemsArray<String>

Output only. A list of recommendations to improve the ad strength. For example, a recommendation could be "Try adding a few more unique headlines or unpinning some assets.". Corresponds to the JSON property actionItems

Returns:

  • (Array<String>)


20273
20274
20275
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20273

def action_items
  @action_items
end

#adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAd

An ad. Corresponds to the JSON property ad



20278
20279
20280
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20278

def ad
  @ad
end

#ad_groupString

Immutable. The ad group to which the ad belongs. Corresponds to the JSON property adGroup

Returns:

  • (String)


20283
20284
20285
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20283

def ad_group
  @ad_group
end

#ad_group_ad_asset_automation_settingsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdAssetAutomationSetting>

Settings that control the types of asset automation. See the AssetAutomationTypeEnum documentation for the default opt in/out behavior of each type. Corresponds to the JSON property adGroupAdAssetAutomationSettings



20290
20291
20292
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20290

def ad_group_ad_asset_automation_settings
  @ad_group_ad_asset_automation_settings
end

#ad_strengthString

Output only. Overall ad strength for this ad group ad. Corresponds to the JSON property adStrength

Returns:

  • (String)


20295
20296
20297
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20295

def ad_strength
  @ad_strength
end

#creation_timeString

Output only. The timestamp when this ad_group_ad was created. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property creationTime

Returns:

  • (String)


20301
20302
20303
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20301

def creation_time
  @creation_time
end

#effective_labelsArray<String>

Output only. The resource names of effective labels attached to this ad. An effective label is a label inherited or directly assigned to this ad. Corresponds to the JSON property effectiveLabels

Returns:

  • (Array<String>)


20307
20308
20309
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20307

def effective_labels
  @effective_labels
end

#engine_idString

Output only. ID of the ad in the external engine account. This field is for Search Ads 360 account only, for example, Yahoo Japan, Microsoft, Baidu etc. For non-Search Ads 360 entity, use "ad_group_ad.ad.id" instead. Corresponds to the JSON property engineId

Returns:

  • (String)


20314
20315
20316
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20314

def engine_id
  @engine_id
end

#engine_statusString

Output only. Additional status of the ad in the external engine account. Possible statuses (depending on the type of external account) include active, eligible, pending review, etc. Corresponds to the JSON property engineStatus

Returns:

  • (String)


20321
20322
20323
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20321

def engine_status
  @engine_status
end

#labelsArray<String>

Output only. The resource names of labels attached to this ad group ad. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


20326
20327
20328
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20326

def labels
  @labels
end

#last_modified_timeString

Output only. The datetime when this ad group ad was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


20333
20334
20335
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20333

def last_modified_time
  @last_modified_time
end

#policy_summaryGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdPolicySummary

Contains policy information for an ad. Corresponds to the JSON property policySummary



20338
20339
20340
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20338

def policy_summary
  @policy_summary
end

#primary_statusString

Output only. Provides aggregated view into why an ad group ad is not serving or not serving optimally. Corresponds to the JSON property primaryStatus

Returns:

  • (String)


20344
20345
20346
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20344

def primary_status
  @primary_status
end

#primary_status_reasonsArray<String>

Output only. Provides reasons for why an ad group ad is not serving or not serving optimally. Corresponds to the JSON property primaryStatusReasons

Returns:

  • (Array<String>)


20350
20351
20352
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20350

def primary_status_reasons
  @primary_status_reasons
end

#resource_nameString

Immutable. The resource name of the ad. Ad group ad resource names have the form: customers/customer_id/adGroupAds/ad_group_id~ad_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


20356
20357
20358
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20356

def resource_name
  @resource_name
end

#statusString

The status of the ad. Corresponds to the JSON property status

Returns:

  • (String)


20361
20362
20363
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20361

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20368
20369
20370
20371
20372
20373
20374
20375
20376
20377
20378
20379
20380
20381
20382
20383
20384
20385
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20368

def update!(**args)
  @action_items = args[:action_items] if args.key?(:action_items)
  @ad = args[:ad] if args.key?(:ad)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @ad_group_ad_asset_automation_settings = args[:ad_group_ad_asset_automation_settings] if args.key?(:ad_group_ad_asset_automation_settings)
  @ad_strength = args[:ad_strength] if args.key?(:ad_strength)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @effective_labels = args[:effective_labels] if args.key?(:effective_labels)
  @engine_id = args[:engine_id] if args.key?(:engine_id)
  @engine_status = args[:engine_status] if args.key?(:engine_status)
  @labels = args[:labels] if args.key?(:labels)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @policy_summary = args[:policy_summary] if args.key?(:policy_summary)
  @primary_status = args[:primary_status] if args.key?(:primary_status)
  @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end