Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Contains policy information for an ad group ad asset.
Instance Attribute Summary collapse
-
#approval_status ⇒ String
Output only.
-
#policy_topic_entries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry>
Output only.
-
#review_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary.
20610 20611 20612 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20610 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval_status ⇒ String
Output only. The overall approval status of this ad group ad asset, calculated
based on the status of its individual policy topic entries.
Corresponds to the JSON property approvalStatus
20598 20599 20600 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20598 def approval_status @approval_status end |
#policy_topic_entries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry>
Output only. The list of policy findings for the ad group ad asset.
Corresponds to the JSON property policyTopicEntries
20603 20604 20605 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20603 def policy_topic_entries @policy_topic_entries end |
#review_status ⇒ String
Output only. Where in the review process this ad group ad asset is.
Corresponds to the JSON property reviewStatus
20608 20609 20610 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20608 def review_status @review_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20615 20616 20617 20618 20619 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20615 def update!(**args) @approval_status = args[:approval_status] if args.key?(:approval_status) @policy_topic_entries = args[:policy_topic_entries] if args.key?(:policy_topic_entries) @review_status = args[:review_status] if args.key?(:review_status) end |