Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Contains policy information for an ad group ad asset.
Instance Attribute Summary collapse
-
#approval_status ⇒ String
Output only.
-
#policy_topic_entries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry>
Output only.
-
#review_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary.
20550 20551 20552 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20550 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval_status ⇒ String
Output only. The overall approval status of this ad group ad asset, calculated
based on the status of its individual policy topic entries.
Corresponds to the JSON property approvalStatus
20538 20539 20540 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20538 def approval_status @approval_status end |
#policy_topic_entries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry>
Output only. The list of policy findings for the ad group ad asset.
Corresponds to the JSON property policyTopicEntries
20543 20544 20545 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20543 def policy_topic_entries @policy_topic_entries end |
#review_status ⇒ String
Output only. Where in the review process this ad group ad asset is.
Corresponds to the JSON property reviewStatus
20548 20549 20550 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20548 def review_status @review_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20555 20556 20557 20558 20559 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20555 def update!(**args) @approval_status = args[:approval_status] if args.key?(:approval_status) @policy_topic_entries = args[:policy_topic_entries] if args.key?(:policy_topic_entries) @review_status = args[:review_status] if args.key?(:review_status) end |