Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Contains policy information for an ad group ad asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary.



20476
20477
20478
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approval_statusString

Output only. The overall approval status of this ad group ad asset, calculated based on the status of its individual policy topic entries. Corresponds to the JSON property approvalStatus

Returns:

  • (String)


20464
20465
20466
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20464

def approval_status
  @approval_status
end

#policy_topic_entriesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry>

Output only. The list of policy findings for the ad group ad asset. Corresponds to the JSON property policyTopicEntries



20469
20470
20471
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20469

def policy_topic_entries
  @policy_topic_entries
end

#review_statusString

Output only. Where in the review process this ad group ad asset is. Corresponds to the JSON property reviewStatus

Returns:

  • (String)


20474
20475
20476
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20474

def review_status
  @review_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20481
20482
20483
20484
20485
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20481

def update!(**args)
  @approval_status = args[:approval_status] if args.key?(:approval_status)
  @policy_topic_entries = args[:policy_topic_entries] if args.key?(:policy_topic_entries)
  @review_status = args[:review_status] if args.key?(:review_status)
end