Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdAssetView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a link between an AdGroupAd and an Asset. This view provides insights into the performance of assets within specific ads. AdGroupAdAssetView supports the following ad types: * App Ads * Demand Gen campaigns * Responsive Search Ads It does not support Responsive Display Ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAdAssetView

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAdAssetView.



20624
20625
20626
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20624

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_adString

Output only. The ad group ad to which the asset is linked. Corresponds to the JSON property adGroupAd

Returns:

  • (String)


20572
20573
20574
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20572

def ad_group_ad
  @ad_group_ad
end

#assetString

Output only. The asset which is linked to the ad group ad. Corresponds to the JSON property asset

Returns:

  • (String)


20577
20578
20579
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20577

def asset
  @asset
end

#enabledBoolean Also known as: enabled?

Output only. The status between the asset and the latest version of the ad. If true, the asset is linked to the latest version of the ad. If false, it means the link once existed but has been removed and is no longer present in the latest version of the ad. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


20585
20586
20587
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20585

def enabled
  @enabled
end

#field_typeString

Output only. Role that the asset takes in the ad. Corresponds to the JSON property fieldType

Returns:

  • (String)


20591
20592
20593
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20591

def field_type
  @field_type
end

#performance_labelString

Output only. Performance of an asset linkage. Corresponds to the JSON property performanceLabel

Returns:

  • (String)


20596
20597
20598
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20596

def performance_label
  @performance_label
end

#pinned_fieldString

Output only. Pinned field. Corresponds to the JSON property pinnedField

Returns:

  • (String)


20601
20602
20603
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20601

def pinned_field
  @pinned_field
end

#policy_summaryGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdAssetPolicySummary

Contains policy information for an ad group ad asset. Corresponds to the JSON property policySummary



20606
20607
20608
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20606

def policy_summary
  @policy_summary
end

#resource_nameString

Output only. The resource name of the ad group ad asset view. Ad group ad asset view resource names have the form (Before V4): customers/customer_id/ adGroupAdAssets/AdGroupAdAsset.ad_group_id~AdGroupAdAsset.ad.ad_id~ AdGroupAdAsset.asset_id~AdGroupAdAsset.field_typeAd group ad asset view resource names have the form (Beginning from V4): `customers/`customer_id`/ adGroupAdAssetViews/`AdGroupAdAsset.ad_group_id`~`AdGroupAdAsset.ad_id`~` AdGroupAdAsset.asset_id`~`AdGroupAdAsset.field_type Corresponds to the JSON property resourceName

Returns:

  • (String)


20617
20618
20619
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20617

def resource_name
  @resource_name
end

#sourceString

Output only. Source of the ad group ad asset. Corresponds to the JSON property source

Returns:

  • (String)


20622
20623
20624
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20622

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20629

def update!(**args)
  @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad)
  @asset = args[:asset] if args.key?(:asset)
  @enabled = args[:enabled] if args.key?(:enabled)
  @field_type = args[:field_type] if args.key?(:field_type)
  @performance_label = args[:performance_label] if args.key?(:performance_label)
  @pinned_field = args[:pinned_field] if args.key?(:pinned_field)
  @policy_summary = args[:policy_summary] if args.key?(:policy_summary)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @source = args[:source] if args.key?(:source)
end