Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdEffectiveLabel
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdEffectiveLabel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A relationship between an ad group ad and an effective label. An effective label is a label inherited or directly assigned to this ad group ad.
Instance Attribute Summary collapse
-
#ad_group_ad ⇒ String
Immutable.
-
#label ⇒ String
Immutable.
-
#owner_customer_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAdEffectiveLabel
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupAdEffectiveLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAdEffectiveLabel
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAdEffectiveLabel.
20595 20596 20597 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_ad ⇒ String
Immutable. The ad group ad to which the effective label is attached.
Corresponds to the JSON property adGroupAd
20576 20577 20578 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20576 def ad_group_ad @ad_group_ad end |
#label ⇒ String
Immutable. The effective label assigned to the ad group ad.
Corresponds to the JSON property label
20581 20582 20583 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20581 def label @label end |
#owner_customer_id ⇒ Fixnum
Output only. The ID of the Customer which owns the effective label.
Corresponds to the JSON property ownerCustomerId
20586 20587 20588 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20586 def owner_customer_id @owner_customer_id end |
#resource_name ⇒ String
Immutable. The resource name of the ad group ad effective label. Ad group ad
effective label resource names have the form: customers/owner_customer_id/
adGroupAdEffectiveLabels/ad_group_id~ad_id~label_id`
Corresponds to the JSON propertyresourceName`
20593 20594 20595 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20593 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20600 20601 20602 20603 20604 20605 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20600 def update!(**args) @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad) @label = args[:label] if args.key?(:label) @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id) @resource_name = args[:resource_name] if args.key?(:resource_name) end |