Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdLabel
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdLabel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A relationship between an ad group ad and a label.
Instance Attribute Summary collapse
-
#ad_group_ad ⇒ String
Immutable.
-
#label ⇒ String
Immutable.
-
#owner_customer_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAdLabel
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupAdLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAdLabel
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAdLabel.
20708 20709 20710 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20708 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_ad ⇒ String
Immutable. The ad group ad to which the label is attached.
Corresponds to the JSON property adGroupAd
20689 20690 20691 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20689 def ad_group_ad @ad_group_ad end |
#label ⇒ String
Immutable. The label assigned to the ad group ad.
Corresponds to the JSON property label
20694 20695 20696 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20694 def label @label end |
#owner_customer_id ⇒ Fixnum
Output only. The ID of the Customer which owns the label.
Corresponds to the JSON property ownerCustomerId
20699 20700 20701 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20699 def owner_customer_id @owner_customer_id end |
#resource_name ⇒ String
Immutable. The resource name of the ad group ad label. Ad group ad label
resource names have the form: customers/owner_customer_id/adGroupAdLabels/
ad_group_id~ad_id~label_id`
Corresponds to the JSON propertyresourceName`
20706 20707 20708 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20706 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20713 20714 20715 20716 20717 20718 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20713 def update!(**args) @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad) @label = args[:label] if args.key?(:label) @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id) @resource_name = args[:resource_name] if args.key?(:resource_name) end |