Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdPolicySummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Contains policy information for an ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAdPolicySummary

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAdPolicySummary.



20667
20668
20669
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approval_statusString

Output only. The overall approval status of this ad, calculated based on the status of its individual policy topic entries. Corresponds to the JSON property approvalStatus

Returns:

  • (String)


20655
20656
20657
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20655

def approval_status
  @approval_status
end

#policy_topic_entriesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyTopicEntry>

Output only. The list of policy findings for this ad. Corresponds to the JSON property policyTopicEntries



20660
20661
20662
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20660

def policy_topic_entries
  @policy_topic_entries
end

#review_statusString

Output only. Where in the review process this ad is. Corresponds to the JSON property reviewStatus

Returns:

  • (String)


20665
20666
20667
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20665

def review_status
  @review_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20672
20673
20674
20675
20676
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20672

def update!(**args)
  @approval_status = args[:approval_status] if args.key?(:approval_status)
  @policy_topic_entries = args[:policy_topic_entries] if args.key?(:policy_topic_entries)
  @review_status = args[:review_status] if args.key?(:review_status)
end