Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A link between an ad group and an asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAsset

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAsset.



20810
20811
20812
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Required. Immutable. The ad group to which the asset is linked. Corresponds to the JSON property adGroup

Returns:

  • (String)


20760
20761
20762
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20760

def ad_group
  @ad_group
end

#assetString

Required. Immutable. The asset which is linked to the ad group. Corresponds to the JSON property asset

Returns:

  • (String)


20765
20766
20767
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20765

def asset
  @asset
end

#field_typeString

Required. Immutable. Role that the asset takes under the linked ad group. Corresponds to the JSON property fieldType

Returns:

  • (String)


20770
20771
20772
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20770

def field_type
  @field_type
end

#primary_statusString

Output only. Provides the PrimaryStatus of this asset link. Primary status is meant essentially to differentiate between the plain "status" field, which has advertiser set values of enabled, paused, or removed. The primary status takes into account other signals (for assets its mainly policy and quality approvals) to come up with a more comprehensive status to indicate its serving state. Corresponds to the JSON property primaryStatus

Returns:

  • (String)


20779
20780
20781
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20779

def primary_status
  @primary_status
end

#primary_status_detailsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetLinkPrimaryStatusDetails>

Output only. Provides the details of the primary status and its associated reasons. Corresponds to the JSON property primaryStatusDetails



20785
20786
20787
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20785

def primary_status_details
  @primary_status_details
end

#primary_status_reasonsArray<String>

Output only. Provides a list of reasons for why an asset is not serving or not serving at full capacity. Corresponds to the JSON property primaryStatusReasons

Returns:

  • (Array<String>)


20791
20792
20793
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20791

def primary_status_reasons
  @primary_status_reasons
end

#resource_nameString

Immutable. The resource name of the ad group asset. AdGroupAsset resource names have the form: customers/customer_id/adGroupAssets/ad_group_id~ asset_id~field_type` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


20798
20799
20800
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20798

def resource_name
  @resource_name
end

#sourceString

Output only. Source of the adgroup asset link. Corresponds to the JSON property source

Returns:

  • (String)


20803
20804
20805
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20803

def source
  @source
end

#statusString

Status of the ad group asset. Corresponds to the JSON property status

Returns:

  • (String)


20808
20809
20810
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20808

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20815
20816
20817
20818
20819
20820
20821
20822
20823
20824
20825
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20815

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @asset = args[:asset] if args.key?(:asset)
  @field_type = args[:field_type] if args.key?(:field_type)
  @primary_status = args[:primary_status] if args.key?(:primary_status)
  @primary_status_details = args[:primary_status_details] if args.key?(:primary_status_details)
  @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @source = args[:source] if args.key?(:source)
  @status = args[:status] if args.key?(:status)
end