Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAssetSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

AdGroupAssetSet is the linkage between an ad group and an asset set. Creating an AdGroupAssetSet links an asset set with an ad group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAssetSet

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAssetSet.



20855
20856
20857
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Immutable. The ad group to which this asset set is linked. Corresponds to the JSON property adGroup

Returns:

  • (String)


20836
20837
20838
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20836

def ad_group
  @ad_group
end

#asset_setString

Immutable. The asset set which is linked to the ad group. Corresponds to the JSON property assetSet

Returns:

  • (String)


20841
20842
20843
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20841

def asset_set
  @asset_set
end

#resource_nameString

Immutable. The resource name of the ad group asset set. Ad group asset set resource names have the form: customers/customer_id/adGroupAssetSets/ ad_group_id~asset_set_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


20848
20849
20850
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20848

def resource_name
  @resource_name
end

#statusString

Output only. The status of the ad group asset set. Read-only. Corresponds to the JSON property status

Returns:

  • (String)


20853
20854
20855
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20853

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20860
20861
20862
20863
20864
20865
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20860

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @asset_set = args[:asset_set] if args.key?(:asset_set)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end