Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAudienceView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAudienceView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An ad group audience view. Includes performance data from interests and remarketing lists for Display Network and YouTube Network ads, and remarketing lists for search ads (RLSA), aggregated at the audience level.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAudienceView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupAudienceView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAudienceView
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAudienceView.
20941 20942 20943 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20941 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Output only. The resource name of the ad group audience view. Ad group
audience view resource names have the form: customers/customer_id/
adGroupAudienceViews/ad_group_id~criterion_id`
Corresponds to the JSON propertyresourceName`
20939 20940 20941 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20939 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20946 20947 20948 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20946 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) end |