Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAudienceView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAudienceView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An ad group audience view. Includes performance data from interests and remarketing lists for Display Network and YouTube Network ads, and remarketing lists for search ads (RLSA), aggregated at the audience level.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAudienceView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupAudienceView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupAudienceView
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupAudienceView.
20807 20808 20809 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20807 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Output only. The resource name of the ad group audience view. Ad group
audience view resource names have the form: customers/customer_id/
adGroupAudienceViews/ad_group_id~criterion_id`
Corresponds to the JSON propertyresourceName`
20805 20806 20807 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20805 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20812 20813 20814 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20812 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) end |