Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupBidModifier

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents an ad group bid modifier.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupBidModifier

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupBidModifier.



20963
20964
20965
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Immutable. The ad group to which this criterion belongs. Corresponds to the JSON property adGroup

Returns:

  • (String)


20898
20899
20900
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20898

def ad_group
  @ad_group
end

#base_ad_groupString

Output only. The base ad group from which this draft/trial adgroup bid modifier was created. If ad_group is a base ad group then this field will be equal to ad_group. If the ad group was created in the draft or trial and has no corresponding base ad group, then this field will be null. This field is readonly. Corresponds to the JSON property baseAdGroup

Returns:

  • (String)


20907
20908
20909
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20907

def base_ad_group
  @base_ad_group
end

#bid_modifierFloat

The modifier for the bid when the criterion matches. The modifier must be in the range: 0.1 - 10.0. Use 0 to opt out of a Device type. Corresponds to the JSON property bidModifier

Returns:

  • (Float)


20913
20914
20915
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20913

def bid_modifier
  @bid_modifier
end

#bid_modifier_sourceString

Output only. Bid modifier source. Corresponds to the JSON property bidModifierSource

Returns:

  • (String)


20918
20919
20920
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20918

def bid_modifier_source
  @bid_modifier_source
end

#criterion_idFixnum

Output only. The ID of the criterion to bid modify. This field is ignored for mutates. Corresponds to the JSON property criterionId

Returns:

  • (Fixnum)


20924
20925
20926
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20924

def criterion_id
  @criterion_id
end

#deviceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo

A device criterion. Corresponds to the JSON property device



20929
20930
20931
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20929

def device
  @device
end

#hotel_advance_booking_windowGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelAdvanceBookingWindowInfo

Criterion for number of days prior to the stay the booking is being made. Corresponds to the JSON property hotelAdvanceBookingWindow



20934
20935
20936
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20934

def hotel_advance_booking_window
  @hotel_advance_booking_window
end

#hotel_check_in_date_rangeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCheckInDateRangeInfo

Criterion for a check-in date range. Corresponds to the JSON property hotelCheckInDateRange



20939
20940
20941
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20939

def hotel_check_in_date_range
  @hotel_check_in_date_range
end

#hotel_check_in_dayGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCheckInDayInfo

Criterion for day of the week the booking is for. Corresponds to the JSON property hotelCheckInDay



20944
20945
20946
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20944

def hotel_check_in_day
  @hotel_check_in_day
end

#hotel_date_selection_typeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelDateSelectionTypeInfo

Criterion for hotel date selection (default dates versus user selected). Corresponds to the JSON property hotelDateSelectionType



20949
20950
20951
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20949

def hotel_date_selection_type
  @hotel_date_selection_type
end

#hotel_length_of_stayGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelLengthOfStayInfo

Criterion for length of hotel stay in nights. Corresponds to the JSON property hotelLengthOfStay



20954
20955
20956
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20954

def hotel_length_of_stay
  @hotel_length_of_stay
end

#resource_nameString

Immutable. The resource name of the ad group bid modifier. Ad group bid modifier resource names have the form: customers/customer_id/ adGroupBidModifiers/ad_group_id~criterion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


20961
20962
20963
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20961

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20968
20969
20970
20971
20972
20973
20974
20975
20976
20977
20978
20979
20980
20981
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20968

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @base_ad_group = args[:base_ad_group] if args.key?(:base_ad_group)
  @bid_modifier = args[:bid_modifier] if args.key?(:bid_modifier)
  @bid_modifier_source = args[:bid_modifier_source] if args.key?(:bid_modifier_source)
  @criterion_id = args[:criterion_id] if args.key?(:criterion_id)
  @device = args[:device] if args.key?(:device)
  @hotel_advance_booking_window = args[:hotel_advance_booking_window] if args.key?(:hotel_advance_booking_window)
  @hotel_check_in_date_range = args[:hotel_check_in_date_range] if args.key?(:hotel_check_in_date_range)
  @hotel_check_in_day = args[:hotel_check_in_day] if args.key?(:hotel_check_in_day)
  @hotel_date_selection_type = args[:hotel_date_selection_type] if args.key?(:hotel_date_selection_type)
  @hotel_length_of_stay = args[:hotel_length_of_stay] if args.key?(:hotel_length_of_stay)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end