Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupBidModifier
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupBidModifier
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents an ad group bid modifier.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Immutable.
-
#base_ad_group ⇒ String
Output only.
-
#bid_modifier ⇒ Float
The modifier for the bid when the criterion matches.
-
#bid_modifier_source ⇒ String
Output only.
-
#criterion_id ⇒ Fixnum
Output only.
-
#device ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo
A device criterion.
-
#hotel_advance_booking_window ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelAdvanceBookingWindowInfo
Criterion for number of days prior to the stay the booking is being made.
-
#hotel_check_in_date_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCheckInDateRangeInfo
Criterion for a check-in date range.
-
#hotel_check_in_day ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCheckInDayInfo
Criterion for day of the week the booking is for.
-
#hotel_date_selection_type ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelDateSelectionTypeInfo
Criterion for hotel date selection (default dates versus user selected).
-
#hotel_length_of_stay ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelLengthOfStayInfo
Criterion for length of hotel stay in nights.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupBidModifier
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupBidModifier.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupBidModifier
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupBidModifier.
20889 20890 20891 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Immutable. The ad group to which this criterion belongs.
Corresponds to the JSON property adGroup
20824 20825 20826 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20824 def ad_group @ad_group end |
#base_ad_group ⇒ String
Output only. The base ad group from which this draft/trial adgroup bid
modifier was created. If ad_group is a base ad group then this field will be
equal to ad_group. If the ad group was created in the draft or trial and has
no corresponding base ad group, then this field will be null. This field is
readonly.
Corresponds to the JSON property baseAdGroup
20833 20834 20835 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20833 def base_ad_group @base_ad_group end |
#bid_modifier ⇒ Float
The modifier for the bid when the criterion matches. The modifier must be in
the range: 0.1 - 10.0. Use 0 to opt out of a Device type.
Corresponds to the JSON property bidModifier
20839 20840 20841 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20839 def bid_modifier @bid_modifier end |
#bid_modifier_source ⇒ String
Output only. Bid modifier source.
Corresponds to the JSON property bidModifierSource
20844 20845 20846 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20844 def bid_modifier_source @bid_modifier_source end |
#criterion_id ⇒ Fixnum
Output only. The ID of the criterion to bid modify. This field is ignored for
mutates.
Corresponds to the JSON property criterionId
20850 20851 20852 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20850 def criterion_id @criterion_id end |
#device ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo
A device criterion.
Corresponds to the JSON property device
20855 20856 20857 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20855 def device @device end |
#hotel_advance_booking_window ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelAdvanceBookingWindowInfo
Criterion for number of days prior to the stay the booking is being made.
Corresponds to the JSON property hotelAdvanceBookingWindow
20860 20861 20862 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20860 def hotel_advance_booking_window @hotel_advance_booking_window end |
#hotel_check_in_date_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCheckInDateRangeInfo
Criterion for a check-in date range.
Corresponds to the JSON property hotelCheckInDateRange
20865 20866 20867 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20865 def hotel_check_in_date_range @hotel_check_in_date_range end |
#hotel_check_in_day ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCheckInDayInfo
Criterion for day of the week the booking is for.
Corresponds to the JSON property hotelCheckInDay
20870 20871 20872 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20870 def hotel_check_in_day @hotel_check_in_day end |
#hotel_date_selection_type ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelDateSelectionTypeInfo
Criterion for hotel date selection (default dates versus user selected).
Corresponds to the JSON property hotelDateSelectionType
20875 20876 20877 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20875 def hotel_date_selection_type @hotel_date_selection_type end |
#hotel_length_of_stay ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelLengthOfStayInfo
Criterion for length of hotel stay in nights.
Corresponds to the JSON property hotelLengthOfStay
20880 20881 20882 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20880 def hotel_length_of_stay @hotel_length_of_stay end |
#resource_name ⇒ String
Immutable. The resource name of the ad group bid modifier. Ad group bid
modifier resource names have the form: customers/customer_id/
adGroupBidModifiers/ad_group_id~criterion_id`
Corresponds to the JSON propertyresourceName`
20887 20888 20889 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20887 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20894 20895 20896 20897 20898 20899 20900 20901 20902 20903 20904 20905 20906 20907 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20894 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @base_ad_group = args[:base_ad_group] if args.key?(:base_ad_group) @bid_modifier = args[:bid_modifier] if args.key?(:bid_modifier) @bid_modifier_source = args[:bid_modifier_source] if args.key?(:bid_modifier_source) @criterion_id = args[:criterion_id] if args.key?(:criterion_id) @device = args[:device] if args.key?(:device) @hotel_advance_booking_window = args[:hotel_advance_booking_window] if args.key?(:hotel_advance_booking_window) @hotel_check_in_date_range = args[:hotel_check_in_date_range] if args.key?(:hotel_check_in_date_range) @hotel_check_in_day = args[:hotel_check_in_day] if args.key?(:hotel_check_in_day) @hotel_date_selection_type = args[:hotel_date_selection_type] if args.key?(:hotel_date_selection_type) @hotel_length_of_stay = args[:hotel_length_of_stay] if args.key?(:hotel_length_of_stay) @resource_name = args[:resource_name] if args.key?(:resource_name) end |