Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An ad group criterion. The ad_group_criterion report only returns criteria that were explicitly added to the ad group.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Immutable.
-
#age_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo
An age range criterion.
-
#app_payment_model ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppPaymentModelInfo
An app payment model criterion.
-
#approval_status ⇒ String
Output only.
-
#audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInfo
An audience criterion.
-
#bid_modifier ⇒ Float
The modifier for the bid when the criterion matches.
-
#brand_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandListInfo
A Brand List Criterion is used to specify a list of brands.
-
#combined_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCombinedAudienceInfo
A combined audience criterion.
-
#cpc_bid_micros ⇒ Fixnum
The CPC (cost-per-click) bid.
-
#cpm_bid_micros ⇒ Fixnum
The CPM (cost-per-thousand viewable impressions) bid.
-
#cpv_bid_micros ⇒ Fixnum
The CPV (cost-per-view) bid.
-
#creation_time ⇒ String
Output only.
-
#criterion_id ⇒ Fixnum
Output only.
-
#custom_affinity ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomAffinityInfo
A custom affinity criterion.
-
#custom_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomAudienceInfo
A custom audience criterion.
-
#custom_intent ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomIntentInfo
A custom intent criterion.
-
#disapproval_reasons ⇒ Array<String>
Output only.
-
#display_name ⇒ String
Output only.
-
#effective_cpc_bid_micros ⇒ Fixnum
Output only.
-
#effective_cpc_bid_source ⇒ String
Output only.
-
#effective_cpm_bid_micros ⇒ Fixnum
Output only.
-
#effective_cpm_bid_source ⇒ String
Output only.
-
#effective_cpv_bid_micros ⇒ Fixnum
Output only.
-
#effective_cpv_bid_source ⇒ String
Output only.
-
#effective_labels ⇒ Array<String>
Output only.
-
#effective_percent_cpc_bid_micros ⇒ Fixnum
Output only.
-
#effective_percent_cpc_bid_source ⇒ String
Output only.
-
#engine_id ⇒ String
Output only.
-
#engine_status ⇒ String
Output only.
-
#extended_demographic ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonExtendedDemographicInfo
Represents an extended demographic criterion.
-
#final_mobile_urls ⇒ Array<String>
The list of possible final mobile URLs after all cross-domain redirects.
-
#final_url_suffix ⇒ String
URL template for appending params to final URL.
-
#final_urls ⇒ Array<String>
The list of possible final URLs after all cross-domain redirects for the ad.
-
#gender ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo
A gender criterion.
-
#income_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIncomeRangeInfo
An income range criterion.
-
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo
A keyword criterion.
-
#labels ⇒ Array<String>
Output only.
-
#language ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLanguageInfo
A language criterion.
-
#last_modified_time ⇒ String
Output only.
-
#life_event ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLifeEventInfo
Represents a life event criterion.
-
#listing_group ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingGroupInfo
A listing group criterion.
-
#location ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo
A location criterion.
-
#mobile_app_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo
A mobile app category criterion.
-
#mobile_application ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo
A mobile application criterion.
-
#negative ⇒ Boolean
(also: #negative?)
Immutable.
-
#parental_status ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo
A parental status criterion.
-
#percent_cpc_bid_micros ⇒ Fixnum
The CPC bid amount, expressed as a fraction of the advertised price for some good or service.
-
#placement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo
A placement criterion.
-
#position_estimates ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates
Estimates for criterion bids at various positions.
-
#primary_status ⇒ String
Output only.
-
#primary_status_reasons ⇒ Array<String>
Output only.
-
#quality_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionQualityInfo
A container for ad group criterion quality information.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
The status of the criterion.
-
#system_serving_status ⇒ String
Output only.
-
#topic ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTopicInfo
A topic criterion.
-
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
-
#type ⇒ String
Output only.
-
#url_custom_parameters ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>
The list of mappings used to substitute custom parameter tags in a
tracking_url_template,final_urls, ormobile_final_urls. -
#user_interest ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserInterestInfo
Represents a particular interest-based topic to be targeted.
-
#user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListInfo
A User List criterion.
-
#vertical_ads_item_group_rule_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleListInfo
A criterion for targeting a shared set of rules for item groups in Vertical Ads (e.g., for hotel ads).
-
#video_lineup ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVideoLineupInfo
A Video lineup criterion.
-
#webpage ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageInfo
Represents a criterion for targeting webpages of an advertiser's website.
-
#youtube_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
A YouTube Channel criterion.
-
#youtube_video ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
A YouTube Video criterion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterion
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterion
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterion.
21278 21279 21280 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21278 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Immutable. The ad group to which the criterion belongs.
Corresponds to the JSON property adGroup
20918 20919 20920 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20918 def ad_group @ad_group end |
#age_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo
An age range criterion.
Corresponds to the JSON property ageRange
20923 20924 20925 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20923 def age_range @age_range end |
#app_payment_model ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppPaymentModelInfo
An app payment model criterion.
Corresponds to the JSON property appPaymentModel
20928 20929 20930 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20928 def app_payment_model @app_payment_model end |
#approval_status ⇒ String
Output only. Approval status of the criterion.
Corresponds to the JSON property approvalStatus
20933 20934 20935 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20933 def approval_status @approval_status end |
#audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInfo
An audience criterion.
Corresponds to the JSON property audience
20938 20939 20940 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20938 def audience @audience end |
#bid_modifier ⇒ Float
The modifier for the bid when the criterion matches. The modifier must be in
the range: 0.1 - 10.0. Most targetable criteria types support modifiers.
Corresponds to the JSON property bidModifier
20944 20945 20946 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20944 def bid_modifier @bid_modifier end |
#brand_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandListInfo
A Brand List Criterion is used to specify a list of brands. The list is
represented as a SharedSet id type BRAND_HINT. A criterion of this type can be
either targeted or excluded.
Corresponds to the JSON property brandList
20951 20952 20953 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20951 def brand_list @brand_list end |
#combined_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCombinedAudienceInfo
A combined audience criterion.
Corresponds to the JSON property combinedAudience
20956 20957 20958 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20956 def combined_audience @combined_audience end |
#cpc_bid_micros ⇒ Fixnum
The CPC (cost-per-click) bid.
Corresponds to the JSON property cpcBidMicros
20961 20962 20963 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20961 def cpc_bid_micros @cpc_bid_micros end |
#cpm_bid_micros ⇒ Fixnum
The CPM (cost-per-thousand viewable impressions) bid.
Corresponds to the JSON property cpmBidMicros
20966 20967 20968 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20966 def cpm_bid_micros @cpm_bid_micros end |
#cpv_bid_micros ⇒ Fixnum
The CPV (cost-per-view) bid.
Corresponds to the JSON property cpvBidMicros
20971 20972 20973 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20971 def cpv_bid_micros @cpv_bid_micros end |
#creation_time ⇒ String
Output only. The timestamp when this ad group criterion was created. The
timestamp is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format.
Corresponds to the JSON property creationTime
20977 20978 20979 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20977 def creation_time @creation_time end |
#criterion_id ⇒ Fixnum
Output only. The ID of the criterion.
Corresponds to the JSON property criterionId
20982 20983 20984 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20982 def criterion_id @criterion_id end |
#custom_affinity ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomAffinityInfo
A custom affinity criterion. A criterion of this type is only targetable.
Corresponds to the JSON property customAffinity
20987 20988 20989 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20987 def custom_affinity @custom_affinity end |
#custom_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomAudienceInfo
A custom audience criterion.
Corresponds to the JSON property customAudience
20992 20993 20994 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20992 def custom_audience @custom_audience end |
#custom_intent ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomIntentInfo
A custom intent criterion. A criterion of this type is only targetable.
Corresponds to the JSON property customIntent
20997 20998 20999 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 20997 def custom_intent @custom_intent end |
#disapproval_reasons ⇒ Array<String>
Output only. List of disapproval reasons of the criterion. The different
reasons for disapproving a criterion can be found here: https://support.google.
com/adspolicy/answer/6008942 This field is read-only.
Corresponds to the JSON property disapprovalReasons
21004 21005 21006 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21004 def disapproval_reasons @disapproval_reasons end |
#display_name ⇒ String
Output only. The display name of the criterion.
Corresponds to the JSON property displayName
21009 21010 21011 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21009 def display_name @display_name end |
#effective_cpc_bid_micros ⇒ Fixnum
Output only. The effective CPC (cost-per-click) bid.
Corresponds to the JSON property effectiveCpcBidMicros
21014 21015 21016 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21014 def effective_cpc_bid_micros @effective_cpc_bid_micros end |
#effective_cpc_bid_source ⇒ String
Output only. Source of the effective CPC bid.
Corresponds to the JSON property effectiveCpcBidSource
21019 21020 21021 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21019 def effective_cpc_bid_source @effective_cpc_bid_source end |
#effective_cpm_bid_micros ⇒ Fixnum
Output only. The effective CPM (cost-per-thousand viewable impressions) bid.
Corresponds to the JSON property effectiveCpmBidMicros
21024 21025 21026 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21024 def effective_cpm_bid_micros @effective_cpm_bid_micros end |
#effective_cpm_bid_source ⇒ String
Output only. Source of the effective CPM bid.
Corresponds to the JSON property effectiveCpmBidSource
21029 21030 21031 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21029 def effective_cpm_bid_source @effective_cpm_bid_source end |
#effective_cpv_bid_micros ⇒ Fixnum
Output only. The effective CPV (cost-per-view) bid.
Corresponds to the JSON property effectiveCpvBidMicros
21034 21035 21036 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21034 def effective_cpv_bid_micros @effective_cpv_bid_micros end |
#effective_cpv_bid_source ⇒ String
Output only. Source of the effective CPV bid.
Corresponds to the JSON property effectiveCpvBidSource
21039 21040 21041 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21039 def effective_cpv_bid_source @effective_cpv_bid_source end |
#effective_labels ⇒ Array<String>
Output only. The resource names of effective labels attached to this ad group
criterion. An effective label is a label inherited or directly assigned to
this ad group criterion.
Corresponds to the JSON property effectiveLabels
21046 21047 21048 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21046 def effective_labels @effective_labels end |
#effective_percent_cpc_bid_micros ⇒ Fixnum
Output only. The effective Percent CPC bid amount.
Corresponds to the JSON property effectivePercentCpcBidMicros
21051 21052 21053 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21051 def effective_percent_cpc_bid_micros @effective_percent_cpc_bid_micros end |
#effective_percent_cpc_bid_source ⇒ String
Output only. Source of the effective Percent CPC bid.
Corresponds to the JSON property effectivePercentCpcBidSource
21056 21057 21058 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21056 def effective_percent_cpc_bid_source @effective_percent_cpc_bid_source end |
#engine_id ⇒ String
Output only. ID of the ad group criterion in the external engine account. This
field is for non-Google Ads account only, for example, Yahoo Japan, Microsoft,
Baidu etc. For Google Ads entity, use "ad_group_criterion.criterion_id"
instead.
Corresponds to the JSON property engineId
21064 21065 21066 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21064 def engine_id @engine_id end |
#engine_status ⇒ String
Output only. The Engine Status for ad group criterion.
Corresponds to the JSON property engineStatus
21069 21070 21071 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21069 def engine_status @engine_status end |
#extended_demographic ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonExtendedDemographicInfo
Represents an extended demographic criterion.
Corresponds to the JSON property extendedDemographic
21074 21075 21076 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21074 def extended_demographic @extended_demographic end |
#final_mobile_urls ⇒ Array<String>
The list of possible final mobile URLs after all cross-domain redirects.
Corresponds to the JSON property finalMobileUrls
21079 21080 21081 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21079 def final_mobile_urls @final_mobile_urls end |
#final_url_suffix ⇒ String
URL template for appending params to final URL.
Corresponds to the JSON property finalUrlSuffix
21084 21085 21086 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21084 def final_url_suffix @final_url_suffix end |
#final_urls ⇒ Array<String>
The list of possible final URLs after all cross-domain redirects for the ad.
Corresponds to the JSON property finalUrls
21089 21090 21091 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21089 def final_urls @final_urls end |
#gender ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo
A gender criterion.
Corresponds to the JSON property gender
21094 21095 21096 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21094 def gender @gender end |
#income_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIncomeRangeInfo
An income range criterion.
Corresponds to the JSON property incomeRange
21099 21100 21101 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21099 def income_range @income_range end |
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo
A keyword criterion.
Corresponds to the JSON property keyword
21104 21105 21106 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21104 def keyword @keyword end |
#labels ⇒ Array<String>
Output only. The resource names of labels attached to this ad group criterion.
Corresponds to the JSON property labels
21109 21110 21111 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21109 def labels @labels end |
#language ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLanguageInfo
A language criterion.
Corresponds to the JSON property language
21114 21115 21116 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21114 def language @language end |
#last_modified_time ⇒ String
Output only. The datetime when this ad group criterion was last modified. The
datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss"
format.
Corresponds to the JSON property lastModifiedTime
21121 21122 21123 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21121 def last_modified_time @last_modified_time end |
#life_event ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLifeEventInfo
Represents a life event criterion.
Corresponds to the JSON property lifeEvent
21126 21127 21128 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21126 def life_event @life_event end |
#listing_group ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingGroupInfo
A listing group criterion.
Corresponds to the JSON property listingGroup
21131 21132 21133 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21131 def listing_group @listing_group end |
#location ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo
A location criterion.
Corresponds to the JSON property location
21136 21137 21138 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21136 def location @location end |
#mobile_app_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo
A mobile app category criterion.
Corresponds to the JSON property mobileAppCategory
21141 21142 21143 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21141 def mobile_app_category @mobile_app_category end |
#mobile_application ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo
A mobile application criterion.
Corresponds to the JSON property mobileApplication
21146 21147 21148 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21146 def mobile_application @mobile_application end |
#negative ⇒ Boolean Also known as: negative?
Immutable. Whether to target (false) or exclude (true) the criterion. This
field is immutable. To switch a criterion from positive to negative, remove
then re-add it.
Corresponds to the JSON property negative
21153 21154 21155 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21153 def negative @negative end |
#parental_status ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo
A parental status criterion.
Corresponds to the JSON property parentalStatus
21159 21160 21161 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21159 def parental_status @parental_status end |
#percent_cpc_bid_micros ⇒ Fixnum
The CPC bid amount, expressed as a fraction of the advertised price for some
good or service. The valid range for the fraction is [0,1) and the value
stored here is 1,000,000 * [fraction].
Corresponds to the JSON property percentCpcBidMicros
21166 21167 21168 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21166 def percent_cpc_bid_micros @percent_cpc_bid_micros end |
#placement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo
A placement criterion. This can be used to modify bids for sites when
targeting the content network.
Corresponds to the JSON property placement
21172 21173 21174 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21172 def placement @placement end |
#position_estimates ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates
Estimates for criterion bids at various positions.
Corresponds to the JSON property positionEstimates
21177 21178 21179 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21177 def position_estimates @position_estimates end |
#primary_status ⇒ String
Output only. The primary status for the ad group criterion.
Corresponds to the JSON property primaryStatus
21182 21183 21184 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21182 def primary_status @primary_status end |
#primary_status_reasons ⇒ Array<String>
Output only. The primary status reasons for the ad group criterion.
Corresponds to the JSON property primaryStatusReasons
21187 21188 21189 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21187 def primary_status_reasons @primary_status_reasons end |
#quality_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionQualityInfo
A container for ad group criterion quality information.
Corresponds to the JSON property qualityInfo
21192 21193 21194 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21192 def quality_info @quality_info end |
#resource_name ⇒ String
Immutable. The resource name of the ad group criterion. Ad group criterion
resource names have the form: customers/customer_id/adGroupCriteria/
ad_group_id~criterion_id`
Corresponds to the JSON propertyresourceName`
21199 21200 21201 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21199 def resource_name @resource_name end |
#status ⇒ String
The status of the criterion. This is the status of the ad group criterion
entity, set by the client. Note: UI reports may incorporate additional
information that affects whether a criterion is eligible to run. In some cases
a criterion that's REMOVED in the API can still show as enabled in the UI. For
example, campaigns by default show to users of all age ranges unless excluded.
The UI will show each age range as "enabled", since they're eligible to see
the ads; but AdGroupCriterion.status will show "removed", since no positive
criterion was added.
Corresponds to the JSON property status
21211 21212 21213 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21211 def status @status end |
#system_serving_status ⇒ String
Output only. Serving status of the criterion.
Corresponds to the JSON property systemServingStatus
21216 21217 21218 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21216 def system_serving_status @system_serving_status end |
#topic ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTopicInfo
A topic criterion. Use topics to target or exclude placements in the Google
Display Network based on the category into which the placement falls (for
example, "Pets & Animals/Pets/Dogs").
Corresponds to the JSON property topic
21223 21224 21225 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21223 def topic @topic end |
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL.
Corresponds to the JSON property trackingUrlTemplate
21228 21229 21230 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21228 def tracking_url_template @tracking_url_template end |
#type ⇒ String
Output only. The type of the criterion.
Corresponds to the JSON property type
21233 21234 21235 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21233 def type @type end |
#url_custom_parameters ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>
The list of mappings used to substitute custom parameter tags in a
tracking_url_template, final_urls, or mobile_final_urls.
Corresponds to the JSON property urlCustomParameters
21239 21240 21241 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21239 def url_custom_parameters @url_custom_parameters end |
#user_interest ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserInterestInfo
Represents a particular interest-based topic to be targeted.
Corresponds to the JSON property userInterest
21244 21245 21246 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21244 def user_interest @user_interest end |
#user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListInfo
A User List criterion. Represents a user list that is defined by the
advertiser to be targeted.
Corresponds to the JSON property userList
21250 21251 21252 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21250 def user_list @user_list end |
#vertical_ads_item_group_rule_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleListInfo
A criterion for targeting a shared set of rules for item groups in Vertical
Ads (e.g., for hotel ads).
Corresponds to the JSON property verticalAdsItemGroupRuleList
21256 21257 21258 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21256 def vertical_ads_item_group_rule_list @vertical_ads_item_group_rule_list end |
#video_lineup ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVideoLineupInfo
A Video lineup criterion.
Corresponds to the JSON property videoLineup
21261 21262 21263 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21261 def video_lineup @video_lineup end |
#webpage ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageInfo
Represents a criterion for targeting webpages of an advertiser's website.
Corresponds to the JSON property webpage
21266 21267 21268 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21266 def webpage @webpage end |
#youtube_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
A YouTube Channel criterion.
Corresponds to the JSON property youtubeChannel
21271 21272 21273 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21271 def youtube_channel @youtube_channel end |
#youtube_video ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
A YouTube Video criterion.
Corresponds to the JSON property youtubeVideo
21276 21277 21278 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21276 def youtube_video @youtube_video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21283 21284 21285 21286 21287 21288 21289 21290 21291 21292 21293 21294 21295 21296 21297 21298 21299 21300 21301 21302 21303 21304 21305 21306 21307 21308 21309 21310 21311 21312 21313 21314 21315 21316 21317 21318 21319 21320 21321 21322 21323 21324 21325 21326 21327 21328 21329 21330 21331 21332 21333 21334 21335 21336 21337 21338 21339 21340 21341 21342 21343 21344 21345 21346 21347 21348 21349 21350 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21283 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @age_range = args[:age_range] if args.key?(:age_range) @app_payment_model = args[:app_payment_model] if args.key?(:app_payment_model) @approval_status = args[:approval_status] if args.key?(:approval_status) @audience = args[:audience] if args.key?(:audience) @bid_modifier = args[:bid_modifier] if args.key?(:bid_modifier) @brand_list = args[:brand_list] if args.key?(:brand_list) @combined_audience = args[:combined_audience] if args.key?(:combined_audience) @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros) @cpm_bid_micros = args[:cpm_bid_micros] if args.key?(:cpm_bid_micros) @cpv_bid_micros = args[:cpv_bid_micros] if args.key?(:cpv_bid_micros) @creation_time = args[:creation_time] if args.key?(:creation_time) @criterion_id = args[:criterion_id] if args.key?(:criterion_id) @custom_affinity = args[:custom_affinity] if args.key?(:custom_affinity) @custom_audience = args[:custom_audience] if args.key?(:custom_audience) @custom_intent = args[:custom_intent] if args.key?(:custom_intent) @disapproval_reasons = args[:disapproval_reasons] if args.key?(:disapproval_reasons) @display_name = args[:display_name] if args.key?(:display_name) @effective_cpc_bid_micros = args[:effective_cpc_bid_micros] if args.key?(:effective_cpc_bid_micros) @effective_cpc_bid_source = args[:effective_cpc_bid_source] if args.key?(:effective_cpc_bid_source) @effective_cpm_bid_micros = args[:effective_cpm_bid_micros] if args.key?(:effective_cpm_bid_micros) @effective_cpm_bid_source = args[:effective_cpm_bid_source] if args.key?(:effective_cpm_bid_source) @effective_cpv_bid_micros = args[:effective_cpv_bid_micros] if args.key?(:effective_cpv_bid_micros) @effective_cpv_bid_source = args[:effective_cpv_bid_source] if args.key?(:effective_cpv_bid_source) @effective_labels = args[:effective_labels] if args.key?(:effective_labels) @effective_percent_cpc_bid_micros = args[:effective_percent_cpc_bid_micros] if args.key?(:effective_percent_cpc_bid_micros) @effective_percent_cpc_bid_source = args[:effective_percent_cpc_bid_source] if args.key?(:effective_percent_cpc_bid_source) @engine_id = args[:engine_id] if args.key?(:engine_id) @engine_status = args[:engine_status] if args.key?(:engine_status) @extended_demographic = args[:extended_demographic] if args.key?(:extended_demographic) @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @final_urls = args[:final_urls] if args.key?(:final_urls) @gender = args[:gender] if args.key?(:gender) @income_range = args[:income_range] if args.key?(:income_range) @keyword = args[:keyword] if args.key?(:keyword) @labels = args[:labels] if args.key?(:labels) @language = args[:language] if args.key?(:language) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @life_event = args[:life_event] if args.key?(:life_event) @listing_group = args[:listing_group] if args.key?(:listing_group) @location = args[:location] if args.key?(:location) @mobile_app_category = args[:mobile_app_category] if args.key?(:mobile_app_category) @mobile_application = args[:mobile_application] if args.key?(:mobile_application) @negative = args[:negative] if args.key?(:negative) @parental_status = args[:parental_status] if args.key?(:parental_status) @percent_cpc_bid_micros = args[:percent_cpc_bid_micros] if args.key?(:percent_cpc_bid_micros) @placement = args[:placement] if args.key?(:placement) @position_estimates = args[:position_estimates] if args.key?(:position_estimates) @primary_status = args[:primary_status] if args.key?(:primary_status) @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons) @quality_info = args[:quality_info] if args.key?(:quality_info) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @system_serving_status = args[:system_serving_status] if args.key?(:system_serving_status) @topic = args[:topic] if args.key?(:topic) @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template) @type = args[:type] if args.key?(:type) @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters) @user_interest = args[:user_interest] if args.key?(:user_interest) @user_list = args[:user_list] if args.key?(:user_list) @vertical_ads_item_group_rule_list = args[:vertical_ads_item_group_rule_list] if args.key?(:vertical_ads_item_group_rule_list) @video_lineup = args[:video_lineup] if args.key?(:video_lineup) @webpage = args[:webpage] if args.key?(:webpage) @youtube_channel = args[:youtube_channel] if args.key?(:youtube_channel) @youtube_video = args[:youtube_video] if args.key?(:youtube_video) end |