Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionCustomizer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A customizer value for the associated CustomizerAttribute at the AdGroupCriterion level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionCustomizer

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionCustomizer.



21463
21464
21465
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21463

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_criterionString

Immutable. The ad group criterion to which the customizer attribute is linked. It must be a keyword criterion. Corresponds to the JSON property adGroupCriterion

Returns:

  • (String)


21436
21437
21438
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21436

def ad_group_criterion
  @ad_group_criterion
end

#customizer_attributeString

Required. Immutable. The customizer attribute which is linked to the ad group criterion. Corresponds to the JSON property customizerAttribute

Returns:

  • (String)


21442
21443
21444
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21442

def customizer_attribute
  @customizer_attribute
end

#resource_nameString

Immutable. The resource name of the ad group criterion customizer. Ad group criterion customizer resource names have the form: customers/customer_id/ adGroupCriterionCustomizers/ad_group_id~criterion_id~ customizer_attribute_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


21450
21451
21452
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21450

def resource_name
  @resource_name
end

#statusString

Output only. The status of the ad group criterion customizer. Corresponds to the JSON property status

Returns:

  • (String)


21455
21456
21457
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21455

def status
  @status
end

#valueGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue

A customizer value that is referenced in customizer linkage entities like CustomerCustomizer, CampaignCustomizer, etc. Corresponds to the JSON property value



21461
21462
21463
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21461

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21468
21469
21470
21471
21472
21473
21474
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21468

def update!(**args)
  @ad_group_criterion = args[:ad_group_criterion] if args.key?(:ad_group_criterion)
  @customizer_attribute = args[:customizer_attribute] if args.key?(:customizer_attribute)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @value = args[:value] if args.key?(:value)
end