Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionCustomizer
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionCustomizer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A customizer value for the associated CustomizerAttribute at the AdGroupCriterion level.
Instance Attribute Summary collapse
-
#ad_group_criterion ⇒ String
Immutable.
-
#customizer_attribute ⇒ String
Required.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#value ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue
A customizer value that is referenced in customizer linkage entities like CustomerCustomizer, CampaignCustomizer, etc.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionCustomizer
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionCustomizer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionCustomizer
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionCustomizer.
21389 21390 21391 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_criterion ⇒ String
Immutable. The ad group criterion to which the customizer attribute is linked.
It must be a keyword criterion.
Corresponds to the JSON property adGroupCriterion
21362 21363 21364 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21362 def ad_group_criterion @ad_group_criterion end |
#customizer_attribute ⇒ String
Required. Immutable. The customizer attribute which is linked to the ad group
criterion.
Corresponds to the JSON property customizerAttribute
21368 21369 21370 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21368 def customizer_attribute @customizer_attribute end |
#resource_name ⇒ String
Immutable. The resource name of the ad group criterion customizer. Ad group
criterion customizer resource names have the form: customers/customer_id/
adGroupCriterionCustomizers/ad_group_id~criterion_id~
customizer_attribute_id`
Corresponds to the JSON propertyresourceName`
21376 21377 21378 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21376 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the ad group criterion customizer.
Corresponds to the JSON property status
21381 21382 21383 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21381 def status @status end |
#value ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue
A customizer value that is referenced in customizer linkage entities like
CustomerCustomizer, CampaignCustomizer, etc.
Corresponds to the JSON property value
21387 21388 21389 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21387 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21394 21395 21396 21397 21398 21399 21400 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21394 def update!(**args) @ad_group_criterion = args[:ad_group_criterion] if args.key?(:ad_group_criterion) @customizer_attribute = args[:customizer_attribute] if args.key?(:customizer_attribute) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @value = args[:value] if args.key?(:value) end |