Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionEffectiveLabel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A relationship between an ad group criterion and an effective label. An effective label is a label inherited or directly assigned to this ad group criterion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionEffectiveLabel

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionEffectiveLabel.



21432
21433
21434
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_criterionString

Immutable. The ad group criterion to which the effective label is attached. Corresponds to the JSON property adGroupCriterion

Returns:

  • (String)


21412
21413
21414
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21412

def ad_group_criterion
  @ad_group_criterion
end

#labelString

Immutable. The effective label assigned to the ad group criterion. Corresponds to the JSON property label

Returns:

  • (String)


21417
21418
21419
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21417

def label
  @label
end

#owner_customer_idFixnum

Output only. The ID of the Customer which owns the effective label. Corresponds to the JSON property ownerCustomerId

Returns:

  • (Fixnum)


21422
21423
21424
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21422

def owner_customer_id
  @owner_customer_id
end

#resource_nameString

Immutable. The resource name of the ad group criterion effective label. Ad group criterion effective label resource names have the form: customers/ owner_customer_id/adGroupCriterionEffectiveLabels/ad_group_id~criterion_id ~label_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


21430
21431
21432
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21430

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21437
21438
21439
21440
21441
21442
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21437

def update!(**args)
  @ad_group_criterion = args[:ad_group_criterion] if args.key?(:ad_group_criterion)
  @label = args[:label] if args.key?(:label)
  @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end