Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionLabel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A relationship between an ad group criterion and a label.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionLabel

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionLabel.



21545
21546
21547
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21545

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_criterionString

Immutable. The ad group criterion to which the label is attached. Corresponds to the JSON property adGroupCriterion

Returns:

  • (String)


21526
21527
21528
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21526

def ad_group_criterion
  @ad_group_criterion
end

#labelString

Immutable. The label assigned to the ad group criterion. Corresponds to the JSON property label

Returns:

  • (String)


21531
21532
21533
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21531

def label
  @label
end

#owner_customer_idFixnum

Output only. The ID of the Customer which owns the label. Corresponds to the JSON property ownerCustomerId

Returns:

  • (Fixnum)


21536
21537
21538
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21536

def owner_customer_id
  @owner_customer_id
end

#resource_nameString

Immutable. The resource name of the ad group criterion label. Ad group criterion label resource names have the form: customers/owner_customer_id/ adGroupCriterionLabels/ad_group_id~criterion_id~label_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


21543
21544
21545
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21543

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21550
21551
21552
21553
21554
21555
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21550

def update!(**args)
  @ad_group_criterion = args[:ad_group_criterion] if args.key?(:ad_group_criterion)
  @label = args[:label] if args.key?(:label)
  @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end