Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Estimates for criterion bids at various positions.
Instance Attribute Summary collapse
-
#estimated_add_clicks_at_first_position_cpc ⇒ Fixnum
Output only.
-
#estimated_add_cost_at_first_position_cpc ⇒ Fixnum
Output only.
-
#first_page_cpc_micros ⇒ Fixnum
Output only.
-
#first_position_cpc_micros ⇒ Fixnum
Output only.
-
#top_of_page_cpc_micros ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates.
15052 15053 15054 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15052 def initialize(**args) update!(**args) end |
Instance Attribute Details
#estimated_add_clicks_at_first_position_cpc ⇒ Fixnum
Output only. Estimate of how many clicks per week you might get by changing
your keyword bid to the value in first_position_cpc_micros.
Corresponds to the JSON property estimatedAddClicksAtFirstPositionCpc
15026 15027 15028 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15026 def estimated_add_clicks_at_first_position_cpc @estimated_add_clicks_at_first_position_cpc end |
#estimated_add_cost_at_first_position_cpc ⇒ Fixnum
Output only. Estimate of how your cost per week might change when changing
your keyword bid to the value in first_position_cpc_micros.
Corresponds to the JSON property estimatedAddCostAtFirstPositionCpc
15032 15033 15034 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15032 def estimated_add_cost_at_first_position_cpc @estimated_add_cost_at_first_position_cpc end |
#first_page_cpc_micros ⇒ Fixnum
Output only. The estimate of the CPC bid required for ad to be shown on first
page of search results.
Corresponds to the JSON property firstPageCpcMicros
15038 15039 15040 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15038 def first_page_cpc_micros @first_page_cpc_micros end |
#first_position_cpc_micros ⇒ Fixnum
Output only. The estimate of the CPC bid required for ad to be displayed in
first position, at the top of the first page of search results.
Corresponds to the JSON property firstPositionCpcMicros
15044 15045 15046 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15044 def first_position_cpc_micros @first_position_cpc_micros end |
#top_of_page_cpc_micros ⇒ Fixnum
Output only. The estimate of the CPC bid required for ad to be displayed at
the top of the first page of search results.
Corresponds to the JSON property topOfPageCpcMicros
15050 15051 15052 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15050 def top_of_page_cpc_micros @top_of_page_cpc_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15057 15058 15059 15060 15061 15062 15063 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15057 def update!(**args) @estimated_add_clicks_at_first_position_cpc = args[:estimated_add_clicks_at_first_position_cpc] if args.key?(:estimated_add_clicks_at_first_position_cpc) @estimated_add_cost_at_first_position_cpc = args[:estimated_add_cost_at_first_position_cpc] if args.key?(:estimated_add_cost_at_first_position_cpc) @first_page_cpc_micros = args[:first_page_cpc_micros] if args.key?(:first_page_cpc_micros) @first_position_cpc_micros = args[:first_position_cpc_micros] if args.key?(:first_position_cpc_micros) @top_of_page_cpc_micros = args[:top_of_page_cpc_micros] if args.key?(:top_of_page_cpc_micros) end |