Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Estimates for criterion bids at various positions.
Instance Attribute Summary collapse
-
#estimated_add_clicks_at_first_position_cpc ⇒ Fixnum
Output only.
-
#estimated_add_cost_at_first_position_cpc ⇒ Fixnum
Output only.
-
#first_page_cpc_micros ⇒ Fixnum
Output only.
-
#first_position_cpc_micros ⇒ Fixnum
Output only.
-
#top_of_page_cpc_micros ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionPositionEstimates.
14986 14987 14988 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14986 def initialize(**args) update!(**args) end |
Instance Attribute Details
#estimated_add_clicks_at_first_position_cpc ⇒ Fixnum
Output only. Estimate of how many clicks per week you might get by changing
your keyword bid to the value in first_position_cpc_micros.
Corresponds to the JSON property estimatedAddClicksAtFirstPositionCpc
14960 14961 14962 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14960 def estimated_add_clicks_at_first_position_cpc @estimated_add_clicks_at_first_position_cpc end |
#estimated_add_cost_at_first_position_cpc ⇒ Fixnum
Output only. Estimate of how your cost per week might change when changing
your keyword bid to the value in first_position_cpc_micros.
Corresponds to the JSON property estimatedAddCostAtFirstPositionCpc
14966 14967 14968 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14966 def estimated_add_cost_at_first_position_cpc @estimated_add_cost_at_first_position_cpc end |
#first_page_cpc_micros ⇒ Fixnum
Output only. The estimate of the CPC bid required for ad to be shown on first
page of search results.
Corresponds to the JSON property firstPageCpcMicros
14972 14973 14974 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14972 def first_page_cpc_micros @first_page_cpc_micros end |
#first_position_cpc_micros ⇒ Fixnum
Output only. The estimate of the CPC bid required for ad to be displayed in
first position, at the top of the first page of search results.
Corresponds to the JSON property firstPositionCpcMicros
14978 14979 14980 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14978 def first_position_cpc_micros @first_position_cpc_micros end |
#top_of_page_cpc_micros ⇒ Fixnum
Output only. The estimate of the CPC bid required for ad to be displayed at
the top of the first page of search results.
Corresponds to the JSON property topOfPageCpcMicros
14984 14985 14986 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14984 def top_of_page_cpc_micros @top_of_page_cpc_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14991 14992 14993 14994 14995 14996 14997 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 14991 def update!(**args) @estimated_add_clicks_at_first_position_cpc = args[:estimated_add_clicks_at_first_position_cpc] if args.key?(:estimated_add_clicks_at_first_position_cpc) @estimated_add_cost_at_first_position_cpc = args[:estimated_add_cost_at_first_position_cpc] if args.key?(:estimated_add_cost_at_first_position_cpc) @first_page_cpc_micros = args[:first_page_cpc_micros] if args.key?(:first_page_cpc_micros) @first_position_cpc_micros = args[:first_position_cpc_micros] if args.key?(:first_position_cpc_micros) @top_of_page_cpc_micros = args[:top_of_page_cpc_micros] if args.key?(:top_of_page_cpc_micros) end |