Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionQualityInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionQualityInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A container for ad group criterion quality information.
Instance Attribute Summary collapse
-
#creative_quality_score ⇒ String
Output only.
-
#post_click_quality_score ⇒ String
Output only.
-
#quality_score ⇒ Fixnum
Output only.
-
#search_predicted_ctr ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionQualityInfo
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionQualityInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionQualityInfo
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionQualityInfo.
15091 15092 15093 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15091 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creative_quality_score ⇒ String
Output only. The performance of the ad compared to other advertisers.
Corresponds to the JSON property creativeQualityScore
15073 15074 15075 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15073 def creative_quality_score @creative_quality_score end |
#post_click_quality_score ⇒ String
Output only. The quality score of the landing page.
Corresponds to the JSON property postClickQualityScore
15078 15079 15080 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15078 def post_click_quality_score @post_click_quality_score end |
#quality_score ⇒ Fixnum
Output only. The quality score. This field may not be populated if Google does
not have enough information to determine a value.
Corresponds to the JSON property qualityScore
15084 15085 15086 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15084 def quality_score @quality_score end |
#search_predicted_ctr ⇒ String
Output only. The click-through rate compared to that of other advertisers.
Corresponds to the JSON property searchPredictedCtr
15089 15090 15091 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15089 def search_predicted_ctr @search_predicted_ctr end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15096 15097 15098 15099 15100 15101 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15096 def update!(**args) @creative_quality_score = args[:creative_quality_score] if args.key?(:creative_quality_score) @post_click_quality_score = args[:post_click_quality_score] if args.key?(:post_click_quality_score) @quality_score = args[:quality_score] if args.key?(:quality_score) @search_predicted_ctr = args[:search_predicted_ctr] if args.key?(:search_predicted_ctr) end |