Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionQualityInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A container for ad group criterion quality information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionQualityInfo

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionQualityInfo.



15025
15026
15027
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15025

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creative_quality_scoreString

Output only. The performance of the ad compared to other advertisers. Corresponds to the JSON property creativeQualityScore

Returns:

  • (String)


15007
15008
15009
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15007

def creative_quality_score
  @creative_quality_score
end

#post_click_quality_scoreString

Output only. The quality score of the landing page. Corresponds to the JSON property postClickQualityScore

Returns:

  • (String)


15012
15013
15014
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15012

def post_click_quality_score
  @post_click_quality_score
end

#quality_scoreFixnum

Output only. The quality score. This field may not be populated if Google does not have enough information to determine a value. Corresponds to the JSON property qualityScore

Returns:

  • (Fixnum)


15018
15019
15020
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15018

def quality_score
  @quality_score
end

#search_predicted_ctrString

Output only. The click-through rate compared to that of other advertisers. Corresponds to the JSON property searchPredictedCtr

Returns:

  • (String)


15023
15024
15025
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15023

def search_predicted_ctr
  @search_predicted_ctr
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15030
15031
15032
15033
15034
15035
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15030

def update!(**args)
  @creative_quality_score = args[:creative_quality_score] if args.key?(:creative_quality_score)
  @post_click_quality_score = args[:post_click_quality_score] if args.key?(:post_click_quality_score)
  @quality_score = args[:quality_score] if args.key?(:quality_score)
  @search_predicted_ctr = args[:search_predicted_ctr] if args.key?(:search_predicted_ctr)
end