Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionSimulation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionSimulation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An ad group criterion simulation. Supported combinations of advertising channel type, criterion type, simulation type, and simulation modification method are detailed below respectively. Hotel AdGroupCriterion simulation operations starting in V5. 1. DISPLAY - KEYWORD - CPC_BID - UNIFORM 2. SEARCH - KEYWORD - CPC_BID - UNIFORM 3. SHOPPING - LISTING_GROUP - CPC_BID - UNIFORM 4. HOTEL - LISTING_GROUP - CPC_BID - UNIFORM 5. HOTEL - LISTING_GROUP - PERCENT_CPC_BID - UNIFORM
Instance Attribute Summary collapse
-
#ad_group_id ⇒ Fixnum
Output only.
-
#cpc_bid_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpcBidSimulationPointList
A container for simulation points for simulations of type CPC_BID.
-
#criterion_id ⇒ Fixnum
Output only.
-
#end_date ⇒ String
Output only.
-
#modification_method ⇒ String
Output only.
-
#percent_cpc_bid_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPercentCpcBidSimulationPointList
A container for simulation points for simulations of type PERCENT_CPC_BID.
-
#resource_name ⇒ String
Output only.
-
#start_date ⇒ String
Output only.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionSimulation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionSimulation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionSimulation
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionSimulation.
21676 21677 21678 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21676 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_id ⇒ Fixnum
Output only. AdGroup ID of the simulation.
Corresponds to the JSON property adGroupId
21631 21632 21633 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21631 def ad_group_id @ad_group_id end |
#cpc_bid_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpcBidSimulationPointList
A container for simulation points for simulations of type CPC_BID.
Corresponds to the JSON property cpcBidPointList
21636 21637 21638 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21636 def cpc_bid_point_list @cpc_bid_point_list end |
#criterion_id ⇒ Fixnum
Output only. Criterion ID of the simulation.
Corresponds to the JSON property criterionId
21641 21642 21643 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21641 def criterion_id @criterion_id end |
#end_date ⇒ String
Output only. Last day on which the simulation is based, in YYYY-MM-DD format.
Corresponds to the JSON property endDate
21646 21647 21648 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21646 def end_date @end_date end |
#modification_method ⇒ String
Output only. How the simulation modifies the field.
Corresponds to the JSON property modificationMethod
21651 21652 21653 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21651 def modification_method @modification_method end |
#percent_cpc_bid_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPercentCpcBidSimulationPointList
A container for simulation points for simulations of type PERCENT_CPC_BID.
Corresponds to the JSON property percentCpcBidPointList
21656 21657 21658 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21656 def percent_cpc_bid_point_list @percent_cpc_bid_point_list end |
#resource_name ⇒ String
Output only. The resource name of the ad group criterion simulation. Ad group
criterion simulation resource names have the form: customers/customer_id/
adGroupCriterionSimulations/ad_group_id~criterion_id~type~
modification_method~start_date~end_date`
Corresponds to the JSON propertyresourceName`
21664 21665 21666 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21664 def resource_name @resource_name end |
#start_date ⇒ String
Output only. First day on which the simulation is based, in YYYY-MM-DD format.
Corresponds to the JSON property startDate
21669 21670 21671 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21669 def start_date @start_date end |
#type ⇒ String
Output only. The field that the simulation modifies.
Corresponds to the JSON property type
21674 21675 21676 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21674 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21681 21682 21683 21684 21685 21686 21687 21688 21689 21690 21691 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21681 def update!(**args) @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id) @cpc_bid_point_list = args[:cpc_bid_point_list] if args.key?(:cpc_bid_point_list) @criterion_id = args[:criterion_id] if args.key?(:criterion_id) @end_date = args[:end_date] if args.key?(:end_date) @modification_method = args[:modification_method] if args.key?(:modification_method) @percent_cpc_bid_point_list = args[:percent_cpc_bid_point_list] if args.key?(:percent_cpc_bid_point_list) @resource_name = args[:resource_name] if args.key?(:resource_name) @start_date = args[:start_date] if args.key?(:start_date) @type = args[:type] if args.key?(:type) end |