Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterionSimulation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An ad group criterion simulation. Supported combinations of advertising channel type, criterion type, simulation type, and simulation modification method are detailed below respectively. Hotel AdGroupCriterion simulation operations starting in V5. 1. DISPLAY - KEYWORD - CPC_BID - UNIFORM 2. SEARCH - KEYWORD - CPC_BID - UNIFORM 3. SHOPPING - LISTING_GROUP - CPC_BID - UNIFORM 4. HOTEL - LISTING_GROUP - CPC_BID - UNIFORM 5. HOTEL - LISTING_GROUP - PERCENT_CPC_BID - UNIFORM

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCriterionSimulation

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCriterionSimulation.



21616
21617
21618
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21616

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_idFixnum

Output only. AdGroup ID of the simulation. Corresponds to the JSON property adGroupId

Returns:

  • (Fixnum)


21571
21572
21573
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21571

def ad_group_id
  @ad_group_id
end

#cpc_bid_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpcBidSimulationPointList

A container for simulation points for simulations of type CPC_BID. Corresponds to the JSON property cpcBidPointList



21576
21577
21578
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21576

def cpc_bid_point_list
  @cpc_bid_point_list
end

#criterion_idFixnum

Output only. Criterion ID of the simulation. Corresponds to the JSON property criterionId

Returns:

  • (Fixnum)


21581
21582
21583
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21581

def criterion_id
  @criterion_id
end

#end_dateString

Output only. Last day on which the simulation is based, in YYYY-MM-DD format. Corresponds to the JSON property endDate

Returns:

  • (String)


21586
21587
21588
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21586

def end_date
  @end_date
end

#modification_methodString

Output only. How the simulation modifies the field. Corresponds to the JSON property modificationMethod

Returns:

  • (String)


21591
21592
21593
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21591

def modification_method
  @modification_method
end

#percent_cpc_bid_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPercentCpcBidSimulationPointList

A container for simulation points for simulations of type PERCENT_CPC_BID. Corresponds to the JSON property percentCpcBidPointList



21596
21597
21598
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21596

def percent_cpc_bid_point_list
  @percent_cpc_bid_point_list
end

#resource_nameString

Output only. The resource name of the ad group criterion simulation. Ad group criterion simulation resource names have the form: customers/customer_id/ adGroupCriterionSimulations/ad_group_id~criterion_id~type~ modification_method~start_date~end_date` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


21604
21605
21606
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21604

def resource_name
  @resource_name
end

#start_dateString

Output only. First day on which the simulation is based, in YYYY-MM-DD format. Corresponds to the JSON property startDate

Returns:

  • (String)


21609
21610
21611
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21609

def start_date
  @start_date
end

#typeString

Output only. The field that the simulation modifies. Corresponds to the JSON property type

Returns:

  • (String)


21614
21615
21616
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21614

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21621
21622
21623
21624
21625
21626
21627
21628
21629
21630
21631
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21621

def update!(**args)
  @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id)
  @cpc_bid_point_list = args[:cpc_bid_point_list] if args.key?(:cpc_bid_point_list)
  @criterion_id = args[:criterion_id] if args.key?(:criterion_id)
  @end_date = args[:end_date] if args.key?(:end_date)
  @modification_method = args[:modification_method] if args.key?(:modification_method)
  @percent_cpc_bid_point_list = args[:percent_cpc_bid_point_list] if args.key?(:percent_cpc_bid_point_list)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @type = args[:type] if args.key?(:type)
end