Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCustomizer
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCustomizer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A customizer value for the associated CustomizerAttribute at the AdGroup level.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Immutable.
-
#customizer_attribute ⇒ String
Required.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#value ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue
A customizer value that is referenced in customizer linkage entities like CustomerCustomizer, CampaignCustomizer, etc.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCustomizer
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupCustomizer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupCustomizer
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupCustomizer.
21592 21593 21594 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Immutable. The ad group to which the customizer attribute is linked.
Corresponds to the JSON property adGroup
21567 21568 21569 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21567 def ad_group @ad_group end |
#customizer_attribute ⇒ String
Required. Immutable. The customizer attribute which is linked to the ad group.
Corresponds to the JSON property customizerAttribute
21572 21573 21574 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21572 def customizer_attribute @customizer_attribute end |
#resource_name ⇒ String
Immutable. The resource name of the ad group customizer. Ad group customizer
resource names have the form: customers/customer_id/adGroupCustomizers/
ad_group_id~customizer_attribute_id`
Corresponds to the JSON propertyresourceName`
21579 21580 21581 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21579 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the ad group customizer.
Corresponds to the JSON property status
21584 21585 21586 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21584 def status @status end |
#value ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue
A customizer value that is referenced in customizer linkage entities like
CustomerCustomizer, CampaignCustomizer, etc.
Corresponds to the JSON property value
21590 21591 21592 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21590 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21597 21598 21599 21600 21601 21602 21603 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21597 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @customizer_attribute = args[:customizer_attribute] if args.key?(:customizer_attribute) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @value = args[:value] if args.key?(:value) end |