Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControls
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControls
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Channel controls for Demand Gen ad groups.
Instance Attribute Summary collapse
-
#channel_config ⇒ String
Output only.
-
#channel_strategy ⇒ String
High level channel strategy.
-
#selected_channels ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControlsDemandGenSelectedChannels
Explicitly selected channels for channel controls in Demand Gen ad groups.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControls
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControls.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControls
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControls.
15239 15240 15241 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15239 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_config ⇒ String
Output only. Channel configuration reflecting which field in the oneof is
populated.
Corresponds to the JSON property channelConfig
15227 15228 15229 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15227 def channel_config @channel_config end |
#channel_strategy ⇒ String
High level channel strategy.
Corresponds to the JSON property channelStrategy
15232 15233 15234 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15232 def channel_strategy @channel_strategy end |
#selected_channels ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControlsDemandGenSelectedChannels
Explicitly selected channels for channel controls in Demand Gen ad groups.
Corresponds to the JSON property selectedChannels
15237 15238 15239 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15237 def selected_channels @selected_channels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15244 15245 15246 15247 15248 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15244 def update!(**args) @channel_config = args[:channel_config] if args.key?(:channel_config) @channel_strategy = args[:channel_strategy] if args.key?(:channel_strategy) @selected_channels = args[:selected_channels] if args.key?(:selected_channels) end |