Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControls

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Channel controls for Demand Gen ad groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControls

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControls.



15179
15180
15181
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15179

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_configString

Output only. Channel configuration reflecting which field in the oneof is populated. Corresponds to the JSON property channelConfig

Returns:

  • (String)


15167
15168
15169
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15167

def channel_config
  @channel_config
end

#channel_strategyString

High level channel strategy. Corresponds to the JSON property channelStrategy

Returns:

  • (String)


15172
15173
15174
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15172

def channel_strategy
  @channel_strategy
end

#selected_channelsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControlsDemandGenSelectedChannels

Explicitly selected channels for channel controls in Demand Gen ad groups. Corresponds to the JSON property selectedChannels



15177
15178
15179
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15177

def selected_channels
  @selected_channels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15184
15185
15186
15187
15188
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15184

def update!(**args)
  @channel_config = args[:channel_config] if args.key?(:channel_config)
  @channel_strategy = args[:channel_strategy] if args.key?(:channel_strategy)
  @selected_channels = args[:selected_channels] if args.key?(:selected_channels)
end