Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControls

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Channel controls for Demand Gen ad groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControls

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControls.



15113
15114
15115
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15113

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_configString

Output only. Channel configuration reflecting which field in the oneof is populated. Corresponds to the JSON property channelConfig

Returns:

  • (String)


15101
15102
15103
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15101

def channel_config
  @channel_config
end

#channel_strategyString

High level channel strategy. Corresponds to the JSON property channelStrategy

Returns:

  • (String)


15106
15107
15108
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15106

def channel_strategy
  @channel_strategy
end

#selected_channelsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupDemandGenAdGroupSettingsDemandGenChannelControlsDemandGenSelectedChannels

Explicitly selected channels for channel controls in Demand Gen ad groups. Corresponds to the JSON property selectedChannels



15111
15112
15113
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15111

def selected_channels
  @selected_channels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15118
15119
15120
15121
15122
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15118

def update!(**args)
  @channel_config = args[:channel_config] if args.key?(:channel_config)
  @channel_strategy = args[:channel_strategy] if args.key?(:channel_strategy)
  @selected_channels = args[:selected_channels] if args.key?(:selected_channels)
end