Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupEffectiveLabel
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupEffectiveLabel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A relationship between an ad group and an effective label. An effective label is a label inherited or directly assigned to this ad group.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Immutable.
-
#label ⇒ String
Immutable.
-
#owner_customer_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupEffectiveLabel
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupEffectiveLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupEffectiveLabel
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupEffectiveLabel.
21633 21634 21635 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21633 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Immutable. The ad group to which the effective label is attached.
Corresponds to the JSON property adGroup
21614 21615 21616 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21614 def ad_group @ad_group end |
#label ⇒ String
Immutable. The effective label assigned to the ad group.
Corresponds to the JSON property label
21619 21620 21621 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21619 def label @label end |
#owner_customer_id ⇒ Fixnum
Output only. The ID of the Customer which owns the effective label.
Corresponds to the JSON property ownerCustomerId
21624 21625 21626 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21624 def owner_customer_id @owner_customer_id end |
#resource_name ⇒ String
Immutable. The resource name of the ad group effective label. Ad group
effective label resource names have the form: customers/owner_customer_id/
adGroupEffectiveLabels/ad_group_id~label_id`
Corresponds to the JSON propertyresourceName`
21631 21632 21633 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21631 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21638 21639 21640 21641 21642 21643 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21638 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @label = args[:label] if args.key?(:label) @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id) @resource_name = args[:resource_name] if args.key?(:resource_name) end |