Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupLabel
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupLabel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A relationship between an ad group and a label.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Immutable.
-
#label ⇒ String
Immutable.
-
#owner_customer_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupLabel
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupLabel
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupLabel.
21672 21673 21674 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21672 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Immutable. The ad group to which the label is attached.
Corresponds to the JSON property adGroup
21653 21654 21655 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21653 def ad_group @ad_group end |
#label ⇒ String
Immutable. The label assigned to the ad group.
Corresponds to the JSON property label
21658 21659 21660 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21658 def label @label end |
#owner_customer_id ⇒ Fixnum
Output only. The ID of the Customer which owns the label.
Corresponds to the JSON property ownerCustomerId
21663 21664 21665 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21663 def owner_customer_id @owner_customer_id end |
#resource_name ⇒ String
Immutable. The resource name of the ad group label. Ad group label resource
names have the form: customers/owner_customer_id/adGroupLabels/ad_group_id
~label_id`
Corresponds to the JSON propertyresourceName`
21670 21671 21672 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21670 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21677 21678 21679 21680 21681 21682 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21677 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @label = args[:label] if args.key?(:label) @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id) @resource_name = args[:resource_name] if args.key?(:resource_name) end |