Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupSimulation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An ad group simulation. Supported combinations of advertising channel type, simulation type and simulation modification method is detailed below respectively. 1. SEARCH - CPC_BID - DEFAULT 2. SEARCH - CPC_BID - UNIFORM 3. SEARCH - TARGET_CPA - UNIFORM 4. SEARCH - TARGET_ROAS - UNIFORM 5. DISPLAY - CPC_BID - DEFAULT 6. DISPLAY - CPC_BID - UNIFORM 7. DISPLAY - TARGET_CPA - UNIFORM

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupSimulation

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupSimulation.



21820
21821
21822
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_idFixnum

Output only. Ad group id of the simulation. Corresponds to the JSON property adGroupId

Returns:

  • (Fixnum)


21771
21772
21773
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21771

def ad_group_id
  @ad_group_id
end

#cpc_bid_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpcBidSimulationPointList

A container for simulation points for simulations of type CPC_BID. Corresponds to the JSON property cpcBidPointList



21776
21777
21778
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21776

def cpc_bid_point_list
  @cpc_bid_point_list
end

#cpv_bid_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpvBidSimulationPointList

A container for simulation points for simulations of type CPV_BID. Corresponds to the JSON property cpvBidPointList



21781
21782
21783
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21781

def cpv_bid_point_list
  @cpv_bid_point_list
end

#end_dateString

Output only. Last day on which the simulation is based, in YYYY-MM-DD format Corresponds to the JSON property endDate

Returns:

  • (String)


21786
21787
21788
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21786

def end_date
  @end_date
end

#modification_methodString

Output only. How the simulation modifies the field. Corresponds to the JSON property modificationMethod

Returns:

  • (String)


21791
21792
21793
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21791

def modification_method
  @modification_method
end

#resource_nameString

Output only. The resource name of the ad group simulation. Ad group simulation resource names have the form: customers/customer_id/adGroupSimulations/ ad_group_id~type~modification_method~start_date~end_date` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


21798
21799
21800
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21798

def resource_name
  @resource_name
end

#start_dateString

Output only. First day on which the simulation is based, in YYYY-MM-DD format. Corresponds to the JSON property startDate

Returns:

  • (String)


21803
21804
21805
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21803

def start_date
  @start_date
end

#target_cpa_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpaSimulationPointList

A container for simulation points for simulations of type TARGET_CPA. Corresponds to the JSON property targetCpaPointList



21808
21809
21810
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21808

def target_cpa_point_list
  @target_cpa_point_list
end

#target_roas_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoasSimulationPointList

A container for simulation points for simulations of type TARGET_ROAS. Corresponds to the JSON property targetRoasPointList



21813
21814
21815
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21813

def target_roas_point_list
  @target_roas_point_list
end

#typeString

Output only. The field that the simulation modifies. Corresponds to the JSON property type

Returns:

  • (String)


21818
21819
21820
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21818

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21825
21826
21827
21828
21829
21830
21831
21832
21833
21834
21835
21836
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21825

def update!(**args)
  @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id)
  @cpc_bid_point_list = args[:cpc_bid_point_list] if args.key?(:cpc_bid_point_list)
  @cpv_bid_point_list = args[:cpv_bid_point_list] if args.key?(:cpv_bid_point_list)
  @end_date = args[:end_date] if args.key?(:end_date)
  @modification_method = args[:modification_method] if args.key?(:modification_method)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @target_cpa_point_list = args[:target_cpa_point_list] if args.key?(:target_cpa_point_list)
  @target_roas_point_list = args[:target_roas_point_list] if args.key?(:target_roas_point_list)
  @type = args[:type] if args.key?(:type)
end