Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupSimulation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupSimulation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An ad group simulation. Supported combinations of advertising channel type, simulation type and simulation modification method is detailed below respectively. 1. SEARCH - CPC_BID - DEFAULT 2. SEARCH - CPC_BID - UNIFORM 3. SEARCH - TARGET_CPA - UNIFORM 4. SEARCH - TARGET_ROAS - UNIFORM 5. DISPLAY - CPC_BID - DEFAULT 6. DISPLAY - CPC_BID - UNIFORM 7. DISPLAY - TARGET_CPA - UNIFORM
Instance Attribute Summary collapse
-
#ad_group_id ⇒ Fixnum
Output only.
-
#cpc_bid_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpcBidSimulationPointList
A container for simulation points for simulations of type CPC_BID.
-
#cpv_bid_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpvBidSimulationPointList
A container for simulation points for simulations of type CPV_BID.
-
#end_date ⇒ String
Output only.
-
#modification_method ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#start_date ⇒ String
Output only.
-
#target_cpa_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpaSimulationPointList
A container for simulation points for simulations of type TARGET_CPA.
-
#target_roas_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoasSimulationPointList
A container for simulation points for simulations of type TARGET_ROAS.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupSimulation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdGroupSimulation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupSimulation
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupSimulation.
21746 21747 21748 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21746 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_id ⇒ Fixnum
Output only. Ad group id of the simulation.
Corresponds to the JSON property adGroupId
21697 21698 21699 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21697 def ad_group_id @ad_group_id end |
#cpc_bid_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpcBidSimulationPointList
A container for simulation points for simulations of type CPC_BID.
Corresponds to the JSON property cpcBidPointList
21702 21703 21704 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21702 def cpc_bid_point_list @cpc_bid_point_list end |
#cpv_bid_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpvBidSimulationPointList
A container for simulation points for simulations of type CPV_BID.
Corresponds to the JSON property cpvBidPointList
21707 21708 21709 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21707 def cpv_bid_point_list @cpv_bid_point_list end |
#end_date ⇒ String
Output only. Last day on which the simulation is based, in YYYY-MM-DD format
Corresponds to the JSON property endDate
21712 21713 21714 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21712 def end_date @end_date end |
#modification_method ⇒ String
Output only. How the simulation modifies the field.
Corresponds to the JSON property modificationMethod
21717 21718 21719 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21717 def modification_method @modification_method end |
#resource_name ⇒ String
Output only. The resource name of the ad group simulation. Ad group simulation
resource names have the form: customers/customer_id/adGroupSimulations/
ad_group_id~type~modification_method~start_date~end_date`
Corresponds to the JSON propertyresourceName`
21724 21725 21726 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21724 def resource_name @resource_name end |
#start_date ⇒ String
Output only. First day on which the simulation is based, in YYYY-MM-DD format.
Corresponds to the JSON property startDate
21729 21730 21731 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21729 def start_date @start_date end |
#target_cpa_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpaSimulationPointList
A container for simulation points for simulations of type TARGET_CPA.
Corresponds to the JSON property targetCpaPointList
21734 21735 21736 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21734 def target_cpa_point_list @target_cpa_point_list end |
#target_roas_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoasSimulationPointList
A container for simulation points for simulations of type TARGET_ROAS.
Corresponds to the JSON property targetRoasPointList
21739 21740 21741 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21739 def target_roas_point_list @target_roas_point_list end |
#type ⇒ String
Output only. The field that the simulation modifies.
Corresponds to the JSON property type
21744 21745 21746 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21744 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21751 21752 21753 21754 21755 21756 21757 21758 21759 21760 21761 21762 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21751 def update!(**args) @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id) @cpc_bid_point_list = args[:cpc_bid_point_list] if args.key?(:cpc_bid_point_list) @cpv_bid_point_list = args[:cpv_bid_point_list] if args.key?(:cpv_bid_point_list) @end_date = args[:end_date] if args.key?(:end_date) @modification_method = args[:modification_method] if args.key?(:modification_method) @resource_name = args[:resource_name] if args.key?(:resource_name) @start_date = args[:start_date] if args.key?(:start_date) @target_cpa_point_list = args[:target_cpa_point_list] if args.key?(:target_cpa_point_list) @target_roas_point_list = args[:target_roas_point_list] if args.key?(:target_roas_point_list) @type = args[:type] if args.key?(:type) end |