Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupVerticalAdsFormatSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Vertical ads setting feature to enable/disable ad group format controls in search campaigns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdGroupVerticalAdsFormatSetting

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdGroupVerticalAdsFormatSetting.



15210
15211
15212
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_text_adsBoolean Also known as: disable_text_ads?

If true, text ads will be disabled for this ad group. Corresponds to the JSON property disableTextAds

Returns:

  • (Boolean)


15195
15196
15197
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15195

def disable_text_ads
  @disable_text_ads
end

If true, booking links will be enabled for this ad group. Corresponds to the JSON property enableBookingLinks

Returns:

  • (Boolean)


15201
15202
15203
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15201

def enable_booking_links
  @enable_booking_links
end

#enable_vertical_promotion_adsBoolean Also known as: enable_vertical_promotion_ads?

If true, vertical promotion ads will be enabled for this ad group. Corresponds to the JSON property enableVerticalPromotionAds

Returns:

  • (Boolean)


15207
15208
15209
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15207

def enable_vertical_promotion_ads
  @enable_vertical_promotion_ads
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15215
15216
15217
15218
15219
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15215

def update!(**args)
  @disable_text_ads = args[:disable_text_ads] if args.key?(:disable_text_ads)
  @enable_booking_links = args[:enable_booking_links] if args.key?(:enable_booking_links)
  @enable_vertical_promotion_ads = args[:enable_vertical_promotion_ads] if args.key?(:enable_vertical_promotion_ads)
end