Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdStrengthActionItemAddAssetDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The details of the asset to add.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdStrengthActionItemAddAssetDetails

Returns a new instance of GoogleAdsSearchads360V23ResourcesAdStrengthActionItemAddAssetDetails.



15243
15244
15245
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_countFixnum

Output only. The number of assets to add. Corresponds to the JSON property assetCount

Returns:

  • (Fixnum)


15229
15230
15231
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15229

def asset_count
  @asset_count
end

#asset_field_typeString

Output only. The asset field type of the asset(s) to add. Corresponds to the JSON property assetFieldType

Returns:

  • (String)


15234
15235
15236
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15234

def asset_field_type
  @asset_field_type
end

#video_aspect_ratio_requirementString

Output only. For video field types, the required aspect ratio of the video. When unset and asset_field_type is YOUTUBE_VIDEO, the system recommends the advertiser upload any YouTube video, regardless of aspect ratio. Corresponds to the JSON property videoAspectRatioRequirement

Returns:

  • (String)


15241
15242
15243
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15241

def video_aspect_ratio_requirement
  @video_aspect_ratio_requirement
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15248
15249
15250
15251
15252
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15248

def update!(**args)
  @asset_count = args[:asset_count] if args.key?(:asset_count)
  @asset_field_type = args[:asset_field_type] if args.key?(:asset_field_type)
  @video_aspect_ratio_requirement = args[:video_aspect_ratio_requirement] if args.key?(:video_aspect_ratio_requirement)
end