Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdvertisingPartnerLinkInvitationIdentifier
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdvertisingPartnerLinkInvitationIdentifier
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The identifier for the Advertising Partner Google Ads account.
Instance Attribute Summary collapse
-
#customer ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdvertisingPartnerLinkInvitationIdentifier
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAdvertisingPartnerLinkInvitationIdentifier.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAdvertisingPartnerLinkInvitationIdentifier
Returns a new instance of GoogleAdsSearchads360V23ResourcesAdvertisingPartnerLinkInvitationIdentifier.
21894 21895 21896 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21894 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer ⇒ String
Immutable. The resource name of the advertising partner Google Ads account.
This field is read only.
Corresponds to the JSON property customer
21892 21893 21894 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21892 def customer @customer end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21899 21900 21901 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21899 def update!(**args) @customer = args[:customer] if args.key?(:customer) end |