Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAgeRangeView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAgeRangeView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An age range view. Represents the view of a customer's performance metrics (
like impressions and clicks) aggregated by age range. All statistics are
aggregated at the ad group level. Note: While you can segment metrics by age
range using age_range_view or by gender using gender_view, the Search Ads
360 API does not support segmenting metrics by both age range and gender
simultaneously in a single query. Analyzing performance across both dimensions
combined is not supported in the Search Ads 360 API.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAgeRangeView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAgeRangeView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAgeRangeView
Returns a new instance of GoogleAdsSearchads360V23ResourcesAgeRangeView.
21995 21996 21997 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Output only. The resource name of the age range view. Age range view resource
names have the form: customers/customer_id/ageRangeViews/ad_group_id~
criterion_id`
Corresponds to the JSON propertyresourceName`
21993 21994 21995 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21993 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22000 22001 22002 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22000 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) end |