Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
AiMaxSearchTermAdCombinationView Resource.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Output only.
-
#headline ⇒ String
Output only.
-
#landing_page ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#search_term ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView
Returns a new instance of GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView.
22040 22041 22042 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22040 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Output only. Ad group where the search term served.
Corresponds to the JSON property adGroup
22012 22013 22014 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22012 def ad_group @ad_group end |
#headline ⇒ String
Output only. The concatenated string containing headline assets for the ad. Up
to three headline assets are concatenated, separated by " | ". This field is
read-only.
Corresponds to the JSON property headline
22019 22020 22021 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22019 def headline @headline end |
#landing_page ⇒ String
Output only. The destination URL, which was dynamically generated. This field
is read-only.
Corresponds to the JSON property landingPage
22025 22026 22027 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22025 def landing_page @landing_page end |
#resource_name ⇒ String
Output only. The resource name of the AI Max Search Term Ad Combination view
AI Max Search Term Ad Combination view resource names have the form:
customers/customer_id/aiMaxSearchTermAdCombinationViews/ad_group_id~URL-
base64_search_term~URL-base64_landing_page~URL-base64_headline`
Corresponds to the JSON propertyresourceName`
22033 22034 22035 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22033 def resource_name @resource_name end |
#search_term ⇒ String
Output only. The search term that triggered the ad. This field is read-only.
Corresponds to the JSON property searchTerm
22038 22039 22040 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22038 def search_term @search_term end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22045 22046 22047 22048 22049 22050 22051 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22045 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @headline = args[:headline] if args.key?(:headline) @landing_page = args[:landing_page] if args.key?(:landing_page) @resource_name = args[:resource_name] if args.key?(:resource_name) @search_term = args[:search_term] if args.key?(:search_term) end |