Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

AiMaxSearchTermAdCombinationView Resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView

Returns a new instance of GoogleAdsSearchads360V23ResourcesAiMaxSearchTermAdCombinationView.



21960
21961
21962
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21960

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Output only. Ad group where the search term served. Corresponds to the JSON property adGroup

Returns:

  • (String)


21932
21933
21934
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21932

def ad_group
  @ad_group
end

#headlineString

Output only. The concatenated string containing headline assets for the ad. Up to three headline assets are concatenated, separated by " | ". This field is read-only. Corresponds to the JSON property headline

Returns:

  • (String)


21939
21940
21941
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21939

def headline
  @headline
end

#landing_pageString

Output only. The destination URL, which was dynamically generated. This field is read-only. Corresponds to the JSON property landingPage

Returns:

  • (String)


21945
21946
21947
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21945

def landing_page
  @landing_page
end

#resource_nameString

Output only. The resource name of the AI Max Search Term Ad Combination view AI Max Search Term Ad Combination view resource names have the form: customers/customer_id/aiMaxSearchTermAdCombinationViews/ad_group_id~URL- base64_search_term~URL-base64_landing_page~URL-base64_headline` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


21953
21954
21955
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21953

def resource_name
  @resource_name
end

#search_termString

Output only. The search term that triggered the ad. This field is read-only. Corresponds to the JSON property searchTerm

Returns:

  • (String)


21958
21959
21960
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21958

def search_term
  @search_term
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21965
21966
21967
21968
21969
21970
21971
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21965

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @headline = args[:headline] if args.key?(:headline)
  @landing_page = args[:landing_page] if args.key?(:landing_page)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @search_term = args[:search_term] if args.key?(:search_term)
end