Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleAdGroup
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleAdGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An Android privacy shared key view for Google ad group key.
Instance Attribute Summary collapse
-
#ad_group_id ⇒ Fixnum
Output only.
-
#android_privacy_interaction_date ⇒ String
Output only.
-
#android_privacy_interaction_type ⇒ String
Output only.
-
#android_privacy_network_type ⇒ String
Output only.
-
#campaign_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Output only.
-
#shared_ad_group_key ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleAdGroup
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleAdGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleAdGroup
Returns a new instance of GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleAdGroup.
22101 22102 22103 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22101 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_id ⇒ Fixnum
Output only. The ad group ID used in the share key encoding.
Corresponds to the JSON property adGroupId
22061 22062 22063 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22061 def ad_group_id @ad_group_id end |
#android_privacy_interaction_date ⇒ String
Output only. The interaction date used in the shared key encoding in the
format of "YYYY-MM-DD" in UTC timezone.
Corresponds to the JSON property androidPrivacyInteractionDate
22067 22068 22069 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22067 def android_privacy_interaction_date @android_privacy_interaction_date end |
#android_privacy_interaction_type ⇒ String
Output only. The interaction type enum used in the share key encoding.
Corresponds to the JSON property androidPrivacyInteractionType
22072 22073 22074 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22072 def android_privacy_interaction_type @android_privacy_interaction_type end |
#android_privacy_network_type ⇒ String
Output only. The network type enum used in the share key encoding.
Corresponds to the JSON property androidPrivacyNetworkType
22077 22078 22079 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22077 def android_privacy_network_type @android_privacy_network_type end |
#campaign_id ⇒ Fixnum
Output only. The campaign ID used in the share key encoding.
Corresponds to the JSON property campaignId
22082 22083 22084 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22082 def campaign_id @campaign_id end |
#resource_name ⇒ String
Output only. The resource name of the Android privacy shared key. Android
privacy shared key resource names have the form: customers/customer_id/
androidPrivacySharedKeyGoogleAdGroups/campaign_id~ad_group_id~
android_privacy_interaction_type~android_privacy_network_type~
android_privacy_interaction_date(yyyy-mm-dd)`
Corresponds to the JSON propertyresourceName`
22091 22092 22093 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22091 def resource_name @resource_name end |
#shared_ad_group_key ⇒ String
Output only. 128 bit hex string of the encoded shared ad group key, including
a '0x' prefix. This key can be used to do a bitwise OR operator with the
aggregate conversion key to create a full aggregation key to retrieve the
Aggregate API Report in Android Privacy Sandbox.
Corresponds to the JSON property sharedAdGroupKey
22099 22100 22101 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22099 def shared_ad_group_key @shared_ad_group_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22106 22107 22108 22109 22110 22111 22112 22113 22114 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22106 def update!(**args) @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id) @android_privacy_interaction_date = args[:android_privacy_interaction_date] if args.key?(:android_privacy_interaction_date) @android_privacy_interaction_type = args[:android_privacy_interaction_type] if args.key?(:android_privacy_interaction_type) @android_privacy_network_type = args[:android_privacy_network_type] if args.key?(:android_privacy_network_type) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @shared_ad_group_key = args[:shared_ad_group_key] if args.key?(:shared_ad_group_key) end |