Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleAdGroup
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleAdGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An Android privacy shared key view for Google ad group key.
Instance Attribute Summary collapse
-
#ad_group_id ⇒ Fixnum
Output only.
-
#android_privacy_interaction_date ⇒ String
Output only.
-
#android_privacy_interaction_type ⇒ String
Output only.
-
#android_privacy_network_type ⇒ String
Output only.
-
#campaign_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Output only.
-
#shared_ad_group_key ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleAdGroup
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleAdGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleAdGroup
Returns a new instance of GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleAdGroup.
22021 22022 22023 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22021 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_id ⇒ Fixnum
Output only. The ad group ID used in the share key encoding.
Corresponds to the JSON property adGroupId
21981 21982 21983 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21981 def ad_group_id @ad_group_id end |
#android_privacy_interaction_date ⇒ String
Output only. The interaction date used in the shared key encoding in the
format of "YYYY-MM-DD" in UTC timezone.
Corresponds to the JSON property androidPrivacyInteractionDate
21987 21988 21989 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21987 def android_privacy_interaction_date @android_privacy_interaction_date end |
#android_privacy_interaction_type ⇒ String
Output only. The interaction type enum used in the share key encoding.
Corresponds to the JSON property androidPrivacyInteractionType
21992 21993 21994 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21992 def android_privacy_interaction_type @android_privacy_interaction_type end |
#android_privacy_network_type ⇒ String
Output only. The network type enum used in the share key encoding.
Corresponds to the JSON property androidPrivacyNetworkType
21997 21998 21999 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 21997 def android_privacy_network_type @android_privacy_network_type end |
#campaign_id ⇒ Fixnum
Output only. The campaign ID used in the share key encoding.
Corresponds to the JSON property campaignId
22002 22003 22004 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22002 def campaign_id @campaign_id end |
#resource_name ⇒ String
Output only. The resource name of the Android privacy shared key. Android
privacy shared key resource names have the form: customers/customer_id/
androidPrivacySharedKeyGoogleAdGroups/campaign_id~ad_group_id~
android_privacy_interaction_type~android_privacy_network_type~
android_privacy_interaction_date(yyyy-mm-dd)`
Corresponds to the JSON propertyresourceName`
22011 22012 22013 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22011 def resource_name @resource_name end |
#shared_ad_group_key ⇒ String
Output only. 128 bit hex string of the encoded shared ad group key, including
a '0x' prefix. This key can be used to do a bitwise OR operator with the
aggregate conversion key to create a full aggregation key to retrieve the
Aggregate API Report in Android Privacy Sandbox.
Corresponds to the JSON property sharedAdGroupKey
22019 22020 22021 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22019 def shared_ad_group_key @shared_ad_group_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22026 22027 22028 22029 22030 22031 22032 22033 22034 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22026 def update!(**args) @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id) @android_privacy_interaction_date = args[:android_privacy_interaction_date] if args.key?(:android_privacy_interaction_date) @android_privacy_interaction_type = args[:android_privacy_interaction_type] if args.key?(:android_privacy_interaction_type) @android_privacy_network_type = args[:android_privacy_network_type] if args.key?(:android_privacy_network_type) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @shared_ad_group_key = args[:shared_ad_group_key] if args.key?(:shared_ad_group_key) end |