Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleCampaign
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleCampaign
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An Android privacy shared key view for Google campaign key.
Instance Attribute Summary collapse
-
#android_privacy_interaction_date ⇒ String
Output only.
-
#android_privacy_interaction_type ⇒ String
Output only.
-
#campaign_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Output only.
-
#shared_campaign_key ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleCampaign
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleCampaign.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleCampaign
Returns a new instance of GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleCampaign.
22074 22075 22076 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22074 def initialize(**args) update!(**args) end |
Instance Attribute Details
#android_privacy_interaction_date ⇒ String
Output only. The interaction date used in the shared key encoding in the
format of "YYYY-MM-DD" in UTC timezone.
Corresponds to the JSON property androidPrivacyInteractionDate
22045 22046 22047 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22045 def android_privacy_interaction_date @android_privacy_interaction_date end |
#android_privacy_interaction_type ⇒ String
Output only. The interaction type enum used in the share key encoding.
Corresponds to the JSON property androidPrivacyInteractionType
22050 22051 22052 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22050 def android_privacy_interaction_type @android_privacy_interaction_type end |
#campaign_id ⇒ Fixnum
Output only. The campaign ID used in the share key encoding.
Corresponds to the JSON property campaignId
22055 22056 22057 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22055 def campaign_id @campaign_id end |
#resource_name ⇒ String
Output only. The resource name of the Android privacy shared key. Android
privacy shared key resource names have the form: customers/customer_id/
androidPrivacySharedKeyGoogleCampaigns/campaign_id~
android_privacy_interaction_type~android_privacy_interaction_date(yyyy-mm-dd)
`
Corresponds to the JSON propertyresourceName`
22064 22065 22066 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22064 def resource_name @resource_name end |
#shared_campaign_key ⇒ String
Output only. 128 bit hex string of the encoded shared campaign key, including
a '0x' prefix. This key can be used to do a bitwise OR operator with the
aggregate conversion key to create a full aggregation key to retrieve the
Aggregate API Report in Android Privacy Sandbox.
Corresponds to the JSON property sharedCampaignKey
22072 22073 22074 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22072 def shared_campaign_key @shared_campaign_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22079 22080 22081 22082 22083 22084 22085 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22079 def update!(**args) @android_privacy_interaction_date = args[:android_privacy_interaction_date] if args.key?(:android_privacy_interaction_date) @android_privacy_interaction_type = args[:android_privacy_interaction_type] if args.key?(:android_privacy_interaction_type) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @shared_campaign_key = args[:shared_campaign_key] if args.key?(:shared_campaign_key) end |