Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Asset is a part of an ad which can be shared across multiple ads. It can be an image (ImageAsset), a video (YoutubeVideoAsset), etc. Assets are immutable and cannot be removed. To stop an asset from serving, remove the asset from the entity that is using it.
Instance Attribute Summary collapse
-
#app_deep_link_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppDeepLinkAsset
An app deep link asset Corresponds to the JSON property
appDeepLinkAsset. -
#book_on_google_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBookOnGoogleAsset
A Book on Google asset.
-
#business_message_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessMessageAsset
A business message asset.
-
#call_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCallAsset
A Call asset.
-
#call_to_action_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCallToActionAsset
A call to action asset.
-
#callout_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCalloutAsset
A Callout asset.
-
#creation_time ⇒ String
Output only.
-
#demand_gen_carousel_card_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenCarouselCardAsset
A Demand Gen Carousel Card asset.
-
#dynamic_custom_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicCustomAsset
A dynamic custom asset.
-
#dynamic_education_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicEducationAsset
A Dynamic Education asset.
-
#dynamic_flights_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicFlightsAsset
A dynamic flights asset.
-
#dynamic_hotels_and_rentals_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicHotelsAndRentalsAsset
A dynamic hotels and rentals asset.
-
#dynamic_jobs_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicJobsAsset
A dynamic jobs asset.
-
#dynamic_local_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicLocalAsset
A dynamic local asset.
-
#dynamic_real_estate_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicRealEstateAsset
A dynamic real estate asset.
-
#dynamic_travel_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicTravelAsset
A dynamic travel asset.
-
#engine_status ⇒ String
Output only.
-
#field_type_policy_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetFieldTypePolicySummary>
Output only.
-
#final_mobile_urls ⇒ Array<String>
A list of possible final mobile URLs after all cross domain redirects.
-
#final_url_suffix ⇒ String
URL template for appending params to landing page URLs served with parallel tracking.
-
#final_urls ⇒ Array<String>
A list of possible final URLs after all cross domain redirects.
-
#hotel_callout_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCalloutAsset
An asset representing a hotel callout.
-
#hotel_property_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelPropertyAsset
A hotel property asset.
-
#id ⇒ Fixnum
Output only.
-
#image_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonImageAsset
An Image asset.
-
#last_modified_time ⇒ String
Output only.
-
#lead_form_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLeadFormAsset
A Lead Form asset.
-
#location_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationAsset
A location asset.
-
#media_bundle_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMediaBundleAsset
A MediaBundle asset.
-
#mobile_app_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppAsset
An asset representing a mobile app.
-
#name ⇒ String
Optional name of the asset.
-
#orientation ⇒ String
Output only.
-
#page_feed_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPageFeedAsset
A Page Feed asset.
-
#policy_summary ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetPolicySummary
Contains policy information for an asset.
-
#price_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPriceAsset
An asset representing a list of price offers.
-
#promotion_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPromotionAsset
A Promotion asset.
-
#resource_name ⇒ String
Immutable.
-
#search_ads360_call_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedCallAsset
A unified call asset.
-
#search_ads360_callout_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedCalloutAsset
A unified callout asset.
-
#search_ads360_location_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedLocationAsset
A unified location asset.
-
#search_ads360_page_feed_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedPageFeedAsset
A Unified Page Feed asset.
-
#search_ads360_sitelink_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedSitelinkAsset
A unified sitelink asset.
-
#sitelink_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSitelinkAsset
A Sitelink asset.
-
#source ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#structured_snippet_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStructuredSnippetAsset
A Structured Snippet asset.
-
#text_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTextAsset
A Text asset.
-
#tracking_url_template ⇒ String
URL template for constructing a tracking URL.
-
#type ⇒ String
Output only.
-
#url_custom_parameters ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>
A list of mappings to be used for substituting URL custom parameter tags in the tracking_url_template, final_urls, and/or final_mobile_urls.
-
#youtube_video_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYoutubeVideoAsset
A YouTube asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAsset
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAsset
Returns a new instance of GoogleAdsSearchads360V23ResourcesAsset.
22414 22415 22416 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22414 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_deep_link_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAppDeepLinkAsset
An app deep link asset
Corresponds to the JSON property appDeepLinkAsset
22155 22156 22157 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22155 def app_deep_link_asset @app_deep_link_asset end |
#book_on_google_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBookOnGoogleAsset
A Book on Google asset. Used to redirect user to book through Google. Book on
Google will change the redirect url to book directly through Google.
Corresponds to the JSON property bookOnGoogleAsset
22161 22162 22163 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22161 def book_on_google_asset @book_on_google_asset end |
#business_message_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessMessageAsset
A business message asset.
Corresponds to the JSON property businessMessageAsset
22166 22167 22168 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22166 def @business_message_asset end |
#call_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCallAsset
A Call asset.
Corresponds to the JSON property callAsset
22171 22172 22173 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22171 def call_asset @call_asset end |
#call_to_action_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCallToActionAsset
A call to action asset.
Corresponds to the JSON property callToActionAsset
22176 22177 22178 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22176 def call_to_action_asset @call_to_action_asset end |
#callout_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCalloutAsset
A Callout asset.
Corresponds to the JSON property calloutAsset
22181 22182 22183 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22181 def callout_asset @callout_asset end |
#creation_time ⇒ String
Output only. The timestamp when this asset was created. The timestamp is in
the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format.
Corresponds to the JSON property creationTime
22187 22188 22189 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22187 def creation_time @creation_time end |
#demand_gen_carousel_card_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDemandGenCarouselCardAsset
A Demand Gen Carousel Card asset.
Corresponds to the JSON property demandGenCarouselCardAsset
22192 22193 22194 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22192 def demand_gen_carousel_card_asset @demand_gen_carousel_card_asset end |
#dynamic_custom_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicCustomAsset
A dynamic custom asset.
Corresponds to the JSON property dynamicCustomAsset
22197 22198 22199 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22197 def dynamic_custom_asset @dynamic_custom_asset end |
#dynamic_education_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicEducationAsset
A Dynamic Education asset.
Corresponds to the JSON property dynamicEducationAsset
22202 22203 22204 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22202 def dynamic_education_asset @dynamic_education_asset end |
#dynamic_flights_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicFlightsAsset
A dynamic flights asset.
Corresponds to the JSON property dynamicFlightsAsset
22207 22208 22209 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22207 def dynamic_flights_asset @dynamic_flights_asset end |
#dynamic_hotels_and_rentals_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicHotelsAndRentalsAsset
A dynamic hotels and rentals asset.
Corresponds to the JSON property dynamicHotelsAndRentalsAsset
22212 22213 22214 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22212 def dynamic_hotels_and_rentals_asset @dynamic_hotels_and_rentals_asset end |
#dynamic_jobs_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicJobsAsset
A dynamic jobs asset.
Corresponds to the JSON property dynamicJobsAsset
22217 22218 22219 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22217 def dynamic_jobs_asset @dynamic_jobs_asset end |
#dynamic_local_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicLocalAsset
A dynamic local asset.
Corresponds to the JSON property dynamicLocalAsset
22222 22223 22224 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22222 def dynamic_local_asset @dynamic_local_asset end |
#dynamic_real_estate_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicRealEstateAsset
A dynamic real estate asset.
Corresponds to the JSON property dynamicRealEstateAsset
22227 22228 22229 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22227 def dynamic_real_estate_asset @dynamic_real_estate_asset end |
#dynamic_travel_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDynamicTravelAsset
A dynamic travel asset.
Corresponds to the JSON property dynamicTravelAsset
22232 22233 22234 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22232 def dynamic_travel_asset @dynamic_travel_asset end |
#engine_status ⇒ String
Output only. The Engine Status for an asset.
Corresponds to the JSON property engineStatus
22237 22238 22239 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22237 def engine_status @engine_status end |
#field_type_policy_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetFieldTypePolicySummary>
Output only. Policy information for the asset for each FieldType.
Corresponds to the JSON property fieldTypePolicySummaries
22242 22243 22244 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22242 def field_type_policy_summaries @field_type_policy_summaries end |
#final_mobile_urls ⇒ Array<String>
A list of possible final mobile URLs after all cross domain redirects.
Corresponds to the JSON property finalMobileUrls
22247 22248 22249 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22247 def final_mobile_urls @final_mobile_urls end |
#final_url_suffix ⇒ String
URL template for appending params to landing page URLs served with parallel
tracking.
Corresponds to the JSON property finalUrlSuffix
22253 22254 22255 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22253 def final_url_suffix @final_url_suffix end |
#final_urls ⇒ Array<String>
A list of possible final URLs after all cross domain redirects.
Corresponds to the JSON property finalUrls
22258 22259 22260 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22258 def final_urls @final_urls end |
#hotel_callout_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelCalloutAsset
An asset representing a hotel callout.
Corresponds to the JSON property hotelCalloutAsset
22263 22264 22265 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22263 def hotel_callout_asset @hotel_callout_asset end |
#hotel_property_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHotelPropertyAsset
A hotel property asset.
Corresponds to the JSON property hotelPropertyAsset
22268 22269 22270 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22268 def hotel_property_asset @hotel_property_asset end |
#id ⇒ Fixnum
Output only. The ID of the asset.
Corresponds to the JSON property id
22273 22274 22275 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22273 def id @id end |
#image_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonImageAsset
An Image asset.
Corresponds to the JSON property imageAsset
22278 22279 22280 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22278 def image_asset @image_asset end |
#last_modified_time ⇒ String
Output only. The datetime when this asset was last modified. The datetime is
in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format.
Corresponds to the JSON property lastModifiedTime
22284 22285 22286 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22284 def last_modified_time @last_modified_time end |
#lead_form_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLeadFormAsset
A Lead Form asset.
Corresponds to the JSON property leadFormAsset
22289 22290 22291 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22289 def lead_form_asset @lead_form_asset end |
#location_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationAsset
A location asset.
Corresponds to the JSON property locationAsset
22294 22295 22296 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22294 def location_asset @location_asset end |
#media_bundle_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMediaBundleAsset
A MediaBundle asset.
Corresponds to the JSON property mediaBundleAsset
22299 22300 22301 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22299 def media_bundle_asset @media_bundle_asset end |
#mobile_app_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppAsset
An asset representing a mobile app.
Corresponds to the JSON property mobileAppAsset
22304 22305 22306 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22304 def mobile_app_asset @mobile_app_asset end |
#name ⇒ String
Optional name of the asset.
Corresponds to the JSON property name
22309 22310 22311 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22309 def name @name end |
#orientation ⇒ String
Output only. Orientation of the asset. This is only supported for image and
video assets.
Corresponds to the JSON property orientation
22315 22316 22317 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22315 def orientation @orientation end |
#page_feed_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPageFeedAsset
A Page Feed asset.
Corresponds to the JSON property pageFeedAsset
22320 22321 22322 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22320 def page_feed_asset @page_feed_asset end |
#policy_summary ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetPolicySummary
Contains policy information for an asset.
Corresponds to the JSON property policySummary
22325 22326 22327 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22325 def policy_summary @policy_summary end |
#price_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPriceAsset
An asset representing a list of price offers.
Corresponds to the JSON property priceAsset
22330 22331 22332 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22330 def price_asset @price_asset end |
#promotion_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPromotionAsset
A Promotion asset.
Corresponds to the JSON property promotionAsset
22335 22336 22337 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22335 def promotion_asset @promotion_asset end |
#resource_name ⇒ String
Immutable. The resource name of the asset. Asset resource names have the form:
customers/customer_id/assets/asset_id`
Corresponds to the JSON propertyresourceName`
22341 22342 22343 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22341 def resource_name @resource_name end |
#search_ads360_call_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedCallAsset
A unified call asset.
Corresponds to the JSON property searchAds360CallAsset
22346 22347 22348 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22346 def search_ads360_call_asset @search_ads360_call_asset end |
#search_ads360_callout_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedCalloutAsset
A unified callout asset.
Corresponds to the JSON property searchAds360CalloutAsset
22351 22352 22353 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22351 def search_ads360_callout_asset @search_ads360_callout_asset end |
#search_ads360_location_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedLocationAsset
A unified location asset.
Corresponds to the JSON property searchAds360LocationAsset
22356 22357 22358 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22356 def search_ads360_location_asset @search_ads360_location_asset end |
#search_ads360_page_feed_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedPageFeedAsset
A Unified Page Feed asset.
Corresponds to the JSON property searchAds360PageFeedAsset
22361 22362 22363 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22361 def search_ads360_page_feed_asset @search_ads360_page_feed_asset end |
#search_ads360_sitelink_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUnifiedSitelinkAsset
A unified sitelink asset.
Corresponds to the JSON property searchAds360SitelinkAsset
22366 22367 22368 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22366 def search_ads360_sitelink_asset @search_ads360_sitelink_asset end |
#sitelink_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSitelinkAsset
A Sitelink asset.
Corresponds to the JSON property sitelinkAsset
22371 22372 22373 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22371 def sitelink_asset @sitelink_asset end |
#source ⇒ String
Output only. Source of the asset.
Corresponds to the JSON property source
22376 22377 22378 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22376 def source @source end |
#status ⇒ String
Output only. The status of the asset.
Corresponds to the JSON property status
22381 22382 22383 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22381 def status @status end |
#structured_snippet_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStructuredSnippetAsset
A Structured Snippet asset.
Corresponds to the JSON property structuredSnippetAsset
22386 22387 22388 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22386 def structured_snippet_asset @structured_snippet_asset end |
#text_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTextAsset
A Text asset.
Corresponds to the JSON property textAsset
22391 22392 22393 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22391 def text_asset @text_asset end |
#tracking_url_template ⇒ String
URL template for constructing a tracking URL.
Corresponds to the JSON property trackingUrlTemplate
22396 22397 22398 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22396 def tracking_url_template @tracking_url_template end |
#type ⇒ String
Output only. Type of the asset.
Corresponds to the JSON property type
22401 22402 22403 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22401 def type @type end |
#url_custom_parameters ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomParameter>
A list of mappings to be used for substituting URL custom parameter tags in
the tracking_url_template, final_urls, and/or final_mobile_urls.
Corresponds to the JSON property urlCustomParameters
22407 22408 22409 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22407 def url_custom_parameters @url_custom_parameters end |
#youtube_video_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYoutubeVideoAsset
A YouTube asset.
Corresponds to the JSON property youtubeVideoAsset
22412 22413 22414 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22412 def youtube_video_asset @youtube_video_asset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22419 22420 22421 22422 22423 22424 22425 22426 22427 22428 22429 22430 22431 22432 22433 22434 22435 22436 22437 22438 22439 22440 22441 22442 22443 22444 22445 22446 22447 22448 22449 22450 22451 22452 22453 22454 22455 22456 22457 22458 22459 22460 22461 22462 22463 22464 22465 22466 22467 22468 22469 22470 22471 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22419 def update!(**args) @app_deep_link_asset = args[:app_deep_link_asset] if args.key?(:app_deep_link_asset) @book_on_google_asset = args[:book_on_google_asset] if args.key?(:book_on_google_asset) @business_message_asset = args[:business_message_asset] if args.key?(:business_message_asset) @call_asset = args[:call_asset] if args.key?(:call_asset) @call_to_action_asset = args[:call_to_action_asset] if args.key?(:call_to_action_asset) @callout_asset = args[:callout_asset] if args.key?(:callout_asset) @creation_time = args[:creation_time] if args.key?(:creation_time) @demand_gen_carousel_card_asset = args[:demand_gen_carousel_card_asset] if args.key?(:demand_gen_carousel_card_asset) @dynamic_custom_asset = args[:dynamic_custom_asset] if args.key?(:dynamic_custom_asset) @dynamic_education_asset = args[:dynamic_education_asset] if args.key?(:dynamic_education_asset) @dynamic_flights_asset = args[:dynamic_flights_asset] if args.key?(:dynamic_flights_asset) @dynamic_hotels_and_rentals_asset = args[:dynamic_hotels_and_rentals_asset] if args.key?(:dynamic_hotels_and_rentals_asset) @dynamic_jobs_asset = args[:dynamic_jobs_asset] if args.key?(:dynamic_jobs_asset) @dynamic_local_asset = args[:dynamic_local_asset] if args.key?(:dynamic_local_asset) @dynamic_real_estate_asset = args[:dynamic_real_estate_asset] if args.key?(:dynamic_real_estate_asset) @dynamic_travel_asset = args[:dynamic_travel_asset] if args.key?(:dynamic_travel_asset) @engine_status = args[:engine_status] if args.key?(:engine_status) @field_type_policy_summaries = args[:field_type_policy_summaries] if args.key?(:field_type_policy_summaries) @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @final_urls = args[:final_urls] if args.key?(:final_urls) @hotel_callout_asset = args[:hotel_callout_asset] if args.key?(:hotel_callout_asset) @hotel_property_asset = args[:hotel_property_asset] if args.key?(:hotel_property_asset) @id = args[:id] if args.key?(:id) @image_asset = args[:image_asset] if args.key?(:image_asset) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @lead_form_asset = args[:lead_form_asset] if args.key?(:lead_form_asset) @location_asset = args[:location_asset] if args.key?(:location_asset) @media_bundle_asset = args[:media_bundle_asset] if args.key?(:media_bundle_asset) @mobile_app_asset = args[:mobile_app_asset] if args.key?(:mobile_app_asset) @name = args[:name] if args.key?(:name) @orientation = args[:orientation] if args.key?(:orientation) @page_feed_asset = args[:page_feed_asset] if args.key?(:page_feed_asset) @policy_summary = args[:policy_summary] if args.key?(:policy_summary) @price_asset = args[:price_asset] if args.key?(:price_asset) @promotion_asset = args[:promotion_asset] if args.key?(:promotion_asset) @resource_name = args[:resource_name] if args.key?(:resource_name) @search_ads360_call_asset = args[:search_ads360_call_asset] if args.key?(:search_ads360_call_asset) @search_ads360_callout_asset = args[:search_ads360_callout_asset] if args.key?(:search_ads360_callout_asset) @search_ads360_location_asset = args[:search_ads360_location_asset] if args.key?(:search_ads360_location_asset) @search_ads360_page_feed_asset = args[:search_ads360_page_feed_asset] if args.key?(:search_ads360_page_feed_asset) @search_ads360_sitelink_asset = args[:search_ads360_sitelink_asset] if args.key?(:search_ads360_sitelink_asset) @sitelink_asset = args[:sitelink_asset] if args.key?(:sitelink_asset) @source = args[:source] if args.key?(:source) @status = args[:status] if args.key?(:status) @structured_snippet_asset = args[:structured_snippet_asset] if args.key?(:structured_snippet_asset) @text_asset = args[:text_asset] if args.key?(:text_asset) @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template) @type = args[:type] if args.key?(:type) @url_custom_parameters = args[:url_custom_parameters] if args.key?(:url_custom_parameters) @youtube_video_asset = args[:youtube_video_asset] if args.key?(:youtube_video_asset) end |