Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetCoverage
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetCoverage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Information about the asset coverage of an asset group.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetCoverage
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAssetCoverage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetCoverage
Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetCoverage.
22484 22485 22486 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22484 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_strength_action_items ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdStrengthActionItem>
Output only. A list of action items to improve the ad strength of an asset
group.
Corresponds to the JSON property adStrengthActionItems
22482 22483 22484 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22482 def ad_strength_action_items @ad_strength_action_items end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22489 22490 22491 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22489 def update!(**args) @ad_strength_action_items = args[:ad_strength_action_items] if args.key?(:ad_strength_action_items) end |