Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An asset group. AssetGroupAsset is used to link an asset to the asset group. AssetGroupSignal is used to associate a signal to an asset group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetGroup

Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetGroup.



22719
22720
22721
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_strengthString

Output only. Overall ad strength of this asset group. Corresponds to the JSON property adStrength

Returns:

  • (String)


22648
22649
22650
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22648

def ad_strength
  @ad_strength
end

#asset_coverageGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetCoverage

Information about the asset coverage of an asset group. Corresponds to the JSON property assetCoverage



22653
22654
22655
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22653

def asset_coverage
  @asset_coverage
end

#campaignString

Immutable. The campaign with which this asset group is associated. The asset which is linked to the asset group. Corresponds to the JSON property campaign

Returns:

  • (String)


22659
22660
22661
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22659

def campaign
  @campaign
end

#final_mobile_urlsArray<String>

A list of final mobile URLs after all cross domain redirects. In performance max, by default, the urls are eligible for expansion unless opted out. Corresponds to the JSON property finalMobileUrls

Returns:

  • (Array<String>)


22665
22666
22667
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22665

def final_mobile_urls
  @final_mobile_urls
end

#final_urlsArray<String>

A list of final URLs after all cross domain redirects. In performance max, by default, the urls are eligible for expansion unless opted out. Corresponds to the JSON property finalUrls

Returns:

  • (Array<String>)


22671
22672
22673
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22671

def final_urls
  @final_urls
end

#idFixnum

Output only. The ID of the asset group. Corresponds to the JSON property id

Returns:

  • (Fixnum)


22676
22677
22678
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22676

def id
  @id
end

#nameString

Required. Name of the asset group. Required. It must have a minimum length of 1 and maximum length of 128. It must be unique under a campaign. Corresponds to the JSON property name

Returns:

  • (String)


22682
22683
22684
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22682

def name
  @name
end

#path1String

First part of text that may appear appended to the url displayed in the ad. Corresponds to the JSON property path1

Returns:

  • (String)


22687
22688
22689
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22687

def path1
  @path1
end

#path2String

Second part of text that may appear appended to the url displayed in the ad. This field can only be set when path1 is set. Corresponds to the JSON property path2

Returns:

  • (String)


22693
22694
22695
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22693

def path2
  @path2
end

#primary_statusString

Output only. The primary status of the asset group. Provides insights into why an asset group is not serving or not serving optimally. Corresponds to the JSON property primaryStatus

Returns:

  • (String)


22699
22700
22701
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22699

def primary_status
  @primary_status
end

#primary_status_reasonsArray<String>

Output only. Provides reasons into why an asset group is not serving or not serving optimally. It will be empty when the asset group is serving without issues. Corresponds to the JSON property primaryStatusReasons

Returns:

  • (Array<String>)


22706
22707
22708
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22706

def primary_status_reasons
  @primary_status_reasons
end

#resource_nameString

Immutable. The resource name of the asset group. Asset group resource names have the form: customers/customer_id/assetGroups/asset_group_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


22712
22713
22714
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22712

def resource_name
  @resource_name
end

#statusString

The status of the asset group. Corresponds to the JSON property status

Returns:

  • (String)


22717
22718
22719
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22717

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22724
22725
22726
22727
22728
22729
22730
22731
22732
22733
22734
22735
22736
22737
22738
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22724

def update!(**args)
  @ad_strength = args[:ad_strength] if args.key?(:ad_strength)
  @asset_coverage = args[:asset_coverage] if args.key?(:asset_coverage)
  @campaign = args[:campaign] if args.key?(:campaign)
  @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls)
  @final_urls = args[:final_urls] if args.key?(:final_urls)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @path1 = args[:path1] if args.key?(:path1)
  @path2 = args[:path2] if args.key?(:path2)
  @primary_status = args[:primary_status] if args.key?(:primary_status)
  @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end