Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroup
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An asset group. AssetGroupAsset is used to link an asset to the asset group. AssetGroupSignal is used to associate a signal to an asset group.
Instance Attribute Summary collapse
-
#ad_strength ⇒ String
Output only.
-
#asset_coverage ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetCoverage
Information about the asset coverage of an asset group.
-
#campaign ⇒ String
Immutable.
-
#final_mobile_urls ⇒ Array<String>
A list of final mobile URLs after all cross domain redirects.
-
#final_urls ⇒ Array<String>
A list of final URLs after all cross domain redirects.
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Required.
-
#path1 ⇒ String
First part of text that may appear appended to the url displayed in the ad.
-
#path2 ⇒ String
Second part of text that may appear appended to the url displayed in the ad.
-
#primary_status ⇒ String
Output only.
-
#primary_status_reasons ⇒ Array<String>
Output only.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
The status of the asset group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetGroup
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAssetGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetGroup
Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetGroup.
22632 22633 22634 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22632 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_strength ⇒ String
Output only. Overall ad strength of this asset group.
Corresponds to the JSON property adStrength
22561 22562 22563 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22561 def ad_strength @ad_strength end |
#asset_coverage ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetCoverage
Information about the asset coverage of an asset group.
Corresponds to the JSON property assetCoverage
22566 22567 22568 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22566 def asset_coverage @asset_coverage end |
#campaign ⇒ String
Immutable. The campaign with which this asset group is associated. The asset
which is linked to the asset group.
Corresponds to the JSON property campaign
22572 22573 22574 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22572 def campaign @campaign end |
#final_mobile_urls ⇒ Array<String>
A list of final mobile URLs after all cross domain redirects. In performance
max, by default, the urls are eligible for expansion unless opted out.
Corresponds to the JSON property finalMobileUrls
22578 22579 22580 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22578 def final_mobile_urls @final_mobile_urls end |
#final_urls ⇒ Array<String>
A list of final URLs after all cross domain redirects. In performance max, by
default, the urls are eligible for expansion unless opted out.
Corresponds to the JSON property finalUrls
22584 22585 22586 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22584 def final_urls @final_urls end |
#id ⇒ Fixnum
Output only. The ID of the asset group.
Corresponds to the JSON property id
22589 22590 22591 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22589 def id @id end |
#name ⇒ String
Required. Name of the asset group. Required. It must have a minimum length of
1 and maximum length of 128. It must be unique under a campaign.
Corresponds to the JSON property name
22595 22596 22597 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22595 def name @name end |
#path1 ⇒ String
First part of text that may appear appended to the url displayed in the ad.
Corresponds to the JSON property path1
22600 22601 22602 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22600 def path1 @path1 end |
#path2 ⇒ String
Second part of text that may appear appended to the url displayed in the ad.
This field can only be set when path1 is set.
Corresponds to the JSON property path2
22606 22607 22608 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22606 def path2 @path2 end |
#primary_status ⇒ String
Output only. The primary status of the asset group. Provides insights into why
an asset group is not serving or not serving optimally.
Corresponds to the JSON property primaryStatus
22612 22613 22614 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22612 def primary_status @primary_status end |
#primary_status_reasons ⇒ Array<String>
Output only. Provides reasons into why an asset group is not serving or not
serving optimally. It will be empty when the asset group is serving without
issues.
Corresponds to the JSON property primaryStatusReasons
22619 22620 22621 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22619 def primary_status_reasons @primary_status_reasons end |
#resource_name ⇒ String
Immutable. The resource name of the asset group. Asset group resource names
have the form: customers/customer_id/assetGroups/asset_group_id`
Corresponds to the JSON propertyresourceName`
22625 22626 22627 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22625 def resource_name @resource_name end |
#status ⇒ String
The status of the asset group.
Corresponds to the JSON property status
22630 22631 22632 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22630 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22637 22638 22639 22640 22641 22642 22643 22644 22645 22646 22647 22648 22649 22650 22651 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22637 def update!(**args) @ad_strength = args[:ad_strength] if args.key?(:ad_strength) @asset_coverage = args[:asset_coverage] if args.key?(:asset_coverage) @campaign = args[:campaign] if args.key?(:campaign) @final_mobile_urls = args[:final_mobile_urls] if args.key?(:final_mobile_urls) @final_urls = args[:final_urls] if args.key?(:final_urls) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @path1 = args[:path1] if args.key?(:path1) @path2 = args[:path2] if args.key?(:path2) @primary_status = args[:primary_status] if args.key?(:primary_status) @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |