Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

AssetGroupAsset is the link between an asset and an asset group. Adding an AssetGroupAsset links an asset with an asset group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetGroupAsset

Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetGroupAsset.



22805
22806
22807
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetString

Immutable. The asset which this asset group asset is linking. Corresponds to the JSON property asset

Returns:

  • (String)


22749
22750
22751
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22749

def asset
  @asset
end

#asset_groupString

Immutable. The asset group which this asset group asset is linking. Corresponds to the JSON property assetGroup

Returns:

  • (String)


22754
22755
22756
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22754

def asset_group
  @asset_group
end

#field_typeString

The description of the placement of the asset within the asset group. For example: HEADLINE, YOUTUBE_VIDEO etc Corresponds to the JSON property fieldType

Returns:

  • (String)


22760
22761
22762
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22760

def field_type
  @field_type
end

#policy_summaryGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicySummary

Contains policy summary information. Corresponds to the JSON property policySummary



22765
22766
22767
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22765

def policy_summary
  @policy_summary
end

#primary_statusString

Output only. Provides the PrimaryStatus of this asset link. Primary status is meant essentially to differentiate between the plain "status" field, which has advertiser set values of enabled, paused, or removed. The primary status takes into account other signals (for assets its mainly policy and quality approvals) to come up with a more comprehensive status to indicate its serving state. Corresponds to the JSON property primaryStatus

Returns:

  • (String)


22774
22775
22776
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22774

def primary_status
  @primary_status
end

#primary_status_detailsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetLinkPrimaryStatusDetails>

Output only. Provides the details of the primary status and its associated reasons. Corresponds to the JSON property primaryStatusDetails



22780
22781
22782
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22780

def primary_status_details
  @primary_status_details
end

#primary_status_reasonsArray<String>

Output only. Provides a list of reasons for why an asset is not serving or not serving at full capacity. Corresponds to the JSON property primaryStatusReasons

Returns:

  • (Array<String>)


22786
22787
22788
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22786

def primary_status_reasons
  @primary_status_reasons
end

#resource_nameString

Immutable. The resource name of the asset group asset. Asset group asset resource name have the form: customers/customer_id/assetGroupAssets/ asset_group_id~asset_id~field_type` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


22793
22794
22795
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22793

def resource_name
  @resource_name
end

#sourceString

Output only. Source of the asset group asset. Corresponds to the JSON property source

Returns:

  • (String)


22798
22799
22800
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22798

def source
  @source
end

#statusString

The status of the link between an asset and asset group. Corresponds to the JSON property status

Returns:

  • (String)


22803
22804
22805
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22803

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22810
22811
22812
22813
22814
22815
22816
22817
22818
22819
22820
22821
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22810

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @asset_group = args[:asset_group] if args.key?(:asset_group)
  @field_type = args[:field_type] if args.key?(:field_type)
  @policy_summary = args[:policy_summary] if args.key?(:policy_summary)
  @primary_status = args[:primary_status] if args.key?(:primary_status)
  @primary_status_details = args[:primary_status_details] if args.key?(:primary_status_details)
  @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @source = args[:source] if args.key?(:source)
  @status = args[:status] if args.key?(:status)
end