Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupProductGroupView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupProductGroupView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An asset group product group view.
Instance Attribute Summary collapse
-
#asset_group ⇒ String
Output only.
-
#asset_group_listing_group_filter ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetGroupProductGroupView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAssetGroupProductGroupView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetGroupProductGroupView
Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetGroupProductGroupView.
22844 22845 22846 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22844 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_group ⇒ String
Output only. The asset group associated with the listing group filter.
Corresponds to the JSON property assetGroup
22830 22831 22832 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22830 def asset_group @asset_group end |
#asset_group_listing_group_filter ⇒ String
Output only. The resource name of the asset group listing group filter.
Corresponds to the JSON property assetGroupListingGroupFilter
22835 22836 22837 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22835 def asset_group_listing_group_filter @asset_group_listing_group_filter end |
#resource_name ⇒ String
Output only. The resource name of the asset group product group view. Asset
group product group view resource names have the form: customers/customer_id
/assetGroupProductGroupViews/asset_group_id~listing_group_filter_id`
Corresponds to the JSON propertyresourceName`
22842 22843 22844 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22842 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22849 22850 22851 22852 22853 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22849 def update!(**args) @asset_group = args[:asset_group] if args.key?(:asset_group) @asset_group_listing_group_filter = args[:asset_group_listing_group_filter] if args.key?(:asset_group_listing_group_filter) @resource_name = args[:resource_name] if args.key?(:resource_name) end |