Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupSignal
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupSignal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
AssetGroupSignal represents a signal in an asset group. The existence of a signal tells the performance max campaign who's most likely to convert. Performance Max uses the signal to look for new people with similar or stronger intent to find conversions across Search, Display, Video, and more.
Instance Attribute Summary collapse
-
#approval_status ⇒ String
Output only.
-
#asset_group ⇒ String
Immutable.
-
#audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInfo
An audience criterion.
-
#disapproval_reasons ⇒ Array<String>
Output only.
-
#resource_name ⇒ String
Immutable.
-
#search_theme ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchThemeInfo
A Search Theme criterion only on Performance Max campaign.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetGroupSignal
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAssetGroupSignal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetGroupSignal
Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetGroupSignal.
22986 22987 22988 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22986 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval_status ⇒ String
Output only. Approval status is the output value for search theme signal after
Google ads policy review. When using Audience signal, this field is not used
and will be absent.
Corresponds to the JSON property approvalStatus
22955 22956 22957 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22955 def approval_status @approval_status end |
#asset_group ⇒ String
Immutable. The asset group which this asset group signal belongs to.
Corresponds to the JSON property assetGroup
22960 22961 22962 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22960 def asset_group @asset_group end |
#audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInfo
An audience criterion.
Corresponds to the JSON property audience
22965 22966 22967 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22965 def audience @audience end |
#disapproval_reasons ⇒ Array<String>
Output only. Computed for SearchTheme signals. When using Audience signal,
this field is not used and will be absent.
Corresponds to the JSON property disapprovalReasons
22971 22972 22973 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22971 def disapproval_reasons @disapproval_reasons end |
#resource_name ⇒ String
Immutable. The resource name of the asset group signal. Asset group signal
resource name have the form: customers/customer_id/assetGroupSignals/
asset_group_id~signal_id`
Corresponds to the JSON propertyresourceName`
22978 22979 22980 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22978 def resource_name @resource_name end |
#search_theme ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchThemeInfo
A Search Theme criterion only on Performance Max campaign. Represents a
keyword-like advertiser input.
Corresponds to the JSON property searchTheme
22984 22985 22986 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22984 def search_theme @search_theme end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22991 22992 22993 22994 22995 22996 22997 22998 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22991 def update!(**args) @approval_status = args[:approval_status] if args.key?(:approval_status) @asset_group = args[:asset_group] if args.key?(:asset_group) @audience = args[:audience] if args.key?(:audience) @disapproval_reasons = args[:disapproval_reasons] if args.key?(:disapproval_reasons) @resource_name = args[:resource_name] if args.key?(:resource_name) @search_theme = args[:search_theme] if args.key?(:search_theme) end |