Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupSignal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

AssetGroupSignal represents a signal in an asset group. The existence of a signal tells the performance max campaign who's most likely to convert. Performance Max uses the signal to look for new people with similar or stronger intent to find conversions across Search, Display, Video, and more.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetGroupSignal

Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetGroupSignal.



22899
22900
22901
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22899

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approval_statusString

Output only. Approval status is the output value for search theme signal after Google ads policy review. When using Audience signal, this field is not used and will be absent. Corresponds to the JSON property approvalStatus

Returns:

  • (String)


22868
22869
22870
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22868

def approval_status
  @approval_status
end

#asset_groupString

Immutable. The asset group which this asset group signal belongs to. Corresponds to the JSON property assetGroup

Returns:

  • (String)


22873
22874
22875
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22873

def asset_group
  @asset_group
end

#audienceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInfo

An audience criterion. Corresponds to the JSON property audience



22878
22879
22880
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22878

def audience
  @audience
end

#disapproval_reasonsArray<String>

Output only. Computed for SearchTheme signals. When using Audience signal, this field is not used and will be absent. Corresponds to the JSON property disapprovalReasons

Returns:

  • (Array<String>)


22884
22885
22886
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22884

def disapproval_reasons
  @disapproval_reasons
end

#resource_nameString

Immutable. The resource name of the asset group signal. Asset group signal resource name have the form: customers/customer_id/assetGroupSignals/ asset_group_id~signal_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


22891
22892
22893
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22891

def resource_name
  @resource_name
end

#search_themeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSearchThemeInfo

A Search Theme criterion only on Performance Max campaign. Represents a keyword-like advertiser input. Corresponds to the JSON property searchTheme



22897
22898
22899
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22897

def search_theme
  @search_theme
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22904
22905
22906
22907
22908
22909
22910
22911
# File 'lib/google/apis/searchads360_v23/classes.rb', line 22904

def update!(**args)
  @approval_status = args[:approval_status] if args.key?(:approval_status)
  @asset_group = args[:asset_group] if args.key?(:asset_group)
  @audience = args[:audience] if args.key?(:audience)
  @disapproval_reasons = args[:disapproval_reasons] if args.key?(:disapproval_reasons)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @search_theme = args[:search_theme] if args.key?(:search_theme)
end