Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An asset set representing a collection of assets. Use AssetSetAsset to link an asset to the asset set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetSet

Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetSet.



23132
23133
23134
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23132

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_profile_location_groupGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBusinessProfileLocationGroup

Information about a Business Profile dynamic location group. Only applicable if the sync level AssetSet's type is LOCATION_SYNC and sync source is Business Profile. Corresponds to the JSON property businessProfileLocationGroup



23071
23072
23073
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23071

def business_profile_location_group
  @business_profile_location_group
end

#chain_location_groupGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonChainLocationGroup

Represents information about a Chain dynamic location group. Only applicable if the sync level AssetSet's type is LOCATION_SYNC and sync source is chain. Corresponds to the JSON property chainLocationGroup



23077
23078
23079
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23077

def chain_location_group
  @chain_location_group
end

#hotel_property_dataGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetHotelPropertyData

For Performance Max for travel goals campaigns with a Hotel Center account link. Read-only. Corresponds to the JSON property hotelPropertyData



23083
23084
23085
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23083

def hotel_property_data
  @hotel_property_data
end

#idFixnum

Output only. The ID of the asset set. Corresponds to the JSON property id

Returns:

  • (Fixnum)


23088
23089
23090
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23088

def id
  @id
end

#location_group_parent_asset_set_idFixnum

Immutable. Parent asset set ID for the asset set where the elements of this asset set come from. For example: the sync level location AssetSet id where the elements in LocationGroup AssetSet come from. This field is required and only applicable for Location Group typed AssetSet. Corresponds to the JSON property locationGroupParentAssetSetId

Returns:

  • (Fixnum)


23096
23097
23098
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23096

def location_group_parent_asset_set_id
  @location_group_parent_asset_set_id
end

#location_setGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationSet

Data related to location set. One of the Google Business Profile (previously known as Google My Business) data, Chain data, and map location data need to be specified. Corresponds to the JSON property locationSet



23103
23104
23105
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23103

def location_set
  @location_set
end

#merchant_center_feedGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetMerchantCenterFeed

Merchant ID and Feed Label from Google Merchant Center. Corresponds to the JSON property merchantCenterFeed



23108
23109
23110
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23108

def merchant_center_feed
  @merchant_center_feed
end

#nameString

Required. Name of the asset set. Required. It must have a minimum length of 1 and maximum length of 128. Corresponds to the JSON property name

Returns:

  • (String)


23114
23115
23116
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23114

def name
  @name
end

#resource_nameString

Immutable. The resource name of the asset set. Asset set resource names have the form: customers/customer_id/assetSets/asset_set_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


23120
23121
23122
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23120

def resource_name
  @resource_name
end

#statusString

Output only. The status of the asset set. Read-only. Corresponds to the JSON property status

Returns:

  • (String)


23125
23126
23127
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23125

def status
  @status
end

#typeString

Required. Immutable. The type of the asset set. Required. Corresponds to the JSON property type

Returns:

  • (String)


23130
23131
23132
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23130

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23137
23138
23139
23140
23141
23142
23143
23144
23145
23146
23147
23148
23149
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23137

def update!(**args)
  @business_profile_location_group = args[:business_profile_location_group] if args.key?(:business_profile_location_group)
  @chain_location_group = args[:chain_location_group] if args.key?(:chain_location_group)
  @hotel_property_data = args[:hotel_property_data] if args.key?(:hotel_property_data)
  @id = args[:id] if args.key?(:id)
  @location_group_parent_asset_set_id = args[:location_group_parent_asset_set_id] if args.key?(:location_group_parent_asset_set_id)
  @location_set = args[:location_set] if args.key?(:location_set)
  @merchant_center_feed = args[:merchant_center_feed] if args.key?(:merchant_center_feed)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end