Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
AssetSetAsset is the link between an asset and an asset set. Adding an AssetSetAsset links an asset with an asset set.
Instance Attribute Summary collapse
-
#asset ⇒ String
Immutable.
-
#asset_set ⇒ String
Immutable.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetSetAsset
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAssetSetAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetSetAsset
Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetSetAsset.
23239 23240 23241 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23239 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset ⇒ String
Immutable. The asset which this asset set asset is linking to.
Corresponds to the JSON property asset
23220 23221 23222 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23220 def asset @asset end |
#asset_set ⇒ String
Immutable. The asset set which this asset set asset is linking to.
Corresponds to the JSON property assetSet
23225 23226 23227 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23225 def asset_set @asset_set end |
#resource_name ⇒ String
Immutable. The resource name of the asset set asset. Asset set asset resource
names have the form: customers/customer_id/assetSetAssets/asset_set_id~
asset_id`
Corresponds to the JSON propertyresourceName`
23232 23233 23234 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23232 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the asset set asset. Read-only.
Corresponds to the JSON property status
23237 23238 23239 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23237 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23244 23245 23246 23247 23248 23249 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23244 def update!(**args) @asset = args[:asset] if args.key?(:asset) @asset_set = args[:asset_set] if args.key?(:asset_set) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |