Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

AssetSetAsset is the link between an asset and an asset set. Adding an AssetSetAsset links an asset with an asset set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetSetAsset

Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetSetAsset.



23179
23180
23181
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23179

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetString

Immutable. The asset which this asset set asset is linking to. Corresponds to the JSON property asset

Returns:

  • (String)


23160
23161
23162
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23160

def asset
  @asset
end

#asset_setString

Immutable. The asset set which this asset set asset is linking to. Corresponds to the JSON property assetSet

Returns:

  • (String)


23165
23166
23167
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23165

def asset_set
  @asset_set
end

#resource_nameString

Immutable. The resource name of the asset set asset. Asset set asset resource names have the form: customers/customer_id/assetSetAssets/asset_set_id~ asset_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


23172
23173
23174
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23172

def resource_name
  @resource_name
end

#statusString

Output only. The status of the asset set asset. Read-only. Corresponds to the JSON property status

Returns:

  • (String)


23177
23178
23179
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23177

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23184
23185
23186
23187
23188
23189
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23184

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @asset_set = args[:asset_set] if args.key?(:asset_set)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end