Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

AssetSetAsset is the link between an asset and an asset set. Adding an AssetSetAsset links an asset with an asset set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetSetAsset

Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetSetAsset.



23092
23093
23094
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23092

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetString

Immutable. The asset which this asset set asset is linking to. Corresponds to the JSON property asset

Returns:

  • (String)


23073
23074
23075
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23073

def asset
  @asset
end

#asset_setString

Immutable. The asset set which this asset set asset is linking to. Corresponds to the JSON property assetSet

Returns:

  • (String)


23078
23079
23080
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23078

def asset_set
  @asset_set
end

#resource_nameString

Immutable. The resource name of the asset set asset. Asset set asset resource names have the form: customers/customer_id/assetSetAssets/asset_set_id~ asset_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


23085
23086
23087
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23085

def resource_name
  @resource_name
end

#statusString

Output only. The status of the asset set asset. Read-only. Corresponds to the JSON property status

Returns:

  • (String)


23090
23091
23092
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23090

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23097
23098
23099
23100
23101
23102
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23097

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @asset_set = args[:asset_set] if args.key?(:asset_set)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end