Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
AssetSetAsset is the link between an asset and an asset set. Adding an AssetSetAsset links an asset with an asset set.
Instance Attribute Summary collapse
-
#asset ⇒ String
Immutable.
-
#asset_set ⇒ String
Immutable.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetSetAsset
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAssetSetAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetSetAsset
Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetSetAsset.
23092 23093 23094 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23092 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset ⇒ String
Immutable. The asset which this asset set asset is linking to.
Corresponds to the JSON property asset
23073 23074 23075 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23073 def asset @asset end |
#asset_set ⇒ String
Immutable. The asset set which this asset set asset is linking to.
Corresponds to the JSON property assetSet
23078 23079 23080 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23078 def asset_set @asset_set end |
#resource_name ⇒ String
Immutable. The resource name of the asset set asset. Asset set asset resource
names have the form: customers/customer_id/assetSetAssets/asset_set_id~
asset_id`
Corresponds to the JSON propertyresourceName`
23085 23086 23087 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23085 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the asset set asset. Read-only.
Corresponds to the JSON property status
23090 23091 23092 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23090 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23097 23098 23099 23100 23101 23102 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23097 def update!(**args) @asset = args[:asset] if args.key?(:asset) @asset_set = args[:asset_set] if args.key?(:asset_set) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |