Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetTypeView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetTypeView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An asset set type view. This view reports non-overcounted metrics for each asset set type. Child asset set types are not included in this report. Their stats are aggregated under the parent asset set type.
Instance Attribute Summary collapse
-
#asset_set_type ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetSetTypeView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAssetSetTypeView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetSetTypeView
Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetSetTypeView.
23270 23271 23272 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23270 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_set_type ⇒ String
Output only. The asset set type of the asset set type view.
Corresponds to the JSON property assetSetType
23261 23262 23263 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23261 def asset_set_type @asset_set_type end |
#resource_name ⇒ String
Output only. The resource name of the asset set type view. Asset set type view
resource names have the form: customers/customer_id/assetSetTypeViews/
asset_set_type`
Corresponds to the JSON propertyresourceName`
23268 23269 23270 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23268 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23275 23276 23277 23278 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23275 def update!(**args) @asset_set_type = args[:asset_set_type] if args.key?(:asset_set_type) @resource_name = args[:resource_name] if args.key?(:resource_name) end |