Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetTypeView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An asset set type view. This view reports non-overcounted metrics for each asset set type. Child asset set types are not included in this report. Their stats are aggregated under the parent asset set type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAssetSetTypeView

Returns a new instance of GoogleAdsSearchads360V23ResourcesAssetSetTypeView.



23210
23211
23212
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_set_typeString

Output only. The asset set type of the asset set type view. Corresponds to the JSON property assetSetType

Returns:

  • (String)


23201
23202
23203
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23201

def asset_set_type
  @asset_set_type
end

#resource_nameString

Output only. The resource name of the asset set type view. Asset set type view resource names have the form: customers/customer_id/assetSetTypeViews/ asset_set_type` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


23208
23209
23210
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23208

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23215
23216
23217
23218
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23215

def update!(**args)
  @asset_set_type = args[:asset_set_type] if args.key?(:asset_set_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end