Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAudience
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAudience
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Audience is an effective targeting option that lets you intersect different segment attributes, such as detailed demographics and affinities, to create audiences that represent sections of your target segments.
Instance Attribute Summary collapse
-
#asset_group ⇒ String
Immutable.
-
#description ⇒ String
Description of this audience.
-
#dimensions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceDimension>
Positive dimensions specifying the audience composition.
-
#exclusion_dimension ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceExclusionDimension
Negative dimension specifying users to exclude from the audience.
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Name of the audience.
-
#resource_name ⇒ String
Immutable.
-
#scope ⇒ String
Defines the scope this audience can be used in.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAudience
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAudience.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAudience
Returns a new instance of GoogleAdsSearchads360V23ResourcesAudience.
23343 23344 23345 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_group ⇒ String
Immutable. The asset group that this audience is scoped under. Must be set if
and only if scope is ASSET_GROUP. Immutable after creation. If an audience
with ASSET_GROUP scope is upgraded to CUSTOMER scope, this field will
automatically be cleared.
Corresponds to the JSON property assetGroup
23293 23294 23295 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23293 def asset_group @asset_group end |
#description ⇒ String
Description of this audience.
Corresponds to the JSON property description
23298 23299 23300 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23298 def description @description end |
#dimensions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceDimension>
Positive dimensions specifying the audience composition.
Corresponds to the JSON property dimensions
23303 23304 23305 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23303 def dimensions @dimensions end |
#exclusion_dimension ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceExclusionDimension
Negative dimension specifying users to exclude from the audience.
Corresponds to the JSON property exclusionDimension
23308 23309 23310 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23308 def exclusion_dimension @exclusion_dimension end |
#id ⇒ Fixnum
Output only. ID of the audience.
Corresponds to the JSON property id
23313 23314 23315 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23313 def id @id end |
#name ⇒ String
Name of the audience. It should be unique across all audiences within the
account. It must have a minimum length of 1 and maximum length of 255.
Required when scope is not set or is set to CUSTOMER. Cannot be set or updated
when scope is ASSET_GROUP.
Corresponds to the JSON property name
23321 23322 23323 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23321 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the audience. Audience names have the form:
customers/customer_id/audiences/audience_id`
Corresponds to the JSON propertyresourceName`
23327 23328 23329 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23327 def resource_name @resource_name end |
#scope ⇒ String
Defines the scope this audience can be used in. By default, the scope is
CUSTOMER. Audiences can be created with a scope of ASSET_GROUP for exclusive
use by a single asset_group. Scope may change from ASSET_GROUP to CUSTOMER but
not from CUSTOMER to ASSET_GROUP.
Corresponds to the JSON property scope
23335 23336 23337 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23335 def scope @scope end |
#status ⇒ String
Output only. Status of this audience. Indicates whether the audience is
enabled or removed.
Corresponds to the JSON property status
23341 23342 23343 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23341 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23348 23349 23350 23351 23352 23353 23354 23355 23356 23357 23358 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23348 def update!(**args) @asset_group = args[:asset_group] if args.key?(:asset_group) @description = args[:description] if args.key?(:description) @dimensions = args[:dimensions] if args.key?(:dimensions) @exclusion_dimension = args[:exclusion_dimension] if args.key?(:exclusion_dimension) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @scope = args[:scope] if args.key?(:scope) @status = args[:status] if args.key?(:status) end |