Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAudience
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAudience
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Audience is an effective targeting option that lets you intersect different segment attributes, such as detailed demographics and affinities, to create audiences that represent sections of your target segments.
Instance Attribute Summary collapse
-
#asset_group ⇒ String
Immutable.
-
#description ⇒ String
Description of this audience.
-
#dimensions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceDimension>
Positive dimensions specifying the audience composition.
-
#exclusion_dimension ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceExclusionDimension
Negative dimension specifying users to exclude from the audience.
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Name of the audience.
-
#resource_name ⇒ String
Immutable.
-
#scope ⇒ String
Defines the scope this audience can be used in.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAudience
constructor
A new instance of GoogleAdsSearchads360V23ResourcesAudience.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesAudience
Returns a new instance of GoogleAdsSearchads360V23ResourcesAudience.
23196 23197 23198 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23196 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_group ⇒ String
Immutable. The asset group that this audience is scoped under. Must be set if
and only if scope is ASSET_GROUP. Immutable after creation. If an audience
with ASSET_GROUP scope is upgraded to CUSTOMER scope, this field will
automatically be cleared.
Corresponds to the JSON property assetGroup
23146 23147 23148 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23146 def asset_group @asset_group end |
#description ⇒ String
Description of this audience.
Corresponds to the JSON property description
23151 23152 23153 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23151 def description @description end |
#dimensions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceDimension>
Positive dimensions specifying the audience composition.
Corresponds to the JSON property dimensions
23156 23157 23158 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23156 def dimensions @dimensions end |
#exclusion_dimension ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceExclusionDimension
Negative dimension specifying users to exclude from the audience.
Corresponds to the JSON property exclusionDimension
23161 23162 23163 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23161 def exclusion_dimension @exclusion_dimension end |
#id ⇒ Fixnum
Output only. ID of the audience.
Corresponds to the JSON property id
23166 23167 23168 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23166 def id @id end |
#name ⇒ String
Name of the audience. It should be unique across all audiences within the
account. It must have a minimum length of 1 and maximum length of 255.
Required when scope is not set or is set to CUSTOMER. Cannot be set or updated
when scope is ASSET_GROUP.
Corresponds to the JSON property name
23174 23175 23176 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23174 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the audience. Audience names have the form:
customers/customer_id/audiences/audience_id`
Corresponds to the JSON propertyresourceName`
23180 23181 23182 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23180 def resource_name @resource_name end |
#scope ⇒ String
Defines the scope this audience can be used in. By default, the scope is
CUSTOMER. Audiences can be created with a scope of ASSET_GROUP for exclusive
use by a single asset_group. Scope may change from ASSET_GROUP to CUSTOMER but
not from CUSTOMER to ASSET_GROUP.
Corresponds to the JSON property scope
23188 23189 23190 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23188 def scope @scope end |
#status ⇒ String
Output only. Status of this audience. Indicates whether the audience is
enabled or removed.
Corresponds to the JSON property status
23194 23195 23196 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23194 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23201 def update!(**args) @asset_group = args[:asset_group] if args.key?(:asset_group) @description = args[:description] if args.key?(:description) @dimensions = args[:dimensions] if args.key?(:dimensions) @exclusion_dimension = args[:exclusion_dimension] if args.key?(:exclusion_dimension) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @scope = args[:scope] if args.key?(:scope) @status = args[:status] if args.key?(:status) end |