Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBatchJob
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBatchJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A list of mutates being processed asynchronously. The mutates are uploaded by the user. The mutates themselves aren't readable and the results of the job can only be read using BatchJobService.ListBatchJobResults.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#long_running_operation ⇒ String
Output only.
-
#metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata
Additional information about the batch job.
-
#next_add_sequence_token ⇒ String
Output only.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBatchJob
constructor
A new instance of GoogleAdsSearchads360V23ResourcesBatchJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBatchJob
Returns a new instance of GoogleAdsSearchads360V23ResourcesBatchJob.
23428 23429 23430 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23428 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. ID of this batch job.
Corresponds to the JSON property id
23397 23398 23399 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23397 def id @id end |
#long_running_operation ⇒ String
Output only. The resource name of the long-running operation that can be used
to poll for completion. Only set when the batch job status is RUNNING or DONE.
Corresponds to the JSON property longRunningOperation
23403 23404 23405 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23403 def long_running_operation @long_running_operation end |
#metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata
Additional information about the batch job. This message is also used as
metadata returned in batch job Long Running Operations.
Corresponds to the JSON property metadata
23409 23410 23411 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23409 def @metadata end |
#next_add_sequence_token ⇒ String
Output only. The next sequence token to use when adding operations. Only set
when the batch job status is PENDING.
Corresponds to the JSON property nextAddSequenceToken
23415 23416 23417 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23415 def next_add_sequence_token @next_add_sequence_token end |
#resource_name ⇒ String
Immutable. The resource name of the batch job. Batch job resource names have
the form: customers/customer_id/batchJobs/batch_job_id`
Corresponds to the JSON propertyresourceName`
23421 23422 23423 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23421 def resource_name @resource_name end |
#status ⇒ String
Output only. Status of this batch job.
Corresponds to the JSON property status
23426 23427 23428 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23426 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23433 23434 23435 23436 23437 23438 23439 23440 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23433 def update!(**args) @id = args[:id] if args.key?(:id) @long_running_operation = args[:long_running_operation] if args.key?(:long_running_operation) @metadata = args[:metadata] if args.key?(:metadata) @next_add_sequence_token = args[:next_add_sequence_token] if args.key?(:next_add_sequence_token) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |