Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBatchJob
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBatchJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A list of mutates being processed asynchronously. The mutates are uploaded by the user. The mutates themselves aren't readable and the results of the job can only be read using BatchJobService.ListBatchJobResults.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#long_running_operation ⇒ String
Output only.
-
#metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata
Additional information about the batch job.
-
#next_add_sequence_token ⇒ String
Output only.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBatchJob
constructor
A new instance of GoogleAdsSearchads360V23ResourcesBatchJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBatchJob
Returns a new instance of GoogleAdsSearchads360V23ResourcesBatchJob.
23281 23282 23283 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23281 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. ID of this batch job.
Corresponds to the JSON property id
23250 23251 23252 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23250 def id @id end |
#long_running_operation ⇒ String
Output only. The resource name of the long-running operation that can be used
to poll for completion. Only set when the batch job status is RUNNING or DONE.
Corresponds to the JSON property longRunningOperation
23256 23257 23258 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23256 def long_running_operation @long_running_operation end |
#metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata
Additional information about the batch job. This message is also used as
metadata returned in batch job Long Running Operations.
Corresponds to the JSON property metadata
23262 23263 23264 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23262 def @metadata end |
#next_add_sequence_token ⇒ String
Output only. The next sequence token to use when adding operations. Only set
when the batch job status is PENDING.
Corresponds to the JSON property nextAddSequenceToken
23268 23269 23270 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23268 def next_add_sequence_token @next_add_sequence_token end |
#resource_name ⇒ String
Immutable. The resource name of the batch job. Batch job resource names have
the form: customers/customer_id/batchJobs/batch_job_id`
Corresponds to the JSON propertyresourceName`
23274 23275 23276 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23274 def resource_name @resource_name end |
#status ⇒ String
Output only. Status of this batch job.
Corresponds to the JSON property status
23279 23280 23281 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23279 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23286 23287 23288 23289 23290 23291 23292 23293 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23286 def update!(**args) @id = args[:id] if args.key?(:id) @long_running_operation = args[:long_running_operation] if args.key?(:long_running_operation) @metadata = args[:metadata] if args.key?(:metadata) @next_add_sequence_token = args[:next_add_sequence_token] if args.key?(:next_add_sequence_token) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |