Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Additional information about the batch job. This message is also used as metadata returned in batch job Long Running Operations.
Instance Attribute Summary collapse
-
#completion_date_time ⇒ String
Output only.
-
#creation_date_time ⇒ String
Output only.
-
#estimated_completion_ratio ⇒ Float
Output only.
-
#executed_operation_count ⇒ Fixnum
Output only.
-
#execution_limit_seconds ⇒ Fixnum
Immutable.
-
#operation_count ⇒ Fixnum
Output only.
-
#start_date_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata
constructor
A new instance of GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata
Returns a new instance of GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata.
15419 15420 15421 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15419 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completion_date_time ⇒ String
Output only. The time when this batch job was completed. Formatted as yyyy-MM-
dd HH:mm:ss. Example: "2018-03-05 09:16:00"
Corresponds to the JSON property completionDateTime
15381 15382 15383 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15381 def completion_date_time @completion_date_time end |
#creation_date_time ⇒ String
Output only. The time when this batch job was created. Formatted as yyyy-mm-dd
hh:mm:ss. Example: "2018-03-05 09:15:00"
Corresponds to the JSON property creationDateTime
15387 15388 15389 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15387 def creation_date_time @creation_date_time end |
#estimated_completion_ratio ⇒ Float
Output only. The fraction (between 0.0 and 1.0) of mutates that have been
processed. This is empty if the job hasn't started running yet.
Corresponds to the JSON property estimatedCompletionRatio
15393 15394 15395 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15393 def estimated_completion_ratio @estimated_completion_ratio end |
#executed_operation_count ⇒ Fixnum
Output only. The number of mutate operations executed by the batch job.
Present only if the job has started running.
Corresponds to the JSON property executedOperationCount
15399 15400 15401 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15399 def executed_operation_count @executed_operation_count end |
#execution_limit_seconds ⇒ Fixnum
Immutable. The approximate upper bound for how long a batch job can be
executed, in seconds. If the job runs more than the given upper bound, the job
will be canceled.
Corresponds to the JSON property executionLimitSeconds
15406 15407 15408 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15406 def execution_limit_seconds @execution_limit_seconds end |
#operation_count ⇒ Fixnum
Output only. The number of mutate operations in the batch job.
Corresponds to the JSON property operationCount
15411 15412 15413 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15411 def operation_count @operation_count end |
#start_date_time ⇒ String
Output only. The time when this batch job started running. Formatted as yyyy-
mm-dd hh:mm:ss. Example: "2018-03-05 09:15:30"
Corresponds to the JSON property startDateTime
15417 15418 15419 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15417 def start_date_time @start_date_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15424 15425 15426 15427 15428 15429 15430 15431 15432 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15424 def update!(**args) @completion_date_time = args[:completion_date_time] if args.key?(:completion_date_time) @creation_date_time = args[:creation_date_time] if args.key?(:creation_date_time) @estimated_completion_ratio = args[:estimated_completion_ratio] if args.key?(:estimated_completion_ratio) @executed_operation_count = args[:executed_operation_count] if args.key?(:executed_operation_count) @execution_limit_seconds = args[:execution_limit_seconds] if args.key?(:execution_limit_seconds) @operation_count = args[:operation_count] if args.key?(:operation_count) @start_date_time = args[:start_date_time] if args.key?(:start_date_time) end |