Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Additional information about the batch job. This message is also used as metadata returned in batch job Long Running Operations.
Instance Attribute Summary collapse
-
#completion_date_time ⇒ String
Output only.
-
#creation_date_time ⇒ String
Output only.
-
#estimated_completion_ratio ⇒ Float
Output only.
-
#executed_operation_count ⇒ Fixnum
Output only.
-
#execution_limit_seconds ⇒ Fixnum
Immutable.
-
#operation_count ⇒ Fixnum
Output only.
-
#start_date_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata
constructor
A new instance of GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata
Returns a new instance of GoogleAdsSearchads360V23ResourcesBatchJobBatchJobMetadata.
15353 15354 15355 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15353 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completion_date_time ⇒ String
Output only. The time when this batch job was completed. Formatted as yyyy-MM-
dd HH:mm:ss. Example: "2018-03-05 09:16:00"
Corresponds to the JSON property completionDateTime
15315 15316 15317 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15315 def completion_date_time @completion_date_time end |
#creation_date_time ⇒ String
Output only. The time when this batch job was created. Formatted as yyyy-mm-dd
hh:mm:ss. Example: "2018-03-05 09:15:00"
Corresponds to the JSON property creationDateTime
15321 15322 15323 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15321 def creation_date_time @creation_date_time end |
#estimated_completion_ratio ⇒ Float
Output only. The fraction (between 0.0 and 1.0) of mutates that have been
processed. This is empty if the job hasn't started running yet.
Corresponds to the JSON property estimatedCompletionRatio
15327 15328 15329 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15327 def estimated_completion_ratio @estimated_completion_ratio end |
#executed_operation_count ⇒ Fixnum
Output only. The number of mutate operations executed by the batch job.
Present only if the job has started running.
Corresponds to the JSON property executedOperationCount
15333 15334 15335 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15333 def executed_operation_count @executed_operation_count end |
#execution_limit_seconds ⇒ Fixnum
Immutable. The approximate upper bound for how long a batch job can be
executed, in seconds. If the job runs more than the given upper bound, the job
will be canceled.
Corresponds to the JSON property executionLimitSeconds
15340 15341 15342 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15340 def execution_limit_seconds @execution_limit_seconds end |
#operation_count ⇒ Fixnum
Output only. The number of mutate operations in the batch job.
Corresponds to the JSON property operationCount
15345 15346 15347 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15345 def operation_count @operation_count end |
#start_date_time ⇒ String
Output only. The time when this batch job started running. Formatted as yyyy-
mm-dd hh:mm:ss. Example: "2018-03-05 09:15:30"
Corresponds to the JSON property startDateTime
15351 15352 15353 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15351 def start_date_time @start_date_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15358 15359 15360 15361 15362 15363 15364 15365 15366 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15358 def update!(**args) @completion_date_time = args[:completion_date_time] if args.key?(:completion_date_time) @creation_date_time = args[:creation_date_time] if args.key?(:creation_date_time) @estimated_completion_ratio = args[:estimated_completion_ratio] if args.key?(:estimated_completion_ratio) @executed_operation_count = args[:executed_operation_count] if args.key?(:executed_operation_count) @execution_limit_seconds = args[:execution_limit_seconds] if args.key?(:execution_limit_seconds) @operation_count = args[:operation_count] if args.key?(:operation_count) @start_date_time = args[:start_date_time] if args.key?(:start_date_time) end |