Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents a bidding seasonality adjustment. Cannot be used in manager accounts. See "About seasonality adjustments" at https://support.google.com/ google-ads/answer/10369906.
Instance Attribute Summary collapse
-
#advertising_channel_types ⇒ Array<String>
The seasonality adjustment will apply to all the campaigns under the listed channels retroactively as well as going forward when the scope of this adjustment is CHANNEL.
-
#campaigns ⇒ Array<String>
The seasonality adjustment will apply to the campaigns listed when the scope of this adjustment is CAMPAIGN.
-
#conversion_rate_modifier ⇒ Float
Conversion rate modifier estimated based on expected conversion rate changes.
-
#description ⇒ String
The description of the seasonality adjustment.
-
#devices ⇒ Array<String>
If not specified, all devices will be included in this adjustment.
-
#end_date_time ⇒ String
Required.
-
#name ⇒ String
The name of the seasonality adjustment.
-
#resource_name ⇒ String
Immutable.
-
#scope ⇒ String
The scope of the seasonality adjustment.
-
#seasonality_adjustment_id ⇒ Fixnum
Output only.
-
#start_date_time ⇒ String
Required.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment
constructor
A new instance of GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment
Returns a new instance of GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment.
23563 23564 23565 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23563 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertising_channel_types ⇒ Array<String>
The seasonality adjustment will apply to all the campaigns under the listed
channels retroactively as well as going forward when the scope of this
adjustment is CHANNEL. The supported advertising channel types are DISPLAY,
SEARCH and SHOPPING. Note: a seasonality adjustment with both
advertising_channel_types and campaign_ids is not supported.
Corresponds to the JSON property advertisingChannelTypes
23493 23494 23495 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23493 def advertising_channel_types @advertising_channel_types end |
#campaigns ⇒ Array<String>
The seasonality adjustment will apply to the campaigns listed when the scope of this adjustment is CAMPAIGN. The maximum number of campaigns per event is
- Note: a seasonality adjustment with both advertising_channel_types and
campaign_ids is not supported.
Corresponds to the JSON property
campaigns
23501 23502 23503 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23501 def campaigns @campaigns end |
#conversion_rate_modifier ⇒ Float
Conversion rate modifier estimated based on expected conversion rate changes.
When this field is unset or set to 1.0 no adjustment will be applied to
traffic. The allowed range is 0.1 to 10.0.
Corresponds to the JSON property conversionRateModifier
23508 23509 23510 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23508 def conversion_rate_modifier @conversion_rate_modifier end |
#description ⇒ String
The description of the seasonality adjustment. The description can be at most
2048 characters.
Corresponds to the JSON property description
23514 23515 23516 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23514 def description @description end |
#devices ⇒ Array<String>
If not specified, all devices will be included in this adjustment. Otherwise,
only the specified targeted devices will be included in this adjustment.
Corresponds to the JSON property devices
23520 23521 23522 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23520 def devices @devices end |
#end_date_time ⇒ String
Required. The exclusive end time of the seasonality adjustment in yyyy-MM-dd
HH:mm:ss format. The length of [start_date_time, end_date_time) interval must
be within (0, 14 days].
Corresponds to the JSON property endDateTime
23527 23528 23529 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23527 def end_date_time @end_date_time end |
#name ⇒ String
The name of the seasonality adjustment. The name can be at most 255 characters.
Corresponds to the JSON property name
23532 23533 23534 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23532 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the seasonality adjustment. Seasonality
adjustment resource names have the form: customers/customer_id/
biddingSeasonalityAdjustments/seasonality_adjustment_id`
Corresponds to the JSON propertyresourceName`
23539 23540 23541 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23539 def resource_name @resource_name end |
#scope ⇒ String
The scope of the seasonality adjustment.
Corresponds to the JSON property scope
23544 23545 23546 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23544 def scope @scope end |
#seasonality_adjustment_id ⇒ Fixnum
Output only. The ID of the seasonality adjustment.
Corresponds to the JSON property seasonalityAdjustmentId
23549 23550 23551 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23549 def seasonality_adjustment_id @seasonality_adjustment_id end |
#start_date_time ⇒ String
Required. The inclusive start time of the seasonality adjustment in yyyy-MM-dd
HH:mm:ss format. A seasonality adjustment is forward looking and should be
used for events that start and end in the future.
Corresponds to the JSON property startDateTime
23556 23557 23558 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23556 def start_date_time @start_date_time end |
#status ⇒ String
Output only. The status of the seasonality adjustment.
Corresponds to the JSON property status
23561 23562 23563 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23561 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23568 23569 23570 23571 23572 23573 23574 23575 23576 23577 23578 23579 23580 23581 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23568 def update!(**args) @advertising_channel_types = args[:advertising_channel_types] if args.key?(:advertising_channel_types) @campaigns = args[:campaigns] if args.key?(:campaigns) @conversion_rate_modifier = args[:conversion_rate_modifier] if args.key?(:conversion_rate_modifier) @description = args[:description] if args.key?(:description) @devices = args[:devices] if args.key?(:devices) @end_date_time = args[:end_date_time] if args.key?(:end_date_time) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @scope = args[:scope] if args.key?(:scope) @seasonality_adjustment_id = args[:seasonality_adjustment_id] if args.key?(:seasonality_adjustment_id) @start_date_time = args[:start_date_time] if args.key?(:start_date_time) @status = args[:status] if args.key?(:status) end |