Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a bidding seasonality adjustment. Cannot be used in manager accounts. See "About seasonality adjustments" at https://support.google.com/ google-ads/answer/10369906.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment

Returns a new instance of GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment.



23476
23477
23478
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertising_channel_typesArray<String>

The seasonality adjustment will apply to all the campaigns under the listed channels retroactively as well as going forward when the scope of this adjustment is CHANNEL. The supported advertising channel types are DISPLAY, SEARCH and SHOPPING. Note: a seasonality adjustment with both advertising_channel_types and campaign_ids is not supported. Corresponds to the JSON property advertisingChannelTypes

Returns:

  • (Array<String>)


23406
23407
23408
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23406

def advertising_channel_types
  @advertising_channel_types
end

#campaignsArray<String>

The seasonality adjustment will apply to the campaigns listed when the scope of this adjustment is CAMPAIGN. The maximum number of campaigns per event is

  1. Note: a seasonality adjustment with both advertising_channel_types and campaign_ids is not supported. Corresponds to the JSON property campaigns

Returns:

  • (Array<String>)


23414
23415
23416
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23414

def campaigns
  @campaigns
end

#conversion_rate_modifierFloat

Conversion rate modifier estimated based on expected conversion rate changes. When this field is unset or set to 1.0 no adjustment will be applied to traffic. The allowed range is 0.1 to 10.0. Corresponds to the JSON property conversionRateModifier

Returns:

  • (Float)


23421
23422
23423
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23421

def conversion_rate_modifier
  @conversion_rate_modifier
end

#descriptionString

The description of the seasonality adjustment. The description can be at most 2048 characters. Corresponds to the JSON property description

Returns:

  • (String)


23427
23428
23429
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23427

def description
  @description
end

#devicesArray<String>

If not specified, all devices will be included in this adjustment. Otherwise, only the specified targeted devices will be included in this adjustment. Corresponds to the JSON property devices

Returns:

  • (Array<String>)


23433
23434
23435
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23433

def devices
  @devices
end

#end_date_timeString

Required. The exclusive end time of the seasonality adjustment in yyyy-MM-dd HH:mm:ss format. The length of [start_date_time, end_date_time) interval must be within (0, 14 days]. Corresponds to the JSON property endDateTime

Returns:

  • (String)


23440
23441
23442
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23440

def end_date_time
  @end_date_time
end

#nameString

The name of the seasonality adjustment. The name can be at most 255 characters. Corresponds to the JSON property name

Returns:

  • (String)


23445
23446
23447
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23445

def name
  @name
end

#resource_nameString

Immutable. The resource name of the seasonality adjustment. Seasonality adjustment resource names have the form: customers/customer_id/ biddingSeasonalityAdjustments/seasonality_adjustment_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


23452
23453
23454
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23452

def resource_name
  @resource_name
end

#scopeString

The scope of the seasonality adjustment. Corresponds to the JSON property scope

Returns:

  • (String)


23457
23458
23459
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23457

def scope
  @scope
end

#seasonality_adjustment_idFixnum

Output only. The ID of the seasonality adjustment. Corresponds to the JSON property seasonalityAdjustmentId

Returns:

  • (Fixnum)


23462
23463
23464
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23462

def seasonality_adjustment_id
  @seasonality_adjustment_id
end

#start_date_timeString

Required. The inclusive start time of the seasonality adjustment in yyyy-MM-dd HH:mm:ss format. A seasonality adjustment is forward looking and should be used for events that start and end in the future. Corresponds to the JSON property startDateTime

Returns:

  • (String)


23469
23470
23471
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23469

def start_date_time
  @start_date_time
end

#statusString

Output only. The status of the seasonality adjustment. Corresponds to the JSON property status

Returns:

  • (String)


23474
23475
23476
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23474

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23481
23482
23483
23484
23485
23486
23487
23488
23489
23490
23491
23492
23493
23494
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23481

def update!(**args)
  @advertising_channel_types = args[:advertising_channel_types] if args.key?(:advertising_channel_types)
  @campaigns = args[:campaigns] if args.key?(:campaigns)
  @conversion_rate_modifier = args[:conversion_rate_modifier] if args.key?(:conversion_rate_modifier)
  @description = args[:description] if args.key?(:description)
  @devices = args[:devices] if args.key?(:devices)
  @end_date_time = args[:end_date_time] if args.key?(:end_date_time)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @scope = args[:scope] if args.key?(:scope)
  @seasonality_adjustment_id = args[:seasonality_adjustment_id] if args.key?(:seasonality_adjustment_id)
  @start_date_time = args[:start_date_time] if args.key?(:start_date_time)
  @status = args[:status] if args.key?(:status)
end