Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A bidding strategy simulation. Supported combinations of simulation type and simulation modification method are detailed below respectively. 1. TARGET_CPA - UNIFORM 2. TARGET_ROAS - UNIFORM
Instance Attribute Summary collapse
-
#bidding_strategy_id ⇒ Fixnum
Output only.
-
#end_date ⇒ String
Output only.
-
#modification_method ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#start_date ⇒ String
Output only.
-
#target_cpa_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpaSimulationPointList
A container for simulation points for simulations of type TARGET_CPA.
-
#target_roas_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoasSimulationPointList
A container for simulation points for simulations of type TARGET_ROAS.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation
Returns a new instance of GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation.
23777 23778 23779 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bidding_strategy_id ⇒ Fixnum
Output only. Bidding strategy shared set id of the simulation.
Corresponds to the JSON property biddingStrategyId
23737 23738 23739 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23737 def bidding_strategy_id @bidding_strategy_id end |
#end_date ⇒ String
Output only. Last day on which the simulation is based, in YYYY-MM-DD format
Corresponds to the JSON property endDate
23742 23743 23744 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23742 def end_date @end_date end |
#modification_method ⇒ String
Output only. How the simulation modifies the field.
Corresponds to the JSON property modificationMethod
23747 23748 23749 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23747 def modification_method @modification_method end |
#resource_name ⇒ String
Output only. The resource name of the bidding strategy simulation. Bidding
strategy simulation resource names have the form: customers/customer_id/
biddingStrategySimulations/bidding_strategy_id~type~modification_method~
start_date~end_date`
Corresponds to the JSON propertyresourceName`
23755 23756 23757 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23755 def resource_name @resource_name end |
#start_date ⇒ String
Output only. First day on which the simulation is based, in YYYY-MM-DD format.
Corresponds to the JSON property startDate
23760 23761 23762 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23760 def start_date @start_date end |
#target_cpa_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpaSimulationPointList
A container for simulation points for simulations of type TARGET_CPA.
Corresponds to the JSON property targetCpaPointList
23765 23766 23767 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23765 def target_cpa_point_list @target_cpa_point_list end |
#target_roas_point_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoasSimulationPointList
A container for simulation points for simulations of type TARGET_ROAS.
Corresponds to the JSON property targetRoasPointList
23770 23771 23772 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23770 def target_roas_point_list @target_roas_point_list end |
#type ⇒ String
Output only. The field that the simulation modifies.
Corresponds to the JSON property type
23775 23776 23777 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23775 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23782 23783 23784 23785 23786 23787 23788 23789 23790 23791 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23782 def update!(**args) @bidding_strategy_id = args[:bidding_strategy_id] if args.key?(:bidding_strategy_id) @end_date = args[:end_date] if args.key?(:end_date) @modification_method = args[:modification_method] if args.key?(:modification_method) @resource_name = args[:resource_name] if args.key?(:resource_name) @start_date = args[:start_date] if args.key?(:start_date) @target_cpa_point_list = args[:target_cpa_point_list] if args.key?(:target_cpa_point_list) @target_roas_point_list = args[:target_roas_point_list] if args.key?(:target_roas_point_list) @type = args[:type] if args.key?(:type) end |