Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A bidding strategy simulation. Supported combinations of simulation type and simulation modification method are detailed below respectively. 1. TARGET_CPA - UNIFORM 2. TARGET_ROAS - UNIFORM

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation

Returns a new instance of GoogleAdsSearchads360V23ResourcesBiddingStrategySimulation.



23690
23691
23692
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23690

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bidding_strategy_idFixnum

Output only. Bidding strategy shared set id of the simulation. Corresponds to the JSON property biddingStrategyId

Returns:

  • (Fixnum)


23650
23651
23652
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23650

def bidding_strategy_id
  @bidding_strategy_id
end

#end_dateString

Output only. Last day on which the simulation is based, in YYYY-MM-DD format Corresponds to the JSON property endDate

Returns:

  • (String)


23655
23656
23657
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23655

def end_date
  @end_date
end

#modification_methodString

Output only. How the simulation modifies the field. Corresponds to the JSON property modificationMethod

Returns:

  • (String)


23660
23661
23662
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23660

def modification_method
  @modification_method
end

#resource_nameString

Output only. The resource name of the bidding strategy simulation. Bidding strategy simulation resource names have the form: customers/customer_id/ biddingStrategySimulations/bidding_strategy_id~type~modification_method~ start_date~end_date` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


23668
23669
23670
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23668

def resource_name
  @resource_name
end

#start_dateString

Output only. First day on which the simulation is based, in YYYY-MM-DD format. Corresponds to the JSON property startDate

Returns:

  • (String)


23673
23674
23675
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23673

def start_date
  @start_date
end

#target_cpa_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpaSimulationPointList

A container for simulation points for simulations of type TARGET_CPA. Corresponds to the JSON property targetCpaPointList



23678
23679
23680
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23678

def target_cpa_point_list
  @target_cpa_point_list
end

#target_roas_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoasSimulationPointList

A container for simulation points for simulations of type TARGET_ROAS. Corresponds to the JSON property targetRoasPointList



23683
23684
23685
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23683

def target_roas_point_list
  @target_roas_point_list
end

#typeString

Output only. The field that the simulation modifies. Corresponds to the JSON property type

Returns:

  • (String)


23688
23689
23690
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23688

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23695
23696
23697
23698
23699
23700
23701
23702
23703
23704
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23695

def update!(**args)
  @bidding_strategy_id = args[:bidding_strategy_id] if args.key?(:bidding_strategy_id)
  @end_date = args[:end_date] if args.key?(:end_date)
  @modification_method = args[:modification_method] if args.key?(:modification_method)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @target_cpa_point_list = args[:target_cpa_point_list] if args.key?(:target_cpa_point_list)
  @target_roas_point_list = args[:target_roas_point_list] if args.key?(:target_roas_point_list)
  @type = args[:type] if args.key?(:type)
end