Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBillingSetup
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBillingSetup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A billing setup, which associates a payments account and an advertiser. A billing setup is specific to one advertiser.
Instance Attribute Summary collapse
-
#end_date_time ⇒ String
Output only.
-
#end_time_type ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#payments_account ⇒ String
Immutable.
-
#payments_account_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBillingSetupPaymentsAccountInfo
Container of payments account information for this billing.
-
#resource_name ⇒ String
Immutable.
-
#start_date_time ⇒ String
Immutable.
-
#start_time_type ⇒ String
Immutable.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBillingSetup
constructor
A new instance of GoogleAdsSearchads360V23ResourcesBillingSetup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBillingSetup
Returns a new instance of GoogleAdsSearchads360V23ResourcesBillingSetup.
23911 23912 23913 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23911 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date_time ⇒ String
Output only. The end date time in yyyy-MM-dd or yyyy-MM-dd HH:mm:ss format.
Corresponds to the JSON property endDateTime
23862 23863 23864 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23862 def end_date_time @end_date_time end |
#end_time_type ⇒ String
Output only. The end time as a type. The only possible value is FOREVER.
Corresponds to the JSON property endTimeType
23867 23868 23869 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23867 def end_time_type @end_time_type end |
#id ⇒ Fixnum
Output only. The ID of the billing setup.
Corresponds to the JSON property id
23872 23873 23874 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23872 def id @id end |
#payments_account ⇒ String
Immutable. The resource name of the payments account associated with this
billing setup. Payments resource names have the form: customers/customer_id/
paymentsAccounts/payments_account_id`When setting up billing, this is used
to signup with an existing payments account (and then payments_account_info
should not be set). When getting a billing setup, this and
payments_account_info will be populated.
Corresponds to the JSON propertypaymentsAccount`
23882 23883 23884 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23882 def payments_account @payments_account end |
#payments_account_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBillingSetupPaymentsAccountInfo
Container of payments account information for this billing.
Corresponds to the JSON property paymentsAccountInfo
23887 23888 23889 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23887 def payments_account_info @payments_account_info end |
#resource_name ⇒ String
Immutable. The resource name of the billing setup. BillingSetup resource names
have the form: customers/customer_id/billingSetups/billing_setup_id`
Corresponds to the JSON propertyresourceName`
23893 23894 23895 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23893 def resource_name @resource_name end |
#start_date_time ⇒ String
Immutable. The start date time in yyyy-MM-dd or yyyy-MM-dd HH:mm:ss format.
Only a future time is allowed.
Corresponds to the JSON property startDateTime
23899 23900 23901 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23899 def start_date_time @start_date_time end |
#start_time_type ⇒ String
Immutable. The start time as a type. Only NOW is allowed.
Corresponds to the JSON property startTimeType
23904 23905 23906 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23904 def start_time_type @start_time_type end |
#status ⇒ String
Output only. The status of the billing setup.
Corresponds to the JSON property status
23909 23910 23911 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23909 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23916 23917 23918 23919 23920 23921 23922 23923 23924 23925 23926 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23916 def update!(**args) @end_date_time = args[:end_date_time] if args.key?(:end_date_time) @end_time_type = args[:end_time_type] if args.key?(:end_time_type) @id = args[:id] if args.key?(:id) @payments_account = args[:payments_account] if args.key?(:payments_account) @payments_account_info = args[:payments_account_info] if args.key?(:payments_account_info) @resource_name = args[:resource_name] if args.key?(:resource_name) @start_date_time = args[:start_date_time] if args.key?(:start_date_time) @start_time_type = args[:start_time_type] if args.key?(:start_time_type) @status = args[:status] if args.key?(:status) end |