Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBillingSetup
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBillingSetup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A billing setup, which associates a payments account and an advertiser. A billing setup is specific to one advertiser.
Instance Attribute Summary collapse
-
#end_date_time ⇒ String
Output only.
-
#end_time_type ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#payments_account ⇒ String
Immutable.
-
#payments_account_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBillingSetupPaymentsAccountInfo
Container of payments account information for this billing.
-
#resource_name ⇒ String
Immutable.
-
#start_date_time ⇒ String
Immutable.
-
#start_time_type ⇒ String
Immutable.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBillingSetup
constructor
A new instance of GoogleAdsSearchads360V23ResourcesBillingSetup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBillingSetup
Returns a new instance of GoogleAdsSearchads360V23ResourcesBillingSetup.
23764 23765 23766 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23764 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date_time ⇒ String
Output only. The end date time in yyyy-MM-dd or yyyy-MM-dd HH:mm:ss format.
Corresponds to the JSON property endDateTime
23715 23716 23717 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23715 def end_date_time @end_date_time end |
#end_time_type ⇒ String
Output only. The end time as a type. The only possible value is FOREVER.
Corresponds to the JSON property endTimeType
23720 23721 23722 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23720 def end_time_type @end_time_type end |
#id ⇒ Fixnum
Output only. The ID of the billing setup.
Corresponds to the JSON property id
23725 23726 23727 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23725 def id @id end |
#payments_account ⇒ String
Immutable. The resource name of the payments account associated with this
billing setup. Payments resource names have the form: customers/customer_id/
paymentsAccounts/payments_account_id`When setting up billing, this is used
to signup with an existing payments account (and then payments_account_info
should not be set). When getting a billing setup, this and
payments_account_info will be populated.
Corresponds to the JSON propertypaymentsAccount`
23735 23736 23737 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23735 def payments_account @payments_account end |
#payments_account_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBillingSetupPaymentsAccountInfo
Container of payments account information for this billing.
Corresponds to the JSON property paymentsAccountInfo
23740 23741 23742 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23740 def payments_account_info @payments_account_info end |
#resource_name ⇒ String
Immutable. The resource name of the billing setup. BillingSetup resource names
have the form: customers/customer_id/billingSetups/billing_setup_id`
Corresponds to the JSON propertyresourceName`
23746 23747 23748 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23746 def resource_name @resource_name end |
#start_date_time ⇒ String
Immutable. The start date time in yyyy-MM-dd or yyyy-MM-dd HH:mm:ss format.
Only a future time is allowed.
Corresponds to the JSON property startDateTime
23752 23753 23754 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23752 def start_date_time @start_date_time end |
#start_time_type ⇒ String
Immutable. The start time as a type. Only NOW is allowed.
Corresponds to the JSON property startTimeType
23757 23758 23759 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23757 def start_time_type @start_time_type end |
#status ⇒ String
Output only. The status of the billing setup.
Corresponds to the JSON property status
23762 23763 23764 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23762 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23769 23770 23771 23772 23773 23774 23775 23776 23777 23778 23779 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23769 def update!(**args) @end_date_time = args[:end_date_time] if args.key?(:end_date_time) @end_time_type = args[:end_time_type] if args.key?(:end_time_type) @id = args[:id] if args.key?(:id) @payments_account = args[:payments_account] if args.key?(:payments_account) @payments_account_info = args[:payments_account_info] if args.key?(:payments_account_info) @resource_name = args[:resource_name] if args.key?(:resource_name) @start_date_time = args[:start_date_time] if args.key?(:start_date_time) @start_time_type = args[:start_time_type] if args.key?(:start_time_type) @status = args[:status] if args.key?(:status) end |