Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBillingSetupPaymentsAccountInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBillingSetupPaymentsAccountInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Container of payments account information for this billing.
Instance Attribute Summary collapse
-
#payments_account_id ⇒ String
Output only.
-
#payments_account_name ⇒ String
Immutable.
-
#payments_profile_id ⇒ String
Immutable.
-
#payments_profile_name ⇒ String
Output only.
-
#secondary_payments_profile_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBillingSetupPaymentsAccountInfo
constructor
A new instance of GoogleAdsSearchads360V23ResourcesBillingSetupPaymentsAccountInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesBillingSetupPaymentsAccountInfo
Returns a new instance of GoogleAdsSearchads360V23ResourcesBillingSetupPaymentsAccountInfo.
15473 15474 15475 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15473 def initialize(**args) update!(**args) end |
Instance Attribute Details
#payments_account_id ⇒ String
Output only. A 16 digit id used to identify the payments account associated
with the billing setup. This must be passed as a string with dashes, for
example, "1234-5678-9012-3456".
Corresponds to the JSON property paymentsAccountId
15444 15445 15446 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15444 def payments_account_id @payments_account_id end |
#payments_account_name ⇒ String
Immutable. The name of the payments account associated with the billing setup.
This enables the user to specify a meaningful name for a payments account to
aid in reconciling monthly invoices. This name will be printed in the monthly
invoices.
Corresponds to the JSON property paymentsAccountName
15452 15453 15454 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15452 def payments_account_name @payments_account_name end |
#payments_profile_id ⇒ String
Immutable. A 12 digit id used to identify the payments profile associated with
the billing setup. This must be passed in as a string with dashes, for example,
"1234-5678-9012".
Corresponds to the JSON property paymentsProfileId
15459 15460 15461 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15459 def payments_profile_id @payments_profile_id end |
#payments_profile_name ⇒ String
Output only. The name of the payments profile associated with the billing
setup.
Corresponds to the JSON property paymentsProfileName
15465 15466 15467 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15465 def payments_profile_name @payments_profile_name end |
#secondary_payments_profile_id ⇒ String
Output only. A secondary payments profile id present in uncommon situations,
for example, when a sequential liability agreement has been arranged.
Corresponds to the JSON property secondaryPaymentsProfileId
15471 15472 15473 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15471 def secondary_payments_profile_id @secondary_payments_profile_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15478 15479 15480 15481 15482 15483 15484 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15478 def update!(**args) @payments_account_id = args[:payments_account_id] if args.key?(:payments_account_id) @payments_account_name = args[:payments_account_name] if args.key?(:payments_account_name) @payments_profile_id = args[:payments_profile_id] if args.key?(:payments_profile_id) @payments_profile_name = args[:payments_profile_name] if args.key?(:payments_profile_name) @secondary_payments_profile_id = args[:secondary_payments_profile_id] if args.key?(:secondary_payments_profile_id) end |