Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCallReportingSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Call reporting setting for a customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCallReportingSetting

Returns a new instance of GoogleAdsSearchads360V23ResourcesCallReportingSetting.



23975
23976
23977
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_conversion_actionString

Customer-level call conversion action to attribute a call conversion to. If not set a default conversion action is used. Only in effect when call_conversion_reporting_enabled is set to true. Corresponds to the JSON property callConversionAction

Returns:

  • (String)


23960
23961
23962
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23960

def call_conversion_action
  @call_conversion_action
end

#call_conversion_reporting_enabledBoolean Also known as: call_conversion_reporting_enabled?

Whether to enable call conversion reporting. Corresponds to the JSON property callConversionReportingEnabled

Returns:

  • (Boolean)


23965
23966
23967
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23965

def call_conversion_reporting_enabled
  @call_conversion_reporting_enabled
end

#call_reporting_enabledBoolean Also known as: call_reporting_enabled?

Enable reporting of phone call events by redirecting them through Google System. Corresponds to the JSON property callReportingEnabled

Returns:

  • (Boolean)


23972
23973
23974
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23972

def call_reporting_enabled
  @call_reporting_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23980
23981
23982
23983
23984
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23980

def update!(**args)
  @call_conversion_action = args[:call_conversion_action] if args.key?(:call_conversion_action)
  @call_conversion_reporting_enabled = args[:call_conversion_reporting_enabled] if args.key?(:call_conversion_reporting_enabled)
  @call_reporting_enabled = args[:call_reporting_enabled] if args.key?(:call_reporting_enabled)
end