Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCallReportingSetting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCallReportingSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Call reporting setting for a customer.
Instance Attribute Summary collapse
-
#call_conversion_action ⇒ String
Customer-level call conversion action to attribute a call conversion to.
-
#call_conversion_reporting_enabled ⇒ Boolean
(also: #call_conversion_reporting_enabled?)
Whether to enable call conversion reporting.
-
#call_reporting_enabled ⇒ Boolean
(also: #call_reporting_enabled?)
Enable reporting of phone call events by redirecting them through Google System.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCallReportingSetting
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCallReportingSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCallReportingSetting
Returns a new instance of GoogleAdsSearchads360V23ResourcesCallReportingSetting.
23888 23889 23890 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23888 def initialize(**args) update!(**args) end |
Instance Attribute Details
#call_conversion_action ⇒ String
Customer-level call conversion action to attribute a call conversion to. If
not set a default conversion action is used. Only in effect when
call_conversion_reporting_enabled is set to true.
Corresponds to the JSON property callConversionAction
23873 23874 23875 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23873 def call_conversion_action @call_conversion_action end |
#call_conversion_reporting_enabled ⇒ Boolean Also known as: call_conversion_reporting_enabled?
Whether to enable call conversion reporting.
Corresponds to the JSON property callConversionReportingEnabled
23878 23879 23880 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23878 def call_conversion_reporting_enabled @call_conversion_reporting_enabled end |
#call_reporting_enabled ⇒ Boolean Also known as: call_reporting_enabled?
Enable reporting of phone call events by redirecting them through Google
System.
Corresponds to the JSON property callReportingEnabled
23885 23886 23887 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23885 def call_reporting_enabled @call_reporting_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23893 23894 23895 23896 23897 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 23893 def update!(**args) @call_conversion_action = args[:call_conversion_action] if args.key?(:call_conversion_action) @call_conversion_reporting_enabled = args[:call_conversion_reporting_enabled] if args.key?(:call_conversion_reporting_enabled) @call_reporting_enabled = args[:call_reporting_enabled] if args.key?(:call_reporting_enabled) end |