Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A link between a Campaign and an Asset.
Instance Attribute Summary collapse
-
#asset ⇒ String
Immutable.
-
#campaign ⇒ String
Immutable.
-
#field_type ⇒ String
Immutable.
-
#primary_status ⇒ String
Output only.
-
#primary_status_details ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetLinkPrimaryStatusDetails>
Output only.
-
#primary_status_reasons ⇒ Array<String>
Output only.
-
#resource_name ⇒ String
Immutable.
-
#source ⇒ String
Output only.
-
#status ⇒ String
Status of the campaign asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignAsset
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignAsset
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignAsset.
24745 24746 24747 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24745 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset ⇒ String
Immutable. The asset which is linked to the campaign.
Corresponds to the JSON property asset
24695 24696 24697 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24695 def asset @asset end |
#campaign ⇒ String
Immutable. The campaign to which the asset is linked.
Corresponds to the JSON property campaign
24700 24701 24702 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24700 def campaign @campaign end |
#field_type ⇒ String
Immutable. Role that the asset takes under the linked campaign. Required.
Corresponds to the JSON property fieldType
24705 24706 24707 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24705 def field_type @field_type end |
#primary_status ⇒ String
Output only. Provides the PrimaryStatus of this asset link. Primary status is
meant essentially to differentiate between the plain "status" field, which has
advertiser set values of enabled, paused, or removed. The primary status takes
into account other signals (for assets its mainly policy and quality approvals)
to come up with a more comprehensive status to indicate its serving state.
Corresponds to the JSON property primaryStatus
24714 24715 24716 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24714 def primary_status @primary_status end |
#primary_status_details ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetLinkPrimaryStatusDetails>
Output only. Provides the details of the primary status and its associated
reasons.
Corresponds to the JSON property primaryStatusDetails
24720 24721 24722 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24720 def primary_status_details @primary_status_details end |
#primary_status_reasons ⇒ Array<String>
Output only. Provides a list of reasons for why an asset is not serving or not
serving at full capacity.
Corresponds to the JSON property primaryStatusReasons
24726 24727 24728 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24726 def primary_status_reasons @primary_status_reasons end |
#resource_name ⇒ String
Immutable. The resource name of the campaign asset. CampaignAsset resource
names have the form: customers/customer_id/campaignAssets/campaign_id~
asset_id~field_type`
Corresponds to the JSON propertyresourceName`
24733 24734 24735 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24733 def resource_name @resource_name end |
#source ⇒ String
Output only. Source of the campaign asset link.
Corresponds to the JSON property source
24738 24739 24740 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24738 def source @source end |
#status ⇒ String
Status of the campaign asset.
Corresponds to the JSON property status
24743 24744 24745 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24743 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24750 24751 24752 24753 24754 24755 24756 24757 24758 24759 24760 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24750 def update!(**args) @asset = args[:asset] if args.key?(:asset) @campaign = args[:campaign] if args.key?(:campaign) @field_type = args[:field_type] if args.key?(:field_type) @primary_status = args[:primary_status] if args.key?(:primary_status) @primary_status_details = args[:primary_status_details] if args.key?(:primary_status_details) @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons) @resource_name = args[:resource_name] if args.key?(:resource_name) @source = args[:source] if args.key?(:source) @status = args[:status] if args.key?(:status) end |