Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A link between a Campaign and an Asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignAsset

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignAsset.



24685
24686
24687
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetString

Immutable. The asset which is linked to the campaign. Corresponds to the JSON property asset

Returns:

  • (String)


24635
24636
24637
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24635

def asset
  @asset
end

#campaignString

Immutable. The campaign to which the asset is linked. Corresponds to the JSON property campaign

Returns:

  • (String)


24640
24641
24642
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24640

def campaign
  @campaign
end

#field_typeString

Immutable. Role that the asset takes under the linked campaign. Required. Corresponds to the JSON property fieldType

Returns:

  • (String)


24645
24646
24647
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24645

def field_type
  @field_type
end

#primary_statusString

Output only. Provides the PrimaryStatus of this asset link. Primary status is meant essentially to differentiate between the plain "status" field, which has advertiser set values of enabled, paused, or removed. The primary status takes into account other signals (for assets its mainly policy and quality approvals) to come up with a more comprehensive status to indicate its serving state. Corresponds to the JSON property primaryStatus

Returns:

  • (String)


24654
24655
24656
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24654

def primary_status
  @primary_status
end

#primary_status_detailsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetLinkPrimaryStatusDetails>

Output only. Provides the details of the primary status and its associated reasons. Corresponds to the JSON property primaryStatusDetails



24660
24661
24662
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24660

def primary_status_details
  @primary_status_details
end

#primary_status_reasonsArray<String>

Output only. Provides a list of reasons for why an asset is not serving or not serving at full capacity. Corresponds to the JSON property primaryStatusReasons

Returns:

  • (Array<String>)


24666
24667
24668
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24666

def primary_status_reasons
  @primary_status_reasons
end

#resource_nameString

Immutable. The resource name of the campaign asset. CampaignAsset resource names have the form: customers/customer_id/campaignAssets/campaign_id~ asset_id~field_type` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


24673
24674
24675
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24673

def resource_name
  @resource_name
end

#sourceString

Output only. Source of the campaign asset link. Corresponds to the JSON property source

Returns:

  • (String)


24678
24679
24680
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24678

def source
  @source
end

#statusString

Status of the campaign asset. Corresponds to the JSON property status

Returns:

  • (String)


24683
24684
24685
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24683

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24690
24691
24692
24693
24694
24695
24696
24697
24698
24699
24700
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24690

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @campaign = args[:campaign] if args.key?(:campaign)
  @field_type = args[:field_type] if args.key?(:field_type)
  @primary_status = args[:primary_status] if args.key?(:primary_status)
  @primary_status_details = args[:primary_status_details] if args.key?(:primary_status_details)
  @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @source = args[:source] if args.key?(:source)
  @status = args[:status] if args.key?(:status)
end