Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A link between a Campaign and an Asset.
Instance Attribute Summary collapse
-
#asset ⇒ String
Immutable.
-
#campaign ⇒ String
Immutable.
-
#field_type ⇒ String
Immutable.
-
#primary_status ⇒ String
Output only.
-
#primary_status_details ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetLinkPrimaryStatusDetails>
Output only.
-
#primary_status_reasons ⇒ Array<String>
Output only.
-
#resource_name ⇒ String
Immutable.
-
#source ⇒ String
Output only.
-
#status ⇒ String
Status of the campaign asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignAsset
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignAsset
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignAsset.
24598 24599 24600 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24598 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset ⇒ String
Immutable. The asset which is linked to the campaign.
Corresponds to the JSON property asset
24548 24549 24550 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24548 def asset @asset end |
#campaign ⇒ String
Immutable. The campaign to which the asset is linked.
Corresponds to the JSON property campaign
24553 24554 24555 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24553 def campaign @campaign end |
#field_type ⇒ String
Immutable. Role that the asset takes under the linked campaign. Required.
Corresponds to the JSON property fieldType
24558 24559 24560 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24558 def field_type @field_type end |
#primary_status ⇒ String
Output only. Provides the PrimaryStatus of this asset link. Primary status is
meant essentially to differentiate between the plain "status" field, which has
advertiser set values of enabled, paused, or removed. The primary status takes
into account other signals (for assets its mainly policy and quality approvals)
to come up with a more comprehensive status to indicate its serving state.
Corresponds to the JSON property primaryStatus
24567 24568 24569 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24567 def primary_status @primary_status end |
#primary_status_details ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetLinkPrimaryStatusDetails>
Output only. Provides the details of the primary status and its associated
reasons.
Corresponds to the JSON property primaryStatusDetails
24573 24574 24575 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24573 def primary_status_details @primary_status_details end |
#primary_status_reasons ⇒ Array<String>
Output only. Provides a list of reasons for why an asset is not serving or not
serving at full capacity.
Corresponds to the JSON property primaryStatusReasons
24579 24580 24581 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24579 def primary_status_reasons @primary_status_reasons end |
#resource_name ⇒ String
Immutable. The resource name of the campaign asset. CampaignAsset resource
names have the form: customers/customer_id/campaignAssets/campaign_id~
asset_id~field_type`
Corresponds to the JSON propertyresourceName`
24586 24587 24588 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24586 def resource_name @resource_name end |
#source ⇒ String
Output only. Source of the campaign asset link.
Corresponds to the JSON property source
24591 24592 24593 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24591 def source @source end |
#status ⇒ String
Status of the campaign asset.
Corresponds to the JSON property status
24596 24597 24598 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24596 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24603 24604 24605 24606 24607 24608 24609 24610 24611 24612 24613 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24603 def update!(**args) @asset = args[:asset] if args.key?(:asset) @campaign = args[:campaign] if args.key?(:campaign) @field_type = args[:field_type] if args.key?(:field_type) @primary_status = args[:primary_status] if args.key?(:primary_status) @primary_status_details = args[:primary_status_details] if args.key?(:primary_status_details) @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons) @resource_name = args[:resource_name] if args.key?(:resource_name) @source = args[:source] if args.key?(:source) @status = args[:status] if args.key?(:status) end |