Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAssetSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

CampaignAssetSet is the linkage between a campaign and an asset set. Adding a CampaignAssetSet links an asset set with a campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignAssetSet

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignAssetSet.



24730
24731
24732
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24730

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_setString

Immutable. The asset set which is linked to the campaign. Corresponds to the JSON property assetSet

Returns:

  • (String)


24711
24712
24713
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24711

def asset_set
  @asset_set
end

#campaignString

Immutable. The campaign to which this asset set is linked. Corresponds to the JSON property campaign

Returns:

  • (String)


24716
24717
24718
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24716

def campaign
  @campaign
end

#resource_nameString

Immutable. The resource name of the campaign asset set. Asset set asset resource names have the form: customers/customer_id/campaignAssetSets/ campaign_id~asset_set_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


24723
24724
24725
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24723

def resource_name
  @resource_name
end

#statusString

Output only. The status of the campaign asset set asset. Read-only. Corresponds to the JSON property status

Returns:

  • (String)


24728
24729
24730
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24728

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24735
24736
24737
24738
24739
24740
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24735

def update!(**args)
  @asset_set = args[:asset_set] if args.key?(:asset_set)
  @campaign = args[:campaign] if args.key?(:campaign)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end