Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBidModifier
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBidModifier
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents a bid-modifiable only criterion at the campaign level.
Instance Attribute Summary collapse
-
#bid_modifier ⇒ Float
The modifier for the bid when the criterion matches.
-
#campaign ⇒ String
Output only.
-
#criterion_id ⇒ Fixnum
Output only.
-
#interaction_type ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonInteractionTypeInfo
Criterion for Interaction Type.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignBidModifier
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignBidModifier.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignBidModifier
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignBidModifier.
24799 24800 24801 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bid_modifier ⇒ Float
The modifier for the bid when the criterion matches.
Corresponds to the JSON property bidModifier
24774 24775 24776 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24774 def bid_modifier @bid_modifier end |
#campaign ⇒ String
Output only. The campaign to which this criterion belongs.
Corresponds to the JSON property campaign
24779 24780 24781 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24779 def campaign @campaign end |
#criterion_id ⇒ Fixnum
Output only. The ID of the criterion to bid modify. This field is ignored for
mutates.
Corresponds to the JSON property criterionId
24785 24786 24787 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24785 def criterion_id @criterion_id end |
#interaction_type ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonInteractionTypeInfo
Criterion for Interaction Type.
Corresponds to the JSON property interactionType
24790 24791 24792 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24790 def interaction_type @interaction_type end |
#resource_name ⇒ String
Immutable. The resource name of the campaign bid modifier. Campaign bid
modifier resource names have the form: customers/customer_id/
campaignBidModifiers/campaign_id~criterion_id`
Corresponds to the JSON propertyresourceName`
24797 24798 24799 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24797 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24804 24805 24806 24807 24808 24809 24810 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24804 def update!(**args) @bid_modifier = args[:bid_modifier] if args.key?(:bid_modifier) @campaign = args[:campaign] if args.key?(:campaign) @criterion_id = args[:criterion_id] if args.key?(:criterion_id) @interaction_type = args[:interaction_type] if args.key?(:interaction_type) @resource_name = args[:resource_name] if args.key?(:resource_name) end |