Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBidModifier
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBidModifier
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents a bid-modifiable only criterion at the campaign level.
Instance Attribute Summary collapse
-
#bid_modifier ⇒ Float
The modifier for the bid when the criterion matches.
-
#campaign ⇒ String
Output only.
-
#criterion_id ⇒ Fixnum
Output only.
-
#interaction_type ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonInteractionTypeInfo
Criterion for Interaction Type.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignBidModifier
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignBidModifier.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignBidModifier
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignBidModifier.
24712 24713 24714 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24712 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bid_modifier ⇒ Float
The modifier for the bid when the criterion matches.
Corresponds to the JSON property bidModifier
24687 24688 24689 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24687 def bid_modifier @bid_modifier end |
#campaign ⇒ String
Output only. The campaign to which this criterion belongs.
Corresponds to the JSON property campaign
24692 24693 24694 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24692 def campaign @campaign end |
#criterion_id ⇒ Fixnum
Output only. The ID of the criterion to bid modify. This field is ignored for
mutates.
Corresponds to the JSON property criterionId
24698 24699 24700 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24698 def criterion_id @criterion_id end |
#interaction_type ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonInteractionTypeInfo
Criterion for Interaction Type.
Corresponds to the JSON property interactionType
24703 24704 24705 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24703 def interaction_type @interaction_type end |
#resource_name ⇒ String
Immutable. The resource name of the campaign bid modifier. Campaign bid
modifier resource names have the form: customers/customer_id/
campaignBidModifiers/campaign_id~criterion_id`
Corresponds to the JSON propertyresourceName`
24710 24711 24712 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24710 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24717 24718 24719 24720 24721 24722 24723 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24717 def update!(**args) @bid_modifier = args[:bid_modifier] if args.key?(:bid_modifier) @campaign = args[:campaign] if args.key?(:campaign) @criterion_id = args[:criterion_id] if args.key?(:criterion_id) @interaction_type = args[:interaction_type] if args.key?(:interaction_type) @resource_name = args[:resource_name] if args.key?(:resource_name) end |