Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBrandGuidelines

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Settings that control the visual appearance of your brand in a campaign's automatically generated assets and formats. Only applicable to Performance Max campaigns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignBrandGuidelines

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignBrandGuidelines.



15644
15645
15646
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accent_colorString

The accent brand color, entered as a hex code (e.g., #00ff00). You must provide the accent_color if you provide a main_color. Corresponds to the JSON property accentColor

Returns:

  • (String)


15629
15630
15631
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15629

def accent_color
  @accent_color
end

#main_colorString

The main brand color, entered as a hex code (e.g., #00ff00). You must provide the main_color if you provide an accent_color. Corresponds to the JSON property mainColor

Returns:

  • (String)


15635
15636
15637
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15635

def main_color
  @main_color
end

#predefined_font_familyString

The brand's font family. Must be one of the following Google Fonts (case sensitive): Open Sans, Roboto, Montserrat, Poppins, Lato, Oswald, Playfair Display, Roboto Slab. Corresponds to the JSON property predefinedFontFamily

Returns:

  • (String)


15642
15643
15644
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15642

def predefined_font_family
  @predefined_font_family
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15649
15650
15651
15652
15653
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15649

def update!(**args)
  @accent_color = args[:accent_color] if args.key?(:accent_color)
  @main_color = args[:main_color] if args.key?(:main_color)
  @predefined_font_family = args[:predefined_font_family] if args.key?(:predefined_font_family)
end