Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBrandGuidelines
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBrandGuidelines
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Settings that control the visual appearance of your brand in a campaign's automatically generated assets and formats. Only applicable to Performance Max campaigns.
Instance Attribute Summary collapse
-
#accent_color ⇒ String
The accent brand color, entered as a hex code (e.g., #00ff00).
-
#main_color ⇒ String
The main brand color, entered as a hex code (e.g., #00ff00).
-
#predefined_font_family ⇒ String
The brand's font family.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignBrandGuidelines
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignBrandGuidelines.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignBrandGuidelines
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignBrandGuidelines.
15578 15579 15580 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15578 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accent_color ⇒ String
The accent brand color, entered as a hex code (e.g., #00ff00). You must
provide the accent_color if you provide a main_color.
Corresponds to the JSON property accentColor
15563 15564 15565 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15563 def accent_color @accent_color end |
#main_color ⇒ String
The main brand color, entered as a hex code (e.g., #00ff00). You must provide
the main_color if you provide an accent_color.
Corresponds to the JSON property mainColor
15569 15570 15571 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15569 def main_color @main_color end |
#predefined_font_family ⇒ String
The brand's font family. Must be one of the following Google Fonts (case
sensitive): Open Sans, Roboto, Montserrat, Poppins, Lato, Oswald, Playfair
Display, Roboto Slab.
Corresponds to the JSON property predefinedFontFamily
15576 15577 15578 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15576 def predefined_font_family @predefined_font_family end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15583 15584 15585 15586 15587 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15583 def update!(**args) @accent_color = args[:accent_color] if args.key?(:accent_color) @main_color = args[:main_color] if args.key?(:main_color) @predefined_font_family = args[:predefined_font_family] if args.key?(:predefined_font_family) end |