Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCategoryBid
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCategoryBid
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Category bids in LocalServicesReportingCampaignSettings.
Instance Attribute Summary collapse
-
#category_id ⇒ String
Category for which the bid will be associated with.
-
#manual_cpa_bid_micros ⇒ Fixnum
Manual CPA bid for the category.
-
#target_cpa_bid_micros ⇒ Fixnum
Target CPA bid for the category.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignCategoryBid
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignCategoryBid.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignCategoryBid
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignCategoryBid.
15739 15740 15741 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category_id ⇒ String
Category for which the bid will be associated with. For example, xcat:
service_area_business_plumber.
Corresponds to the JSON property categoryId
15724 15725 15726 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15724 def category_id @category_id end |
#manual_cpa_bid_micros ⇒ Fixnum
Manual CPA bid for the category. Bid must be greater than the reserve price
associated for that category. Value is in micros and in the advertiser's
currency.
Corresponds to the JSON property manualCpaBidMicros
15731 15732 15733 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15731 def manual_cpa_bid_micros @manual_cpa_bid_micros end |
#target_cpa_bid_micros ⇒ Fixnum
Target CPA bid for the category. Value is in micros and in the advertiser's
currency.
Corresponds to the JSON property targetCpaBidMicros
15737 15738 15739 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15737 def target_cpa_bid_micros @target_cpa_bid_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15744 15745 15746 15747 15748 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15744 def update!(**args) @category_id = args[:category_id] if args.key?(:category_id) @manual_cpa_bid_micros = args[:manual_cpa_bid_micros] if args.key?(:manual_cpa_bid_micros) @target_cpa_bid_micros = args[:target_cpa_bid_micros] if args.key?(:target_cpa_bid_micros) end |