Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCategoryBid

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Category bids in LocalServicesReportingCampaignSettings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignCategoryBid

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignCategoryBid.



15679
15680
15681
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_idString

Category for which the bid will be associated with. For example, xcat: service_area_business_plumber. Corresponds to the JSON property categoryId

Returns:

  • (String)


15664
15665
15666
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15664

def category_id
  @category_id
end

#manual_cpa_bid_microsFixnum

Manual CPA bid for the category. Bid must be greater than the reserve price associated for that category. Value is in micros and in the advertiser's currency. Corresponds to the JSON property manualCpaBidMicros

Returns:

  • (Fixnum)


15671
15672
15673
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15671

def manual_cpa_bid_micros
  @manual_cpa_bid_micros
end

#target_cpa_bid_microsFixnum

Target CPA bid for the category. Value is in micros and in the advertiser's currency. Corresponds to the JSON property targetCpaBidMicros

Returns:

  • (Fixnum)


15677
15678
15679
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15677

def target_cpa_bid_micros
  @target_cpa_bid_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15684
15685
15686
15687
15688
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15684

def update!(**args)
  @category_id = args[:category_id] if args.key?(:category_id)
  @manual_cpa_bid_micros = args[:manual_cpa_bid_micros] if args.key?(:manual_cpa_bid_micros)
  @target_cpa_bid_micros = args[:target_cpa_bid_micros] if args.key?(:target_cpa_bid_micros)
end