Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignConversionGoal
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignConversionGoal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The biddability setting for the specified campaign only for all conversion actions with a matching category and origin.
Instance Attribute Summary collapse
-
#biddable ⇒ Boolean
(also: #biddable?)
The biddability of the campaign conversion goal.
-
#campaign ⇒ String
Immutable.
-
#category ⇒ String
The conversion category of this campaign conversion goal.
-
#origin ⇒ String
The conversion origin of this campaign conversion goal.
-
#resource_name ⇒ String
Immutable.
-
#search_ads360_biddable ⇒ Boolean
(also: #search_ads360_biddable?)
Search Ads 360 biddability of the campaign conversion goal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignConversionGoal
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignConversionGoal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignConversionGoal
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignConversionGoal.
24932 24933 24934 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#biddable ⇒ Boolean Also known as: biddable?
The biddability of the campaign conversion goal.
Corresponds to the JSON property biddable
24901 24902 24903 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24901 def biddable @biddable end |
#campaign ⇒ String
Immutable. The campaign with which this campaign conversion goal is associated.
Corresponds to the JSON property campaign
24907 24908 24909 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24907 def campaign @campaign end |
#category ⇒ String
The conversion category of this campaign conversion goal.
Corresponds to the JSON property category
24912 24913 24914 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24912 def category @category end |
#origin ⇒ String
The conversion origin of this campaign conversion goal.
Corresponds to the JSON property origin
24917 24918 24919 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24917 def origin @origin end |
#resource_name ⇒ String
Immutable. The resource name of the campaign conversion goal. Campaign
conversion goal resource names have the form: customers/customer_id/
campaignConversionGoals/campaign_id~category~origin`
Corresponds to the JSON propertyresourceName`
24924 24925 24926 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24924 def resource_name @resource_name end |
#search_ads360_biddable ⇒ Boolean Also known as: search_ads360_biddable?
Search Ads 360 biddability of the campaign conversion goal.
Corresponds to the JSON property searchAds360Biddable
24929 24930 24931 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24929 def search_ads360_biddable @search_ads360_biddable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24937 24938 24939 24940 24941 24942 24943 24944 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24937 def update!(**args) @biddable = args[:biddable] if args.key?(:biddable) @campaign = args[:campaign] if args.key?(:campaign) @category = args[:category] if args.key?(:category) @origin = args[:origin] if args.key?(:origin) @resource_name = args[:resource_name] if args.key?(:resource_name) @search_ads360_biddable = args[:search_ads360_biddable] if args.key?(:search_ads360_biddable) end |