Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A campaign criterion.
Instance Attribute Summary collapse
-
#ad_schedule ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo
Represents an AdSchedule criterion.
-
#age_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo
An age range criterion.
-
#bid_modifier ⇒ Float
The modifier for the bids when the criterion matches.
-
#brand_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandListInfo
A Brand List Criterion is used to specify a list of brands.
-
#campaign ⇒ String
Immutable.
-
#carrier ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCarrierInfo
Represents a Carrier Criterion.
-
#combined_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCombinedAudienceInfo
A combined audience criterion.
-
#content_label ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonContentLabelInfo
Content Label for category exclusion.
-
#criterion_id ⇒ Fixnum
Output only.
-
#device ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo
A device criterion.
-
#display_name ⇒ String
Output only.
-
#extended_demographic ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonExtendedDemographicInfo
Represents an extended demographic criterion.
-
#gender ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo
A gender criterion.
-
#income_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIncomeRangeInfo
An income range criterion.
-
#ip_block ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIpBlockInfo
An IpBlock criterion used for excluding IP addresses.
-
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo
A keyword criterion.
-
#keyword_theme ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordThemeInfo
A Smart Campaign keyword theme.
-
#language ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLanguageInfo
A language criterion.
-
#last_modified_time ⇒ String
Output only.
-
#life_event ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLifeEventInfo
Represents a life event criterion.
-
#listing_scope ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingScopeInfo
A listing scope criterion.
-
#local_service_id ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalServiceIdInfo
A Local Services Ads service ID.
-
#location ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo
A location criterion.
-
#location_group ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationGroupInfo
A radius around a list of locations specified through a feed.
-
#mobile_app_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo
A mobile app category criterion.
-
#mobile_application ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo
A mobile application criterion.
-
#mobile_device ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileDeviceInfo
A mobile device criterion.
-
#negative ⇒ Boolean
(also: #negative?)
Immutable.
-
#operating_system_version ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonOperatingSystemVersionInfo
Represents an operating system version to be targeted.
-
#parental_status ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo
A parental status criterion.
-
#placement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo
A placement criterion.
-
#proximity ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProximityInfo
A Proximity criterion.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
The status of the criterion.
-
#topic ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTopicInfo
A topic criterion.
-
#type ⇒ String
Output only.
-
#user_interest ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserInterestInfo
Represents a particular interest-based topic to be targeted.
-
#user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListInfo
A User List criterion.
-
#video_lineup ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVideoLineupInfo
A Video lineup criterion.
-
#webpage ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageInfo
Represents a criterion for targeting webpages of an advertiser's website.
-
#webpage_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageListInfo
Represents a list of webpage criteria.
-
#youtube_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
A YouTube Channel criterion.
-
#youtube_video ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
A YouTube Video criterion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignCriterion
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignCriterion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignCriterion
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignCriterion.
25196 25197 25198 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25196 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_schedule ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo
Represents an AdSchedule criterion. AdSchedule is specified as the day of the
week and a time interval within which ads will be shown. No more than six
AdSchedules can be added for the same day.
Corresponds to the JSON property adSchedule
24956 24957 24958 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24956 def ad_schedule @ad_schedule end |
#age_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo
An age range criterion.
Corresponds to the JSON property ageRange
24961 24962 24963 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24961 def age_range @age_range end |
#bid_modifier ⇒ Float
The modifier for the bids when the criterion matches. The modifier must be in
the range: 0.1 - 10.0. Most targetable criteria types support modifiers. Use 0
to opt out of a Device type.
Corresponds to the JSON property bidModifier
24968 24969 24970 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24968 def bid_modifier @bid_modifier end |
#brand_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandListInfo
A Brand List Criterion is used to specify a list of brands. The list is
represented as a SharedSet id type BRAND_HINT. A criterion of this type can be
either targeted or excluded.
Corresponds to the JSON property brandList
24975 24976 24977 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24975 def brand_list @brand_list end |
#campaign ⇒ String
Immutable. The campaign to which the criterion belongs.
Corresponds to the JSON property campaign
24980 24981 24982 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24980 def campaign @campaign end |
#carrier ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCarrierInfo
Represents a Carrier Criterion.
Corresponds to the JSON property carrier
24985 24986 24987 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24985 def carrier @carrier end |
#combined_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCombinedAudienceInfo
A combined audience criterion.
Corresponds to the JSON property combinedAudience
24990 24991 24992 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24990 def combined_audience @combined_audience end |
#content_label ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonContentLabelInfo
Content Label for category exclusion.
Corresponds to the JSON property contentLabel
24995 24996 24997 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 24995 def content_label @content_label end |
#criterion_id ⇒ Fixnum
Output only. The ID of the criterion. This field is ignored during mutate.
Corresponds to the JSON property criterionId
25000 25001 25002 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25000 def criterion_id @criterion_id end |
#device ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo
A device criterion.
Corresponds to the JSON property device
25005 25006 25007 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25005 def device @device end |
#display_name ⇒ String
Output only. The display name of the criterion. This field is ignored for
mutates.
Corresponds to the JSON property displayName
25011 25012 25013 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25011 def display_name @display_name end |
#extended_demographic ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonExtendedDemographicInfo
Represents an extended demographic criterion.
Corresponds to the JSON property extendedDemographic
25016 25017 25018 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25016 def extended_demographic @extended_demographic end |
#gender ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo
A gender criterion.
Corresponds to the JSON property gender
25021 25022 25023 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25021 def gender @gender end |
#income_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIncomeRangeInfo
An income range criterion.
Corresponds to the JSON property incomeRange
25026 25027 25028 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25026 def income_range @income_range end |
#ip_block ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIpBlockInfo
An IpBlock criterion used for excluding IP addresses. We support excluding
individual IP addresses or CIDR blocks. Create one IpBlockInfo criterion for
each individual IP address or CIDR block you want to exclude. You can exclude
up to 500 IP addresses per campaign. For more details, see Exclude IP
addresses. IPv4 examples: *
Individual address: 192.168.0.1 * Individual address as CIDR block: 192.168.0.
1/32 * CIDR block: 192.168.0.0/24 IPv6 examples: * Individual address: 2001:
db8:a0b:12f0::1 * Individual address as CIDR block: 2001:db8:a0b:12f0::1/128 *
CIDR block: 2001:db8::/48
Corresponds to the JSON property ipBlock
25039 25040 25041 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25039 def ip_block @ip_block end |
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo
A keyword criterion.
Corresponds to the JSON property keyword
25044 25045 25046 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25044 def keyword @keyword end |
#keyword_theme ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordThemeInfo
A Smart Campaign keyword theme.
Corresponds to the JSON property keywordTheme
25049 25050 25051 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25049 def keyword_theme @keyword_theme end |
#language ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLanguageInfo
A language criterion.
Corresponds to the JSON property language
25054 25055 25056 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25054 def language @language end |
#last_modified_time ⇒ String
Output only. The datetime when this campaign criterion was last modified. The
datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss"
format.
Corresponds to the JSON property lastModifiedTime
25061 25062 25063 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25061 def last_modified_time @last_modified_time end |
#life_event ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLifeEventInfo
Represents a life event criterion.
Corresponds to the JSON property lifeEvent
25066 25067 25068 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25066 def life_event @life_event end |
#listing_scope ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonListingScopeInfo
A listing scope criterion.
Corresponds to the JSON property listingScope
25071 25072 25073 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25071 def listing_scope @listing_scope end |
#local_service_id ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalServiceIdInfo
A Local Services Ads service ID. Represents a service type (such as
install_faucet) that a Local Services Campaign can target.
Corresponds to the JSON property localServiceId
25077 25078 25079 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25077 def local_service_id @local_service_id end |
#location ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo
A location criterion.
Corresponds to the JSON property location
25082 25083 25084 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25082 def location @location end |
#location_group ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationGroupInfo
A radius around a list of locations specified through a feed.
Corresponds to the JSON property locationGroup
25087 25088 25089 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25087 def location_group @location_group end |
#mobile_app_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo
A mobile app category criterion.
Corresponds to the JSON property mobileAppCategory
25092 25093 25094 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25092 def mobile_app_category @mobile_app_category end |
#mobile_application ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo
A mobile application criterion.
Corresponds to the JSON property mobileApplication
25097 25098 25099 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25097 def mobile_application @mobile_application end |
#mobile_device ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileDeviceInfo
A mobile device criterion.
Corresponds to the JSON property mobileDevice
25102 25103 25104 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25102 def mobile_device @mobile_device end |
#negative ⇒ Boolean Also known as: negative?
Immutable. Whether to target (false) or exclude (true) the criterion.
Corresponds to the JSON property negative
25107 25108 25109 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25107 def negative @negative end |
#operating_system_version ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonOperatingSystemVersionInfo
Represents an operating system version to be targeted.
Corresponds to the JSON property operatingSystemVersion
25113 25114 25115 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25113 def @operating_system_version end |
#parental_status ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo
A parental status criterion.
Corresponds to the JSON property parentalStatus
25118 25119 25120 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25118 def parental_status @parental_status end |
#placement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo
A placement criterion. This can be used to modify bids for sites when
targeting the content network.
Corresponds to the JSON property placement
25124 25125 25126 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25124 def placement @placement end |
#proximity ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProximityInfo
A Proximity criterion. The geo point and radius determine what geographical
area is included. The address is a description of the geo point that does not
affect ad serving. There are two ways to create a proximity. First, by setting
an address and radius. The geo point will be automatically computed. Second,
by setting a geo point and radius. The address is an optional label that won't
be validated.
Corresponds to the JSON property proximity
25134 25135 25136 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25134 def proximity @proximity end |
#resource_name ⇒ String
Immutable. The resource name of the campaign criterion. Campaign criterion
resource names have the form: customers/customer_id/campaignCriteria/
campaign_id~criterion_id`
Corresponds to the JSON propertyresourceName`
25141 25142 25143 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25141 def resource_name @resource_name end |
#status ⇒ String
The status of the criterion.
Corresponds to the JSON property status
25146 25147 25148 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25146 def status @status end |
#topic ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTopicInfo
A topic criterion. Use topics to target or exclude placements in the Google
Display Network based on the category into which the placement falls (for
example, "Pets & Animals/Pets/Dogs").
Corresponds to the JSON property topic
25153 25154 25155 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25153 def topic @topic end |
#type ⇒ String
Output only. The type of the criterion.
Corresponds to the JSON property type
25158 25159 25160 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25158 def type @type end |
#user_interest ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserInterestInfo
Represents a particular interest-based topic to be targeted.
Corresponds to the JSON property userInterest
25163 25164 25165 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25163 def user_interest @user_interest end |
#user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListInfo
A User List criterion. Represents a user list that is defined by the
advertiser to be targeted.
Corresponds to the JSON property userList
25169 25170 25171 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25169 def user_list @user_list end |
#video_lineup ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVideoLineupInfo
A Video lineup criterion.
Corresponds to the JSON property videoLineup
25174 25175 25176 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25174 def video_lineup @video_lineup end |
#webpage ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageInfo
Represents a criterion for targeting webpages of an advertiser's website.
Corresponds to the JSON property webpage
25179 25180 25181 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25179 def webpage @webpage end |
#webpage_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageListInfo
Represents a list of webpage criteria.
Corresponds to the JSON property webpageList
25184 25185 25186 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25184 def webpage_list @webpage_list end |
#youtube_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
A YouTube Channel criterion.
Corresponds to the JSON property youtubeChannel
25189 25190 25191 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25189 def youtube_channel @youtube_channel end |
#youtube_video ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
A YouTube Video criterion.
Corresponds to the JSON property youtubeVideo
25194 25195 25196 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25194 def youtube_video @youtube_video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25201 25202 25203 25204 25205 25206 25207 25208 25209 25210 25211 25212 25213 25214 25215 25216 25217 25218 25219 25220 25221 25222 25223 25224 25225 25226 25227 25228 25229 25230 25231 25232 25233 25234 25235 25236 25237 25238 25239 25240 25241 25242 25243 25244 25245 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25201 def update!(**args) @ad_schedule = args[:ad_schedule] if args.key?(:ad_schedule) @age_range = args[:age_range] if args.key?(:age_range) @bid_modifier = args[:bid_modifier] if args.key?(:bid_modifier) @brand_list = args[:brand_list] if args.key?(:brand_list) @campaign = args[:campaign] if args.key?(:campaign) @carrier = args[:carrier] if args.key?(:carrier) @combined_audience = args[:combined_audience] if args.key?(:combined_audience) @content_label = args[:content_label] if args.key?(:content_label) @criterion_id = args[:criterion_id] if args.key?(:criterion_id) @device = args[:device] if args.key?(:device) @display_name = args[:display_name] if args.key?(:display_name) @extended_demographic = args[:extended_demographic] if args.key?(:extended_demographic) @gender = args[:gender] if args.key?(:gender) @income_range = args[:income_range] if args.key?(:income_range) @ip_block = args[:ip_block] if args.key?(:ip_block) @keyword = args[:keyword] if args.key?(:keyword) @keyword_theme = args[:keyword_theme] if args.key?(:keyword_theme) @language = args[:language] if args.key?(:language) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @life_event = args[:life_event] if args.key?(:life_event) @listing_scope = args[:listing_scope] if args.key?(:listing_scope) @local_service_id = args[:local_service_id] if args.key?(:local_service_id) @location = args[:location] if args.key?(:location) @location_group = args[:location_group] if args.key?(:location_group) @mobile_app_category = args[:mobile_app_category] if args.key?(:mobile_app_category) @mobile_application = args[:mobile_application] if args.key?(:mobile_application) @mobile_device = args[:mobile_device] if args.key?(:mobile_device) @negative = args[:negative] if args.key?(:negative) @operating_system_version = args[:operating_system_version] if args.key?(:operating_system_version) @parental_status = args[:parental_status] if args.key?(:parental_status) @placement = args[:placement] if args.key?(:placement) @proximity = args[:proximity] if args.key?(:proximity) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @topic = args[:topic] if args.key?(:topic) @type = args[:type] if args.key?(:type) @user_interest = args[:user_interest] if args.key?(:user_interest) @user_list = args[:user_list] if args.key?(:user_list) @video_lineup = args[:video_lineup] if args.key?(:video_lineup) @webpage = args[:webpage] if args.key?(:webpage) @webpage_list = args[:webpage_list] if args.key?(:webpage_list) @youtube_channel = args[:youtube_channel] if args.key?(:youtube_channel) @youtube_video = args[:youtube_video] if args.key?(:youtube_video) end |