Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCustomizer
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCustomizer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A customizer value for the associated CustomizerAttribute at the Campaign level.
Instance Attribute Summary collapse
-
#campaign ⇒ String
Immutable.
-
#customizer_attribute ⇒ String
Required.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#value ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue
A customizer value that is referenced in customizer linkage entities like CustomerCustomizer, CampaignCustomizer, etc.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignCustomizer
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignCustomizer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignCustomizer
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignCustomizer.
25368 25369 25370 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25368 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign ⇒ String
Immutable. The campaign to which the customizer attribute is linked.
Corresponds to the JSON property campaign
25343 25344 25345 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25343 def campaign @campaign end |
#customizer_attribute ⇒ String
Required. Immutable. The customizer attribute which is linked to the campaign.
Corresponds to the JSON property customizerAttribute
25348 25349 25350 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25348 def customizer_attribute @customizer_attribute end |
#resource_name ⇒ String
Immutable. The resource name of the campaign customizer. Campaign customizer
resource names have the form: customers/customer_id/campaignCustomizers/
campaign_id~customizer_attribute_id`
Corresponds to the JSON propertyresourceName`
25355 25356 25357 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25355 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the campaign customizer.
Corresponds to the JSON property status
25360 25361 25362 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25360 def status @status end |
#value ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue
A customizer value that is referenced in customizer linkage entities like
CustomerCustomizer, CampaignCustomizer, etc.
Corresponds to the JSON property value
25366 25367 25368 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25366 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25373 25374 25375 25376 25377 25378 25379 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25373 def update!(**args) @campaign = args[:campaign] if args.key?(:campaign) @customizer_attribute = args[:customizer_attribute] if args.key?(:customizer_attribute) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @value = args[:value] if args.key?(:value) end |