Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCustomizer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A customizer value for the associated CustomizerAttribute at the Campaign level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignCustomizer

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignCustomizer.



25281
25282
25283
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaignString

Immutable. The campaign to which the customizer attribute is linked. Corresponds to the JSON property campaign

Returns:

  • (String)


25256
25257
25258
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25256

def campaign
  @campaign
end

#customizer_attributeString

Required. Immutable. The customizer attribute which is linked to the campaign. Corresponds to the JSON property customizerAttribute

Returns:

  • (String)


25261
25262
25263
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25261

def customizer_attribute
  @customizer_attribute
end

#resource_nameString

Immutable. The resource name of the campaign customizer. Campaign customizer resource names have the form: customers/customer_id/campaignCustomizers/ campaign_id~customizer_attribute_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25268
25269
25270
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25268

def resource_name
  @resource_name
end

#statusString

Output only. The status of the campaign customizer. Corresponds to the JSON property status

Returns:

  • (String)


25273
25274
25275
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25273

def status
  @status
end

#valueGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue

A customizer value that is referenced in customizer linkage entities like CustomerCustomizer, CampaignCustomizer, etc. Corresponds to the JSON property value



25279
25280
25281
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25279

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25286
25287
25288
25289
25290
25291
25292
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25286

def update!(**args)
  @campaign = args[:campaign] if args.key?(:campaign)
  @customizer_attribute = args[:customizer_attribute] if args.key?(:customizer_attribute)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @value = args[:value] if args.key?(:value)
end