Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDemandGenCampaignSettings
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDemandGenCampaignSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Settings for Demand Gen campaign.
Instance Attribute Summary collapse
-
#upgraded_targeting ⇒ Boolean
(also: #upgraded_targeting?)
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignDemandGenCampaignSettings
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignDemandGenCampaignSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignDemandGenCampaignSettings
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignDemandGenCampaignSettings.
15763 15764 15765 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15763 def initialize(**args) update!(**args) end |
Instance Attribute Details
#upgraded_targeting ⇒ Boolean Also known as: upgraded_targeting?
Immutable. Specifies whether this campaign uses upgraded targeting options.
When this field is set to true, you can use location and language targeting
at the ad group level as opposed to the standard campaign-level targeting.
Corresponds to the JSON property upgradedTargeting
15760 15761 15762 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15760 def upgraded_targeting @upgraded_targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15768 15769 15770 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15768 def update!(**args) @upgraded_targeting = args[:upgraded_targeting] if args.key?(:upgraded_targeting) end |