Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDraft
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDraft
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A campaign draft.
Instance Attribute Summary collapse
-
#base_campaign ⇒ String
Immutable.
-
#draft_campaign ⇒ String
Output only.
-
#draft_id ⇒ Fixnum
Output only.
-
#has_experiment_running ⇒ Boolean
(also: #has_experiment_running?)
Output only.
-
#long_running_operation ⇒ String
Output only.
-
#name ⇒ String
The name of the campaign draft.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignDraft
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignDraft.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignDraft
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignDraft.
25437 25438 25439 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25437 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_campaign ⇒ String
Immutable. The base campaign to which the draft belongs.
Corresponds to the JSON property baseCampaign
25389 25390 25391 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25389 def base_campaign @base_campaign end |
#draft_campaign ⇒ String
Output only. Resource name of the Campaign that results from overlaying the
draft changes onto the base campaign. This field is read-only.
Corresponds to the JSON property draftCampaign
25395 25396 25397 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25395 def draft_campaign @draft_campaign end |
#draft_id ⇒ Fixnum
Output only. The ID of the draft. This field is read-only.
Corresponds to the JSON property draftId
25400 25401 25402 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25400 def draft_id @draft_id end |
#has_experiment_running ⇒ Boolean Also known as: has_experiment_running?
Output only. Whether there is an experiment based on this draft currently
serving.
Corresponds to the JSON property hasExperimentRunning
25406 25407 25408 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25406 def has_experiment_running @has_experiment_running end |
#long_running_operation ⇒ String
Output only. The resource name of the long-running operation that can be used
to poll for completion of draft promotion. This is only set if the draft
promotion is in progress or finished.
Corresponds to the JSON property longRunningOperation
25414 25415 25416 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25414 def long_running_operation @long_running_operation end |
#name ⇒ String
The name of the campaign draft. This field is required and should not be empty
when creating new campaign drafts. It must not contain any null (code point
0x0), NL line feed (code point 0xA) or carriage return (code point 0xD)
characters.
Corresponds to the JSON property name
25422 25423 25424 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25422 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the campaign draft. Campaign draft resource
names have the form: customers/customer_id/campaignDrafts/base_campaign_id
~draft_id`
Corresponds to the JSON propertyresourceName`
25429 25430 25431 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25429 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the campaign draft. This field is read-only. When a
new campaign draft is added, the status defaults to PROPOSED.
Corresponds to the JSON property status
25435 25436 25437 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25435 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25442 def update!(**args) @base_campaign = args[:base_campaign] if args.key?(:base_campaign) @draft_campaign = args[:draft_campaign] if args.key?(:draft_campaign) @draft_id = args[:draft_id] if args.key?(:draft_id) @has_experiment_running = args[:has_experiment_running] if args.key?(:has_experiment_running) @long_running_operation = args[:long_running_operation] if args.key?(:long_running_operation) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |