Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDraft
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDraft
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A campaign draft.
Instance Attribute Summary collapse
-
#base_campaign ⇒ String
Immutable.
-
#draft_campaign ⇒ String
Output only.
-
#draft_id ⇒ Fixnum
Output only.
-
#has_experiment_running ⇒ Boolean
(also: #has_experiment_running?)
Output only.
-
#long_running_operation ⇒ String
Output only.
-
#name ⇒ String
The name of the campaign draft.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignDraft
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignDraft.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignDraft
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignDraft.
25350 25351 25352 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25350 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_campaign ⇒ String
Immutable. The base campaign to which the draft belongs.
Corresponds to the JSON property baseCampaign
25302 25303 25304 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25302 def base_campaign @base_campaign end |
#draft_campaign ⇒ String
Output only. Resource name of the Campaign that results from overlaying the
draft changes onto the base campaign. This field is read-only.
Corresponds to the JSON property draftCampaign
25308 25309 25310 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25308 def draft_campaign @draft_campaign end |
#draft_id ⇒ Fixnum
Output only. The ID of the draft. This field is read-only.
Corresponds to the JSON property draftId
25313 25314 25315 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25313 def draft_id @draft_id end |
#has_experiment_running ⇒ Boolean Also known as: has_experiment_running?
Output only. Whether there is an experiment based on this draft currently
serving.
Corresponds to the JSON property hasExperimentRunning
25319 25320 25321 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25319 def has_experiment_running @has_experiment_running end |
#long_running_operation ⇒ String
Output only. The resource name of the long-running operation that can be used
to poll for completion of draft promotion. This is only set if the draft
promotion is in progress or finished.
Corresponds to the JSON property longRunningOperation
25327 25328 25329 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25327 def long_running_operation @long_running_operation end |
#name ⇒ String
The name of the campaign draft. This field is required and should not be empty
when creating new campaign drafts. It must not contain any null (code point
0x0), NL line feed (code point 0xA) or carriage return (code point 0xD)
characters.
Corresponds to the JSON property name
25335 25336 25337 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25335 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the campaign draft. Campaign draft resource
names have the form: customers/customer_id/campaignDrafts/base_campaign_id
~draft_id`
Corresponds to the JSON propertyresourceName`
25342 25343 25344 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25342 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the campaign draft. This field is read-only. When a
new campaign draft is added, the status defaults to PROPOSED.
Corresponds to the JSON property status
25348 25349 25350 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25348 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25355 25356 25357 25358 25359 25360 25361 25362 25363 25364 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25355 def update!(**args) @base_campaign = args[:base_campaign] if args.key?(:base_campaign) @draft_campaign = args[:draft_campaign] if args.key?(:draft_campaign) @draft_id = args[:draft_id] if args.key?(:draft_id) @has_experiment_running = args[:has_experiment_running] if args.key?(:has_experiment_running) @long_running_operation = args[:long_running_operation] if args.key?(:long_running_operation) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |