Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignEffectiveLabel
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignEffectiveLabel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents a relationship between a campaign and an effective label. An effective label is a label inherited or directly assigned to this campaign.
Instance Attribute Summary collapse
-
#campaign ⇒ String
Immutable.
-
#label ⇒ String
Immutable.
-
#owner_customer_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignEffectiveLabel
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignEffectiveLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignEffectiveLabel
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignEffectiveLabel.
25394 25395 25396 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25394 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign ⇒ String
Immutable. The campaign to which the effective label is attached.
Corresponds to the JSON property campaign
25375 25376 25377 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25375 def campaign @campaign end |
#label ⇒ String
Immutable. The effective label assigned to the campaign.
Corresponds to the JSON property label
25380 25381 25382 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25380 def label @label end |
#owner_customer_id ⇒ Fixnum
Output only. The ID of the Customer which owns the effective label.
Corresponds to the JSON property ownerCustomerId
25385 25386 25387 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25385 def owner_customer_id @owner_customer_id end |
#resource_name ⇒ String
Immutable. Name of the resource. CampaignEffectivelabel resource names have
the form: customers/owner_customer_id/campaignEffectiveLabels/campaign_id~
label_id`
Corresponds to the JSON propertyresourceName`
25392 25393 25394 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25392 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25399 25400 25401 25402 25403 25404 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25399 def update!(**args) @campaign = args[:campaign] if args.key?(:campaign) @label = args[:label] if args.key?(:label) @owner_customer_id = args[:owner_customer_id] if args.key?(:owner_customer_id) @resource_name = args[:resource_name] if args.key?(:resource_name) end |