Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGeoTargetTypeSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a collection of settings related to ads geotargeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignGeoTargetTypeSetting

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignGeoTargetTypeSetting.



15695
15696
15697
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15695

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#negative_geo_target_typeString

The setting used for negative geotargeting in this particular campaign. Corresponds to the JSON property negativeGeoTargetType

Returns:

  • (String)


15688
15689
15690
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15688

def negative_geo_target_type
  @negative_geo_target_type
end

#positive_geo_target_typeString

The setting used for positive geotargeting in this particular campaign. Corresponds to the JSON property positiveGeoTargetType

Returns:

  • (String)


15693
15694
15695
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15693

def positive_geo_target_type
  @positive_geo_target_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15700
15701
15702
15703
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15700

def update!(**args)
  @negative_geo_target_type = args[:negative_geo_target_type] if args.key?(:negative_geo_target_type)
  @positive_geo_target_type = args[:positive_geo_target_type] if args.key?(:positive_geo_target_type)
end