Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGoalConfig
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGoalConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A link between a campaign and a goal enabling campaign-specific optimization.
Instance Attribute Summary collapse
-
#campaign ⇒ String
Immutable.
-
#campaign_retention_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCampaignGoalSettingsCampaignRetentionGoalSettings
Retention campaign goal settings.
-
#goal ⇒ String
Immutable.
-
#goal_type ⇒ String
Output only.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignGoalConfig
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignGoalConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignGoalConfig
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignGoalConfig.
25525 25526 25527 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25525 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign ⇒ String
Immutable. The resource name of the campaign for this link.
Corresponds to the JSON property campaign
25501 25502 25503 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25501 def campaign @campaign end |
#campaign_retention_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCampaignGoalSettingsCampaignRetentionGoalSettings
Retention campaign goal settings.
Corresponds to the JSON property campaignRetentionSettings
25506 25507 25508 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25506 def campaign_retention_settings @campaign_retention_settings end |
#goal ⇒ String
Immutable. The resource name of the goal this link is attached to.
Corresponds to the JSON property goal
25511 25512 25513 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25511 def goal @goal end |
#goal_type ⇒ String
Output only. The goal type this link is attached to.
Corresponds to the JSON property goalType
25516 25517 25518 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25516 def goal_type @goal_type end |
#resource_name ⇒ String
Immutable. The resource name of the campaign goal config. campaign goal config
resource names have the form: customers/customer_id/campaignGoalConfigs/
campaign_id~goal_id`
Corresponds to the JSON propertyresourceName`
25523 25524 25525 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25523 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25530 25531 25532 25533 25534 25535 25536 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25530 def update!(**args) @campaign = args[:campaign] if args.key?(:campaign) @campaign_retention_settings = args[:campaign_retention_settings] if args.key?(:campaign_retention_settings) @goal = args[:goal] if args.key?(:goal) @goal_type = args[:goal_type] if args.key?(:goal_type) @resource_name = args[:resource_name] if args.key?(:resource_name) end |