Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGoalConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A link between a campaign and a goal enabling campaign-specific optimization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignGoalConfig

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignGoalConfig.



25438
25439
25440
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaignString

Immutable. The resource name of the campaign for this link. Corresponds to the JSON property campaign

Returns:

  • (String)


25414
25415
25416
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25414

def campaign
  @campaign
end

#campaign_retention_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCampaignGoalSettingsCampaignRetentionGoalSettings

Retention campaign goal settings. Corresponds to the JSON property campaignRetentionSettings



25419
25420
25421
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25419

def campaign_retention_settings
  @campaign_retention_settings
end

#goalString

Immutable. The resource name of the goal this link is attached to. Corresponds to the JSON property goal

Returns:

  • (String)


25424
25425
25426
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25424

def goal
  @goal
end

#goal_typeString

Output only. The goal type this link is attached to. Corresponds to the JSON property goalType

Returns:

  • (String)


25429
25430
25431
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25429

def goal_type
  @goal_type
end

#resource_nameString

Immutable. The resource name of the campaign goal config. campaign goal config resource names have the form: customers/customer_id/campaignGoalConfigs/ campaign_id~goal_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25436
25437
25438
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25436

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25443
25444
25445
25446
25447
25448
25449
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25443

def update!(**args)
  @campaign = args[:campaign] if args.key?(:campaign)
  @campaign_retention_settings = args[:campaign_retention_settings] if args.key?(:campaign_retention_settings)
  @goal = args[:goal] if args.key?(:goal)
  @goal_type = args[:goal_type] if args.key?(:goal_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end