Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A campaign group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignGroup

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignGroup.



25569
25570
25571
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25569

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. The ID of the campaign group. Corresponds to the JSON property id

Returns:

  • (Fixnum)


25546
25547
25548
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25546

def id
  @id
end

#nameString

The name of the campaign group. This field is required and should not be empty when creating new campaign groups. It must not contain any null (code point 0x0), NL line feed (code point 0xA) or carriage return (code point 0xD) characters. Corresponds to the JSON property name

Returns:

  • (String)


25554
25555
25556
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25554

def name
  @name
end

#resource_nameString

Immutable. The resource name of the campaign group. Campaign group resource names have the form: customers/customer_id/campaignGroups/ campaign_group_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25561
25562
25563
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25561

def resource_name
  @resource_name
end

#statusString

The status of the campaign group. When a new campaign group is added, the status defaults to ENABLED. Corresponds to the JSON property status

Returns:

  • (String)


25567
25568
25569
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25567

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25574
25575
25576
25577
25578
25579
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25574

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end