Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A campaign group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignGroup

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignGroup.



25482
25483
25484
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. The ID of the campaign group. Corresponds to the JSON property id

Returns:

  • (Fixnum)


25459
25460
25461
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25459

def id
  @id
end

#nameString

The name of the campaign group. This field is required and should not be empty when creating new campaign groups. It must not contain any null (code point 0x0), NL line feed (code point 0xA) or carriage return (code point 0xD) characters. Corresponds to the JSON property name

Returns:

  • (String)


25467
25468
25469
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25467

def name
  @name
end

#resource_nameString

Immutable. The resource name of the campaign group. Campaign group resource names have the form: customers/customer_id/campaignGroups/ campaign_group_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25474
25475
25476
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25474

def resource_name
  @resource_name
end

#statusString

The status of the campaign group. When a new campaign group is added, the status defaults to ENABLED. Corresponds to the JSON property status

Returns:

  • (String)


25480
25481
25482
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25480

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25487
25488
25489
25490
25491
25492
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25487

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end