Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSearchTermInsight
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSearchTermInsight
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
This report provides a high-level view of search demand at the campaign level by grouping similar search terms into categories and showing their search volume. Historical data is available starting March 2023.
Instance Attribute Summary collapse
-
#campaign_id ⇒ Fixnum
Output only.
-
#category_label ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignSearchTermInsight
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignSearchTermInsight.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignSearchTermInsight
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignSearchTermInsight.
25681 25682 25683 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25681 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign_id ⇒ Fixnum
Output only. The ID of the campaign.
Corresponds to the JSON property campaignId
25661 25662 25663 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25661 def campaign_id @campaign_id end |
#category_label ⇒ String
Output only. The label for the search category. An empty string denotes the
catch-all category for search terms that didn't fit into another category.
Corresponds to the JSON property categoryLabel
25667 25668 25669 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25667 def category_label @category_label end |
#id ⇒ Fixnum
Output only. The ID of the insight.
Corresponds to the JSON property id
25672 25673 25674 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25672 def id @id end |
#resource_name ⇒ String
Output only. The resource name of the campaign level search term insight.
Campaign level search term insight resource names have the form: customers/
customer_id/campaignSearchTermInsights/campaign_id~category_id`
Corresponds to the JSON propertyresourceName`
25679 25680 25681 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25679 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25686 25687 25688 25689 25690 25691 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25686 def update!(**args) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @category_label = args[:category_label] if args.key?(:category_label) @id = args[:id] if args.key?(:id) @resource_name = args[:resource_name] if args.key?(:resource_name) end |