Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSearchTermInsight

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

This report provides a high-level view of search demand at the campaign level by grouping similar search terms into categories and showing their search volume. Historical data is available starting March 2023.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignSearchTermInsight

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignSearchTermInsight.



25594
25595
25596
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25594

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaign_idFixnum

Output only. The ID of the campaign. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


25574
25575
25576
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25574

def campaign_id
  @campaign_id
end

#category_labelString

Output only. The label for the search category. An empty string denotes the catch-all category for search terms that didn't fit into another category. Corresponds to the JSON property categoryLabel

Returns:

  • (String)


25580
25581
25582
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25580

def category_label
  @category_label
end

#idFixnum

Output only. The ID of the insight. Corresponds to the JSON property id

Returns:

  • (Fixnum)


25585
25586
25587
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25585

def id
  @id
end

#resource_nameString

Output only. The resource name of the campaign level search term insight. Campaign level search term insight resource names have the form: customers/ customer_id/campaignSearchTermInsights/campaign_id~category_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25592
25593
25594
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25592

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25599
25600
25601
25602
25603
25604
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25599

def update!(**args)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @category_label = args[:category_label] if args.key?(:category_label)
  @id = args[:id] if args.key?(:id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end