Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSearchTermView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

This report provides granular performance data, including cost metrics, for each individual search term that triggered your ads. If keyword-related segments are used, Performance Max data will be excluded from the results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignSearchTermView

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignSearchTermView.



25717
25718
25719
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25717

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaignString

Output only. The campaign the search term served in. Corresponds to the JSON property campaign

Returns:

  • (String)


25703
25704
25705
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25703

def campaign
  @campaign
end

#resource_nameString

Output only. The resource name of the campaign search term view. Campaign search term view resource names have the form: customers/customer_id/ campaignSearchTermViews/campaign_id~URL-base64_search_term` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25710
25711
25712
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25710

def resource_name
  @resource_name
end

#search_termString

Output only. The search term. Corresponds to the JSON property searchTerm

Returns:

  • (String)


25715
25716
25717
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25715

def search_term
  @search_term
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25722
25723
25724
25725
25726
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25722

def update!(**args)
  @campaign = args[:campaign] if args.key?(:campaign)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @search_term = args[:search_term] if args.key?(:search_term)
end