Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSearchTermView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSearchTermView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
This report provides granular performance data, including cost metrics, for each individual search term that triggered your ads. If keyword-related segments are used, Performance Max data will be excluded from the results.
Instance Attribute Summary collapse
-
#campaign ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#search_term ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignSearchTermView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignSearchTermView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignSearchTermView
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignSearchTermView.
25630 25631 25632 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25630 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign ⇒ String
Output only. The campaign the search term served in.
Corresponds to the JSON property campaign
25616 25617 25618 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25616 def campaign @campaign end |
#resource_name ⇒ String
Output only. The resource name of the campaign search term view. Campaign
search term view resource names have the form: customers/customer_id/
campaignSearchTermViews/campaign_id~URL-base64_search_term`
Corresponds to the JSON propertyresourceName`
25623 25624 25625 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25623 def resource_name @resource_name end |
#search_term ⇒ String
Output only. The search term.
Corresponds to the JSON property searchTerm
25628 25629 25630 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25628 def search_term @search_term end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25635 25636 25637 25638 25639 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25635 def update!(**args) @campaign = args[:campaign] if args.key?(:campaign) @resource_name = args[:resource_name] if args.key?(:resource_name) @search_term = args[:search_term] if args.key?(:search_term) end |