Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSharedSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

CampaignSharedSets are used for managing the shared sets associated with a campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignSharedSet

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignSharedSet.



25674
25675
25676
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25674

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaignString

Immutable. The campaign to which the campaign shared set belongs. Corresponds to the JSON property campaign

Returns:

  • (String)


25650
25651
25652
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25650

def campaign
  @campaign
end

#resource_nameString

Immutable. The resource name of the campaign shared set. Campaign shared set resource names have the form: customers/customer_id/campaignSharedSets/ campaign_id~shared_set_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25657
25658
25659
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25657

def resource_name
  @resource_name
end

#shared_setString

Immutable. The shared set associated with the campaign. This may be a negative keyword shared set of another customer. This customer should be a manager of the other customer, otherwise the campaign shared set will exist but have no serving effect. Only negative keyword shared sets can be associated with Shopping campaigns. Only negative placement shared sets can be associated with Display mobile app campaigns. Corresponds to the JSON property sharedSet

Returns:

  • (String)


25667
25668
25669
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25667

def shared_set
  @shared_set
end

#statusString

Output only. The status of this campaign shared set. Read only. Corresponds to the JSON property status

Returns:

  • (String)


25672
25673
25674
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25672

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25679
25680
25681
25682
25683
25684
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25679

def update!(**args)
  @campaign = args[:campaign] if args.key?(:campaign)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @shared_set = args[:shared_set] if args.key?(:shared_set)
  @status = args[:status] if args.key?(:status)
end