Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The setting for Shopping campaigns. Defines the universe of products that can be advertised by the campaign, and how this campaign interacts with other Shopping campaigns.
Instance Attribute Summary collapse
-
#advertising_partner_ids ⇒ Array<Fixnum>
The list of Google Ads accounts IDs of advertising partners cooperating within the campaign.
-
#campaign_priority ⇒ Fixnum
Priority of the campaign.
-
#disable_product_feed ⇒ Boolean
(also: #disable_product_feed?)
Disable the optional product feed.
-
#enable_local ⇒ Boolean
(also: #enable_local?)
Whether to include local products.
-
#feed_label ⇒ String
Feed label of products to include in the campaign.
-
#merchant_id ⇒ Fixnum
ID of the Merchant Center account.
-
#use_vehicle_inventory ⇒ Boolean
(also: #use_vehicle_inventory?)
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting.
16104 16105 16106 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertising_partner_ids ⇒ Array<Fixnum>
The list of Google Ads accounts IDs of advertising partners cooperating within
the campaign. This feature is currently available only for accounts having an
advertising partner link. This feature is currently supported only for
Performance Max, Shopping, Search and Demand Gen campaign types.
Corresponds to the JSON property advertisingPartnerIds
16058 16059 16060 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16058 def advertising_partner_ids @advertising_partner_ids end |
#campaign_priority ⇒ Fixnum
Priority of the campaign. Campaigns with numerically higher priorities take
precedence over those with lower priorities. This field is required for
Shopping campaigns, with values between 0 and 2, inclusive. This field is
optional for Smart Shopping campaigns, but must be equal to 3 if set.
Corresponds to the JSON property campaignPriority
16066 16067 16068 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16066 def campaign_priority @campaign_priority end |
#disable_product_feed ⇒ Boolean Also known as: disable_product_feed?
Disable the optional product feed. This field is currently supported only for
Demand Gen campaigns. See https://support.google.com/google-ads/answer/
13721750 to learn more about this feature.
Corresponds to the JSON property disableProductFeed
16073 16074 16075 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16073 def disable_product_feed @disable_product_feed end |
#enable_local ⇒ Boolean Also known as: enable_local?
Whether to include local products.
Corresponds to the JSON property enableLocal
16079 16080 16081 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16079 def enable_local @enable_local end |
#feed_label ⇒ String
Feed label of products to include in the campaign. Valid feed labels may
contain a maximum of 20 characters including uppercase letters, numbers,
hyphens, and underscores. If you previously used the deprecated sales_country
in the two-letter country code (XX) format, the feed_label field should
be used instead. For more information see the feed label support article.
Corresponds to the JSON property feedLabel
16090 16091 16092 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16090 def feed_label @feed_label end |
#merchant_id ⇒ Fixnum
ID of the Merchant Center account. This field is required for create
operations. This field is immutable for Shopping campaigns.
Corresponds to the JSON property merchantId
16096 16097 16098 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16096 def merchant_id @merchant_id end |
#use_vehicle_inventory ⇒ Boolean Also known as: use_vehicle_inventory?
Immutable. Whether to target Vehicle Listing inventory.
Corresponds to the JSON property useVehicleInventory
16101 16102 16103 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16101 def use_vehicle_inventory @use_vehicle_inventory end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16109 16110 16111 16112 16113 16114 16115 16116 16117 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16109 def update!(**args) @advertising_partner_ids = args[:advertising_partner_ids] if args.key?(:advertising_partner_ids) @campaign_priority = args[:campaign_priority] if args.key?(:campaign_priority) @disable_product_feed = args[:disable_product_feed] if args.key?(:disable_product_feed) @enable_local = args[:enable_local] if args.key?(:enable_local) @feed_label = args[:feed_label] if args.key?(:feed_label) @merchant_id = args[:merchant_id] if args.key?(:merchant_id) @use_vehicle_inventory = args[:use_vehicle_inventory] if args.key?(:use_vehicle_inventory) end |