Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The setting for Shopping campaigns. Defines the universe of products that can be advertised by the campaign, and how this campaign interacts with other Shopping campaigns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting.



16044
16045
16046
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertising_partner_idsArray<Fixnum>

The list of Google Ads accounts IDs of advertising partners cooperating within the campaign. This feature is currently available only for accounts having an advertising partner link. This feature is currently supported only for Performance Max, Shopping, Search and Demand Gen campaign types. Corresponds to the JSON property advertisingPartnerIds

Returns:

  • (Array<Fixnum>)


15998
15999
16000
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15998

def advertising_partner_ids
  @advertising_partner_ids
end

#campaign_priorityFixnum

Priority of the campaign. Campaigns with numerically higher priorities take precedence over those with lower priorities. This field is required for Shopping campaigns, with values between 0 and 2, inclusive. This field is optional for Smart Shopping campaigns, but must be equal to 3 if set. Corresponds to the JSON property campaignPriority

Returns:

  • (Fixnum)


16006
16007
16008
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16006

def campaign_priority
  @campaign_priority
end

#disable_product_feedBoolean Also known as: disable_product_feed?

Disable the optional product feed. This field is currently supported only for Demand Gen campaigns. See https://support.google.com/google-ads/answer/ 13721750 to learn more about this feature. Corresponds to the JSON property disableProductFeed

Returns:

  • (Boolean)


16013
16014
16015
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16013

def disable_product_feed
  @disable_product_feed
end

#enable_localBoolean Also known as: enable_local?

Whether to include local products. Corresponds to the JSON property enableLocal

Returns:

  • (Boolean)


16019
16020
16021
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16019

def enable_local
  @enable_local
end

#feed_labelString

Feed label of products to include in the campaign. Valid feed labels may contain a maximum of 20 characters including uppercase letters, numbers, hyphens, and underscores. If you previously used the deprecated sales_country in the two-letter country code (XX) format, the feed_label field should be used instead. For more information see the feed label support article. Corresponds to the JSON property feedLabel

Returns:

  • (String)


16030
16031
16032
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16030

def feed_label
  @feed_label
end

#merchant_idFixnum

ID of the Merchant Center account. This field is required for create operations. This field is immutable for Shopping campaigns. Corresponds to the JSON property merchantId

Returns:

  • (Fixnum)


16036
16037
16038
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16036

def merchant_id
  @merchant_id
end

#use_vehicle_inventoryBoolean Also known as: use_vehicle_inventory?

Immutable. Whether to target Vehicle Listing inventory. Corresponds to the JSON property useVehicleInventory

Returns:

  • (Boolean)


16041
16042
16043
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16041

def use_vehicle_inventory
  @use_vehicle_inventory
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16049
16050
16051
16052
16053
16054
16055
16056
16057
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16049

def update!(**args)
  @advertising_partner_ids = args[:advertising_partner_ids] if args.key?(:advertising_partner_ids)
  @campaign_priority = args[:campaign_priority] if args.key?(:campaign_priority)
  @disable_product_feed = args[:disable_product_feed] if args.key?(:disable_product_feed)
  @enable_local = args[:enable_local] if args.key?(:enable_local)
  @feed_label = args[:feed_label] if args.key?(:feed_label)
  @merchant_id = args[:merchant_id] if args.key?(:merchant_id)
  @use_vehicle_inventory = args[:use_vehicle_inventory] if args.key?(:use_vehicle_inventory)
end