Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The setting for Shopping campaigns. Defines the universe of products that can be advertised by the campaign, and how this campaign interacts with other Shopping campaigns.
Instance Attribute Summary collapse
-
#advertising_partner_ids ⇒ Array<Fixnum>
The list of Google Ads accounts IDs of advertising partners cooperating within the campaign.
-
#campaign_priority ⇒ Fixnum
Priority of the campaign.
-
#disable_product_feed ⇒ Boolean
(also: #disable_product_feed?)
Disable the optional product feed.
-
#enable_local ⇒ Boolean
(also: #enable_local?)
Whether to include local products.
-
#feed_label ⇒ String
Feed label of products to include in the campaign.
-
#merchant_id ⇒ Fixnum
ID of the Merchant Center account.
-
#use_vehicle_inventory ⇒ Boolean
(also: #use_vehicle_inventory?)
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting
Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignShoppingSetting.
15978 15979 15980 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertising_partner_ids ⇒ Array<Fixnum>
The list of Google Ads accounts IDs of advertising partners cooperating within
the campaign. This feature is currently available only for accounts having an
advertising partner link. This feature is currently supported only for
Performance Max, Shopping, Search and Demand Gen campaign types.
Corresponds to the JSON property advertisingPartnerIds
15932 15933 15934 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15932 def advertising_partner_ids @advertising_partner_ids end |
#campaign_priority ⇒ Fixnum
Priority of the campaign. Campaigns with numerically higher priorities take
precedence over those with lower priorities. This field is required for
Shopping campaigns, with values between 0 and 2, inclusive. This field is
optional for Smart Shopping campaigns, but must be equal to 3 if set.
Corresponds to the JSON property campaignPriority
15940 15941 15942 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15940 def campaign_priority @campaign_priority end |
#disable_product_feed ⇒ Boolean Also known as: disable_product_feed?
Disable the optional product feed. This field is currently supported only for
Demand Gen campaigns. See https://support.google.com/google-ads/answer/
13721750 to learn more about this feature.
Corresponds to the JSON property disableProductFeed
15947 15948 15949 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15947 def disable_product_feed @disable_product_feed end |
#enable_local ⇒ Boolean Also known as: enable_local?
Whether to include local products.
Corresponds to the JSON property enableLocal
15953 15954 15955 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15953 def enable_local @enable_local end |
#feed_label ⇒ String
Feed label of products to include in the campaign. Valid feed labels may
contain a maximum of 20 characters including uppercase letters, numbers,
hyphens, and underscores. If you previously used the deprecated sales_country
in the two-letter country code (XX) format, the feed_label field should
be used instead. For more information see the feed label support article.
Corresponds to the JSON property feedLabel
15964 15965 15966 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15964 def feed_label @feed_label end |
#merchant_id ⇒ Fixnum
ID of the Merchant Center account. This field is required for create
operations. This field is immutable for Shopping campaigns.
Corresponds to the JSON property merchantId
15970 15971 15972 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15970 def merchant_id @merchant_id end |
#use_vehicle_inventory ⇒ Boolean Also known as: use_vehicle_inventory?
Immutable. Whether to target Vehicle Listing inventory.
Corresponds to the JSON property useVehicleInventory
15975 15976 15977 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15975 def use_vehicle_inventory @use_vehicle_inventory end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15983 15984 15985 15986 15987 15988 15989 15990 15991 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 15983 def update!(**args) @advertising_partner_ids = args[:advertising_partner_ids] if args.key?(:advertising_partner_ids) @campaign_priority = args[:campaign_priority] if args.key?(:campaign_priority) @disable_product_feed = args[:disable_product_feed] if args.key?(:disable_product_feed) @enable_local = args[:enable_local] if args.key?(:enable_local) @feed_label = args[:feed_label] if args.key?(:feed_label) @merchant_id = args[:merchant_id] if args.key?(:merchant_id) @use_vehicle_inventory = args[:use_vehicle_inventory] if args.key?(:use_vehicle_inventory) end |