Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSimulation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A campaign simulation. Supported combinations of advertising channel type, simulation type and simulation modification method is detailed below respectively. * SEARCH - CPC_BID - UNIFORM * SEARCH - CPC_BID - SCALING * SEARCH - TARGET_CPA - UNIFORM * SEARCH - TARGET_CPA - SCALING * SEARCH - TARGET_ROAS - UNIFORM * SEARCH - TARGET_IMPRESSION_SHARE - UNIFORM * SEARCH - BUDGET - UNIFORM * SHOPPING - BUDGET - UNIFORM * SHOPPING - TARGET_ROAS - UNIFORM * MULTI_CHANNEL - TARGET_CPA - UNIFORM * MULTI_CHANNEL - TARGET_ROAS - UNIFORM * DEMAND_GEN - TARGET_CPA - DEFAULT * DISPLAY - TARGET_CPA - UNIFORM * PERFORMANCE_MAX - TARGET_CPA - UNIFORM * PERFORMANCE_MAX - TARGET_ROAS - UNIFORM * PERFORMANCE_MAX - BUDGET - UNIFORM

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignSimulation

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignSimulation.



25845
25846
25847
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25845

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBudgetSimulationPointList

A container for simulation points for simulations of type BUDGET. Corresponds to the JSON property budgetPointList



25790
25791
25792
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25790

def budget_point_list
  @budget_point_list
end

#campaign_idFixnum

Output only. Campaign id of the simulation. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


25795
25796
25797
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25795

def campaign_id
  @campaign_id
end

#cpc_bid_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpcBidSimulationPointList

A container for simulation points for simulations of type CPC_BID. Corresponds to the JSON property cpcBidPointList



25800
25801
25802
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25800

def cpc_bid_point_list
  @cpc_bid_point_list
end

#end_dateString

Output only. Last day on which the simulation is based, in YYYY-MM-DD format Corresponds to the JSON property endDate

Returns:

  • (String)


25805
25806
25807
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25805

def end_date
  @end_date
end

#modification_methodString

Output only. How the simulation modifies the field. Corresponds to the JSON property modificationMethod

Returns:

  • (String)


25810
25811
25812
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25810

def modification_method
  @modification_method
end

#resource_nameString

Output only. The resource name of the campaign simulation. Campaign simulation resource names have the form: customers/customer_id/campaignSimulations/ campaign_id~type~modification_method~start_date~end_date` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25817
25818
25819
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25817

def resource_name
  @resource_name
end

#start_dateString

Output only. First day on which the simulation is based, in YYYY-MM-DD format. Corresponds to the JSON property startDate

Returns:

  • (String)


25822
25823
25824
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25822

def start_date
  @start_date
end

#target_cpa_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpaSimulationPointList

A container for simulation points for simulations of type TARGET_CPA. Corresponds to the JSON property targetCpaPointList



25827
25828
25829
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25827

def target_cpa_point_list
  @target_cpa_point_list
end

#target_impression_share_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPointList

A container for simulation points for simulations of type TARGET_IMPRESSION_SHARE. Corresponds to the JSON property targetImpressionSharePointList



25833
25834
25835
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25833

def target_impression_share_point_list
  @target_impression_share_point_list
end

#target_roas_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoasSimulationPointList

A container for simulation points for simulations of type TARGET_ROAS. Corresponds to the JSON property targetRoasPointList



25838
25839
25840
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25838

def target_roas_point_list
  @target_roas_point_list
end

#typeString

Output only. The field that the simulation modifies. Corresponds to the JSON property type

Returns:

  • (String)


25843
25844
25845
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25843

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25850
25851
25852
25853
25854
25855
25856
25857
25858
25859
25860
25861
25862
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25850

def update!(**args)
  @budget_point_list = args[:budget_point_list] if args.key?(:budget_point_list)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @cpc_bid_point_list = args[:cpc_bid_point_list] if args.key?(:cpc_bid_point_list)
  @end_date = args[:end_date] if args.key?(:end_date)
  @modification_method = args[:modification_method] if args.key?(:modification_method)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @target_cpa_point_list = args[:target_cpa_point_list] if args.key?(:target_cpa_point_list)
  @target_impression_share_point_list = args[:target_impression_share_point_list] if args.key?(:target_impression_share_point_list)
  @target_roas_point_list = args[:target_roas_point_list] if args.key?(:target_roas_point_list)
  @type = args[:type] if args.key?(:type)
end