Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSimulation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A campaign simulation. Supported combinations of advertising channel type, simulation type and simulation modification method is detailed below respectively. * SEARCH - CPC_BID - UNIFORM * SEARCH - CPC_BID - SCALING * SEARCH - TARGET_CPA - UNIFORM * SEARCH - TARGET_CPA - SCALING * SEARCH - TARGET_ROAS - UNIFORM * SEARCH - TARGET_IMPRESSION_SHARE - UNIFORM * SEARCH - BUDGET - UNIFORM * SHOPPING - BUDGET - UNIFORM * SHOPPING - TARGET_ROAS - UNIFORM * MULTI_CHANNEL - TARGET_CPA - UNIFORM * MULTI_CHANNEL - TARGET_ROAS - UNIFORM * DEMAND_GEN - TARGET_CPA - DEFAULT * DISPLAY - TARGET_CPA - UNIFORM * PERFORMANCE_MAX - TARGET_CPA - UNIFORM * PERFORMANCE_MAX - TARGET_ROAS - UNIFORM * PERFORMANCE_MAX - BUDGET - UNIFORM

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignSimulation

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignSimulation.



25758
25759
25760
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25758

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBudgetSimulationPointList

A container for simulation points for simulations of type BUDGET. Corresponds to the JSON property budgetPointList



25703
25704
25705
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25703

def budget_point_list
  @budget_point_list
end

#campaign_idFixnum

Output only. Campaign id of the simulation. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


25708
25709
25710
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25708

def campaign_id
  @campaign_id
end

#cpc_bid_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCpcBidSimulationPointList

A container for simulation points for simulations of type CPC_BID. Corresponds to the JSON property cpcBidPointList



25713
25714
25715
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25713

def cpc_bid_point_list
  @cpc_bid_point_list
end

#end_dateString

Output only. Last day on which the simulation is based, in YYYY-MM-DD format Corresponds to the JSON property endDate

Returns:

  • (String)


25718
25719
25720
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25718

def end_date
  @end_date
end

#modification_methodString

Output only. How the simulation modifies the field. Corresponds to the JSON property modificationMethod

Returns:

  • (String)


25723
25724
25725
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25723

def modification_method
  @modification_method
end

#resource_nameString

Output only. The resource name of the campaign simulation. Campaign simulation resource names have the form: customers/customer_id/campaignSimulations/ campaign_id~type~modification_method~start_date~end_date` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25730
25731
25732
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25730

def resource_name
  @resource_name
end

#start_dateString

Output only. First day on which the simulation is based, in YYYY-MM-DD format. Corresponds to the JSON property startDate

Returns:

  • (String)


25735
25736
25737
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25735

def start_date
  @start_date
end

#target_cpa_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetCpaSimulationPointList

A container for simulation points for simulations of type TARGET_CPA. Corresponds to the JSON property targetCpaPointList



25740
25741
25742
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25740

def target_cpa_point_list
  @target_cpa_point_list
end

#target_impression_share_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetImpressionShareSimulationPointList

A container for simulation points for simulations of type TARGET_IMPRESSION_SHARE. Corresponds to the JSON property targetImpressionSharePointList



25746
25747
25748
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25746

def target_impression_share_point_list
  @target_impression_share_point_list
end

#target_roas_point_listGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTargetRoasSimulationPointList

A container for simulation points for simulations of type TARGET_ROAS. Corresponds to the JSON property targetRoasPointList



25751
25752
25753
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25751

def target_roas_point_list
  @target_roas_point_list
end

#typeString

Output only. The field that the simulation modifies. Corresponds to the JSON property type

Returns:

  • (String)


25756
25757
25758
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25756

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25763
25764
25765
25766
25767
25768
25769
25770
25771
25772
25773
25774
25775
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25763

def update!(**args)
  @budget_point_list = args[:budget_point_list] if args.key?(:budget_point_list)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @cpc_bid_point_list = args[:cpc_bid_point_list] if args.key?(:cpc_bid_point_list)
  @end_date = args[:end_date] if args.key?(:end_date)
  @modification_method = args[:modification_method] if args.key?(:modification_method)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @start_date = args[:start_date] if args.key?(:start_date)
  @target_cpa_point_list = args[:target_cpa_point_list] if args.key?(:target_cpa_point_list)
  @target_impression_share_point_list = args[:target_impression_share_point_list] if args.key?(:target_impression_share_point_list)
  @target_roas_point_list = args[:target_roas_point_list] if args.key?(:target_roas_point_list)
  @type = args[:type] if args.key?(:type)
end