Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignVanityPharma

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Describes how unbranded pharma ads will be displayed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCampaignVanityPharma

Returns a new instance of GoogleAdsSearchads360V23ResourcesCampaignVanityPharma.



16047
16048
16049
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16047

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#vanity_pharma_display_url_modeString

The display mode for vanity pharma URLs. Corresponds to the JSON property vanityPharmaDisplayUrlMode

Returns:

  • (String)


16039
16040
16041
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16039

def vanity_pharma_display_url_mode
  @vanity_pharma_display_url_mode
end

#vanity_pharma_textString

The text that will be displayed in display URL of the text ad when website description is the selected display mode for vanity pharma URLs. Corresponds to the JSON property vanityPharmaText

Returns:

  • (String)


16045
16046
16047
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16045

def vanity_pharma_text
  @vanity_pharma_text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16052
16053
16054
16055
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16052

def update!(**args)
  @vanity_pharma_display_url_mode = args[:vanity_pharma_display_url_mode] if args.key?(:vanity_pharma_display_url_mode)
  @vanity_pharma_text = args[:vanity_pharma_text] if args.key?(:vanity_pharma_text)
end