Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCarrierConstant
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCarrierConstant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A carrier criterion that can be used in campaign targeting.
Instance Attribute Summary collapse
-
#country_code ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCarrierConstant
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCarrierConstant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCarrierConstant
Returns a new instance of GoogleAdsSearchads360V23ResourcesCarrierConstant.
25891 25892 25893 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25891 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_code ⇒ String
Output only. The country code of the country where the carrier is located, for
example, "AR", "FR", etc.
Corresponds to the JSON property countryCode
25873 25874 25875 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25873 def country_code @country_code end |
#id ⇒ Fixnum
Output only. The ID of the carrier criterion.
Corresponds to the JSON property id
25878 25879 25880 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25878 def id @id end |
#name ⇒ String
Output only. The full name of the carrier in English.
Corresponds to the JSON property name
25883 25884 25885 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25883 def name @name end |
#resource_name ⇒ String
Output only. The resource name of the carrier criterion. Carrier criterion
resource names have the form: carrierConstants/criterion_id`
Corresponds to the JSON propertyresourceName`
25889 25890 25891 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25889 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25896 25897 25898 25899 25900 25901 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25896 def update!(**args) @country_code = args[:country_code] if args.key?(:country_code) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) end |