Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCarrierConstant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A carrier criterion that can be used in campaign targeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCarrierConstant

Returns a new instance of GoogleAdsSearchads360V23ResourcesCarrierConstant.



25804
25805
25806
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Output only. The country code of the country where the carrier is located, for example, "AR", "FR", etc. Corresponds to the JSON property countryCode

Returns:

  • (String)


25786
25787
25788
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25786

def country_code
  @country_code
end

#idFixnum

Output only. The ID of the carrier criterion. Corresponds to the JSON property id

Returns:

  • (Fixnum)


25791
25792
25793
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25791

def id
  @id
end

#nameString

Output only. The full name of the carrier in English. Corresponds to the JSON property name

Returns:

  • (String)


25796
25797
25798
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25796

def name
  @name
end

#resource_nameString

Output only. The resource name of the carrier criterion. Carrier criterion resource names have the form: carrierConstants/criterion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25802
25803
25804
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25802

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25809
25810
25811
25812
25813
25814
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25809

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end