Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCartDataSalesView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCartDataSalesView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Cart data sales view. Provides information about the products which were purchased if conversions with cart data is implemented. Performance metrics like revenue, gross profit, lead/cross-sell metrics etc. and Merchant Center attributes such as brand, category etc. are available for products defined in an inventory feed and sold as a result of Google ads. For purchases attributed to clicks on Shopping ads, dimensions of both clicked and sold products can be viewed together.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCartDataSalesView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCartDataSalesView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCartDataSalesView
Returns a new instance of GoogleAdsSearchads360V23ResourcesCartDataSalesView.
25833 25834 25835 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25833 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Output only. The resource name of the Cart data sales view. Cart data sales
view resource names have the form: customers/customer_id/cartDataSalesView
Corresponds to the JSON property resourceName
25831 25832 25833 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25831 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25838 25839 25840 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25838 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) end |