Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEvent
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Describes the granular change of returned resources of certain resource types. Changes made through the UI or API in the past 30 days are included. Previous and new values of the changed fields are shown. ChangeEvent could have up to 3 minutes delay to reflect a new change.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Output only.
-
#asset ⇒ String
Output only.
-
#campaign ⇒ String
Output only.
-
#change_date_time ⇒ String
Output only.
-
#change_resource_name ⇒ String
Output only.
-
#change_resource_type ⇒ String
Output only.
-
#changed_fields ⇒ String
Output only.
-
#client_type ⇒ String
Output only.
-
#new_resource ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEventChangedResource
A wrapper proto presenting all supported resources.
-
#old_resource ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEventChangedResource
A wrapper proto presenting all supported resources.
-
#resource_change_operation ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#user_email ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesChangeEvent
constructor
A new instance of GoogleAdsSearchads360V23ResourcesChangeEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesChangeEvent
Returns a new instance of GoogleAdsSearchads360V23ResourcesChangeEvent.
26007 26008 26009 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26007 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Output only. The AdGroup affected by this change.
Corresponds to the JSON property adGroup
25940 25941 25942 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25940 def ad_group @ad_group end |
#asset ⇒ String
Output only. The Asset affected by this change.
Corresponds to the JSON property asset
25945 25946 25947 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25945 def asset @asset end |
#campaign ⇒ String
Output only. The Campaign affected by this change.
Corresponds to the JSON property campaign
25950 25951 25952 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25950 def campaign @campaign end |
#change_date_time ⇒ String
Output only. Time at which the change was committed on this resource.
Corresponds to the JSON property changeDateTime
25955 25956 25957 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25955 def change_date_time @change_date_time end |
#change_resource_name ⇒ String
Output only. The Simply resource this change occurred on.
Corresponds to the JSON property changeResourceName
25960 25961 25962 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25960 def change_resource_name @change_resource_name end |
#change_resource_type ⇒ String
Output only. The type of the changed resource. This dictates what resource
will be set in old_resource and new_resource.
Corresponds to the JSON property changeResourceType
25966 25967 25968 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25966 def change_resource_type @change_resource_type end |
#changed_fields ⇒ String
Output only. A list of fields that are changed in the returned resource.
Corresponds to the JSON property changedFields
25971 25972 25973 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25971 def changed_fields @changed_fields end |
#client_type ⇒ String
Output only. Where the change was made through.
Corresponds to the JSON property clientType
25976 25977 25978 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25976 def client_type @client_type end |
#new_resource ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEventChangedResource
A wrapper proto presenting all supported resources. Only the resource of the
change_resource_type will be set.
Corresponds to the JSON property newResource
25982 25983 25984 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25982 def new_resource @new_resource end |
#old_resource ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEventChangedResource
A wrapper proto presenting all supported resources. Only the resource of the
change_resource_type will be set.
Corresponds to the JSON property oldResource
25988 25989 25990 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25988 def old_resource @old_resource end |
#resource_change_operation ⇒ String
Output only. The operation on the changed resource.
Corresponds to the JSON property resourceChangeOperation
25993 25994 25995 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25993 def resource_change_operation @resource_change_operation end |
#resource_name ⇒ String
Output only. The resource name of the change event. Change event resource
names have the form: customers/customer_id/changeEvents/timestamp_micros~
command_index~mutate_index`
Corresponds to the JSON propertyresourceName`
26000 26001 26002 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26000 def resource_name @resource_name end |
#user_email ⇒ String
Output only. The email of the user who made this change.
Corresponds to the JSON property userEmail
26005 26006 26007 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26005 def user_email @user_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26012 26013 26014 26015 26016 26017 26018 26019 26020 26021 26022 26023 26024 26025 26026 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26012 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @asset = args[:asset] if args.key?(:asset) @campaign = args[:campaign] if args.key?(:campaign) @change_date_time = args[:change_date_time] if args.key?(:change_date_time) @change_resource_name = args[:change_resource_name] if args.key?(:change_resource_name) @change_resource_type = args[:change_resource_type] if args.key?(:change_resource_type) @changed_fields = args[:changed_fields] if args.key?(:changed_fields) @client_type = args[:client_type] if args.key?(:client_type) @new_resource = args[:new_resource] if args.key?(:new_resource) @old_resource = args[:old_resource] if args.key?(:old_resource) @resource_change_operation = args[:resource_change_operation] if args.key?(:resource_change_operation) @resource_name = args[:resource_name] if args.key?(:resource_name) @user_email = args[:user_email] if args.key?(:user_email) end |