Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Describes the granular change of returned resources of certain resource types. Changes made through the UI or API in the past 30 days are included. Previous and new values of the changed fields are shown. ChangeEvent could have up to 3 minutes delay to reflect a new change.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesChangeEvent

Returns a new instance of GoogleAdsSearchads360V23ResourcesChangeEvent.



25920
25921
25922
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25920

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Output only. The AdGroup affected by this change. Corresponds to the JSON property adGroup

Returns:

  • (String)


25853
25854
25855
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25853

def ad_group
  @ad_group
end

#assetString

Output only. The Asset affected by this change. Corresponds to the JSON property asset

Returns:

  • (String)


25858
25859
25860
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25858

def asset
  @asset
end

#campaignString

Output only. The Campaign affected by this change. Corresponds to the JSON property campaign

Returns:

  • (String)


25863
25864
25865
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25863

def campaign
  @campaign
end

#change_date_timeString

Output only. Time at which the change was committed on this resource. Corresponds to the JSON property changeDateTime

Returns:

  • (String)


25868
25869
25870
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25868

def change_date_time
  @change_date_time
end

#change_resource_nameString

Output only. The Simply resource this change occurred on. Corresponds to the JSON property changeResourceName

Returns:

  • (String)


25873
25874
25875
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25873

def change_resource_name
  @change_resource_name
end

#change_resource_typeString

Output only. The type of the changed resource. This dictates what resource will be set in old_resource and new_resource. Corresponds to the JSON property changeResourceType

Returns:

  • (String)


25879
25880
25881
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25879

def change_resource_type
  @change_resource_type
end

#changed_fieldsString

Output only. A list of fields that are changed in the returned resource. Corresponds to the JSON property changedFields

Returns:

  • (String)


25884
25885
25886
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25884

def changed_fields
  @changed_fields
end

#client_typeString

Output only. Where the change was made through. Corresponds to the JSON property clientType

Returns:

  • (String)


25889
25890
25891
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25889

def client_type
  @client_type
end

#new_resourceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEventChangedResource

A wrapper proto presenting all supported resources. Only the resource of the change_resource_type will be set. Corresponds to the JSON property newResource



25895
25896
25897
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25895

def new_resource
  @new_resource
end

#old_resourceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEventChangedResource

A wrapper proto presenting all supported resources. Only the resource of the change_resource_type will be set. Corresponds to the JSON property oldResource



25901
25902
25903
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25901

def old_resource
  @old_resource
end

#resource_change_operationString

Output only. The operation on the changed resource. Corresponds to the JSON property resourceChangeOperation

Returns:

  • (String)


25906
25907
25908
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25906

def resource_change_operation
  @resource_change_operation
end

#resource_nameString

Output only. The resource name of the change event. Change event resource names have the form: customers/customer_id/changeEvents/timestamp_micros~ command_index~mutate_index` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


25913
25914
25915
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25913

def resource_name
  @resource_name
end

#user_emailString

Output only. The email of the user who made this change. Corresponds to the JSON property userEmail

Returns:

  • (String)


25918
25919
25920
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25918

def user_email
  @user_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25925
25926
25927
25928
25929
25930
25931
25932
25933
25934
25935
25936
25937
25938
25939
# File 'lib/google/apis/searchads360_v23/classes.rb', line 25925

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @asset = args[:asset] if args.key?(:asset)
  @campaign = args[:campaign] if args.key?(:campaign)
  @change_date_time = args[:change_date_time] if args.key?(:change_date_time)
  @change_resource_name = args[:change_resource_name] if args.key?(:change_resource_name)
  @change_resource_type = args[:change_resource_type] if args.key?(:change_resource_type)
  @changed_fields = args[:changed_fields] if args.key?(:changed_fields)
  @client_type = args[:client_type] if args.key?(:client_type)
  @new_resource = args[:new_resource] if args.key?(:new_resource)
  @old_resource = args[:old_resource] if args.key?(:old_resource)
  @resource_change_operation = args[:resource_change_operation] if args.key?(:resource_change_operation)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @user_email = args[:user_email] if args.key?(:user_email)
end