Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEventChangedResource
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEventChangedResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A wrapper proto presenting all supported resources. Only the resource of the change_resource_type will be set.
Instance Attribute Summary collapse
-
#ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAd
An ad.
-
#ad_group ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup
An ad group.
-
#ad_group_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAd
An ad group ad.
-
#ad_group_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAsset
A link between an ad group and an asset.
-
#ad_group_bid_modifier ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupBidModifier
Represents an ad group bid modifier.
-
#ad_group_criterion ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterion
An ad group criterion.
-
#asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAsset
Asset is a part of an ad which can be shared across multiple ads.
-
#asset_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSet
An asset set representing a collection of assets.
-
#asset_set_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset
AssetSetAsset is the link between an asset and an asset set.
-
#campaign ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaign
A campaign.
-
#campaign_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAsset
A link between a Campaign and an Asset.
-
#campaign_asset_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAssetSet
CampaignAssetSet is the linkage between a campaign and an asset set.
-
#campaign_budget ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBudget
A campaign budget.
-
#campaign_criterion ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion
A campaign criterion.
-
#customer_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAsset
A link between a customer and an asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesChangeEventChangedResource
constructor
A new instance of GoogleAdsSearchads360V23ResourcesChangeEventChangedResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesChangeEventChangedResource
Returns a new instance of GoogleAdsSearchads360V23ResourcesChangeEventChangedResource.
16271 16272 16273 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAd
An ad.
Corresponds to the JSON property ad
16192 16193 16194 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16192 def ad @ad end |
#ad_group ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup
An ad group.
Corresponds to the JSON property adGroup
16197 16198 16199 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16197 def ad_group @ad_group end |
#ad_group_ad ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAd
An ad group ad.
Corresponds to the JSON property adGroupAd
16202 16203 16204 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16202 def ad_group_ad @ad_group_ad end |
#ad_group_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAsset
A link between an ad group and an asset.
Corresponds to the JSON property adGroupAsset
16207 16208 16209 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16207 def ad_group_asset @ad_group_asset end |
#ad_group_bid_modifier ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupBidModifier
Represents an ad group bid modifier.
Corresponds to the JSON property adGroupBidModifier
16212 16213 16214 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16212 def ad_group_bid_modifier @ad_group_bid_modifier end |
#ad_group_criterion ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterion
An ad group criterion. The ad_group_criterion report only returns criteria
that were explicitly added to the ad group.
Corresponds to the JSON property adGroupCriterion
16218 16219 16220 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16218 def ad_group_criterion @ad_group_criterion end |
#asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAsset
Asset is a part of an ad which can be shared across multiple ads. It can be an
image (ImageAsset), a video (YoutubeVideoAsset), etc. Assets are immutable and
cannot be removed. To stop an asset from serving, remove the asset from the
entity that is using it.
Corresponds to the JSON property asset
16226 16227 16228 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16226 def asset @asset end |
#asset_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSet
An asset set representing a collection of assets. Use AssetSetAsset to link an
asset to the asset set.
Corresponds to the JSON property assetSet
16232 16233 16234 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16232 def asset_set @asset_set end |
#asset_set_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset
AssetSetAsset is the link between an asset and an asset set. Adding an
AssetSetAsset links an asset with an asset set.
Corresponds to the JSON property assetSetAsset
16238 16239 16240 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16238 def asset_set_asset @asset_set_asset end |
#campaign ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaign
A campaign.
Corresponds to the JSON property campaign
16243 16244 16245 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16243 def campaign @campaign end |
#campaign_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAsset
A link between a Campaign and an Asset.
Corresponds to the JSON property campaignAsset
16248 16249 16250 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16248 def campaign_asset @campaign_asset end |
#campaign_asset_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAssetSet
CampaignAssetSet is the linkage between a campaign and an asset set. Adding a
CampaignAssetSet links an asset set with a campaign.
Corresponds to the JSON property campaignAssetSet
16254 16255 16256 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16254 def campaign_asset_set @campaign_asset_set end |
#campaign_budget ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBudget
A campaign budget.
Corresponds to the JSON property campaignBudget
16259 16260 16261 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16259 def campaign_budget @campaign_budget end |
#campaign_criterion ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion
A campaign criterion.
Corresponds to the JSON property campaignCriterion
16264 16265 16266 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16264 def campaign_criterion @campaign_criterion end |
#customer_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAsset
A link between a customer and an asset.
Corresponds to the JSON property customerAsset
16269 16270 16271 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16269 def customer_asset @customer_asset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16276 16277 16278 16279 16280 16281 16282 16283 16284 16285 16286 16287 16288 16289 16290 16291 16292 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16276 def update!(**args) @ad = args[:ad] if args.key?(:ad) @ad_group = args[:ad_group] if args.key?(:ad_group) @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad) @ad_group_asset = args[:ad_group_asset] if args.key?(:ad_group_asset) @ad_group_bid_modifier = args[:ad_group_bid_modifier] if args.key?(:ad_group_bid_modifier) @ad_group_criterion = args[:ad_group_criterion] if args.key?(:ad_group_criterion) @asset = args[:asset] if args.key?(:asset) @asset_set = args[:asset_set] if args.key?(:asset_set) @asset_set_asset = args[:asset_set_asset] if args.key?(:asset_set_asset) @campaign = args[:campaign] if args.key?(:campaign) @campaign_asset = args[:campaign_asset] if args.key?(:campaign_asset) @campaign_asset_set = args[:campaign_asset_set] if args.key?(:campaign_asset_set) @campaign_budget = args[:campaign_budget] if args.key?(:campaign_budget) @campaign_criterion = args[:campaign_criterion] if args.key?(:campaign_criterion) @customer_asset = args[:customer_asset] if args.key?(:customer_asset) end |