Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesChangeEventChangedResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A wrapper proto presenting all supported resources. Only the resource of the change_resource_type will be set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesChangeEventChangedResource

Returns a new instance of GoogleAdsSearchads360V23ResourcesChangeEventChangedResource.



16145
16146
16147
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAd

An ad. Corresponds to the JSON property ad



16066
16067
16068
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16066

def ad
  @ad
end

#ad_groupGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup

An ad group. Corresponds to the JSON property adGroup



16071
16072
16073
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16071

def ad_group
  @ad_group
end

#ad_group_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAd

An ad group ad. Corresponds to the JSON property adGroupAd



16076
16077
16078
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16076

def ad_group_ad
  @ad_group_ad
end

#ad_group_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAsset

A link between an ad group and an asset. Corresponds to the JSON property adGroupAsset



16081
16082
16083
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16081

def ad_group_asset
  @ad_group_asset
end

#ad_group_bid_modifierGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupBidModifier

Represents an ad group bid modifier. Corresponds to the JSON property adGroupBidModifier



16086
16087
16088
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16086

def ad_group_bid_modifier
  @ad_group_bid_modifier
end

#ad_group_criterionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterion

An ad group criterion. The ad_group_criterion report only returns criteria that were explicitly added to the ad group. Corresponds to the JSON property adGroupCriterion



16092
16093
16094
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16092

def ad_group_criterion
  @ad_group_criterion
end

#assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAsset

Asset is a part of an ad which can be shared across multiple ads. It can be an image (ImageAsset), a video (YoutubeVideoAsset), etc. Assets are immutable and cannot be removed. To stop an asset from serving, remove the asset from the entity that is using it. Corresponds to the JSON property asset



16100
16101
16102
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16100

def asset
  @asset
end

#asset_setGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSet

An asset set representing a collection of assets. Use AssetSetAsset to link an asset to the asset set. Corresponds to the JSON property assetSet



16106
16107
16108
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16106

def asset_set
  @asset_set
end

#asset_set_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset

AssetSetAsset is the link between an asset and an asset set. Adding an AssetSetAsset links an asset with an asset set. Corresponds to the JSON property assetSetAsset



16112
16113
16114
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16112

def asset_set_asset
  @asset_set_asset
end

#campaignGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaign

A campaign. Corresponds to the JSON property campaign



16117
16118
16119
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16117

def campaign
  @campaign
end

#campaign_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAsset

A link between a Campaign and an Asset. Corresponds to the JSON property campaignAsset



16122
16123
16124
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16122

def campaign_asset
  @campaign_asset
end

#campaign_asset_setGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAssetSet

CampaignAssetSet is the linkage between a campaign and an asset set. Adding a CampaignAssetSet links an asset set with a campaign. Corresponds to the JSON property campaignAssetSet



16128
16129
16130
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16128

def campaign_asset_set
  @campaign_asset_set
end

#campaign_budgetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBudget

A campaign budget. Corresponds to the JSON property campaignBudget



16133
16134
16135
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16133

def campaign_budget
  @campaign_budget
end

#campaign_criterionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion

A campaign criterion. Corresponds to the JSON property campaignCriterion



16138
16139
16140
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16138

def campaign_criterion
  @campaign_criterion
end

#customer_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAsset

A link between a customer and an asset. Corresponds to the JSON property customerAsset



16143
16144
16145
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16143

def customer_asset
  @customer_asset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16150
16151
16152
16153
16154
16155
16156
16157
16158
16159
16160
16161
16162
16163
16164
16165
16166
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16150

def update!(**args)
  @ad = args[:ad] if args.key?(:ad)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad)
  @ad_group_asset = args[:ad_group_asset] if args.key?(:ad_group_asset)
  @ad_group_bid_modifier = args[:ad_group_bid_modifier] if args.key?(:ad_group_bid_modifier)
  @ad_group_criterion = args[:ad_group_criterion] if args.key?(:ad_group_criterion)
  @asset = args[:asset] if args.key?(:asset)
  @asset_set = args[:asset_set] if args.key?(:asset_set)
  @asset_set_asset = args[:asset_set_asset] if args.key?(:asset_set_asset)
  @campaign = args[:campaign] if args.key?(:campaign)
  @campaign_asset = args[:campaign_asset] if args.key?(:campaign_asset)
  @campaign_asset_set = args[:campaign_asset_set] if args.key?(:campaign_asset_set)
  @campaign_budget = args[:campaign_budget] if args.key?(:campaign_budget)
  @campaign_criterion = args[:campaign_criterion] if args.key?(:campaign_criterion)
  @customer_asset = args[:customer_asset] if args.key?(:customer_asset)
end