Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesClickView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A click view with metrics aggregated at each click level, including both valid and invalid clicks. For non-Search campaigns, metrics.clicks represents the number of valid and invalid interactions. Queries including ClickView must have a filter limiting the results to one day and can be requested for dates back to 90 days before the time of the request. GCLIDs are not available in this report for App Campaigns for Installs (ACi) and App Campaigns for Pre- registration (ACpre).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesClickView

Returns a new instance of GoogleAdsSearchads360V23ResourcesClickView.



26235
26236
26237
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_adString

Output only. The associated ad. Corresponds to the JSON property adGroupAd

Returns:

  • (String)


26186
26187
26188
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26186

def ad_group_ad
  @ad_group_ad
end

#area_of_interestGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonClickLocation

Location criteria associated with a click. Corresponds to the JSON property areaOfInterest



26191
26192
26193
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26191

def area_of_interest
  @area_of_interest
end

#campaign_location_targetString

Output only. The associated campaign location target, if one exists. Corresponds to the JSON property campaignLocationTarget

Returns:

  • (String)


26196
26197
26198
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26196

def campaign_location_target
  @campaign_location_target
end

#gclidString

Output only. The Google Click ID. Corresponds to the JSON property gclid

Returns:

  • (String)


26201
26202
26203
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26201

def gclid
  @gclid
end

#keywordString

Output only. The associated keyword, if one exists and the click corresponds to the SEARCH channel. Corresponds to the JSON property keyword

Returns:

  • (String)


26207
26208
26209
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26207

def keyword
  @keyword
end

#keyword_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo

A keyword criterion. Corresponds to the JSON property keywordInfo



26212
26213
26214
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26212

def keyword_info
  @keyword_info
end

#location_of_presenceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonClickLocation

Location criteria associated with a click. Corresponds to the JSON property locationOfPresence



26217
26218
26219
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26217

def location_of_presence
  @location_of_presence
end

#page_numberFixnum

Output only. Page number in search results where the ad was shown. Corresponds to the JSON property pageNumber

Returns:

  • (Fixnum)


26222
26223
26224
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26222

def page_number
  @page_number
end

#resource_nameString

Output only. The resource name of the click view. Click view resource names have the form: customers/customer_id/clickViews/date (yyyy-MM-dd)~gclid` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


26228
26229
26230
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26228

def resource_name
  @resource_name
end

#user_listString

Output only. The associated user list, if one exists. Corresponds to the JSON property userList

Returns:

  • (String)


26233
26234
26235
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26233

def user_list
  @user_list
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26240
26241
26242
26243
26244
26245
26246
26247
26248
26249
26250
26251
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26240

def update!(**args)
  @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad)
  @area_of_interest = args[:area_of_interest] if args.key?(:area_of_interest)
  @campaign_location_target = args[:campaign_location_target] if args.key?(:campaign_location_target)
  @gclid = args[:gclid] if args.key?(:gclid)
  @keyword = args[:keyword] if args.key?(:keyword)
  @keyword_info = args[:keyword_info] if args.key?(:keyword_info)
  @location_of_presence = args[:location_of_presence] if args.key?(:location_of_presence)
  @page_number = args[:page_number] if args.key?(:page_number)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @user_list = args[:user_list] if args.key?(:user_list)
end