Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesClickView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A click view with metrics aggregated at each click level, including both valid and invalid clicks. For non-Search campaigns, metrics.clicks represents the number of valid and invalid interactions. Queries including ClickView must have a filter limiting the results to one day and can be requested for dates back to 90 days before the time of the request. GCLIDs are not available in this report for App Campaigns for Installs (ACi) and App Campaigns for Pre- registration (ACpre).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesClickView

Returns a new instance of GoogleAdsSearchads360V23ResourcesClickView.



26148
26149
26150
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26148

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_adString

Output only. The associated ad. Corresponds to the JSON property adGroupAd

Returns:

  • (String)


26099
26100
26101
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26099

def ad_group_ad
  @ad_group_ad
end

#area_of_interestGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonClickLocation

Location criteria associated with a click. Corresponds to the JSON property areaOfInterest



26104
26105
26106
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26104

def area_of_interest
  @area_of_interest
end

#campaign_location_targetString

Output only. The associated campaign location target, if one exists. Corresponds to the JSON property campaignLocationTarget

Returns:

  • (String)


26109
26110
26111
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26109

def campaign_location_target
  @campaign_location_target
end

#gclidString

Output only. The Google Click ID. Corresponds to the JSON property gclid

Returns:

  • (String)


26114
26115
26116
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26114

def gclid
  @gclid
end

#keywordString

Output only. The associated keyword, if one exists and the click corresponds to the SEARCH channel. Corresponds to the JSON property keyword

Returns:

  • (String)


26120
26121
26122
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26120

def keyword
  @keyword
end

#keyword_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo

A keyword criterion. Corresponds to the JSON property keywordInfo



26125
26126
26127
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26125

def keyword_info
  @keyword_info
end

#location_of_presenceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonClickLocation

Location criteria associated with a click. Corresponds to the JSON property locationOfPresence



26130
26131
26132
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26130

def location_of_presence
  @location_of_presence
end

#page_numberFixnum

Output only. Page number in search results where the ad was shown. Corresponds to the JSON property pageNumber

Returns:

  • (Fixnum)


26135
26136
26137
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26135

def page_number
  @page_number
end

#resource_nameString

Output only. The resource name of the click view. Click view resource names have the form: customers/customer_id/clickViews/date (yyyy-MM-dd)~gclid` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


26141
26142
26143
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26141

def resource_name
  @resource_name
end

#user_listString

Output only. The associated user list, if one exists. Corresponds to the JSON property userList

Returns:

  • (String)


26146
26147
26148
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26146

def user_list
  @user_list
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26153
26154
26155
26156
26157
26158
26159
26160
26161
26162
26163
26164
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26153

def update!(**args)
  @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad)
  @area_of_interest = args[:area_of_interest] if args.key?(:area_of_interest)
  @campaign_location_target = args[:campaign_location_target] if args.key?(:campaign_location_target)
  @gclid = args[:gclid] if args.key?(:gclid)
  @keyword = args[:keyword] if args.key?(:keyword)
  @keyword_info = args[:keyword_info] if args.key?(:keyword_info)
  @location_of_presence = args[:location_of_presence] if args.key?(:location_of_presence)
  @page_number = args[:page_number] if args.key?(:page_number)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @user_list = args[:user_list] if args.key?(:user_list)
end