Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCombinedAudience

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Describe a resource for combined audiences which includes different audiences.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCombinedAudience

Returns a new instance of GoogleAdsSearchads360V23ResourcesCombinedAudience.



26200
26201
26202
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Output only. Description of this combined audience. Corresponds to the JSON property description

Returns:

  • (String)


26174
26175
26176
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26174

def description
  @description
end

#idFixnum

Output only. ID of the combined audience. Corresponds to the JSON property id

Returns:

  • (Fixnum)


26179
26180
26181
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26179

def id
  @id
end

#nameString

Output only. Name of the combined audience. It should be unique across all combined audiences. Corresponds to the JSON property name

Returns:

  • (String)


26185
26186
26187
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26185

def name
  @name
end

#resource_nameString

Immutable. The resource name of the combined audience. Combined audience names have the form: customers/customer_id/combinedAudience/combined_audience_id Corresponds to the JSON property resourceName

Returns:

  • (String)


26192
26193
26194
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26192

def resource_name
  @resource_name
end

#statusString

Output only. Status of this combined audience. Indicates whether the combined audience is enabled or removed. Corresponds to the JSON property status

Returns:

  • (String)


26198
26199
26200
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26198

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26205
26206
26207
26208
26209
26210
26211
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26205

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end