Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesContactDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Fields containing consumer contact details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesContactDetails

Returns a new instance of GoogleAdsSearchads360V23ResourcesContactDetails.



26237
26238
26239
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_nameString

Output only. Consumer name if consumer provided name from Message or Booking form on google.com Corresponds to the JSON property consumerName

Returns:

  • (String)


26222
26223
26224
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26222

def consumer_name
  @consumer_name
end

#emailString

Output only. Consumer email address. Corresponds to the JSON property email

Returns:

  • (String)


26227
26228
26229
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26227

def email
  @email
end

#phone_numberString

Output only. Phone number of the consumer for the lead. This can be a real phone number or a tracking number. The phone number is returned in E164 format. See https://support.google.com/google-ads/answer/16355235?hl=en to learn more. Example: +16504519489. Corresponds to the JSON property phoneNumber

Returns:

  • (String)


26235
26236
26237
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26235

def phone_number
  @phone_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26242
26243
26244
26245
26246
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26242

def update!(**args)
  @consumer_name = args[:consumer_name] if args.key?(:consumer_name)
  @email = args[:email] if args.key?(:email)
  @phone_number = args[:phone_number] if args.key?(:phone_number)
end