Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A conversion.
Instance Attribute Summary collapse
-
#ad_id ⇒ Fixnum
Output only.
-
#advertiser_conversion_id ⇒ String
Output only.
-
#asset_field_type ⇒ String
Output only.
-
#asset_id ⇒ Fixnum
Output only.
-
#attribution_type ⇒ String
Output only.
-
#click_id ⇒ String
Output only.
-
#conversion_date_time ⇒ String
Output only.
-
#conversion_last_modified_date_time ⇒ String
Output only.
-
#conversion_quantity ⇒ Fixnum
Output only.
-
#conversion_revenue_micros ⇒ Fixnum
Output only.
-
#conversion_visit_date_time ⇒ String
Output only.
-
#criterion_id ⇒ Fixnum
Output only.
-
#floodlight_order_id ⇒ String
Output only.
-
#floodlight_original_revenue ⇒ Fixnum
Output only.
-
#id ⇒ Fixnum
Output only.
-
#merchant_id ⇒ Fixnum
Output only.
-
#product_channel ⇒ String
Output only.
-
#product_country_code ⇒ String
Output only.
-
#product_id ⇒ String
Output only.
-
#product_language_code ⇒ String
Output only.
-
#product_store_id ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#visit_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversion
constructor
A new instance of GoogleAdsSearchads360V23ResourcesConversion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversion
Returns a new instance of GoogleAdsSearchads360V23ResourcesConversion.
26574 26575 26576 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26574 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_id ⇒ Fixnum
Output only. Ad ID. A value of 0 indicates that the ad is unattributed.
Corresponds to the JSON property adId
26436 26437 26438 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26436 def ad_id @ad_id end |
#advertiser_conversion_id ⇒ String
Output only. For offline conversions, this is an ID provided by advertisers.
If an advertiser doesn't specify such an ID, Search Ads 360 generates one. For
online conversions, this is equal to the id column or the floodlight_order_id
column depending on the advertiser's Floodlight instructions.
Corresponds to the JSON property advertiserConversionId
26444 26445 26446 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26444 def advertiser_conversion_id @advertiser_conversion_id end |
#asset_field_type ⇒ String
Output only. Asset field type of the conversion event.
Corresponds to the JSON property assetFieldType
26449 26450 26451 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26449 def asset_field_type @asset_field_type end |
#asset_id ⇒ Fixnum
Output only. ID of the asset which was interacted with during the conversion
event.
Corresponds to the JSON property assetId
26455 26456 26457 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26455 def asset_id @asset_id end |
#attribution_type ⇒ String
Output only. What the conversion is attributed to: Visit or Keyword+Ad.
Corresponds to the JSON property attributionType
26460 26461 26462 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26460 def attribution_type @attribution_type end |
#click_id ⇒ String
Output only. A unique string, for the visit that the conversion is attributed
to, that is passed to the landing page as the click id URL parameter.
Corresponds to the JSON property clickId
26466 26467 26468 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26466 def click_id @click_id end |
#conversion_date_time ⇒ String
Output only. The timestamp of the conversion event.
Corresponds to the JSON property conversionDateTime
26471 26472 26473 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26471 def conversion_date_time @conversion_date_time end |
#conversion_last_modified_date_time ⇒ String
Output only. The timestamp of the last time the conversion was modified.
Corresponds to the JSON property conversionLastModifiedDateTime
26476 26477 26478 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26476 def conversion_last_modified_date_time @conversion_last_modified_date_time end |
#conversion_quantity ⇒ Fixnum
Output only. The quantity of items recorded by the conversion, as determined
by the qty url parameter. The advertiser is responsible for dynamically
populating the parameter (such as number of items sold in the conversion),
otherwise it defaults to 1.
Corresponds to the JSON property conversionQuantity
26484 26485 26486 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26484 def conversion_quantity @conversion_quantity end |
#conversion_revenue_micros ⇒ Fixnum
Output only. The adjusted revenue in micros for the conversion event. This
will always be in the currency of the serving account.
Corresponds to the JSON property conversionRevenueMicros
26490 26491 26492 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26490 def conversion_revenue_micros @conversion_revenue_micros end |
#conversion_visit_date_time ⇒ String
Output only. The timestamp of the visit that the conversion is attributed to.
Corresponds to the JSON property conversionVisitDateTime
26495 26496 26497 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26495 def conversion_visit_date_time @conversion_visit_date_time end |
#criterion_id ⇒ Fixnum
Output only. Search Ads 360 criterion ID. A value of 0 indicates that the
criterion is unattributed.
Corresponds to the JSON property criterionId
26501 26502 26503 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26501 def criterion_id @criterion_id end |
#floodlight_order_id ⇒ String
Output only. The Floodlight order ID provided by the advertiser for the
conversion.
Corresponds to the JSON property floodlightOrderId
26507 26508 26509 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26507 def floodlight_order_id @floodlight_order_id end |
#floodlight_original_revenue ⇒ Fixnum
Output only. The original, unchanged revenue associated with the Floodlight
event (in the currency of the current report), before Floodlight currency
instruction modifications.
Corresponds to the JSON property floodlightOriginalRevenue
26514 26515 26516 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26514 def floodlight_original_revenue @floodlight_original_revenue end |
#id ⇒ Fixnum
Output only. The ID of the conversion
Corresponds to the JSON property id
26519 26520 26521 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26519 def id @id end |
#merchant_id ⇒ Fixnum
Output only. The Search Ads 360 inventory account ID containing the product
that was clicked on. Search Ads 360 generates this ID when you link an
inventory account in Search Ads 360.
Corresponds to the JSON property merchantId
26526 26527 26528 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26526 def merchant_id @merchant_id end |
#product_channel ⇒ String
Output only. The sales channel of the product that was clicked on: Online or
Local.
Corresponds to the JSON property productChannel
26532 26533 26534 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26532 def product_channel @product_channel end |
#product_country_code ⇒ String
Output only. The country (ISO-3166-format) registered for the inventory feed
that contains the product clicked on.
Corresponds to the JSON property productCountryCode
26538 26539 26540 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26538 def product_country_code @product_country_code end |
#product_id ⇒ String
Output only. The ID of the product clicked on.
Corresponds to the JSON property productId
26543 26544 26545 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26543 def product_id @product_id end |
#product_language_code ⇒ String
Output only. The language (ISO-639-1) that has been set for the Merchant
Center feed containing data about the product.
Corresponds to the JSON property productLanguageCode
26549 26550 26551 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26549 def product_language_code @product_language_code end |
#product_store_id ⇒ String
Output only. The store in the Local Inventory Ad that was clicked on. This
should match the store IDs used in your local products feed.
Corresponds to the JSON property productStoreId
26555 26556 26557 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26555 def product_store_id @product_store_id end |
#resource_name ⇒ String
Output only. The resource name of the conversion. Conversion resource names
have the form: customers/customer_id/conversions/ad_group_id~
criterion_id~ds_conversion_id`
Corresponds to the JSON propertyresourceName`
26562 26563 26564 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26562 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the conversion, either ENABLED or REMOVED..
Corresponds to the JSON property status
26567 26568 26569 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26567 def status @status end |
#visit_id ⇒ Fixnum
Output only. The Search Ads 360 visit ID that the conversion is attributed to.
Corresponds to the JSON property visitId
26572 26573 26574 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26572 def visit_id @visit_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26579 26580 26581 26582 26583 26584 26585 26586 26587 26588 26589 26590 26591 26592 26593 26594 26595 26596 26597 26598 26599 26600 26601 26602 26603 26604 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26579 def update!(**args) @ad_id = args[:ad_id] if args.key?(:ad_id) @advertiser_conversion_id = args[:advertiser_conversion_id] if args.key?(:advertiser_conversion_id) @asset_field_type = args[:asset_field_type] if args.key?(:asset_field_type) @asset_id = args[:asset_id] if args.key?(:asset_id) @attribution_type = args[:attribution_type] if args.key?(:attribution_type) @click_id = args[:click_id] if args.key?(:click_id) @conversion_date_time = args[:conversion_date_time] if args.key?(:conversion_date_time) @conversion_last_modified_date_time = args[:conversion_last_modified_date_time] if args.key?(:conversion_last_modified_date_time) @conversion_quantity = args[:conversion_quantity] if args.key?(:conversion_quantity) @conversion_revenue_micros = args[:conversion_revenue_micros] if args.key?(:conversion_revenue_micros) @conversion_visit_date_time = args[:conversion_visit_date_time] if args.key?(:conversion_visit_date_time) @criterion_id = args[:criterion_id] if args.key?(:criterion_id) @floodlight_order_id = args[:floodlight_order_id] if args.key?(:floodlight_order_id) @floodlight_original_revenue = args[:floodlight_original_revenue] if args.key?(:floodlight_original_revenue) @id = args[:id] if args.key?(:id) @merchant_id = args[:merchant_id] if args.key?(:merchant_id) @product_channel = args[:product_channel] if args.key?(:product_channel) @product_country_code = args[:product_country_code] if args.key?(:product_country_code) @product_id = args[:product_id] if args.key?(:product_id) @product_language_code = args[:product_language_code] if args.key?(:product_language_code) @product_store_id = args[:product_store_id] if args.key?(:product_store_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @visit_id = args[:visit_id] if args.key?(:visit_id) end |