Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A conversion.
Instance Attribute Summary collapse
-
#ad_id ⇒ Fixnum
Output only.
-
#advertiser_conversion_id ⇒ String
Output only.
-
#asset_field_type ⇒ String
Output only.
-
#asset_id ⇒ Fixnum
Output only.
-
#attribution_type ⇒ String
Output only.
-
#click_id ⇒ String
Output only.
-
#conversion_date_time ⇒ String
Output only.
-
#conversion_last_modified_date_time ⇒ String
Output only.
-
#conversion_quantity ⇒ Fixnum
Output only.
-
#conversion_revenue_micros ⇒ Fixnum
Output only.
-
#conversion_visit_date_time ⇒ String
Output only.
-
#criterion_id ⇒ Fixnum
Output only.
-
#floodlight_order_id ⇒ String
Output only.
-
#floodlight_original_revenue ⇒ Fixnum
Output only.
-
#id ⇒ Fixnum
Output only.
-
#merchant_id ⇒ Fixnum
Output only.
-
#product_channel ⇒ String
Output only.
-
#product_country_code ⇒ String
Output only.
-
#product_id ⇒ String
Output only.
-
#product_language_code ⇒ String
Output only.
-
#product_store_id ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#visit_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversion
constructor
A new instance of GoogleAdsSearchads360V23ResourcesConversion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversion
Returns a new instance of GoogleAdsSearchads360V23ResourcesConversion.
26415 26416 26417 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_id ⇒ Fixnum
Output only. Ad ID. A value of 0 indicates that the ad is unattributed.
Corresponds to the JSON property adId
26277 26278 26279 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26277 def ad_id @ad_id end |
#advertiser_conversion_id ⇒ String
Output only. For offline conversions, this is an ID provided by advertisers.
If an advertiser doesn't specify such an ID, Search Ads 360 generates one. For
online conversions, this is equal to the id column or the floodlight_order_id
column depending on the advertiser's Floodlight instructions.
Corresponds to the JSON property advertiserConversionId
26285 26286 26287 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26285 def advertiser_conversion_id @advertiser_conversion_id end |
#asset_field_type ⇒ String
Output only. Asset field type of the conversion event.
Corresponds to the JSON property assetFieldType
26290 26291 26292 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26290 def asset_field_type @asset_field_type end |
#asset_id ⇒ Fixnum
Output only. ID of the asset which was interacted with during the conversion
event.
Corresponds to the JSON property assetId
26296 26297 26298 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26296 def asset_id @asset_id end |
#attribution_type ⇒ String
Output only. What the conversion is attributed to: Visit or Keyword+Ad.
Corresponds to the JSON property attributionType
26301 26302 26303 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26301 def attribution_type @attribution_type end |
#click_id ⇒ String
Output only. A unique string, for the visit that the conversion is attributed
to, that is passed to the landing page as the click id URL parameter.
Corresponds to the JSON property clickId
26307 26308 26309 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26307 def click_id @click_id end |
#conversion_date_time ⇒ String
Output only. The timestamp of the conversion event.
Corresponds to the JSON property conversionDateTime
26312 26313 26314 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26312 def conversion_date_time @conversion_date_time end |
#conversion_last_modified_date_time ⇒ String
Output only. The timestamp of the last time the conversion was modified.
Corresponds to the JSON property conversionLastModifiedDateTime
26317 26318 26319 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26317 def conversion_last_modified_date_time @conversion_last_modified_date_time end |
#conversion_quantity ⇒ Fixnum
Output only. The quantity of items recorded by the conversion, as determined
by the qty url parameter. The advertiser is responsible for dynamically
populating the parameter (such as number of items sold in the conversion),
otherwise it defaults to 1.
Corresponds to the JSON property conversionQuantity
26325 26326 26327 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26325 def conversion_quantity @conversion_quantity end |
#conversion_revenue_micros ⇒ Fixnum
Output only. The adjusted revenue in micros for the conversion event. This
will always be in the currency of the serving account.
Corresponds to the JSON property conversionRevenueMicros
26331 26332 26333 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26331 def conversion_revenue_micros @conversion_revenue_micros end |
#conversion_visit_date_time ⇒ String
Output only. The timestamp of the visit that the conversion is attributed to.
Corresponds to the JSON property conversionVisitDateTime
26336 26337 26338 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26336 def conversion_visit_date_time @conversion_visit_date_time end |
#criterion_id ⇒ Fixnum
Output only. Search Ads 360 criterion ID. A value of 0 indicates that the
criterion is unattributed.
Corresponds to the JSON property criterionId
26342 26343 26344 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26342 def criterion_id @criterion_id end |
#floodlight_order_id ⇒ String
Output only. The Floodlight order ID provided by the advertiser for the
conversion.
Corresponds to the JSON property floodlightOrderId
26348 26349 26350 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26348 def floodlight_order_id @floodlight_order_id end |
#floodlight_original_revenue ⇒ Fixnum
Output only. The original, unchanged revenue associated with the Floodlight
event (in the currency of the current report), before Floodlight currency
instruction modifications.
Corresponds to the JSON property floodlightOriginalRevenue
26355 26356 26357 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26355 def floodlight_original_revenue @floodlight_original_revenue end |
#id ⇒ Fixnum
Output only. The ID of the conversion
Corresponds to the JSON property id
26360 26361 26362 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26360 def id @id end |
#merchant_id ⇒ Fixnum
Output only. The Search Ads 360 inventory account ID containing the product
that was clicked on. Search Ads 360 generates this ID when you link an
inventory account in Search Ads 360.
Corresponds to the JSON property merchantId
26367 26368 26369 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26367 def merchant_id @merchant_id end |
#product_channel ⇒ String
Output only. The sales channel of the product that was clicked on: Online or
Local.
Corresponds to the JSON property productChannel
26373 26374 26375 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26373 def product_channel @product_channel end |
#product_country_code ⇒ String
Output only. The country (ISO-3166-format) registered for the inventory feed
that contains the product clicked on.
Corresponds to the JSON property productCountryCode
26379 26380 26381 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26379 def product_country_code @product_country_code end |
#product_id ⇒ String
Output only. The ID of the product clicked on.
Corresponds to the JSON property productId
26384 26385 26386 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26384 def product_id @product_id end |
#product_language_code ⇒ String
Output only. The language (ISO-639-1) that has been set for the Merchant
Center feed containing data about the product.
Corresponds to the JSON property productLanguageCode
26390 26391 26392 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26390 def product_language_code @product_language_code end |
#product_store_id ⇒ String
Output only. The store in the Local Inventory Ad that was clicked on. This
should match the store IDs used in your local products feed.
Corresponds to the JSON property productStoreId
26396 26397 26398 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26396 def product_store_id @product_store_id end |
#resource_name ⇒ String
Output only. The resource name of the conversion. Conversion resource names
have the form: customers/customer_id/conversions/ad_group_id~
criterion_id~ds_conversion_id`
Corresponds to the JSON propertyresourceName`
26403 26404 26405 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26403 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the conversion, either ENABLED or REMOVED..
Corresponds to the JSON property status
26408 26409 26410 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26408 def status @status end |
#visit_id ⇒ Fixnum
Output only. The Search Ads 360 visit ID that the conversion is attributed to.
Corresponds to the JSON property visitId
26413 26414 26415 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26413 def visit_id @visit_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26420 26421 26422 26423 26424 26425 26426 26427 26428 26429 26430 26431 26432 26433 26434 26435 26436 26437 26438 26439 26440 26441 26442 26443 26444 26445 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26420 def update!(**args) @ad_id = args[:ad_id] if args.key?(:ad_id) @advertiser_conversion_id = args[:advertiser_conversion_id] if args.key?(:advertiser_conversion_id) @asset_field_type = args[:asset_field_type] if args.key?(:asset_field_type) @asset_id = args[:asset_id] if args.key?(:asset_id) @attribution_type = args[:attribution_type] if args.key?(:attribution_type) @click_id = args[:click_id] if args.key?(:click_id) @conversion_date_time = args[:conversion_date_time] if args.key?(:conversion_date_time) @conversion_last_modified_date_time = args[:conversion_last_modified_date_time] if args.key?(:conversion_last_modified_date_time) @conversion_quantity = args[:conversion_quantity] if args.key?(:conversion_quantity) @conversion_revenue_micros = args[:conversion_revenue_micros] if args.key?(:conversion_revenue_micros) @conversion_visit_date_time = args[:conversion_visit_date_time] if args.key?(:conversion_visit_date_time) @criterion_id = args[:criterion_id] if args.key?(:criterion_id) @floodlight_order_id = args[:floodlight_order_id] if args.key?(:floodlight_order_id) @floodlight_original_revenue = args[:floodlight_original_revenue] if args.key?(:floodlight_original_revenue) @id = args[:id] if args.key?(:id) @merchant_id = args[:merchant_id] if args.key?(:merchant_id) @product_channel = args[:product_channel] if args.key?(:product_channel) @product_country_code = args[:product_country_code] if args.key?(:product_country_code) @product_id = args[:product_id] if args.key?(:product_id) @product_language_code = args[:product_language_code] if args.key?(:product_language_code) @product_store_id = args[:product_store_id] if args.key?(:product_store_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @visit_id = args[:visit_id] if args.key?(:visit_id) end |