Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionAction
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A conversion action.
Instance Attribute Summary collapse
-
#app_id ⇒ String
App ID for an app conversion action.
-
#attribution_model_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionAttributionModelSettings
Settings related to this conversion action's attribution model.
-
#category ⇒ String
The category of conversions reported for this conversion action.
-
#click_through_lookback_window_days ⇒ Fixnum
The maximum number of days that may elapse between an interaction (for example, a click) and a conversion event.
-
#counting_type ⇒ String
How to count conversion events for the conversion action.
-
#creation_time ⇒ String
Output only.
-
#firebase_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionFirebaseSettings
Settings related to a Firebase conversion action.
-
#floodlight_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionFloodlightSettings
Settings related to a Floodlight conversion action.
-
#google_analytics4_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionGoogleAnalytics4Settings
Settings related to a Google Analytics 4 conversion action.
-
#id ⇒ Fixnum
Output only.
-
#include_in_client_account_conversions_metric ⇒ Boolean
(also: #include_in_client_account_conversions_metric?)
Whether this conversion action should be included in the " client_account_conversions" metric.
-
#include_in_conversions_metric ⇒ Boolean
(also: #include_in_conversions_metric?)
Output only.
-
#mobile_app_vendor ⇒ String
Output only.
-
#name ⇒ String
The name of the conversion action.
-
#origin ⇒ String
Output only.
-
#owner_customer ⇒ String
Output only.
-
#phone_call_duration_seconds ⇒ Fixnum
The phone call duration in seconds after which a conversion should be reported for this conversion action.
-
#primary_for_goal ⇒ Boolean
(also: #primary_for_goal?)
If a conversion action's primary_for_goal bit is false, the conversion action is non-biddable for all campaigns regardless of their customer conversion goal or campaign conversion goal.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
The status of this conversion action for conversion event accrual.
-
#tag_snippets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTagSnippet>
Output only.
-
#third_party_app_analytics_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionThirdPartyAppAnalyticsSettings
Settings related to a third party app analytics conversion action.
-
#type ⇒ String
Immutable.
-
#value_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionValueSettings
Settings related to the value for conversion events associated with this conversion action.
-
#view_through_lookback_window_days ⇒ Fixnum
The maximum number of days which may elapse between an impression and a conversion without an interaction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionAction
constructor
A new instance of GoogleAdsSearchads360V23ResourcesConversionAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionAction
Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionAction.
26757 26758 26759 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ String
App ID for an app conversion action.
Corresponds to the JSON property appId
26614 26615 26616 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26614 def app_id @app_id end |
#attribution_model_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionAttributionModelSettings
Settings related to this conversion action's attribution model.
Corresponds to the JSON property attributionModelSettings
26619 26620 26621 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26619 def attribution_model_settings @attribution_model_settings end |
#category ⇒ String
The category of conversions reported for this conversion action.
Corresponds to the JSON property category
26624 26625 26626 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26624 def category @category end |
#click_through_lookback_window_days ⇒ Fixnum
The maximum number of days that may elapse between an interaction (for example,
a click) and a conversion event.
Corresponds to the JSON property clickThroughLookbackWindowDays
26630 26631 26632 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26630 def click_through_lookback_window_days @click_through_lookback_window_days end |
#counting_type ⇒ String
How to count conversion events for the conversion action.
Corresponds to the JSON property countingType
26635 26636 26637 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26635 def counting_type @counting_type end |
#creation_time ⇒ String
Output only. Timestamp of the Floodlight activity's creation, formatted in ISO
8601.
Corresponds to the JSON property creationTime
26641 26642 26643 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26641 def creation_time @creation_time end |
#firebase_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionFirebaseSettings
Settings related to a Firebase conversion action.
Corresponds to the JSON property firebaseSettings
26646 26647 26648 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26646 def firebase_settings @firebase_settings end |
#floodlight_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionFloodlightSettings
Settings related to a Floodlight conversion action.
Corresponds to the JSON property floodlightSettings
26651 26652 26653 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26651 def floodlight_settings @floodlight_settings end |
#google_analytics4_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionGoogleAnalytics4Settings
Settings related to a Google Analytics 4 conversion action.
Corresponds to the JSON property googleAnalytics4Settings
26656 26657 26658 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26656 def google_analytics4_settings @google_analytics4_settings end |
#id ⇒ Fixnum
Output only. The ID of the conversion action.
Corresponds to the JSON property id
26661 26662 26663 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26661 def id @id end |
#include_in_client_account_conversions_metric ⇒ Boolean Also known as: include_in_client_account_conversions_metric?
Whether this conversion action should be included in the "
client_account_conversions" metric.
Corresponds to the JSON property includeInClientAccountConversionsMetric
26667 26668 26669 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26667 def include_in_client_account_conversions_metric @include_in_client_account_conversions_metric end |
#include_in_conversions_metric ⇒ Boolean Also known as: include_in_conversions_metric?
Output only. Whether this conversion action should be included in the "
conversions" metric.
Corresponds to the JSON property includeInConversionsMetric
26674 26675 26676 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26674 def include_in_conversions_metric @include_in_conversions_metric end |
#mobile_app_vendor ⇒ String
Output only. Mobile app vendor for an app conversion action.
Corresponds to the JSON property mobileAppVendor
26680 26681 26682 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26680 def mobile_app_vendor @mobile_app_vendor end |
#name ⇒ String
The name of the conversion action. This field is required and should not be
empty when creating new conversion actions.
Corresponds to the JSON property name
26686 26687 26688 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26686 def name @name end |
#origin ⇒ String
Output only. The conversion origin of this conversion action.
Corresponds to the JSON property origin
26691 26692 26693 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26691 def origin @origin end |
#owner_customer ⇒ String
Output only. The resource name of the conversion action owner customer, or
null if this is a system-defined conversion action.
Corresponds to the JSON property ownerCustomer
26697 26698 26699 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26697 def owner_customer @owner_customer end |
#phone_call_duration_seconds ⇒ Fixnum
The phone call duration in seconds after which a conversion should be reported
for this conversion action. The value must be between 0 and 10000, inclusive.
Corresponds to the JSON property phoneCallDurationSeconds
26703 26704 26705 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26703 def phone_call_duration_seconds @phone_call_duration_seconds end |
#primary_for_goal ⇒ Boolean Also known as: primary_for_goal?
If a conversion action's primary_for_goal bit is false, the conversion action
is non-biddable for all campaigns regardless of their customer conversion goal
or campaign conversion goal. However, custom conversion goals do not respect
primary_for_goal, so if a campaign has a custom conversion goal configured
with a primary_for_goal = false conversion action, that conversion action is
still biddable. By default, primary_for_goal will be true if not set. In V9,
primary_for_goal can only be set to false after creation through an 'update'
operation because it's not declared as optional.
Corresponds to the JSON property primaryForGoal
26715 26716 26717 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26715 def primary_for_goal @primary_for_goal end |
#resource_name ⇒ String
Immutable. The resource name of the conversion action. Conversion action
resource names have the form: customers/customer_id/conversionActions/
conversion_action_id`
Corresponds to the JSON propertyresourceName`
26723 26724 26725 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26723 def resource_name @resource_name end |
#status ⇒ String
The status of this conversion action for conversion event accrual.
Corresponds to the JSON property status
26728 26729 26730 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26728 def status @status end |
#tag_snippets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTagSnippet>
Output only. The snippets used for tracking conversions.
Corresponds to the JSON property tagSnippets
26733 26734 26735 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26733 def tag_snippets @tag_snippets end |
#third_party_app_analytics_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionThirdPartyAppAnalyticsSettings
Settings related to a third party app analytics conversion action.
Corresponds to the JSON property thirdPartyAppAnalyticsSettings
26738 26739 26740 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26738 def third_party_app_analytics_settings @third_party_app_analytics_settings end |
#type ⇒ String
Immutable. The type of this conversion action.
Corresponds to the JSON property type
26743 26744 26745 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26743 def type @type end |
#value_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionValueSettings
Settings related to the value for conversion events associated with this
conversion action.
Corresponds to the JSON property valueSettings
26749 26750 26751 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26749 def value_settings @value_settings end |
#view_through_lookback_window_days ⇒ Fixnum
The maximum number of days which may elapse between an impression and a
conversion without an interaction.
Corresponds to the JSON property viewThroughLookbackWindowDays
26755 26756 26757 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26755 def view_through_lookback_window_days @view_through_lookback_window_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26762 26763 26764 26765 26766 26767 26768 26769 26770 26771 26772 26773 26774 26775 26776 26777 26778 26779 26780 26781 26782 26783 26784 26785 26786 26787 26788 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26762 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @attribution_model_settings = args[:attribution_model_settings] if args.key?(:attribution_model_settings) @category = args[:category] if args.key?(:category) @click_through_lookback_window_days = args[:click_through_lookback_window_days] if args.key?(:click_through_lookback_window_days) @counting_type = args[:counting_type] if args.key?(:counting_type) @creation_time = args[:creation_time] if args.key?(:creation_time) @firebase_settings = args[:firebase_settings] if args.key?(:firebase_settings) @floodlight_settings = args[:floodlight_settings] if args.key?(:floodlight_settings) @google_analytics4_settings = args[:google_analytics4_settings] if args.key?(:google_analytics4_settings) @id = args[:id] if args.key?(:id) @include_in_client_account_conversions_metric = args[:include_in_client_account_conversions_metric] if args.key?(:include_in_client_account_conversions_metric) @include_in_conversions_metric = args[:include_in_conversions_metric] if args.key?(:include_in_conversions_metric) @mobile_app_vendor = args[:mobile_app_vendor] if args.key?(:mobile_app_vendor) @name = args[:name] if args.key?(:name) @origin = args[:origin] if args.key?(:origin) @owner_customer = args[:owner_customer] if args.key?(:owner_customer) @phone_call_duration_seconds = args[:phone_call_duration_seconds] if args.key?(:phone_call_duration_seconds) @primary_for_goal = args[:primary_for_goal] if args.key?(:primary_for_goal) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @tag_snippets = args[:tag_snippets] if args.key?(:tag_snippets) @third_party_app_analytics_settings = args[:third_party_app_analytics_settings] if args.key?(:third_party_app_analytics_settings) @type = args[:type] if args.key?(:type) @value_settings = args[:value_settings] if args.key?(:value_settings) @view_through_lookback_window_days = args[:view_through_lookback_window_days] if args.key?(:view_through_lookback_window_days) end |