Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A conversion action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionAction

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionAction.



26685
26686
26687
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

App ID for an app conversion action. Corresponds to the JSON property appId

Returns:

  • (String)


26542
26543
26544
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26542

def app_id
  @app_id
end

#attribution_model_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionAttributionModelSettings

Settings related to this conversion action's attribution model. Corresponds to the JSON property attributionModelSettings



26547
26548
26549
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26547

def attribution_model_settings
  @attribution_model_settings
end

#categoryString

The category of conversions reported for this conversion action. Corresponds to the JSON property category

Returns:

  • (String)


26552
26553
26554
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26552

def category
  @category
end

#click_through_lookback_window_daysFixnum

The maximum number of days that may elapse between an interaction (for example, a click) and a conversion event. Corresponds to the JSON property clickThroughLookbackWindowDays

Returns:

  • (Fixnum)


26558
26559
26560
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26558

def click_through_lookback_window_days
  @click_through_lookback_window_days
end

#counting_typeString

How to count conversion events for the conversion action. Corresponds to the JSON property countingType

Returns:

  • (String)


26563
26564
26565
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26563

def counting_type
  @counting_type
end

#creation_timeString

Output only. Timestamp of the Floodlight activity's creation, formatted in ISO 8601. Corresponds to the JSON property creationTime

Returns:

  • (String)


26569
26570
26571
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26569

def creation_time
  @creation_time
end

#firebase_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionFirebaseSettings

Settings related to a Firebase conversion action. Corresponds to the JSON property firebaseSettings



26574
26575
26576
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26574

def firebase_settings
  @firebase_settings
end

#floodlight_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionFloodlightSettings

Settings related to a Floodlight conversion action. Corresponds to the JSON property floodlightSettings



26579
26580
26581
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26579

def floodlight_settings
  @floodlight_settings
end

#google_analytics4_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionGoogleAnalytics4Settings

Settings related to a Google Analytics 4 conversion action. Corresponds to the JSON property googleAnalytics4Settings



26584
26585
26586
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26584

def google_analytics4_settings
  @google_analytics4_settings
end

#idFixnum

Output only. The ID of the conversion action. Corresponds to the JSON property id

Returns:

  • (Fixnum)


26589
26590
26591
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26589

def id
  @id
end

#include_in_client_account_conversions_metricBoolean Also known as: include_in_client_account_conversions_metric?

Whether this conversion action should be included in the " client_account_conversions" metric. Corresponds to the JSON property includeInClientAccountConversionsMetric

Returns:

  • (Boolean)


26595
26596
26597
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26595

def 
  @include_in_client_account_conversions_metric
end

#include_in_conversions_metricBoolean Also known as: include_in_conversions_metric?

Output only. Whether this conversion action should be included in the " conversions" metric. Corresponds to the JSON property includeInConversionsMetric

Returns:

  • (Boolean)


26602
26603
26604
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26602

def include_in_conversions_metric
  @include_in_conversions_metric
end

#mobile_app_vendorString

Output only. Mobile app vendor for an app conversion action. Corresponds to the JSON property mobileAppVendor

Returns:

  • (String)


26608
26609
26610
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26608

def mobile_app_vendor
  @mobile_app_vendor
end

#nameString

The name of the conversion action. This field is required and should not be empty when creating new conversion actions. Corresponds to the JSON property name

Returns:

  • (String)


26614
26615
26616
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26614

def name
  @name
end

#originString

Output only. The conversion origin of this conversion action. Corresponds to the JSON property origin

Returns:

  • (String)


26619
26620
26621
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26619

def origin
  @origin
end

#owner_customerString

Output only. The resource name of the conversion action owner customer, or null if this is a system-defined conversion action. Corresponds to the JSON property ownerCustomer

Returns:

  • (String)


26625
26626
26627
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26625

def owner_customer
  @owner_customer
end

#phone_call_duration_secondsFixnum

The phone call duration in seconds after which a conversion should be reported for this conversion action. The value must be between 0 and 10000, inclusive. Corresponds to the JSON property phoneCallDurationSeconds

Returns:

  • (Fixnum)


26631
26632
26633
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26631

def phone_call_duration_seconds
  @phone_call_duration_seconds
end

#primary_for_goalBoolean Also known as: primary_for_goal?

If a conversion action's primary_for_goal bit is false, the conversion action is non-biddable for all campaigns regardless of their customer conversion goal or campaign conversion goal. However, custom conversion goals do not respect primary_for_goal, so if a campaign has a custom conversion goal configured with a primary_for_goal = false conversion action, that conversion action is still biddable. By default, primary_for_goal will be true if not set. In V9, primary_for_goal can only be set to false after creation through an 'update' operation because it's not declared as optional. Corresponds to the JSON property primaryForGoal

Returns:

  • (Boolean)


26643
26644
26645
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26643

def primary_for_goal
  @primary_for_goal
end

#resource_nameString

Immutable. The resource name of the conversion action. Conversion action resource names have the form: customers/customer_id/conversionActions/ conversion_action_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


26651
26652
26653
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26651

def resource_name
  @resource_name
end

#statusString

The status of this conversion action for conversion event accrual. Corresponds to the JSON property status

Returns:

  • (String)


26656
26657
26658
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26656

def status
  @status
end

#tag_snippetsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTagSnippet>

Output only. The snippets used for tracking conversions. Corresponds to the JSON property tagSnippets



26661
26662
26663
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26661

def tag_snippets
  @tag_snippets
end

#third_party_app_analytics_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionThirdPartyAppAnalyticsSettings

Settings related to a third party app analytics conversion action. Corresponds to the JSON property thirdPartyAppAnalyticsSettings



26666
26667
26668
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26666

def third_party_app_analytics_settings
  @third_party_app_analytics_settings
end

#typeString

Immutable. The type of this conversion action. Corresponds to the JSON property type

Returns:

  • (String)


26671
26672
26673
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26671

def type
  @type
end

#value_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionValueSettings

Settings related to the value for conversion events associated with this conversion action. Corresponds to the JSON property valueSettings



26677
26678
26679
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26677

def value_settings
  @value_settings
end

#view_through_lookback_window_daysFixnum

The maximum number of days which may elapse between an impression and a conversion without an interaction. Corresponds to the JSON property viewThroughLookbackWindowDays

Returns:

  • (Fixnum)


26683
26684
26685
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26683

def view_through_lookback_window_days
  @view_through_lookback_window_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26690
26691
26692
26693
26694
26695
26696
26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
26708
26709
26710
26711
26712
26713
26714
26715
26716
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26690

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @attribution_model_settings = args[:attribution_model_settings] if args.key?(:attribution_model_settings)
  @category = args[:category] if args.key?(:category)
  @click_through_lookback_window_days = args[:click_through_lookback_window_days] if args.key?(:click_through_lookback_window_days)
  @counting_type = args[:counting_type] if args.key?(:counting_type)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @firebase_settings = args[:firebase_settings] if args.key?(:firebase_settings)
  @floodlight_settings = args[:floodlight_settings] if args.key?(:floodlight_settings)
  @google_analytics4_settings = args[:google_analytics4_settings] if args.key?(:google_analytics4_settings)
  @id = args[:id] if args.key?(:id)
  @include_in_client_account_conversions_metric = args[:include_in_client_account_conversions_metric] if args.key?(:include_in_client_account_conversions_metric)
  @include_in_conversions_metric = args[:include_in_conversions_metric] if args.key?(:include_in_conversions_metric)
  @mobile_app_vendor = args[:mobile_app_vendor] if args.key?(:mobile_app_vendor)
  @name = args[:name] if args.key?(:name)
  @origin = args[:origin] if args.key?(:origin)
  @owner_customer = args[:owner_customer] if args.key?(:owner_customer)
  @phone_call_duration_seconds = args[:phone_call_duration_seconds] if args.key?(:phone_call_duration_seconds)
  @primary_for_goal = args[:primary_for_goal] if args.key?(:primary_for_goal)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @tag_snippets = args[:tag_snippets] if args.key?(:tag_snippets)
  @third_party_app_analytics_settings = args[:third_party_app_analytics_settings] if args.key?(:third_party_app_analytics_settings)
  @type = args[:type] if args.key?(:type)
  @value_settings = args[:value_settings] if args.key?(:value_settings)
  @view_through_lookback_window_days = args[:view_through_lookback_window_days] if args.key?(:view_through_lookback_window_days)
end