Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A conversion action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionAction

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionAction.



26598
26599
26600
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26598

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

App ID for an app conversion action. Corresponds to the JSON property appId

Returns:

  • (String)


26455
26456
26457
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26455

def app_id
  @app_id
end

#attribution_model_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionAttributionModelSettings

Settings related to this conversion action's attribution model. Corresponds to the JSON property attributionModelSettings



26460
26461
26462
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26460

def attribution_model_settings
  @attribution_model_settings
end

#categoryString

The category of conversions reported for this conversion action. Corresponds to the JSON property category

Returns:

  • (String)


26465
26466
26467
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26465

def category
  @category
end

#click_through_lookback_window_daysFixnum

The maximum number of days that may elapse between an interaction (for example, a click) and a conversion event. Corresponds to the JSON property clickThroughLookbackWindowDays

Returns:

  • (Fixnum)


26471
26472
26473
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26471

def click_through_lookback_window_days
  @click_through_lookback_window_days
end

#counting_typeString

How to count conversion events for the conversion action. Corresponds to the JSON property countingType

Returns:

  • (String)


26476
26477
26478
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26476

def counting_type
  @counting_type
end

#creation_timeString

Output only. Timestamp of the Floodlight activity's creation, formatted in ISO 8601. Corresponds to the JSON property creationTime

Returns:

  • (String)


26482
26483
26484
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26482

def creation_time
  @creation_time
end

#firebase_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionFirebaseSettings

Settings related to a Firebase conversion action. Corresponds to the JSON property firebaseSettings



26487
26488
26489
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26487

def firebase_settings
  @firebase_settings
end

#floodlight_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionFloodlightSettings

Settings related to a Floodlight conversion action. Corresponds to the JSON property floodlightSettings



26492
26493
26494
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26492

def floodlight_settings
  @floodlight_settings
end

#google_analytics4_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionGoogleAnalytics4Settings

Settings related to a Google Analytics 4 conversion action. Corresponds to the JSON property googleAnalytics4Settings



26497
26498
26499
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26497

def google_analytics4_settings
  @google_analytics4_settings
end

#idFixnum

Output only. The ID of the conversion action. Corresponds to the JSON property id

Returns:

  • (Fixnum)


26502
26503
26504
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26502

def id
  @id
end

#include_in_client_account_conversions_metricBoolean Also known as: include_in_client_account_conversions_metric?

Whether this conversion action should be included in the " client_account_conversions" metric. Corresponds to the JSON property includeInClientAccountConversionsMetric

Returns:

  • (Boolean)


26508
26509
26510
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26508

def 
  @include_in_client_account_conversions_metric
end

#include_in_conversions_metricBoolean Also known as: include_in_conversions_metric?

Output only. Whether this conversion action should be included in the " conversions" metric. Corresponds to the JSON property includeInConversionsMetric

Returns:

  • (Boolean)


26515
26516
26517
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26515

def include_in_conversions_metric
  @include_in_conversions_metric
end

#mobile_app_vendorString

Output only. Mobile app vendor for an app conversion action. Corresponds to the JSON property mobileAppVendor

Returns:

  • (String)


26521
26522
26523
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26521

def mobile_app_vendor
  @mobile_app_vendor
end

#nameString

The name of the conversion action. This field is required and should not be empty when creating new conversion actions. Corresponds to the JSON property name

Returns:

  • (String)


26527
26528
26529
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26527

def name
  @name
end

#originString

Output only. The conversion origin of this conversion action. Corresponds to the JSON property origin

Returns:

  • (String)


26532
26533
26534
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26532

def origin
  @origin
end

#owner_customerString

Output only. The resource name of the conversion action owner customer, or null if this is a system-defined conversion action. Corresponds to the JSON property ownerCustomer

Returns:

  • (String)


26538
26539
26540
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26538

def owner_customer
  @owner_customer
end

#phone_call_duration_secondsFixnum

The phone call duration in seconds after which a conversion should be reported for this conversion action. The value must be between 0 and 10000, inclusive. Corresponds to the JSON property phoneCallDurationSeconds

Returns:

  • (Fixnum)


26544
26545
26546
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26544

def phone_call_duration_seconds
  @phone_call_duration_seconds
end

#primary_for_goalBoolean Also known as: primary_for_goal?

If a conversion action's primary_for_goal bit is false, the conversion action is non-biddable for all campaigns regardless of their customer conversion goal or campaign conversion goal. However, custom conversion goals do not respect primary_for_goal, so if a campaign has a custom conversion goal configured with a primary_for_goal = false conversion action, that conversion action is still biddable. By default, primary_for_goal will be true if not set. In V9, primary_for_goal can only be set to false after creation through an 'update' operation because it's not declared as optional. Corresponds to the JSON property primaryForGoal

Returns:

  • (Boolean)


26556
26557
26558
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26556

def primary_for_goal
  @primary_for_goal
end

#resource_nameString

Immutable. The resource name of the conversion action. Conversion action resource names have the form: customers/customer_id/conversionActions/ conversion_action_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


26564
26565
26566
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26564

def resource_name
  @resource_name
end

#statusString

The status of this conversion action for conversion event accrual. Corresponds to the JSON property status

Returns:

  • (String)


26569
26570
26571
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26569

def status
  @status
end

#tag_snippetsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTagSnippet>

Output only. The snippets used for tracking conversions. Corresponds to the JSON property tagSnippets



26574
26575
26576
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26574

def tag_snippets
  @tag_snippets
end

#third_party_app_analytics_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionThirdPartyAppAnalyticsSettings

Settings related to a third party app analytics conversion action. Corresponds to the JSON property thirdPartyAppAnalyticsSettings



26579
26580
26581
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26579

def third_party_app_analytics_settings
  @third_party_app_analytics_settings
end

#typeString

Immutable. The type of this conversion action. Corresponds to the JSON property type

Returns:

  • (String)


26584
26585
26586
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26584

def type
  @type
end

#value_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionValueSettings

Settings related to the value for conversion events associated with this conversion action. Corresponds to the JSON property valueSettings



26590
26591
26592
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26590

def value_settings
  @value_settings
end

#view_through_lookback_window_daysFixnum

The maximum number of days which may elapse between an impression and a conversion without an interaction. Corresponds to the JSON property viewThroughLookbackWindowDays

Returns:

  • (Fixnum)


26596
26597
26598
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26596

def view_through_lookback_window_days
  @view_through_lookback_window_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26603
26604
26605
26606
26607
26608
26609
26610
26611
26612
26613
26614
26615
26616
26617
26618
26619
26620
26621
26622
26623
26624
26625
26626
26627
26628
26629
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26603

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @attribution_model_settings = args[:attribution_model_settings] if args.key?(:attribution_model_settings)
  @category = args[:category] if args.key?(:category)
  @click_through_lookback_window_days = args[:click_through_lookback_window_days] if args.key?(:click_through_lookback_window_days)
  @counting_type = args[:counting_type] if args.key?(:counting_type)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @firebase_settings = args[:firebase_settings] if args.key?(:firebase_settings)
  @floodlight_settings = args[:floodlight_settings] if args.key?(:floodlight_settings)
  @google_analytics4_settings = args[:google_analytics4_settings] if args.key?(:google_analytics4_settings)
  @id = args[:id] if args.key?(:id)
  @include_in_client_account_conversions_metric = args[:include_in_client_account_conversions_metric] if args.key?(:include_in_client_account_conversions_metric)
  @include_in_conversions_metric = args[:include_in_conversions_metric] if args.key?(:include_in_conversions_metric)
  @mobile_app_vendor = args[:mobile_app_vendor] if args.key?(:mobile_app_vendor)
  @name = args[:name] if args.key?(:name)
  @origin = args[:origin] if args.key?(:origin)
  @owner_customer = args[:owner_customer] if args.key?(:owner_customer)
  @phone_call_duration_seconds = args[:phone_call_duration_seconds] if args.key?(:phone_call_duration_seconds)
  @primary_for_goal = args[:primary_for_goal] if args.key?(:primary_for_goal)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @tag_snippets = args[:tag_snippets] if args.key?(:tag_snippets)
  @third_party_app_analytics_settings = args[:third_party_app_analytics_settings] if args.key?(:third_party_app_analytics_settings)
  @type = args[:type] if args.key?(:type)
  @value_settings = args[:value_settings] if args.key?(:value_settings)
  @view_through_lookback_window_days = args[:view_through_lookback_window_days] if args.key?(:view_through_lookback_window_days)
end