Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionValueSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Settings related to the value for conversion events associated with this conversion action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionActionValueSettings

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionActionValueSettings.



16415
16416
16417
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16415

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#always_use_default_valueBoolean Also known as: always_use_default_value?

Controls whether the default value and default currency code are used in place of the value and currency code specified in conversion events for this conversion action. Corresponds to the JSON property alwaysUseDefaultValue

Returns:

  • (Boolean)


16398
16399
16400
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16398

def always_use_default_value
  @always_use_default_value
end

#default_currency_codeString

The currency code to use when conversion events for this conversion action are sent with an invalid or missing currency code, or when this conversion action is configured to always use the default value. Corresponds to the JSON property defaultCurrencyCode

Returns:

  • (String)


16406
16407
16408
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16406

def default_currency_code
  @default_currency_code
end

#default_valueFloat

The value to use when conversion events for this conversion action are sent with an invalid, disallowed or missing value, or when this conversion action is configured to always use the default value. Corresponds to the JSON property defaultValue

Returns:

  • (Float)


16413
16414
16415
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16413

def default_value
  @default_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16420
16421
16422
16423
16424
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16420

def update!(**args)
  @always_use_default_value = args[:always_use_default_value] if args.key?(:always_use_default_value)
  @default_currency_code = args[:default_currency_code] if args.key?(:default_currency_code)
  @default_value = args[:default_value] if args.key?(:default_value)
end