Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionActionValueSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Settings related to the value for conversion events associated with this conversion action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionActionValueSettings

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionActionValueSettings.



16349
16350
16351
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#always_use_default_valueBoolean Also known as: always_use_default_value?

Controls whether the default value and default currency code are used in place of the value and currency code specified in conversion events for this conversion action. Corresponds to the JSON property alwaysUseDefaultValue

Returns:

  • (Boolean)


16332
16333
16334
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16332

def always_use_default_value
  @always_use_default_value
end

#default_currency_codeString

The currency code to use when conversion events for this conversion action are sent with an invalid or missing currency code, or when this conversion action is configured to always use the default value. Corresponds to the JSON property defaultCurrencyCode

Returns:

  • (String)


16340
16341
16342
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16340

def default_currency_code
  @default_currency_code
end

#default_valueFloat

The value to use when conversion events for this conversion action are sent with an invalid, disallowed or missing value, or when this conversion action is configured to always use the default value. Corresponds to the JSON property defaultValue

Returns:

  • (Float)


16347
16348
16349
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16347

def default_value
  @default_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16354
16355
16356
16357
16358
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16354

def update!(**args)
  @always_use_default_value = args[:always_use_default_value] if args.key?(:always_use_default_value)
  @default_currency_code = args[:default_currency_code] if args.key?(:default_currency_code)
  @default_value = args[:default_value] if args.key?(:default_value)
end