Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionCustomVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A conversion custom variable. See "About custom Floodlight metrics and dimensions in the new Search Ads 360" at https://support.google.com/sa360/ answer/13567857

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionCustomVariable

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionCustomVariable.



26696
26697
26698
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26696

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

Output only. Cardinality of the conversion custom variable. Corresponds to the JSON property cardinality

Returns:

  • (String)


26641
26642
26643
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26641

def cardinality
  @cardinality
end

#custom_column_idsArray<Fixnum>

Output only. The IDs of custom columns that use this conversion custom variable. Corresponds to the JSON property customColumnIds

Returns:

  • (Array<Fixnum>)


26647
26648
26649
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26647

def custom_column_ids
  @custom_column_ids
end

#familyString

Output only. Family of the conversion custom variable. Corresponds to the JSON property family

Returns:

  • (String)


26652
26653
26654
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26652

def family
  @family
end

#floodlight_conversion_custom_variable_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionCustomVariableFloodlightConversionCustomVariableInfo

Information for Search Ads 360 Floodlight Conversion Custom Variables. Corresponds to the JSON property floodlightConversionCustomVariableInfo



26657
26658
26659
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26657

def floodlight_conversion_custom_variable_info
  @floodlight_conversion_custom_variable_info
end

#idFixnum

Output only. The ID of the conversion custom variable. Corresponds to the JSON property id

Returns:

  • (Fixnum)


26662
26663
26664
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26662

def id
  @id
end

#nameString

Required. The name of the conversion custom variable. Name should be unique. The maximum length of name is 100 characters. There should not be any extra spaces before and after. Corresponds to the JSON property name

Returns:

  • (String)


26669
26670
26671
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26669

def name
  @name
end

#owner_customerString

Output only. The resource name of the customer that owns the conversion custom variable. Corresponds to the JSON property ownerCustomer

Returns:

  • (String)


26675
26676
26677
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26675

def owner_customer
  @owner_customer
end

#resource_nameString

Immutable. The resource name of the conversion custom variable. Conversion custom variable resource names have the form: customers/customer_id/ conversionCustomVariables/conversion_custom_variable_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


26682
26683
26684
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26682

def resource_name
  @resource_name
end

#statusString

The status of the conversion custom variable for conversion event accrual. Corresponds to the JSON property status

Returns:

  • (String)


26687
26688
26689
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26687

def status
  @status
end

#tagString

Required. Immutable. The tag of the conversion custom variable. Tag should be unique and consist of a "u" character directly followed with a number less than ormequal to 100. For example: "u4". Corresponds to the JSON property tag

Returns:

  • (String)


26694
26695
26696
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26694

def tag
  @tag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26701
26702
26703
26704
26705
26706
26707
26708
26709
26710
26711
26712
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26701

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @custom_column_ids = args[:custom_column_ids] if args.key?(:custom_column_ids)
  @family = args[:family] if args.key?(:family)
  @floodlight_conversion_custom_variable_info = args[:floodlight_conversion_custom_variable_info] if args.key?(:floodlight_conversion_custom_variable_info)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @owner_customer = args[:owner_customer] if args.key?(:owner_customer)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @tag = args[:tag] if args.key?(:tag)
end