Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionGoalCampaignConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Conversion goal settings for a Campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionGoalCampaignConfig

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionGoalCampaignConfig.



26840
26841
26842
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaignString

Immutable. The campaign with which this conversion goal campaign config is associated. Corresponds to the JSON property campaign

Returns:

  • (String)


26810
26811
26812
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26810

def campaign
  @campaign
end

#custom_conversion_goalString

The custom conversion goal the campaign is using for optimization. Corresponds to the JSON property customConversionGoal

Returns:

  • (String)


26815
26816
26817
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26815

def custom_conversion_goal
  @custom_conversion_goal
end

#goal_config_levelString

The level of goal config the campaign is using. Corresponds to the JSON property goalConfigLevel

Returns:

  • (String)


26820
26821
26822
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26820

def goal_config_level
  @goal_config_level
end

#resource_nameString

Immutable. The resource name of the conversion goal campaign config. Conversion goal campaign config resource names have the form: customers/ customer_id/conversionGoalCampaignConfigs/campaign_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


26827
26828
26829
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26827

def resource_name
  @resource_name
end

#search_ads360_custom_conversion_goalString

The Search Ads 360 custom conversion goal the campaign is using for optimization. Corresponds to the JSON property searchAds360CustomConversionGoal

Returns:

  • (String)


26833
26834
26835
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26833

def search_ads360_custom_conversion_goal
  @search_ads360_custom_conversion_goal
end

#search_ads360_goal_config_levelString

The level of Search Ads 360 goal config the campaign is using. Corresponds to the JSON property searchAds360GoalConfigLevel

Returns:

  • (String)


26838
26839
26840
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26838

def search_ads360_goal_config_level
  @search_ads360_goal_config_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26845
26846
26847
26848
26849
26850
26851
26852
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26845

def update!(**args)
  @campaign = args[:campaign] if args.key?(:campaign)
  @custom_conversion_goal = args[:custom_conversion_goal] if args.key?(:custom_conversion_goal)
  @goal_config_level = args[:goal_config_level] if args.key?(:goal_config_level)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @search_ads360_custom_conversion_goal = args[:search_ads360_custom_conversion_goal] if args.key?(:search_ads360_custom_conversion_goal)
  @search_ads360_goal_config_level = args[:search_ads360_goal_config_level] if args.key?(:search_ads360_goal_config_level)
end