Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionGoalCampaignConfig
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionGoalCampaignConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Conversion goal settings for a Campaign.
Instance Attribute Summary collapse
-
#campaign ⇒ String
Immutable.
-
#custom_conversion_goal ⇒ String
The custom conversion goal the campaign is using for optimization.
-
#goal_config_level ⇒ String
The level of goal config the campaign is using.
-
#resource_name ⇒ String
Immutable.
-
#search_ads360_custom_conversion_goal ⇒ String
The Search Ads 360 custom conversion goal the campaign is using for optimization.
-
#search_ads360_goal_config_level ⇒ String
The level of Search Ads 360 goal config the campaign is using.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionGoalCampaignConfig
constructor
A new instance of GoogleAdsSearchads360V23ResourcesConversionGoalCampaignConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionGoalCampaignConfig
Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionGoalCampaignConfig.
26753 26754 26755 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26753 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign ⇒ String
Immutable. The campaign with which this conversion goal campaign config is
associated.
Corresponds to the JSON property campaign
26723 26724 26725 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26723 def campaign @campaign end |
#custom_conversion_goal ⇒ String
The custom conversion goal the campaign is using for optimization.
Corresponds to the JSON property customConversionGoal
26728 26729 26730 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26728 def custom_conversion_goal @custom_conversion_goal end |
#goal_config_level ⇒ String
The level of goal config the campaign is using.
Corresponds to the JSON property goalConfigLevel
26733 26734 26735 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26733 def goal_config_level @goal_config_level end |
#resource_name ⇒ String
Immutable. The resource name of the conversion goal campaign config.
Conversion goal campaign config resource names have the form: customers/
customer_id/conversionGoalCampaignConfigs/campaign_id`
Corresponds to the JSON propertyresourceName`
26740 26741 26742 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26740 def resource_name @resource_name end |
#search_ads360_custom_conversion_goal ⇒ String
The Search Ads 360 custom conversion goal the campaign is using for
optimization.
Corresponds to the JSON property searchAds360CustomConversionGoal
26746 26747 26748 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26746 def search_ads360_custom_conversion_goal @search_ads360_custom_conversion_goal end |
#search_ads360_goal_config_level ⇒ String
The level of Search Ads 360 goal config the campaign is using.
Corresponds to the JSON property searchAds360GoalConfigLevel
26751 26752 26753 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26751 def search_ads360_goal_config_level @search_ads360_goal_config_level end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26758 26759 26760 26761 26762 26763 26764 26765 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26758 def update!(**args) @campaign = args[:campaign] if args.key?(:campaign) @custom_conversion_goal = args[:custom_conversion_goal] if args.key?(:custom_conversion_goal) @goal_config_level = args[:goal_config_level] if args.key?(:goal_config_level) @resource_name = args[:resource_name] if args.key?(:resource_name) @search_ads360_custom_conversion_goal = args[:search_ads360_custom_conversion_goal] if args.key?(:search_ads360_custom_conversion_goal) @search_ads360_goal_config_level = args[:search_ads360_goal_config_level] if args.key?(:search_ads360_goal_config_level) end |