Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionTrackingSetting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionTrackingSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A collection of customer-wide settings related to Search Ads 360 Conversion Tracking.
Instance Attribute Summary collapse
-
#accepted_customer_data_terms ⇒ Boolean
(also: #accepted_customer_data_terms?)
Output only.
-
#conversion_tracking_id ⇒ Fixnum
Output only.
-
#conversion_tracking_status ⇒ String
Output only.
-
#cross_account_conversion_tracking_id ⇒ Fixnum
Output only.
-
#enhanced_conversions_for_leads_enabled ⇒ Boolean
(also: #enhanced_conversions_for_leads_enabled?)
Output only.
-
#google_ads_conversion_customer ⇒ String
The resource name of the customer where conversions are created and managed.
-
#google_ads_cross_account_conversion_tracking_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionTrackingSetting
constructor
A new instance of GoogleAdsSearchads360V23ResourcesConversionTrackingSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionTrackingSetting
Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionTrackingSetting.
26985 26986 26987 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accepted_customer_data_terms ⇒ Boolean Also known as: accepted_customer_data_terms?
Output only. Whether the customer has accepted customer data terms. If using
cross-account conversion tracking, this value is inherited from the manager.
This field is read-only. For more information, see https://support.google.com/
adspolicy/answer/7475709.
Corresponds to the JSON property acceptedCustomerDataTerms
26938 26939 26940 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26938 def accepted_customer_data_terms @accepted_customer_data_terms end |
#conversion_tracking_id ⇒ Fixnum
Output only. The conversion tracking id used for this account. This id doesn't
indicate whether the customer uses conversion tracking (
conversion_tracking_status does). This field is read-only.
Corresponds to the JSON property conversionTrackingId
26946 26947 26948 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26946 def conversion_tracking_id @conversion_tracking_id end |
#conversion_tracking_status ⇒ String
Output only. Conversion tracking status. It indicates whether the customer is
using conversion tracking, and who is the conversion tracking owner of this
customer. If this customer is using cross-account conversion tracking, the
value returned will differ based on the login-customer-id of the request.
Corresponds to the JSON property conversionTrackingStatus
26954 26955 26956 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26954 def conversion_tracking_status @conversion_tracking_status end |
#cross_account_conversion_tracking_id ⇒ Fixnum
Output only. The conversion tracking id of the customer's manager. This is set
when the customer is opted into cross-account conversion tracking, and it
overrides conversion_tracking_id.
Corresponds to the JSON property crossAccountConversionTrackingId
26961 26962 26963 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26961 def cross_account_conversion_tracking_id @cross_account_conversion_tracking_id end |
#enhanced_conversions_for_leads_enabled ⇒ Boolean Also known as: enhanced_conversions_for_leads_enabled?
Output only. Whether the customer is opted-in for enhanced conversions for
leads. If using cross-account conversion tracking, this value is inherited
from the manager. This field is read-only.
Corresponds to the JSON property enhancedConversionsForLeadsEnabled
26968 26969 26970 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26968 def enhanced_conversions_for_leads_enabled @enhanced_conversions_for_leads_enabled end |
#google_ads_conversion_customer ⇒ String
The resource name of the customer where conversions are created and managed.
This field is read-only.
Corresponds to the JSON property googleAdsConversionCustomer
26975 26976 26977 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26975 def google_ads_conversion_customer @google_ads_conversion_customer end |
#google_ads_cross_account_conversion_tracking_id ⇒ Fixnum
Output only. The conversion tracking id of the customer's manager. This is set
when the customer is opted into conversion tracking, and it overrides
conversion_tracking_id. This field can only be managed through the Google Ads
UI. This field is read-only.
Corresponds to the JSON property googleAdsCrossAccountConversionTrackingId
26983 26984 26985 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26983 def google_ads_cross_account_conversion_tracking_id @google_ads_cross_account_conversion_tracking_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26990 26991 26992 26993 26994 26995 26996 26997 26998 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26990 def update!(**args) @accepted_customer_data_terms = args[:accepted_customer_data_terms] if args.key?(:accepted_customer_data_terms) @conversion_tracking_id = args[:conversion_tracking_id] if args.key?(:conversion_tracking_id) @conversion_tracking_status = args[:conversion_tracking_status] if args.key?(:conversion_tracking_status) @cross_account_conversion_tracking_id = args[:cross_account_conversion_tracking_id] if args.key?(:cross_account_conversion_tracking_id) @enhanced_conversions_for_leads_enabled = args[:enhanced_conversions_for_leads_enabled] if args.key?(:enhanced_conversions_for_leads_enabled) @google_ads_conversion_customer = args[:google_ads_conversion_customer] if args.key?(:google_ads_conversion_customer) @google_ads_cross_account_conversion_tracking_id = args[:google_ads_cross_account_conversion_tracking_id] if args.key?(:google_ads_cross_account_conversion_tracking_id) end |