Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionTrackingSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A collection of customer-wide settings related to Search Ads 360 Conversion Tracking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionTrackingSetting

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionTrackingSetting.



26913
26914
26915
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26913

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accepted_customer_data_termsBoolean Also known as: accepted_customer_data_terms?

Output only. Whether the customer has accepted customer data terms. If using cross-account conversion tracking, this value is inherited from the manager. This field is read-only. For more information, see https://support.google.com/ adspolicy/answer/7475709. Corresponds to the JSON property acceptedCustomerDataTerms

Returns:

  • (Boolean)


26866
26867
26868
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26866

def accepted_customer_data_terms
  @accepted_customer_data_terms
end

#conversion_tracking_idFixnum

Output only. The conversion tracking id used for this account. This id doesn't indicate whether the customer uses conversion tracking ( conversion_tracking_status does). This field is read-only. Corresponds to the JSON property conversionTrackingId

Returns:

  • (Fixnum)


26874
26875
26876
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26874

def conversion_tracking_id
  @conversion_tracking_id
end

#conversion_tracking_statusString

Output only. Conversion tracking status. It indicates whether the customer is using conversion tracking, and who is the conversion tracking owner of this customer. If this customer is using cross-account conversion tracking, the value returned will differ based on the login-customer-id of the request. Corresponds to the JSON property conversionTrackingStatus

Returns:

  • (String)


26882
26883
26884
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26882

def conversion_tracking_status
  @conversion_tracking_status
end

#cross_account_conversion_tracking_idFixnum

Output only. The conversion tracking id of the customer's manager. This is set when the customer is opted into cross-account conversion tracking, and it overrides conversion_tracking_id. Corresponds to the JSON property crossAccountConversionTrackingId

Returns:

  • (Fixnum)


26889
26890
26891
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26889

def 
  @cross_account_conversion_tracking_id
end

#enhanced_conversions_for_leads_enabledBoolean Also known as: enhanced_conversions_for_leads_enabled?

Output only. Whether the customer is opted-in for enhanced conversions for leads. If using cross-account conversion tracking, this value is inherited from the manager. This field is read-only. Corresponds to the JSON property enhancedConversionsForLeadsEnabled

Returns:

  • (Boolean)


26896
26897
26898
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26896

def enhanced_conversions_for_leads_enabled
  @enhanced_conversions_for_leads_enabled
end

The resource name of the customer where conversions are created and managed. This field is read-only. Corresponds to the JSON property googleAdsConversionCustomer

Returns:

  • (String)


26903
26904
26905
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26903

def google_ads_conversion_customer
  @google_ads_conversion_customer
end

Output only. The conversion tracking id of the customer's manager. This is set when the customer is opted into conversion tracking, and it overrides conversion_tracking_id. This field can only be managed through the Google Ads UI. This field is read-only. Corresponds to the JSON property googleAdsCrossAccountConversionTrackingId

Returns:

  • (Fixnum)


26911
26912
26913
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26911

def 
  @google_ads_cross_account_conversion_tracking_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26918
26919
26920
26921
26922
26923
26924
26925
26926
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26918

def update!(**args)
  @accepted_customer_data_terms = args[:accepted_customer_data_terms] if args.key?(:accepted_customer_data_terms)
  @conversion_tracking_id = args[:conversion_tracking_id] if args.key?(:conversion_tracking_id)
  @conversion_tracking_status = args[:conversion_tracking_status] if args.key?(:conversion_tracking_status)
  @cross_account_conversion_tracking_id = args[:cross_account_conversion_tracking_id] if args.key?(:cross_account_conversion_tracking_id)
  @enhanced_conversions_for_leads_enabled = args[:enhanced_conversions_for_leads_enabled] if args.key?(:enhanced_conversions_for_leads_enabled)
  @google_ads_conversion_customer = args[:google_ads_conversion_customer] if args.key?(:google_ads_conversion_customer)
  @google_ads_cross_account_conversion_tracking_id = args[:google_ads_cross_account_conversion_tracking_id] if args.key?(:google_ads_cross_account_conversion_tracking_id)
end