Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRule
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A conversion value rule
Instance Attribute Summary collapse
-
#action ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleAction
Action applied when rule is applied.
-
#audience_condition ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleAudienceCondition
Condition on Audience dimension.
-
#device_condition ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleDeviceCondition
Condition on Device dimension.
-
#geo_location_condition ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleGeoLocationCondition
Condition on Geo dimension.
-
#id ⇒ Fixnum
Output only.
-
#itinerary_condition ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryCondition
Condition on Itinerary dimension.
-
#owner_customer ⇒ String
Output only.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
The status of the conversion value rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionValueRule
constructor
A new instance of GoogleAdsSearchads360V23ResourcesConversionValueRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionValueRule
Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionValueRule.
27055 27056 27057 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleAction
Action applied when rule is applied.
Corresponds to the JSON property action
27008 27009 27010 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27008 def action @action end |
#audience_condition ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleAudienceCondition
Condition on Audience dimension.
Corresponds to the JSON property audienceCondition
27013 27014 27015 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27013 def audience_condition @audience_condition end |
#device_condition ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleDeviceCondition
Condition on Device dimension.
Corresponds to the JSON property deviceCondition
27018 27019 27020 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27018 def device_condition @device_condition end |
#geo_location_condition ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleGeoLocationCondition
Condition on Geo dimension.
Corresponds to the JSON property geoLocationCondition
27023 27024 27025 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27023 def geo_location_condition @geo_location_condition end |
#id ⇒ Fixnum
Output only. The ID of the conversion value rule.
Corresponds to the JSON property id
27028 27029 27030 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27028 def id @id end |
#itinerary_condition ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryCondition
Condition on Itinerary dimension.
Corresponds to the JSON property itineraryCondition
27033 27034 27035 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27033 def itinerary_condition @itinerary_condition end |
#owner_customer ⇒ String
Output only. The resource name of the conversion value rule's owner customer.
When the value rule is inherited from a manager customer, owner_customer will
be the resource name of the manager whereas the customer in the resource_name
will be of the requesting serving customer. ** Read-only **
Corresponds to the JSON property ownerCustomer
27041 27042 27043 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27041 def owner_customer @owner_customer end |
#resource_name ⇒ String
Immutable. The resource name of the conversion value rule. Conversion value
rule resource names have the form: customers/customer_id/
conversionValueRules/conversion_value_rule_id`
Corresponds to the JSON propertyresourceName`
27048 27049 27050 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27048 def resource_name @resource_name end |
#status ⇒ String
The status of the conversion value rule.
Corresponds to the JSON property status
27053 27054 27055 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27053 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27060 27061 27062 27063 27064 27065 27066 27067 27068 27069 27070 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27060 def update!(**args) @action = args[:action] if args.key?(:action) @audience_condition = args[:audience_condition] if args.key?(:audience_condition) @device_condition = args[:device_condition] if args.key?(:device_condition) @geo_location_condition = args[:geo_location_condition] if args.key?(:geo_location_condition) @id = args[:id] if args.key?(:id) @itinerary_condition = args[:itinerary_condition] if args.key?(:itinerary_condition) @owner_customer = args[:owner_customer] if args.key?(:owner_customer) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |