Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A conversion value rule

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionValueRule

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionValueRule.



26983
26984
26985
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26983

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleAction

Action applied when rule is applied. Corresponds to the JSON property action



26936
26937
26938
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26936

def action
  @action
end

#audience_conditionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleAudienceCondition

Condition on Audience dimension. Corresponds to the JSON property audienceCondition



26941
26942
26943
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26941

def audience_condition
  @audience_condition
end

#device_conditionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleDeviceCondition

Condition on Device dimension. Corresponds to the JSON property deviceCondition



26946
26947
26948
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26946

def device_condition
  @device_condition
end

#geo_location_conditionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleGeoLocationCondition

Condition on Geo dimension. Corresponds to the JSON property geoLocationCondition



26951
26952
26953
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26951

def geo_location_condition
  @geo_location_condition
end

#idFixnum

Output only. The ID of the conversion value rule. Corresponds to the JSON property id

Returns:

  • (Fixnum)


26956
26957
26958
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26956

def id
  @id
end

#itinerary_conditionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryCondition

Condition on Itinerary dimension. Corresponds to the JSON property itineraryCondition



26961
26962
26963
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26961

def itinerary_condition
  @itinerary_condition
end

#owner_customerString

Output only. The resource name of the conversion value rule's owner customer. When the value rule is inherited from a manager customer, owner_customer will be the resource name of the manager whereas the customer in the resource_name will be of the requesting serving customer. ** Read-only ** Corresponds to the JSON property ownerCustomer

Returns:

  • (String)


26969
26970
26971
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26969

def owner_customer
  @owner_customer
end

#resource_nameString

Immutable. The resource name of the conversion value rule. Conversion value rule resource names have the form: customers/customer_id/ conversionValueRules/conversion_value_rule_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


26976
26977
26978
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26976

def resource_name
  @resource_name
end

#statusString

The status of the conversion value rule. Corresponds to the JSON property status

Returns:

  • (String)


26981
26982
26983
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26981

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26988
26989
26990
26991
26992
26993
26994
26995
26996
26997
26998
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26988

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @audience_condition = args[:audience_condition] if args.key?(:audience_condition)
  @device_condition = args[:device_condition] if args.key?(:device_condition)
  @geo_location_condition = args[:geo_location_condition] if args.key?(:geo_location_condition)
  @id = args[:id] if args.key?(:id)
  @itinerary_condition = args[:itinerary_condition] if args.key?(:itinerary_condition)
  @owner_customer = args[:owner_customer] if args.key?(:owner_customer)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end