Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A conversion value rule

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionValueRule

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionValueRule.



26896
26897
26898
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleAction

Action applied when rule is applied. Corresponds to the JSON property action



26849
26850
26851
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26849

def action
  @action
end

#audience_conditionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleAudienceCondition

Condition on Audience dimension. Corresponds to the JSON property audienceCondition



26854
26855
26856
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26854

def audience_condition
  @audience_condition
end

#device_conditionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleDeviceCondition

Condition on Device dimension. Corresponds to the JSON property deviceCondition



26859
26860
26861
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26859

def device_condition
  @device_condition
end

#geo_location_conditionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleGeoLocationCondition

Condition on Geo dimension. Corresponds to the JSON property geoLocationCondition



26864
26865
26866
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26864

def geo_location_condition
  @geo_location_condition
end

#idFixnum

Output only. The ID of the conversion value rule. Corresponds to the JSON property id

Returns:

  • (Fixnum)


26869
26870
26871
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26869

def id
  @id
end

#itinerary_conditionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryCondition

Condition on Itinerary dimension. Corresponds to the JSON property itineraryCondition



26874
26875
26876
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26874

def itinerary_condition
  @itinerary_condition
end

#owner_customerString

Output only. The resource name of the conversion value rule's owner customer. When the value rule is inherited from a manager customer, owner_customer will be the resource name of the manager whereas the customer in the resource_name will be of the requesting serving customer. ** Read-only ** Corresponds to the JSON property ownerCustomer

Returns:

  • (String)


26882
26883
26884
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26882

def owner_customer
  @owner_customer
end

#resource_nameString

Immutable. The resource name of the conversion value rule. Conversion value rule resource names have the form: customers/customer_id/ conversionValueRules/conversion_value_rule_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


26889
26890
26891
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26889

def resource_name
  @resource_name
end

#statusString

The status of the conversion value rule. Corresponds to the JSON property status

Returns:

  • (String)


26894
26895
26896
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26894

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26901
26902
26903
26904
26905
26906
26907
26908
26909
26910
26911
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26901

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @audience_condition = args[:audience_condition] if args.key?(:audience_condition)
  @device_condition = args[:device_condition] if args.key?(:device_condition)
  @geo_location_condition = args[:geo_location_condition] if args.key?(:geo_location_condition)
  @id = args[:id] if args.key?(:id)
  @itinerary_condition = args[:itinerary_condition] if args.key?(:itinerary_condition)
  @owner_customer = args[:owner_customer] if args.key?(:owner_customer)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end