Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleSet
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A conversion value rule set is a collection of conversion value rules that
lets you adjust conversion values based on the dimensions specified in the
dimensions field.
Instance Attribute Summary collapse
-
#attachment_type ⇒ String
Immutable.
-
#campaign ⇒ String
The resource name of the campaign when the conversion value rule set is attached to a campaign.
-
#conversion_action_categories ⇒ Array<String>
Immutable.
-
#conversion_value_rules ⇒ Array<String>
Resource names of rules within the rule set.
-
#dimensions ⇒ Array<String>
Defines dimensions for Value Rule conditions.
-
#id ⇒ Fixnum
Output only.
-
#owner_customer ⇒ String
Output only.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionValueRuleSet
constructor
A new instance of GoogleAdsSearchads360V23ResourcesConversionValueRuleSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionValueRuleSet
Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionValueRuleSet.
27064 27065 27066 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27064 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_type ⇒ String
Immutable. Defines the scope where the conversion value rule set is attached.
Corresponds to the JSON property attachmentType
27010 27011 27012 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27010 def @attachment_type end |
#campaign ⇒ String
The resource name of the campaign when the conversion value rule set is
attached to a campaign.
Corresponds to the JSON property campaign
27016 27017 27018 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27016 def campaign @campaign end |
#conversion_action_categories ⇒ Array<String>
Immutable. The conversion action categories of the conversion value rule set.
Corresponds to the JSON property conversionActionCategories
27021 27022 27023 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27021 def conversion_action_categories @conversion_action_categories end |
#conversion_value_rules ⇒ Array<String>
Resource names of rules within the rule set.
Corresponds to the JSON property conversionValueRules
27026 27027 27028 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27026 def conversion_value_rules @conversion_value_rules end |
#dimensions ⇒ Array<String>
Defines dimensions for Value Rule conditions. The condition types of value
rules within this value rule set must be of these dimensions. The first entry
in this list is the primary dimension of the included value rules. When using
value rule primary dimension segmentation, conversion values will be segmented
into the values adjusted by value rules and the original values, if some value
rules apply.
Corresponds to the JSON property dimensions
27036 27037 27038 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27036 def dimensions @dimensions end |
#id ⇒ Fixnum
Output only. The ID of the conversion value rule set.
Corresponds to the JSON property id
27041 27042 27043 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27041 def id @id end |
#owner_customer ⇒ String
Output only. The resource name of the conversion value rule set's owner
customer. When the value rule set is inherited from a manager customer,
owner_customer will be the resource name of the manager whereas the customer
in the resource_name will be of the requesting serving customer. ** Read-only *
*
Corresponds to the JSON property ownerCustomer
27050 27051 27052 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27050 def owner_customer @owner_customer end |
#resource_name ⇒ String
Immutable. The resource name of the conversion value rule set. Conversion
value rule set resource names have the form: customers/customer_id/
conversionValueRuleSets/conversion_value_rule_set_id`
Corresponds to the JSON propertyresourceName`
27057 27058 27059 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27057 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the conversion value rule set. ** Read-only **
Corresponds to the JSON property status
27062 27063 27064 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27062 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27069 27070 27071 27072 27073 27074 27075 27076 27077 27078 27079 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27069 def update!(**args) @attachment_type = args[:attachment_type] if args.key?(:attachment_type) @campaign = args[:campaign] if args.key?(:campaign) @conversion_action_categories = args[:conversion_action_categories] if args.key?(:conversion_action_categories) @conversion_value_rules = args[:conversion_value_rules] if args.key?(:conversion_value_rules) @dimensions = args[:dimensions] if args.key?(:dimensions) @id = args[:id] if args.key?(:id) @owner_customer = args[:owner_customer] if args.key?(:owner_customer) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |