Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A conversion value rule set is a collection of conversion value rules that lets you adjust conversion values based on the dimensions specified in the dimensions field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionValueRuleSet

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionValueRuleSet.



26977
26978
26979
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26977

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_typeString

Immutable. Defines the scope where the conversion value rule set is attached. Corresponds to the JSON property attachmentType

Returns:

  • (String)


26923
26924
26925
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26923

def attachment_type
  @attachment_type
end

#campaignString

The resource name of the campaign when the conversion value rule set is attached to a campaign. Corresponds to the JSON property campaign

Returns:

  • (String)


26929
26930
26931
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26929

def campaign
  @campaign
end

#conversion_action_categoriesArray<String>

Immutable. The conversion action categories of the conversion value rule set. Corresponds to the JSON property conversionActionCategories

Returns:

  • (Array<String>)


26934
26935
26936
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26934

def conversion_action_categories
  @conversion_action_categories
end

#conversion_value_rulesArray<String>

Resource names of rules within the rule set. Corresponds to the JSON property conversionValueRules

Returns:

  • (Array<String>)


26939
26940
26941
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26939

def conversion_value_rules
  @conversion_value_rules
end

#dimensionsArray<String>

Defines dimensions for Value Rule conditions. The condition types of value rules within this value rule set must be of these dimensions. The first entry in this list is the primary dimension of the included value rules. When using value rule primary dimension segmentation, conversion values will be segmented into the values adjusted by value rules and the original values, if some value rules apply. Corresponds to the JSON property dimensions

Returns:

  • (Array<String>)


26949
26950
26951
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26949

def dimensions
  @dimensions
end

#idFixnum

Output only. The ID of the conversion value rule set. Corresponds to the JSON property id

Returns:

  • (Fixnum)


26954
26955
26956
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26954

def id
  @id
end

#owner_customerString

Output only. The resource name of the conversion value rule set's owner customer. When the value rule set is inherited from a manager customer, owner_customer will be the resource name of the manager whereas the customer in the resource_name will be of the requesting serving customer. ** Read-only * * Corresponds to the JSON property ownerCustomer

Returns:

  • (String)


26963
26964
26965
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26963

def owner_customer
  @owner_customer
end

#resource_nameString

Immutable. The resource name of the conversion value rule set. Conversion value rule set resource names have the form: customers/customer_id/ conversionValueRuleSets/conversion_value_rule_set_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


26970
26971
26972
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26970

def resource_name
  @resource_name
end

#statusString

Output only. The status of the conversion value rule set. ** Read-only ** Corresponds to the JSON property status

Returns:

  • (String)


26975
26976
26977
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26975

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26982
26983
26984
26985
26986
26987
26988
26989
26990
26991
26992
# File 'lib/google/apis/searchads360_v23/classes.rb', line 26982

def update!(**args)
  @attachment_type = args[:attachment_type] if args.key?(:attachment_type)
  @campaign = args[:campaign] if args.key?(:campaign)
  @conversion_action_categories = args[:conversion_action_categories] if args.key?(:conversion_action_categories)
  @conversion_value_rules = args[:conversion_value_rules] if args.key?(:conversion_value_rules)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @id = args[:id] if args.key?(:id)
  @owner_customer = args[:owner_customer] if args.key?(:owner_customer)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end