Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryAdvanceBookingWindow
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryAdvanceBookingWindow
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Range for the number of days between the date of the booking and the start of the itinerary.
Instance Attribute Summary collapse
-
#max_days ⇒ Fixnum
Maximum number of days between the date of the booking the start date.
-
#min_days ⇒ Fixnum
Minimum number of days between the date of the booking the start date.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryAdvanceBookingWindow
constructor
A new instance of GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryAdvanceBookingWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryAdvanceBookingWindow
Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryAdvanceBookingWindow.
16507 16508 16509 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16507 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_days ⇒ Fixnum
Maximum number of days between the date of the booking the start date.
Corresponds to the JSON property maxDays
16500 16501 16502 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16500 def max_days @max_days end |
#min_days ⇒ Fixnum
Minimum number of days between the date of the booking the start date.
Corresponds to the JSON property minDays
16505 16506 16507 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16505 def min_days @min_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16512 16513 16514 16515 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16512 def update!(**args) @max_days = args[:max_days] if args.key?(:max_days) @min_days = args[:min_days] if args.key?(:min_days) end |