Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryCondition
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Condition on Itinerary dimension.
Instance Attribute Summary collapse
-
#advance_booking_window ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryAdvanceBookingWindow
Range for the number of days between the date of the booking and the start of the itinerary.
-
#travel_length ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryTravelLength
Range for the itinerary length in number of nights.
-
#travel_start_day ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryTravelStartDay
The days of the week on which an itinerary's travel can start.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryCondition
constructor
A new instance of GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryCondition
Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryCondition.
16538 16539 16540 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16538 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advance_booking_window ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryAdvanceBookingWindow
Range for the number of days between the date of the booking and the start of
the itinerary.
Corresponds to the JSON property advanceBookingWindow
16526 16527 16528 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16526 def advance_booking_window @advance_booking_window end |
#travel_length ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryTravelLength
Range for the itinerary length in number of nights.
Corresponds to the JSON property travelLength
16531 16532 16533 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16531 def travel_length @travel_length end |
#travel_start_day ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryTravelStartDay
The days of the week on which an itinerary's travel can start.
Corresponds to the JSON property travelStartDay
16536 16537 16538 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16536 def travel_start_day @travel_start_day end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16543 16544 16545 16546 16547 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16543 def update!(**args) @advance_booking_window = args[:advance_booking_window] if args.key?(:advance_booking_window) @travel_length = args[:travel_length] if args.key?(:travel_length) @travel_start_day = args[:travel_start_day] if args.key?(:travel_start_day) end |