Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryTravelLength

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Range for the itinerary length in number of nights.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryTravelLength

Returns a new instance of GoogleAdsSearchads360V23ResourcesConversionValueRuleValueRuleItineraryTravelLength.



16564
16565
16566
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16564

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_nightsFixnum

Maximum number of days between the start date and the end date. Corresponds to the JSON property maxNights

Returns:

  • (Fixnum)


16557
16558
16559
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16557

def max_nights
  @max_nights
end

#min_nightsFixnum

Minimum number of nights between the start date and the end date. Corresponds to the JSON property minNights

Returns:

  • (Fixnum)


16562
16563
16564
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16562

def min_nights
  @min_nights
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16569
16570
16571
16572
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16569

def update!(**args)
  @max_nights = args[:max_nights] if args.key?(:max_nights)
  @min_nights = args[:min_nights] if args.key?(:min_nights)
end