Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudience

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A custom audience. This is a list of users by interest. The unique key of a custom audience consists of the following fields: name. Violating the unique key constraint produces error: CustomAudienceError.NAME_ALREADY_USED

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomAudience

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomAudience.



27203
27204
27205
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description of this custom audience. Corresponds to the JSON property description

Returns:

  • (String)


27164
27165
27166
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27164

def description
  @description
end

#idFixnum

Output only. ID of the custom audience. Corresponds to the JSON property id

Returns:

  • (Fixnum)


27169
27170
27171
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27169

def id
  @id
end

#membersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudienceMember>

List of custom audience members that this custom audience is composed of. Members can be added during CustomAudience creation. If members are presented in UPDATE operation, existing members will be overridden. Corresponds to the JSON property members



27176
27177
27178
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27176

def members
  @members
end

#nameString

Name of the custom audience. It should be unique for all custom audiences created by a customer. This field is required for creating operations. Corresponds to the JSON property name

Returns:

  • (String)


27182
27183
27184
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27182

def name
  @name
end

#resource_nameString

Immutable. The resource name of the custom audience. Custom audience resource names have the form: customers/customer_id/customAudiences/ custom_audience_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


27189
27190
27191
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27189

def resource_name
  @resource_name
end

#statusString

Output only. Status of this custom audience. Indicates whether the custom audience is enabled or removed. Corresponds to the JSON property status

Returns:

  • (String)


27195
27196
27197
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27195

def status
  @status
end

#typeString

Type of the custom audience. ("INTEREST" OR "PURCHASE_INTENT" is not allowed for newly created custom audience but kept for existing audiences) Corresponds to the JSON property type

Returns:

  • (String)


27201
27202
27203
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27201

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27208
27209
27210
27211
27212
27213
27214
27215
27216
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27208

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @members = args[:members] if args.key?(:members)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end