Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudience
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudience
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A custom audience. This is a list of users by interest. The unique key of a custom audience consists of the following fields: name. Violating the unique key constraint produces error: CustomAudienceError.NAME_ALREADY_USED
Instance Attribute Summary collapse
-
#description ⇒ String
Description of this custom audience.
-
#id ⇒ Fixnum
Output only.
-
#members ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudienceMember>
List of custom audience members that this custom audience is composed of.
-
#name ⇒ String
Name of the custom audience.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#type ⇒ String
Type of the custom audience.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomAudience
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomAudience.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomAudience
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomAudience.
27116 27117 27118 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27116 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Description of this custom audience.
Corresponds to the JSON property description
27077 27078 27079 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27077 def description @description end |
#id ⇒ Fixnum
Output only. ID of the custom audience.
Corresponds to the JSON property id
27082 27083 27084 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27082 def id @id end |
#members ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudienceMember>
List of custom audience members that this custom audience is composed of.
Members can be added during CustomAudience creation. If members are presented
in UPDATE operation, existing members will be overridden.
Corresponds to the JSON property members
27089 27090 27091 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27089 def members @members end |
#name ⇒ String
Name of the custom audience. It should be unique for all custom audiences
created by a customer. This field is required for creating operations.
Corresponds to the JSON property name
27095 27096 27097 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27095 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the custom audience. Custom audience resource
names have the form: customers/customer_id/customAudiences/
custom_audience_id`
Corresponds to the JSON propertyresourceName`
27102 27103 27104 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27102 def resource_name @resource_name end |
#status ⇒ String
Output only. Status of this custom audience. Indicates whether the custom
audience is enabled or removed.
Corresponds to the JSON property status
27108 27109 27110 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27108 def status @status end |
#type ⇒ String
Type of the custom audience. ("INTEREST" OR "PURCHASE_INTENT" is not allowed
for newly created custom audience but kept for existing audiences)
Corresponds to the JSON property type
27114 27115 27116 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27114 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27121 27122 27123 27124 27125 27126 27127 27128 27129 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27121 def update!(**args) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @members = args[:members] if args.key?(:members) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) end |