Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudienceMember
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudienceMember
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A member of custom audience. A member can be a KEYWORD, URL, PLACE_CATEGORY or APP. It can only be created or removed but not changed.
Instance Attribute Summary collapse
-
#app ⇒ String
A package name of Android apps which users installed such as com.google.
-
#keyword ⇒ String
A keyword or keyword phrase — at most 10 words and 80 characters.
-
#member_type ⇒ String
The type of custom audience member, KEYWORD, URL, PLACE_CATEGORY or APP.
-
#place_category ⇒ Fixnum
A place type described by a place category users visit.
-
#url ⇒ String
An HTTP URL, protocol-included — at most 2048 characters, which includes contents users have interests in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomAudienceMember
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomAudienceMember.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomAudienceMember
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomAudienceMember.
27325 27326 27327 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app ⇒ String
A package name of Android apps which users installed such as com.google.
example.
Corresponds to the JSON property app
27300 27301 27302 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27300 def app @app end |
#keyword ⇒ String
A keyword or keyword phrase — at most 10 words and 80 characters. Languages
with double-width characters such as Chinese, Japanese, or Korean, are allowed
40 characters, which describes the user's interests or actions.
Corresponds to the JSON property keyword
27307 27308 27309 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27307 def keyword @keyword end |
#member_type ⇒ String
The type of custom audience member, KEYWORD, URL, PLACE_CATEGORY or APP.
Corresponds to the JSON property memberType
27312 27313 27314 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27312 def member_type @member_type end |
#place_category ⇒ Fixnum
A place type described by a place category users visit.
Corresponds to the JSON property placeCategory
27317 27318 27319 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27317 def place_category @place_category end |
#url ⇒ String
An HTTP URL, protocol-included — at most 2048 characters, which includes
contents users have interests in.
Corresponds to the JSON property url
27323 27324 27325 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27323 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27330 27331 27332 27333 27334 27335 27336 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27330 def update!(**args) @app = args[:app] if args.key?(:app) @keyword = args[:keyword] if args.key?(:keyword) @member_type = args[:member_type] if args.key?(:member_type) @place_category = args[:place_category] if args.key?(:place_category) @url = args[:url] if args.key?(:url) end |