Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudienceMember
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudienceMember
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A member of custom audience. A member can be a KEYWORD, URL, PLACE_CATEGORY or APP. It can only be created or removed but not changed.
Instance Attribute Summary collapse
-
#app ⇒ String
A package name of Android apps which users installed such as com.google.
-
#keyword ⇒ String
A keyword or keyword phrase — at most 10 words and 80 characters.
-
#member_type ⇒ String
The type of custom audience member, KEYWORD, URL, PLACE_CATEGORY or APP.
-
#place_category ⇒ Fixnum
A place type described by a place category users visit.
-
#url ⇒ String
An HTTP URL, protocol-included — at most 2048 characters, which includes contents users have interests in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomAudienceMember
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomAudienceMember.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomAudienceMember
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomAudienceMember.
27166 27167 27168 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27166 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app ⇒ String
A package name of Android apps which users installed such as com.google.
example.
Corresponds to the JSON property app
27141 27142 27143 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27141 def app @app end |
#keyword ⇒ String
A keyword or keyword phrase — at most 10 words and 80 characters. Languages
with double-width characters such as Chinese, Japanese, or Korean, are allowed
40 characters, which describes the user's interests or actions.
Corresponds to the JSON property keyword
27148 27149 27150 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27148 def keyword @keyword end |
#member_type ⇒ String
The type of custom audience member, KEYWORD, URL, PLACE_CATEGORY or APP.
Corresponds to the JSON property memberType
27153 27154 27155 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27153 def member_type @member_type end |
#place_category ⇒ Fixnum
A place type described by a place category users visit.
Corresponds to the JSON property placeCategory
27158 27159 27160 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27158 def place_category @place_category end |
#url ⇒ String
An HTTP URL, protocol-included — at most 2048 characters, which includes
contents users have interests in.
Corresponds to the JSON property url
27164 27165 27166 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27164 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27171 27172 27173 27174 27175 27176 27177 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27171 def update!(**args) @app = args[:app] if args.key?(:app) @keyword = args[:keyword] if args.key?(:keyword) @member_type = args[:member_type] if args.key?(:member_type) @place_category = args[:place_category] if args.key?(:place_category) @url = args[:url] if args.key?(:url) end |