Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomConversionGoal
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomConversionGoal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Custom conversion goal that can make arbitrary conversion actions biddable.
Instance Attribute Summary collapse
-
#conversion_actions ⇒ Array<String>
Conversion actions that the custom conversion goal makes biddable.
-
#id ⇒ Fixnum
Immutable.
-
#name ⇒ String
The name for this custom conversion goal.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
The status of the custom conversion goal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomConversionGoal
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomConversionGoal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomConversionGoal
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomConversionGoal.
27380 27381 27382 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27380 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_actions ⇒ Array<String>
Conversion actions that the custom conversion goal makes biddable.
Corresponds to the JSON property conversionActions
27356 27357 27358 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27356 def conversion_actions @conversion_actions end |
#id ⇒ Fixnum
Immutable. The ID for this custom conversion goal.
Corresponds to the JSON property id
27361 27362 27363 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27361 def id @id end |
#name ⇒ String
The name for this custom conversion goal.
Corresponds to the JSON property name
27366 27367 27368 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27366 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the custom conversion goal. Custom conversion
goal resource names have the form: customers/customer_id/
customConversionGoals/goal_id`
Corresponds to the JSON propertyresourceName`
27373 27374 27375 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27373 def resource_name @resource_name end |
#status ⇒ String
The status of the custom conversion goal.
Corresponds to the JSON property status
27378 27379 27380 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27378 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27385 27386 27387 27388 27389 27390 27391 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27385 def update!(**args) @conversion_actions = args[:conversion_actions] if args.key?(:conversion_actions) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |