Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomConversionGoal
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomConversionGoal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Custom conversion goal that can make arbitrary conversion actions biddable.
Instance Attribute Summary collapse
-
#conversion_actions ⇒ Array<String>
Conversion actions that the custom conversion goal makes biddable.
-
#id ⇒ Fixnum
Immutable.
-
#name ⇒ String
The name for this custom conversion goal.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
The status of the custom conversion goal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomConversionGoal
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomConversionGoal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomConversionGoal
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomConversionGoal.
27293 27294 27295 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27293 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_actions ⇒ Array<String>
Conversion actions that the custom conversion goal makes biddable.
Corresponds to the JSON property conversionActions
27269 27270 27271 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27269 def conversion_actions @conversion_actions end |
#id ⇒ Fixnum
Immutable. The ID for this custom conversion goal.
Corresponds to the JSON property id
27274 27275 27276 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27274 def id @id end |
#name ⇒ String
The name for this custom conversion goal.
Corresponds to the JSON property name
27279 27280 27281 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27279 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the custom conversion goal. Custom conversion
goal resource names have the form: customers/customer_id/
customConversionGoals/goal_id`
Corresponds to the JSON propertyresourceName`
27286 27287 27288 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27286 def resource_name @resource_name end |
#status ⇒ String
The status of the custom conversion goal.
Corresponds to the JSON property status
27291 27292 27293 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27291 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27298 27299 27300 27301 27302 27303 27304 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27298 def update!(**args) @conversion_actions = args[:conversion_actions] if args.key?(:conversion_actions) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |