Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomInterest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomInterest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A custom interest. This is a list of users by interest.
Instance Attribute Summary collapse
-
#description ⇒ String
Description of this custom interest audience.
-
#id ⇒ Fixnum
Output only.
-
#members ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomInterestMember>
List of custom interest members that this custom interest is composed of.
-
#name ⇒ String
Name of the custom interest.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Status of this custom interest.
-
#type ⇒ String
Type of the custom interest, CUSTOM_AFFINITY or CUSTOM_INTENT.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomInterest
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomInterest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomInterest
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomInterest.
27512 27513 27514 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27512 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Description of this custom interest audience.
Corresponds to the JSON property description
27473 27474 27475 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27473 def description @description end |
#id ⇒ Fixnum
Output only. Id of the custom interest.
Corresponds to the JSON property id
27478 27479 27480 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27478 def id @id end |
#members ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomInterestMember>
List of custom interest members that this custom interest is composed of.
Members can be added during CustomInterest creation. If members are presented
in UPDATE operation, existing members will be overridden.
Corresponds to the JSON property members
27485 27486 27487 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27485 def members @members end |
#name ⇒ String
Name of the custom interest. It should be unique across the same custom
affinity audience. This field is required for create operations.
Corresponds to the JSON property name
27491 27492 27493 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27491 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the custom interest. Custom interest resource
names have the form: customers/customer_id/customInterests/
custom_interest_id`
Corresponds to the JSON propertyresourceName`
27498 27499 27500 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27498 def resource_name @resource_name end |
#status ⇒ String
Status of this custom interest. Indicates whether the custom interest is
enabled or removed.
Corresponds to the JSON property status
27504 27505 27506 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27504 def status @status end |
#type ⇒ String
Type of the custom interest, CUSTOM_AFFINITY or CUSTOM_INTENT. By default the
type is set to CUSTOM_AFFINITY.
Corresponds to the JSON property type
27510 27511 27512 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27510 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27517 27518 27519 27520 27521 27522 27523 27524 27525 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27517 def update!(**args) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @members = args[:members] if args.key?(:members) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) end |