Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomInterest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A custom interest. This is a list of users by interest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomInterest

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomInterest.



27440
27441
27442
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description of this custom interest audience. Corresponds to the JSON property description

Returns:

  • (String)


27401
27402
27403
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27401

def description
  @description
end

#idFixnum

Output only. Id of the custom interest. Corresponds to the JSON property id

Returns:

  • (Fixnum)


27406
27407
27408
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27406

def id
  @id
end

#membersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomInterestMember>

List of custom interest members that this custom interest is composed of. Members can be added during CustomInterest creation. If members are presented in UPDATE operation, existing members will be overridden. Corresponds to the JSON property members



27413
27414
27415
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27413

def members
  @members
end

#nameString

Name of the custom interest. It should be unique across the same custom affinity audience. This field is required for create operations. Corresponds to the JSON property name

Returns:

  • (String)


27419
27420
27421
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27419

def name
  @name
end

#resource_nameString

Immutable. The resource name of the custom interest. Custom interest resource names have the form: customers/customer_id/customInterests/ custom_interest_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


27426
27427
27428
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27426

def resource_name
  @resource_name
end

#statusString

Status of this custom interest. Indicates whether the custom interest is enabled or removed. Corresponds to the JSON property status

Returns:

  • (String)


27432
27433
27434
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27432

def status
  @status
end

#typeString

Type of the custom interest, CUSTOM_AFFINITY or CUSTOM_INTENT. By default the type is set to CUSTOM_AFFINITY. Corresponds to the JSON property type

Returns:

  • (String)


27438
27439
27440
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27438

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27445
27446
27447
27448
27449
27450
27451
27452
27453
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27445

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @members = args[:members] if args.key?(:members)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end