Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomer
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A customer.
Instance Attribute Summary collapse
-
#account_level ⇒ String
Output only.
-
#account_status ⇒ String
Output only.
-
#account_type ⇒ String
Output only.
-
#associate_manager_descriptive_name ⇒ String
Output only.
-
#associate_manager_id ⇒ Fixnum
Output only.
-
#auto_tagging_enabled ⇒ Boolean
(also: #auto_tagging_enabled?)
Whether auto-tagging is enabled for the customer.
-
#call_reporting_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCallReportingSetting
Call reporting setting for a customer.
-
#contains_eu_political_advertising ⇒ String
Output only.
-
#conversion_tracking_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionTrackingSetting
A collection of customer-wide settings related to Search Ads 360 Conversion Tracking.
-
#creation_time ⇒ String
Output only.
-
#currency_code ⇒ String
Immutable.
-
#customer_agreement_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAgreementSetting
Customer Agreement Setting for a customer.
-
#descriptive_name ⇒ String
Optional, non-unique descriptive name of the customer.
-
#double_click_campaign_manager_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting
DoubleClick Campaign Manager (DCM) setting for a manager customer.
-
#engine_id ⇒ String
Output only.
-
#final_url_suffix ⇒ String
The URL template for appending params to the final URL.
-
#has_partners_badge ⇒ Boolean
(also: #has_partners_badge?)
Output only.
-
#id ⇒ Fixnum
Output only.
-
#image_asset_auto_migration_done ⇒ Boolean
(also: #image_asset_auto_migration_done?)
Output only.
-
#image_asset_auto_migration_done_date_time ⇒ String
Output only.
-
#last_modified_time ⇒ String
Output only.
-
#local_services_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLocalServicesSettings
Settings for Local Services customer.
-
#location_asset_auto_migration_done ⇒ Boolean
(also: #location_asset_auto_migration_done?)
Output only.
-
#location_asset_auto_migration_done_date_time ⇒ String
Output only.
-
#manager ⇒ Boolean
(also: #manager?)
Output only.
-
#manager_descriptive_name ⇒ String
Output only.
-
#manager_id ⇒ Fixnum
Output only.
-
#optimization_score ⇒ Float
Output only.
-
#optimization_score_weight ⇒ Float
Output only.
-
#pay_per_conversion_eligibility_failure_reasons ⇒ Array<String>
Output only.
-
#remarketing_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRemarketingSetting
Remarketing setting for a customer.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#sub_manager_descriptive_name ⇒ String
Output only.
-
#sub_manager_id ⇒ Fixnum
Output only.
-
#test_account ⇒ Boolean
(also: #test_account?)
Output only.
-
#time_zone ⇒ String
Immutable.
-
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL out of parameters.
-
#video_brand_safety_suitability ⇒ String
Brand Safety setting at the account level.
-
#video_customer ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesVideoCustomer
Video specific information about a Customer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomer
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomer
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomer.
27823 27824 27825 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27823 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_level ⇒ String
Output only. The account level of the customer: Manager, Sub-manager,
Associate manager, Service account.
Corresponds to the JSON property accountLevel
27589 27590 27591 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27589 def account_level @account_level end |
#account_status ⇒ String
Output only. Account status, for example, Enabled, Paused, Removed, etc.
Corresponds to the JSON property accountStatus
27594 27595 27596 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27594 def account_status @account_status end |
#account_type ⇒ String
Output only. Engine account type, for example, Google Ads, Microsoft
Advertising, Yahoo Japan, Baidu, Facebook, Engine Track, etc.
Corresponds to the JSON property accountType
27600 27601 27602 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27600 def account_type @account_type end |
#associate_manager_descriptive_name ⇒ String
Output only. The descriptive name of the associate manager.
Corresponds to the JSON property associateManagerDescriptiveName
27605 27606 27607 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27605 def associate_manager_descriptive_name @associate_manager_descriptive_name end |
#associate_manager_id ⇒ Fixnum
Output only. The customer ID of the associate manager. A 0 value indicates
that the customer has no SA360 associate manager.
Corresponds to the JSON property associateManagerId
27611 27612 27613 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27611 def associate_manager_id @associate_manager_id end |
#auto_tagging_enabled ⇒ Boolean Also known as: auto_tagging_enabled?
Whether auto-tagging is enabled for the customer.
Corresponds to the JSON property autoTaggingEnabled
27616 27617 27618 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27616 def auto_tagging_enabled @auto_tagging_enabled end |
#call_reporting_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCallReportingSetting
Call reporting setting for a customer.
Corresponds to the JSON property callReportingSetting
27622 27623 27624 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27622 def call_reporting_setting @call_reporting_setting end |
#contains_eu_political_advertising ⇒ String
Output only. Returns the advertiser self-declaration status of whether this
customer contains political advertising content targeted towards the European
Union. You can use the Google Ads UI to update this account-level declaration,
or use the API to update the self-declaration status of individual campaigns.
Corresponds to the JSON property containsEuPoliticalAdvertising
27630 27631 27632 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27630 def contains_eu_political_advertising @contains_eu_political_advertising end |
#conversion_tracking_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionTrackingSetting
A collection of customer-wide settings related to Search Ads 360 Conversion
Tracking.
Corresponds to the JSON property conversionTrackingSetting
27636 27637 27638 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27636 def conversion_tracking_setting @conversion_tracking_setting end |
#creation_time ⇒ String
Output only. The timestamp when this customer was created. The timestamp is in
the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format.
Corresponds to the JSON property creationTime
27642 27643 27644 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27642 def creation_time @creation_time end |
#currency_code ⇒ String
Immutable. The currency in which the account operates. A subset of the
currency codes from the ISO 4217 standard is supported.
Corresponds to the JSON property currencyCode
27648 27649 27650 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27648 def currency_code @currency_code end |
#customer_agreement_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAgreementSetting
Customer Agreement Setting for a customer.
Corresponds to the JSON property customerAgreementSetting
27653 27654 27655 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27653 def customer_agreement_setting @customer_agreement_setting end |
#descriptive_name ⇒ String
Optional, non-unique descriptive name of the customer.
Corresponds to the JSON property descriptiveName
27658 27659 27660 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27658 def descriptive_name @descriptive_name end |
#double_click_campaign_manager_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting
DoubleClick Campaign Manager (DCM) setting for a manager customer.
Corresponds to the JSON property doubleClickCampaignManagerSetting
27663 27664 27665 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27663 def double_click_campaign_manager_setting @double_click_campaign_manager_setting end |
#engine_id ⇒ String
Output only. ID of the account in the external engine account.
Corresponds to the JSON property engineId
27668 27669 27670 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27668 def engine_id @engine_id end |
#final_url_suffix ⇒ String
The URL template for appending params to the final URL.
Corresponds to the JSON property finalUrlSuffix
27673 27674 27675 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27673 def final_url_suffix @final_url_suffix end |
#has_partners_badge ⇒ Boolean Also known as: has_partners_badge?
Output only. Whether the Customer has a Partners program badge. If the
Customer is not associated with the Partners program, this will be false. For
more information, see https://support.google.com/partners/answer/3125774.
Corresponds to the JSON property hasPartnersBadge
27680 27681 27682 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27680 def has_partners_badge @has_partners_badge end |
#id ⇒ Fixnum
Output only. The ID of the customer.
Corresponds to the JSON property id
27686 27687 27688 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27686 def id @id end |
#image_asset_auto_migration_done ⇒ Boolean Also known as: image_asset_auto_migration_done?
Output only. True if feed based image has been migrated to asset based image.
Corresponds to the JSON property imageAssetAutoMigrationDone
27691 27692 27693 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27691 def image_asset_auto_migration_done @image_asset_auto_migration_done end |
#image_asset_auto_migration_done_date_time ⇒ String
Output only. Timestamp of migration from feed based image to asset base image
in yyyy-MM-dd HH:mm:ss format.
Corresponds to the JSON property imageAssetAutoMigrationDoneDateTime
27698 27699 27700 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27698 def image_asset_auto_migration_done_date_time @image_asset_auto_migration_done_date_time end |
#last_modified_time ⇒ String
Output only. The datetime when this customer was last modified. The datetime
is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format.
Corresponds to the JSON property lastModifiedTime
27704 27705 27706 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27704 def last_modified_time @last_modified_time end |
#local_services_settings ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLocalServicesSettings
Settings for Local Services customer.
Corresponds to the JSON property localServicesSettings
27709 27710 27711 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27709 def local_services_settings @local_services_settings end |
#location_asset_auto_migration_done ⇒ Boolean Also known as: location_asset_auto_migration_done?
Output only. True if feed based location has been migrated to asset based
location.
Corresponds to the JSON property locationAssetAutoMigrationDone
27715 27716 27717 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27715 def location_asset_auto_migration_done @location_asset_auto_migration_done end |
#location_asset_auto_migration_done_date_time ⇒ String
Output only. Timestamp of migration from feed based location to asset base
location in yyyy-MM-dd HH:mm:ss format.
Corresponds to the JSON property locationAssetAutoMigrationDoneDateTime
27722 27723 27724 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27722 def location_asset_auto_migration_done_date_time @location_asset_auto_migration_done_date_time end |
#manager ⇒ Boolean Also known as: manager?
Output only. Whether the customer is a manager.
Corresponds to the JSON property manager
27727 27728 27729 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27727 def manager @manager end |
#manager_descriptive_name ⇒ String
Output only. The descriptive name of the manager.
Corresponds to the JSON property managerDescriptiveName
27733 27734 27735 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27733 def manager_descriptive_name @manager_descriptive_name end |
#manager_id ⇒ Fixnum
Output only. The customer ID of the manager. A 0 value indicates that the
customer has no SA360 manager.
Corresponds to the JSON property managerId
27739 27740 27741 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27739 def manager_id @manager_id end |
#optimization_score ⇒ Float
Output only. Optimization score of the customer. Optimization score is an
estimate of how well a customer's campaigns are set to perform. It ranges from
0% (0.0) to 100% (1.0). This field is null for all manager customers, and for
unscored non-manager customers. See "About optimization score" at https://
support.google.com/google-ads/answer/9061546. This field is read-only.
Corresponds to the JSON property optimizationScore
27748 27749 27750 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27748 def optimization_score @optimization_score end |
#optimization_score_weight ⇒ Float
Output only. Optimization score weight of the customer. Optimization score
weight can be used to compare/aggregate optimization scores across multiple
non-manager customers. The aggregate optimization score of a manager is
computed as the sum over all of their customers of Customer.
optimization_score * Customer.optimization_score_weight. This field is 0 for
all manager customers, and for unscored non-manager customers. This field is
read-only.
Corresponds to the JSON property optimizationScoreWeight
27759 27760 27761 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27759 def optimization_score_weight @optimization_score_weight end |
#pay_per_conversion_eligibility_failure_reasons ⇒ Array<String>
Output only. Reasons why the customer is not eligible to use PaymentMode.
CONVERSIONS. If the list is empty, the customer is eligible. This field is
read-only.
Corresponds to the JSON property payPerConversionEligibilityFailureReasons
27766 27767 27768 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27766 def pay_per_conversion_eligibility_failure_reasons @pay_per_conversion_eligibility_failure_reasons end |
#remarketing_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRemarketingSetting
Remarketing setting for a customer.
Corresponds to the JSON property remarketingSetting
27771 27772 27773 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27771 def remarketing_setting @remarketing_setting end |
#resource_name ⇒ String
Immutable. The resource name of the customer. Customer resource names have the
form: customers/customer_id`
Corresponds to the JSON propertyresourceName`
27777 27778 27779 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27777 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the customer.
Corresponds to the JSON property status
27782 27783 27784 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27782 def status @status end |
#sub_manager_descriptive_name ⇒ String
Output only. The descriptive name of the sub manager.
Corresponds to the JSON property subManagerDescriptiveName
27787 27788 27789 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27787 def sub_manager_descriptive_name @sub_manager_descriptive_name end |
#sub_manager_id ⇒ Fixnum
Output only. The customer ID of the sub manager. A 0 value indicates that the
customer has no sub SA360 manager.
Corresponds to the JSON property subManagerId
27793 27794 27795 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27793 def sub_manager_id @sub_manager_id end |
#test_account ⇒ Boolean Also known as: test_account?
Output only. Whether the customer is a test account.
Corresponds to the JSON property testAccount
27798 27799 27800 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27798 def test_account @test_account end |
#time_zone ⇒ String
Immutable. The local timezone ID of the customer.
Corresponds to the JSON property timeZone
27804 27805 27806 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27804 def time_zone @time_zone end |
#tracking_url_template ⇒ String
The URL template for constructing a tracking URL out of parameters.
Corresponds to the JSON property trackingUrlTemplate
27809 27810 27811 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27809 def tracking_url_template @tracking_url_template end |
#video_brand_safety_suitability ⇒ String
Brand Safety setting at the account level. Allows for selecting an inventory
type to show your ads on content that is the right fit for your brand. See
https://support.google.com/google-ads/answer/7515513.
Corresponds to the JSON property videoBrandSafetySuitability
27816 27817 27818 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27816 def video_brand_safety_suitability @video_brand_safety_suitability end |
#video_customer ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesVideoCustomer
Video specific information about a Customer.
Corresponds to the JSON property videoCustomer
27821 27822 27823 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27821 def video_customer @video_customer end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27828 27829 27830 27831 27832 27833 27834 27835 27836 27837 27838 27839 27840 27841 27842 27843 27844 27845 27846 27847 27848 27849 27850 27851 27852 27853 27854 27855 27856 27857 27858 27859 27860 27861 27862 27863 27864 27865 27866 27867 27868 27869 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27828 def update!(**args) @account_level = args[:account_level] if args.key?(:account_level) @account_status = args[:account_status] if args.key?(:account_status) @account_type = args[:account_type] if args.key?(:account_type) @associate_manager_descriptive_name = args[:associate_manager_descriptive_name] if args.key?(:associate_manager_descriptive_name) @associate_manager_id = args[:associate_manager_id] if args.key?(:associate_manager_id) @auto_tagging_enabled = args[:auto_tagging_enabled] if args.key?(:auto_tagging_enabled) @call_reporting_setting = args[:call_reporting_setting] if args.key?(:call_reporting_setting) @contains_eu_political_advertising = args[:contains_eu_political_advertising] if args.key?(:contains_eu_political_advertising) @conversion_tracking_setting = args[:conversion_tracking_setting] if args.key?(:conversion_tracking_setting) @creation_time = args[:creation_time] if args.key?(:creation_time) @currency_code = args[:currency_code] if args.key?(:currency_code) @customer_agreement_setting = args[:customer_agreement_setting] if args.key?(:customer_agreement_setting) @descriptive_name = args[:descriptive_name] if args.key?(:descriptive_name) @double_click_campaign_manager_setting = args[:double_click_campaign_manager_setting] if args.key?(:double_click_campaign_manager_setting) @engine_id = args[:engine_id] if args.key?(:engine_id) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @has_partners_badge = args[:has_partners_badge] if args.key?(:has_partners_badge) @id = args[:id] if args.key?(:id) @image_asset_auto_migration_done = args[:image_asset_auto_migration_done] if args.key?(:image_asset_auto_migration_done) @image_asset_auto_migration_done_date_time = args[:image_asset_auto_migration_done_date_time] if args.key?(:image_asset_auto_migration_done_date_time) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @local_services_settings = args[:local_services_settings] if args.key?(:local_services_settings) @location_asset_auto_migration_done = args[:location_asset_auto_migration_done] if args.key?(:location_asset_auto_migration_done) @location_asset_auto_migration_done_date_time = args[:location_asset_auto_migration_done_date_time] if args.key?(:location_asset_auto_migration_done_date_time) @manager = args[:manager] if args.key?(:manager) @manager_descriptive_name = args[:manager_descriptive_name] if args.key?(:manager_descriptive_name) @manager_id = args[:manager_id] if args.key?(:manager_id) @optimization_score = args[:optimization_score] if args.key?(:optimization_score) @optimization_score_weight = args[:optimization_score_weight] if args.key?(:optimization_score_weight) @pay_per_conversion_eligibility_failure_reasons = args[:pay_per_conversion_eligibility_failure_reasons] if args.key?(:pay_per_conversion_eligibility_failure_reasons) @remarketing_setting = args[:remarketing_setting] if args.key?(:remarketing_setting) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @sub_manager_descriptive_name = args[:sub_manager_descriptive_name] if args.key?(:sub_manager_descriptive_name) @sub_manager_id = args[:sub_manager_id] if args.key?(:sub_manager_id) @test_account = args[:test_account] if args.key?(:test_account) @time_zone = args[:time_zone] if args.key?(:time_zone) @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template) @video_brand_safety_suitability = args[:video_brand_safety_suitability] if args.key?(:video_brand_safety_suitability) @video_customer = args[:video_customer] if args.key?(:video_customer) end |