Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomer

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomer.



27751
27752
27753
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_levelString

Output only. The account level of the customer: Manager, Sub-manager, Associate manager, Service account. Corresponds to the JSON property accountLevel

Returns:

  • (String)


27517
27518
27519
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27517

def 
  @account_level
end

#account_statusString

Output only. Account status, for example, Enabled, Paused, Removed, etc. Corresponds to the JSON property accountStatus

Returns:

  • (String)


27522
27523
27524
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27522

def 
  @account_status
end

#account_typeString

Output only. Engine account type, for example, Google Ads, Microsoft Advertising, Yahoo Japan, Baidu, Facebook, Engine Track, etc. Corresponds to the JSON property accountType

Returns:

  • (String)


27528
27529
27530
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27528

def 
  @account_type
end

#associate_manager_descriptive_nameString

Output only. The descriptive name of the associate manager. Corresponds to the JSON property associateManagerDescriptiveName

Returns:

  • (String)


27533
27534
27535
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27533

def associate_manager_descriptive_name
  @associate_manager_descriptive_name
end

#associate_manager_idFixnum

Output only. The customer ID of the associate manager. A 0 value indicates that the customer has no SA360 associate manager. Corresponds to the JSON property associateManagerId

Returns:

  • (Fixnum)


27539
27540
27541
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27539

def associate_manager_id
  @associate_manager_id
end

#auto_tagging_enabledBoolean Also known as: auto_tagging_enabled?

Whether auto-tagging is enabled for the customer. Corresponds to the JSON property autoTaggingEnabled

Returns:

  • (Boolean)


27544
27545
27546
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27544

def auto_tagging_enabled
  @auto_tagging_enabled
end

#call_reporting_settingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCallReportingSetting

Call reporting setting for a customer. Corresponds to the JSON property callReportingSetting



27550
27551
27552
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27550

def call_reporting_setting
  @call_reporting_setting
end

#contains_eu_political_advertisingString

Output only. Returns the advertiser self-declaration status of whether this customer contains political advertising content targeted towards the European Union. You can use the Google Ads UI to update this account-level declaration, or use the API to update the self-declaration status of individual campaigns. Corresponds to the JSON property containsEuPoliticalAdvertising

Returns:

  • (String)


27558
27559
27560
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27558

def contains_eu_political_advertising
  @contains_eu_political_advertising
end

#conversion_tracking_settingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionTrackingSetting

A collection of customer-wide settings related to Search Ads 360 Conversion Tracking. Corresponds to the JSON property conversionTrackingSetting



27564
27565
27566
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27564

def conversion_tracking_setting
  @conversion_tracking_setting
end

#creation_timeString

Output only. The timestamp when this customer was created. The timestamp is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. Corresponds to the JSON property creationTime

Returns:

  • (String)


27570
27571
27572
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27570

def creation_time
  @creation_time
end

#currency_codeString

Immutable. The currency in which the account operates. A subset of the currency codes from the ISO 4217 standard is supported. Corresponds to the JSON property currencyCode

Returns:

  • (String)


27576
27577
27578
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27576

def currency_code
  @currency_code
end

#customer_agreement_settingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAgreementSetting

Customer Agreement Setting for a customer. Corresponds to the JSON property customerAgreementSetting



27581
27582
27583
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27581

def customer_agreement_setting
  @customer_agreement_setting
end

#descriptive_nameString

Optional, non-unique descriptive name of the customer. Corresponds to the JSON property descriptiveName

Returns:

  • (String)


27586
27587
27588
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27586

def descriptive_name
  @descriptive_name
end

#double_click_campaign_manager_settingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting

DoubleClick Campaign Manager (DCM) setting for a manager customer. Corresponds to the JSON property doubleClickCampaignManagerSetting



27591
27592
27593
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27591

def double_click_campaign_manager_setting
  @double_click_campaign_manager_setting
end

#engine_idString

Output only. ID of the account in the external engine account. Corresponds to the JSON property engineId

Returns:

  • (String)


27596
27597
27598
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27596

def engine_id
  @engine_id
end

#final_url_suffixString

The URL template for appending params to the final URL. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


27601
27602
27603
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27601

def final_url_suffix
  @final_url_suffix
end

#has_partners_badgeBoolean Also known as: has_partners_badge?

Output only. Whether the Customer has a Partners program badge. If the Customer is not associated with the Partners program, this will be false. For more information, see https://support.google.com/partners/answer/3125774. Corresponds to the JSON property hasPartnersBadge

Returns:

  • (Boolean)


27608
27609
27610
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27608

def has_partners_badge
  @has_partners_badge
end

#idFixnum

Output only. The ID of the customer. Corresponds to the JSON property id

Returns:

  • (Fixnum)


27614
27615
27616
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27614

def id
  @id
end

#image_asset_auto_migration_doneBoolean Also known as: image_asset_auto_migration_done?

Output only. True if feed based image has been migrated to asset based image. Corresponds to the JSON property imageAssetAutoMigrationDone

Returns:

  • (Boolean)


27619
27620
27621
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27619

def image_asset_auto_migration_done
  @image_asset_auto_migration_done
end

#image_asset_auto_migration_done_date_timeString

Output only. Timestamp of migration from feed based image to asset base image in yyyy-MM-dd HH:mm:ss format. Corresponds to the JSON property imageAssetAutoMigrationDoneDateTime

Returns:

  • (String)


27626
27627
27628
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27626

def image_asset_auto_migration_done_date_time
  @image_asset_auto_migration_done_date_time
end

#last_modified_timeString

Output only. The datetime when this customer was last modified. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


27632
27633
27634
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27632

def last_modified_time
  @last_modified_time
end

#local_services_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLocalServicesSettings

Settings for Local Services customer. Corresponds to the JSON property localServicesSettings



27637
27638
27639
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27637

def local_services_settings
  @local_services_settings
end

#location_asset_auto_migration_doneBoolean Also known as: location_asset_auto_migration_done?

Output only. True if feed based location has been migrated to asset based location. Corresponds to the JSON property locationAssetAutoMigrationDone

Returns:

  • (Boolean)


27643
27644
27645
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27643

def location_asset_auto_migration_done
  @location_asset_auto_migration_done
end

#location_asset_auto_migration_done_date_timeString

Output only. Timestamp of migration from feed based location to asset base location in yyyy-MM-dd HH:mm:ss format. Corresponds to the JSON property locationAssetAutoMigrationDoneDateTime

Returns:

  • (String)


27650
27651
27652
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27650

def location_asset_auto_migration_done_date_time
  @location_asset_auto_migration_done_date_time
end

#managerBoolean Also known as: manager?

Output only. Whether the customer is a manager. Corresponds to the JSON property manager

Returns:

  • (Boolean)


27655
27656
27657
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27655

def manager
  @manager
end

#manager_descriptive_nameString

Output only. The descriptive name of the manager. Corresponds to the JSON property managerDescriptiveName

Returns:

  • (String)


27661
27662
27663
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27661

def manager_descriptive_name
  @manager_descriptive_name
end

#manager_idFixnum

Output only. The customer ID of the manager. A 0 value indicates that the customer has no SA360 manager. Corresponds to the JSON property managerId

Returns:

  • (Fixnum)


27667
27668
27669
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27667

def manager_id
  @manager_id
end

#optimization_scoreFloat

Output only. Optimization score of the customer. Optimization score is an estimate of how well a customer's campaigns are set to perform. It ranges from 0% (0.0) to 100% (1.0). This field is null for all manager customers, and for unscored non-manager customers. See "About optimization score" at https:// support.google.com/google-ads/answer/9061546. This field is read-only. Corresponds to the JSON property optimizationScore

Returns:

  • (Float)


27676
27677
27678
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27676

def optimization_score
  @optimization_score
end

#optimization_score_weightFloat

Output only. Optimization score weight of the customer. Optimization score weight can be used to compare/aggregate optimization scores across multiple non-manager customers. The aggregate optimization score of a manager is computed as the sum over all of their customers of Customer. optimization_score * Customer.optimization_score_weight. This field is 0 for all manager customers, and for unscored non-manager customers. This field is read-only. Corresponds to the JSON property optimizationScoreWeight

Returns:

  • (Float)


27687
27688
27689
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27687

def optimization_score_weight
  @optimization_score_weight
end

#pay_per_conversion_eligibility_failure_reasonsArray<String>

Output only. Reasons why the customer is not eligible to use PaymentMode. CONVERSIONS. If the list is empty, the customer is eligible. This field is read-only. Corresponds to the JSON property payPerConversionEligibilityFailureReasons

Returns:

  • (Array<String>)


27694
27695
27696
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27694

def pay_per_conversion_eligibility_failure_reasons
  @pay_per_conversion_eligibility_failure_reasons
end

#remarketing_settingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRemarketingSetting

Remarketing setting for a customer. Corresponds to the JSON property remarketingSetting



27699
27700
27701
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27699

def remarketing_setting
  @remarketing_setting
end

#resource_nameString

Immutable. The resource name of the customer. Customer resource names have the form: customers/customer_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


27705
27706
27707
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27705

def resource_name
  @resource_name
end

#statusString

Output only. The status of the customer. Corresponds to the JSON property status

Returns:

  • (String)


27710
27711
27712
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27710

def status
  @status
end

#sub_manager_descriptive_nameString

Output only. The descriptive name of the sub manager. Corresponds to the JSON property subManagerDescriptiveName

Returns:

  • (String)


27715
27716
27717
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27715

def sub_manager_descriptive_name
  @sub_manager_descriptive_name
end

#sub_manager_idFixnum

Output only. The customer ID of the sub manager. A 0 value indicates that the customer has no sub SA360 manager. Corresponds to the JSON property subManagerId

Returns:

  • (Fixnum)


27721
27722
27723
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27721

def sub_manager_id
  @sub_manager_id
end

#test_accountBoolean Also known as: test_account?

Output only. Whether the customer is a test account. Corresponds to the JSON property testAccount

Returns:

  • (Boolean)


27726
27727
27728
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27726

def 
  @test_account
end

#time_zoneString

Immutable. The local timezone ID of the customer. Corresponds to the JSON property timeZone

Returns:

  • (String)


27732
27733
27734
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27732

def time_zone
  @time_zone
end

#tracking_url_templateString

The URL template for constructing a tracking URL out of parameters. Corresponds to the JSON property trackingUrlTemplate

Returns:

  • (String)


27737
27738
27739
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27737

def tracking_url_template
  @tracking_url_template
end

#video_brand_safety_suitabilityString

Brand Safety setting at the account level. Allows for selecting an inventory type to show your ads on content that is the right fit for your brand. See https://support.google.com/google-ads/answer/7515513. Corresponds to the JSON property videoBrandSafetySuitability

Returns:

  • (String)


27744
27745
27746
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27744

def video_brand_safety_suitability
  @video_brand_safety_suitability
end

#video_customerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesVideoCustomer

Video specific information about a Customer. Corresponds to the JSON property videoCustomer



27749
27750
27751
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27749

def video_customer
  @video_customer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27756
27757
27758
27759
27760
27761
27762
27763
27764
27765
27766
27767
27768
27769
27770
27771
27772
27773
27774
27775
27776
27777
27778
27779
27780
27781
27782
27783
27784
27785
27786
27787
27788
27789
27790
27791
27792
27793
27794
27795
27796
27797
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27756

def update!(**args)
  @account_level = args[:account_level] if args.key?(:account_level)
  @account_status = args[:account_status] if args.key?(:account_status)
  @account_type = args[:account_type] if args.key?(:account_type)
  @associate_manager_descriptive_name = args[:associate_manager_descriptive_name] if args.key?(:associate_manager_descriptive_name)
  @associate_manager_id = args[:associate_manager_id] if args.key?(:associate_manager_id)
  @auto_tagging_enabled = args[:auto_tagging_enabled] if args.key?(:auto_tagging_enabled)
  @call_reporting_setting = args[:call_reporting_setting] if args.key?(:call_reporting_setting)
  @contains_eu_political_advertising = args[:contains_eu_political_advertising] if args.key?(:contains_eu_political_advertising)
  @conversion_tracking_setting = args[:conversion_tracking_setting] if args.key?(:conversion_tracking_setting)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @customer_agreement_setting = args[:customer_agreement_setting] if args.key?(:customer_agreement_setting)
  @descriptive_name = args[:descriptive_name] if args.key?(:descriptive_name)
  @double_click_campaign_manager_setting = args[:double_click_campaign_manager_setting] if args.key?(:double_click_campaign_manager_setting)
  @engine_id = args[:engine_id] if args.key?(:engine_id)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @has_partners_badge = args[:has_partners_badge] if args.key?(:has_partners_badge)
  @id = args[:id] if args.key?(:id)
  @image_asset_auto_migration_done = args[:image_asset_auto_migration_done] if args.key?(:image_asset_auto_migration_done)
  @image_asset_auto_migration_done_date_time = args[:image_asset_auto_migration_done_date_time] if args.key?(:image_asset_auto_migration_done_date_time)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @local_services_settings = args[:local_services_settings] if args.key?(:local_services_settings)
  @location_asset_auto_migration_done = args[:location_asset_auto_migration_done] if args.key?(:location_asset_auto_migration_done)
  @location_asset_auto_migration_done_date_time = args[:location_asset_auto_migration_done_date_time] if args.key?(:location_asset_auto_migration_done_date_time)
  @manager = args[:manager] if args.key?(:manager)
  @manager_descriptive_name = args[:manager_descriptive_name] if args.key?(:manager_descriptive_name)
  @manager_id = args[:manager_id] if args.key?(:manager_id)
  @optimization_score = args[:optimization_score] if args.key?(:optimization_score)
  @optimization_score_weight = args[:optimization_score_weight] if args.key?(:optimization_score_weight)
  @pay_per_conversion_eligibility_failure_reasons = args[:pay_per_conversion_eligibility_failure_reasons] if args.key?(:pay_per_conversion_eligibility_failure_reasons)
  @remarketing_setting = args[:remarketing_setting] if args.key?(:remarketing_setting)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @sub_manager_descriptive_name = args[:sub_manager_descriptive_name] if args.key?(:sub_manager_descriptive_name)
  @sub_manager_id = args[:sub_manager_id] if args.key?(:sub_manager_id)
  @test_account = args[:test_account] if args.key?(:test_account)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @tracking_url_template = args[:tracking_url_template] if args.key?(:tracking_url_template)
  @video_brand_safety_suitability = args[:video_brand_safety_suitability] if args.key?(:video_brand_safety_suitability)
  @video_customer = args[:video_customer] if args.key?(:video_customer)
end