Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAsset
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A link between a customer and an asset.
Instance Attribute Summary collapse
-
#asset ⇒ String
Required.
-
#field_type ⇒ String
Required.
-
#primary_status ⇒ String
Output only.
-
#primary_status_details ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetLinkPrimaryStatusDetails>
Output only.
-
#primary_status_reasons ⇒ Array<String>
Output only.
-
#resource_name ⇒ String
Immutable.
-
#source ⇒ String
Output only.
-
#status ⇒ String
Status of the customer asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerAsset
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomerAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerAsset
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerAsset.
27969 27970 27971 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27969 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset ⇒ String
Required. Immutable. The asset which is linked to the customer.
Corresponds to the JSON property asset
27924 27925 27926 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27924 def asset @asset end |
#field_type ⇒ String
Required. Immutable. Role that the asset takes for the customer link.
Corresponds to the JSON property fieldType
27929 27930 27931 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27929 def field_type @field_type end |
#primary_status ⇒ String
Output only. Provides the PrimaryStatus of this asset link. Primary status is
meant essentially to differentiate between the plain "status" field, which has
advertiser set values of enabled, paused, or removed. The primary status takes
into account other signals (for assets its mainly policy and quality approvals)
to come up with a more comprehensive status to indicate its serving state.
Corresponds to the JSON property primaryStatus
27938 27939 27940 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27938 def primary_status @primary_status end |
#primary_status_details ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetLinkPrimaryStatusDetails>
Output only. Provides the details of the primary status and its associated
reasons.
Corresponds to the JSON property primaryStatusDetails
27944 27945 27946 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27944 def primary_status_details @primary_status_details end |
#primary_status_reasons ⇒ Array<String>
Output only. Provides a list of reasons for why an asset is not serving or not
serving at full capacity.
Corresponds to the JSON property primaryStatusReasons
27950 27951 27952 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27950 def primary_status_reasons @primary_status_reasons end |
#resource_name ⇒ String
Immutable. The resource name of the customer asset. CustomerAsset resource
names have the form: customers/customer_id/customerAssets/asset_id~
field_type`
Corresponds to the JSON propertyresourceName`
27957 27958 27959 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27957 def resource_name @resource_name end |
#source ⇒ String
Output only. Source of the customer asset link.
Corresponds to the JSON property source
27962 27963 27964 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27962 def source @source end |
#status ⇒ String
Status of the customer asset.
Corresponds to the JSON property status
27967 27968 27969 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27967 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27974 27975 27976 27977 27978 27979 27980 27981 27982 27983 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27974 def update!(**args) @asset = args[:asset] if args.key?(:asset) @field_type = args[:field_type] if args.key?(:field_type) @primary_status = args[:primary_status] if args.key?(:primary_status) @primary_status_details = args[:primary_status_details] if args.key?(:primary_status_details) @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons) @resource_name = args[:resource_name] if args.key?(:resource_name) @source = args[:source] if args.key?(:source) @status = args[:status] if args.key?(:status) end |