Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A link between a customer and an asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerAsset

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerAsset.



27897
27898
27899
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetString

Required. Immutable. The asset which is linked to the customer. Corresponds to the JSON property asset

Returns:

  • (String)


27852
27853
27854
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27852

def asset
  @asset
end

#field_typeString

Required. Immutable. Role that the asset takes for the customer link. Corresponds to the JSON property fieldType

Returns:

  • (String)


27857
27858
27859
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27857

def field_type
  @field_type
end

#primary_statusString

Output only. Provides the PrimaryStatus of this asset link. Primary status is meant essentially to differentiate between the plain "status" field, which has advertiser set values of enabled, paused, or removed. The primary status takes into account other signals (for assets its mainly policy and quality approvals) to come up with a more comprehensive status to indicate its serving state. Corresponds to the JSON property primaryStatus

Returns:

  • (String)


27866
27867
27868
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27866

def primary_status
  @primary_status
end

#primary_status_detailsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAssetLinkPrimaryStatusDetails>

Output only. Provides the details of the primary status and its associated reasons. Corresponds to the JSON property primaryStatusDetails



27872
27873
27874
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27872

def primary_status_details
  @primary_status_details
end

#primary_status_reasonsArray<String>

Output only. Provides a list of reasons for why an asset is not serving or not serving at full capacity. Corresponds to the JSON property primaryStatusReasons

Returns:

  • (Array<String>)


27878
27879
27880
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27878

def primary_status_reasons
  @primary_status_reasons
end

#resource_nameString

Immutable. The resource name of the customer asset. CustomerAsset resource names have the form: customers/customer_id/customerAssets/asset_id~ field_type` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


27885
27886
27887
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27885

def resource_name
  @resource_name
end

#sourceString

Output only. Source of the customer asset link. Corresponds to the JSON property source

Returns:

  • (String)


27890
27891
27892
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27890

def source
  @source
end

#statusString

Status of the customer asset. Corresponds to the JSON property status

Returns:

  • (String)


27895
27896
27897
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27895

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27902
27903
27904
27905
27906
27907
27908
27909
27910
27911
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27902

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @field_type = args[:field_type] if args.key?(:field_type)
  @primary_status = args[:primary_status] if args.key?(:primary_status)
  @primary_status_details = args[:primary_status_details] if args.key?(:primary_status_details)
  @primary_status_reasons = args[:primary_status_reasons] if args.key?(:primary_status_reasons)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @source = args[:source] if args.key?(:source)
  @status = args[:status] if args.key?(:status)
end