Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClient
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClient
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A link between the given customer and a client customer. CustomerClients only exist for manager customers. All direct and indirect client customers are included, as well as the manager itself.
Instance Attribute Summary collapse
-
#applied_labels ⇒ Array<String>
Output only.
-
#client_customer ⇒ String
Output only.
-
#currency_code ⇒ String
Output only.
-
#descriptive_name ⇒ String
Output only.
-
#hidden ⇒ Boolean
(also: #hidden?)
Output only.
-
#id ⇒ Fixnum
Output only.
-
#level ⇒ Fixnum
Output only.
-
#manager ⇒ Boolean
(also: #manager?)
Output only.
-
#resource_name ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#test_account ⇒ Boolean
(also: #test_account?)
Output only.
-
#time_zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerClient
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomerClient.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerClient
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerClient.
28031 28032 28033 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28031 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_labels ⇒ Array<String>
Output only. The resource names of the labels owned by the requesting customer
that are applied to the client customer. Label resource names have the form:
customers/customer_id/labels/label_id`
Corresponds to the JSON propertyappliedLabels`
27965 27966 27967 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27965 def applied_labels @applied_labels end |
#client_customer ⇒ String
Output only. The resource name of the client-customer which is linked to the
given customer. Read only.
Corresponds to the JSON property clientCustomer
27971 27972 27973 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27971 def client_customer @client_customer end |
#currency_code ⇒ String
Output only. Currency code (for example, 'USD', 'EUR') for the client. Read
only.
Corresponds to the JSON property currencyCode
27977 27978 27979 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27977 def currency_code @currency_code end |
#descriptive_name ⇒ String
Output only. Descriptive name for the client. Read only.
Corresponds to the JSON property descriptiveName
27982 27983 27984 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27982 def descriptive_name @descriptive_name end |
#hidden ⇒ Boolean Also known as:
Output only. Specifies whether this is a hidden account. Read only.
Corresponds to the JSON property hidden
27987 27988 27989 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27987 def hidden @hidden end |
#id ⇒ Fixnum
Output only. The ID of the client customer. Read only.
Corresponds to the JSON property id
27993 27994 27995 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27993 def id @id end |
#level ⇒ Fixnum
Output only. Distance between given customer and client. For self link, the
level value will be 0. Read only.
Corresponds to the JSON property level
27999 28000 28001 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27999 def level @level end |
#manager ⇒ Boolean Also known as: manager?
Output only. Identifies if the client is a manager. Read only.
Corresponds to the JSON property manager
28004 28005 28006 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28004 def manager @manager end |
#resource_name ⇒ String
Output only. The resource name of the customer client. CustomerClient resource
names have the form: customers/customer_id/customerClients/
client_customer_id`
Corresponds to the JSON propertyresourceName`
28012 28013 28014 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28012 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the client customer. Read only.
Corresponds to the JSON property status
28017 28018 28019 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28017 def status @status end |
#test_account ⇒ Boolean Also known as: test_account?
Output only. Identifies if the client is a test account. Read only.
Corresponds to the JSON property testAccount
28022 28023 28024 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28022 def test_account @test_account end |
#time_zone ⇒ String
Output only. Common Locale Data Repository (CLDR) string representation of the
time zone of the client, for example, America/Los_Angeles. Read only.
Corresponds to the JSON property timeZone
28029 28030 28031 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28029 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28036 28037 28038 28039 28040 28041 28042 28043 28044 28045 28046 28047 28048 28049 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28036 def update!(**args) @applied_labels = args[:applied_labels] if args.key?(:applied_labels) @client_customer = args[:client_customer] if args.key?(:client_customer) @currency_code = args[:currency_code] if args.key?(:currency_code) @descriptive_name = args[:descriptive_name] if args.key?(:descriptive_name) @hidden = args[:hidden] if args.key?(:hidden) @id = args[:id] if args.key?(:id) @level = args[:level] if args.key?(:level) @manager = args[:manager] if args.key?(:manager) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @test_account = args[:test_account] if args.key?(:test_account) @time_zone = args[:time_zone] if args.key?(:time_zone) end |