Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClient

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A link between the given customer and a client customer. CustomerClients only exist for manager customers. All direct and indirect client customers are included, as well as the manager itself.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerClient

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerClient.



27944
27945
27946
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27944

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applied_labelsArray<String>

Output only. The resource names of the labels owned by the requesting customer that are applied to the client customer. Label resource names have the form: customers/customer_id/labels/label_id` Corresponds to the JSON propertyappliedLabels`

Returns:

  • (Array<String>)


27878
27879
27880
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27878

def applied_labels
  @applied_labels
end

#client_customerString

Output only. The resource name of the client-customer which is linked to the given customer. Read only. Corresponds to the JSON property clientCustomer

Returns:

  • (String)


27884
27885
27886
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27884

def client_customer
  @client_customer
end

#currency_codeString

Output only. Currency code (for example, 'USD', 'EUR') for the client. Read only. Corresponds to the JSON property currencyCode

Returns:

  • (String)


27890
27891
27892
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27890

def currency_code
  @currency_code
end

#descriptive_nameString

Output only. Descriptive name for the client. Read only. Corresponds to the JSON property descriptiveName

Returns:

  • (String)


27895
27896
27897
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27895

def descriptive_name
  @descriptive_name
end

#hiddenBoolean Also known as: hidden?

Output only. Specifies whether this is a hidden account. Read only. Corresponds to the JSON property hidden

Returns:

  • (Boolean)


27900
27901
27902
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27900

def hidden
  @hidden
end

#idFixnum

Output only. The ID of the client customer. Read only. Corresponds to the JSON property id

Returns:

  • (Fixnum)


27906
27907
27908
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27906

def id
  @id
end

#levelFixnum

Output only. Distance between given customer and client. For self link, the level value will be 0. Read only. Corresponds to the JSON property level

Returns:

  • (Fixnum)


27912
27913
27914
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27912

def level
  @level
end

#managerBoolean Also known as: manager?

Output only. Identifies if the client is a manager. Read only. Corresponds to the JSON property manager

Returns:

  • (Boolean)


27917
27918
27919
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27917

def manager
  @manager
end

#resource_nameString

Output only. The resource name of the customer client. CustomerClient resource names have the form: customers/customer_id/customerClients/ client_customer_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


27925
27926
27927
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27925

def resource_name
  @resource_name
end

#statusString

Output only. The status of the client customer. Read only. Corresponds to the JSON property status

Returns:

  • (String)


27930
27931
27932
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27930

def status
  @status
end

#test_accountBoolean Also known as: test_account?

Output only. Identifies if the client is a test account. Read only. Corresponds to the JSON property testAccount

Returns:

  • (Boolean)


27935
27936
27937
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27935

def 
  @test_account
end

#time_zoneString

Output only. Common Locale Data Repository (CLDR) string representation of the time zone of the client, for example, America/Los_Angeles. Read only. Corresponds to the JSON property timeZone

Returns:

  • (String)


27942
27943
27944
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27942

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27949
27950
27951
27952
27953
27954
27955
27956
27957
27958
27959
27960
27961
27962
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27949

def update!(**args)
  @applied_labels = args[:applied_labels] if args.key?(:applied_labels)
  @client_customer = args[:client_customer] if args.key?(:client_customer)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @descriptive_name = args[:descriptive_name] if args.key?(:descriptive_name)
  @hidden = args[:hidden] if args.key?(:hidden)
  @id = args[:id] if args.key?(:id)
  @level = args[:level] if args.key?(:level)
  @manager = args[:manager] if args.key?(:manager)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @test_account = args[:test_account] if args.key?(:test_account)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end