Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClientLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents customer client link relationship.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerClientLink

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerClientLink.



28085
28086
28087
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_customerString

Immutable. The client customer linked to this customer. Corresponds to the JSON property clientCustomer

Returns:

  • (String)


28059
28060
28061
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28059

def client_customer
  @client_customer
end

#hiddenBoolean Also known as: hidden?

The visibility of the link. Users can choose whether or not to see hidden links in the Google Ads UI. Default value is false Corresponds to the JSON property hidden

Returns:

  • (Boolean)


28065
28066
28067
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28065

def hidden
  @hidden
end

Output only. This is uniquely identifies a customer client link. Read only. Corresponds to the JSON property managerLinkId

Returns:

  • (Fixnum)


28071
28072
28073
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28071

def manager_link_id
  @manager_link_id
end

#resource_nameString

Immutable. Name of the resource. CustomerClientLink resource names have the form: customers/customer_id/customerClientLinks/client_customer_id~ manager_link_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28078
28079
28080
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28078

def resource_name
  @resource_name
end

#statusString

This is the status of the link between client and manager. Corresponds to the JSON property status

Returns:

  • (String)


28083
28084
28085
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28083

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28090
28091
28092
28093
28094
28095
28096
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28090

def update!(**args)
  @client_customer = args[:client_customer] if args.key?(:client_customer)
  @hidden = args[:hidden] if args.key?(:hidden)
  @manager_link_id = args[:manager_link_id] if args.key?(:manager_link_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end