Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClientLink
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClientLink
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents customer client link relationship.
Instance Attribute Summary collapse
-
#client_customer ⇒ String
Immutable.
-
#hidden ⇒ Boolean
(also: #hidden?)
The visibility of the link.
-
#manager_link_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
This is the status of the link between client and manager.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerClientLink
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomerClientLink.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerClientLink
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerClientLink.
27998 27999 28000 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27998 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_customer ⇒ String
Immutable. The client customer linked to this customer.
Corresponds to the JSON property clientCustomer
27972 27973 27974 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27972 def client_customer @client_customer end |
#hidden ⇒ Boolean Also known as:
The visibility of the link. Users can choose whether or not to see hidden
links in the Google Ads UI. Default value is false
Corresponds to the JSON property hidden
27978 27979 27980 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27978 def hidden @hidden end |
#manager_link_id ⇒ Fixnum
Output only. This is uniquely identifies a customer client link. Read only.
Corresponds to the JSON property managerLinkId
27984 27985 27986 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27984 def manager_link_id @manager_link_id end |
#resource_name ⇒ String
Immutable. Name of the resource. CustomerClientLink resource names have the
form: customers/customer_id/customerClientLinks/client_customer_id~
manager_link_id`
Corresponds to the JSON propertyresourceName`
27991 27992 27993 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27991 def resource_name @resource_name end |
#status ⇒ String
This is the status of the link between client and manager.
Corresponds to the JSON property status
27996 27997 27998 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 27996 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28003 28004 28005 28006 28007 28008 28009 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28003 def update!(**args) @client_customer = args[:client_customer] if args.key?(:client_customer) @hidden = args[:hidden] if args.key?(:hidden) @manager_link_id = args[:manager_link_id] if args.key?(:manager_link_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |