Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerConversionGoal
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerConversionGoal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Biddability control for conversion actions with a matching category and origin.
Instance Attribute Summary collapse
-
#biddable ⇒ Boolean
(also: #biddable?)
The biddability of the customer conversion goal.
-
#category ⇒ String
The conversion category of this customer conversion goal.
-
#origin ⇒ String
The conversion origin of this customer conversion goal.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerConversionGoal
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomerConversionGoal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerConversionGoal
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerConversionGoal.
28128 28129 28130 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#biddable ⇒ Boolean Also known as: biddable?
The biddability of the customer conversion goal.
Corresponds to the JSON property biddable
28106 28107 28108 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28106 def biddable @biddable end |
#category ⇒ String
The conversion category of this customer conversion goal. Only conversion
actions that have this category will be included in this goal.
Corresponds to the JSON property category
28113 28114 28115 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28113 def category @category end |
#origin ⇒ String
The conversion origin of this customer conversion goal. Only conversion
actions that have this conversion origin will be included in this goal.
Corresponds to the JSON property origin
28119 28120 28121 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28119 def origin @origin end |
#resource_name ⇒ String
Immutable. The resource name of the customer conversion goal. Customer
conversion goal resource names have the form: customers/customer_id/
customerConversionGoals/category~origin`
Corresponds to the JSON propertyresourceName`
28126 28127 28128 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28126 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28133 28134 28135 28136 28137 28138 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28133 def update!(**args) @biddable = args[:biddable] if args.key?(:biddable) @category = args[:category] if args.key?(:category) @origin = args[:origin] if args.key?(:origin) @resource_name = args[:resource_name] if args.key?(:resource_name) end |