Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerConversionGoal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Biddability control for conversion actions with a matching category and origin.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerConversionGoal

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerConversionGoal.



28041
28042
28043
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#biddableBoolean Also known as: biddable?

The biddability of the customer conversion goal. Corresponds to the JSON property biddable

Returns:

  • (Boolean)


28019
28020
28021
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28019

def biddable
  @biddable
end

#categoryString

The conversion category of this customer conversion goal. Only conversion actions that have this category will be included in this goal. Corresponds to the JSON property category

Returns:

  • (String)


28026
28027
28028
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28026

def category
  @category
end

#originString

The conversion origin of this customer conversion goal. Only conversion actions that have this conversion origin will be included in this goal. Corresponds to the JSON property origin

Returns:

  • (String)


28032
28033
28034
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28032

def origin
  @origin
end

#resource_nameString

Immutable. The resource name of the customer conversion goal. Customer conversion goal resource names have the form: customers/customer_id/ customerConversionGoals/category~origin` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28039
28040
28041
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28039

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28046
28047
28048
28049
28050
28051
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28046

def update!(**args)
  @biddable = args[:biddable] if args.key?(:biddable)
  @category = args[:category] if args.key?(:category)
  @origin = args[:origin] if args.key?(:origin)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end