Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerConversionGoal
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerConversionGoal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Biddability control for conversion actions with a matching category and origin.
Instance Attribute Summary collapse
-
#biddable ⇒ Boolean
(also: #biddable?)
The biddability of the customer conversion goal.
-
#category ⇒ String
The conversion category of this customer conversion goal.
-
#origin ⇒ String
The conversion origin of this customer conversion goal.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerConversionGoal
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomerConversionGoal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerConversionGoal
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerConversionGoal.
28041 28042 28043 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28041 def initialize(**args) update!(**args) end |
Instance Attribute Details
#biddable ⇒ Boolean Also known as: biddable?
The biddability of the customer conversion goal.
Corresponds to the JSON property biddable
28019 28020 28021 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28019 def biddable @biddable end |
#category ⇒ String
The conversion category of this customer conversion goal. Only conversion
actions that have this category will be included in this goal.
Corresponds to the JSON property category
28026 28027 28028 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28026 def category @category end |
#origin ⇒ String
The conversion origin of this customer conversion goal. Only conversion
actions that have this conversion origin will be included in this goal.
Corresponds to the JSON property origin
28032 28033 28034 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28032 def origin @origin end |
#resource_name ⇒ String
Immutable. The resource name of the customer conversion goal. Customer
conversion goal resource names have the form: customers/customer_id/
customerConversionGoals/category~origin`
Corresponds to the JSON propertyresourceName`
28039 28040 28041 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28039 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28046 28047 28048 28049 28050 28051 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28046 def update!(**args) @biddable = args[:biddable] if args.key?(:biddable) @category = args[:category] if args.key?(:category) @origin = args[:origin] if args.key?(:origin) @resource_name = args[:resource_name] if args.key?(:resource_name) end |