Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerCustomizer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A customizer value for the associated CustomizerAttribute at the Customer level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerCustomizer

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerCustomizer.



28169
28170
28171
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28169

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customizer_attributeString

Required. Immutable. The customizer attribute which is linked to the customer. Corresponds to the JSON property customizerAttribute

Returns:

  • (String)


28149
28150
28151
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28149

def customizer_attribute
  @customizer_attribute
end

#resource_nameString

Immutable. The resource name of the customer customizer. Customer customizer resource names have the form: customers/customer_id/customerCustomizers/ customizer_attribute_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28156
28157
28158
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28156

def resource_name
  @resource_name
end

#statusString

Output only. The status of the customer customizer attribute. Corresponds to the JSON property status

Returns:

  • (String)


28161
28162
28163
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28161

def status
  @status
end

#valueGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue

A customizer value that is referenced in customizer linkage entities like CustomerCustomizer, CampaignCustomizer, etc. Corresponds to the JSON property value



28167
28168
28169
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28167

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28174
28175
28176
28177
28178
28179
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28174

def update!(**args)
  @customizer_attribute = args[:customizer_attribute] if args.key?(:customizer_attribute)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @value = args[:value] if args.key?(:value)
end