Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerCustomizer
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerCustomizer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A customizer value for the associated CustomizerAttribute at the Customer level.
Instance Attribute Summary collapse
-
#customizer_attribute ⇒ String
Required.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#value ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue
A customizer value that is referenced in customizer linkage entities like CustomerCustomizer, CampaignCustomizer, etc.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerCustomizer
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomerCustomizer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerCustomizer
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerCustomizer.
28082 28083 28084 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28082 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customizer_attribute ⇒ String
Required. Immutable. The customizer attribute which is linked to the customer.
Corresponds to the JSON property customizerAttribute
28062 28063 28064 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28062 def customizer_attribute @customizer_attribute end |
#resource_name ⇒ String
Immutable. The resource name of the customer customizer. Customer customizer
resource names have the form: customers/customer_id/customerCustomizers/
customizer_attribute_id`
Corresponds to the JSON propertyresourceName`
28069 28070 28071 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28069 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the customer customizer attribute.
Corresponds to the JSON property status
28074 28075 28076 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28074 def status @status end |
#value ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomizerValue
A customizer value that is referenced in customizer linkage entities like
CustomerCustomizer, CampaignCustomizer, etc.
Corresponds to the JSON property value
28080 28081 28082 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28080 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28087 28088 28089 28090 28091 28092 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28087 def update!(**args) @customizer_attribute = args[:customizer_attribute] if args.key?(:customizer_attribute) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @value = args[:value] if args.key?(:value) end |