Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerLabel
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerLabel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents a relationship between a customer and a label. This customer may not have access to all the labels attached to it. Additional CustomerLabels may be returned by increasing permissions with login-customer-id.
Instance Attribute Summary collapse
-
#customer ⇒ String
Output only.
-
#label ⇒ String
Output only.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerLabel
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomerLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerLabel
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerLabel.
28208 28209 28210 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28208 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer ⇒ String
Output only. The resource name of the customer to which the label is attached.
This field should not be set when creating a new CustomerLabel.
Corresponds to the JSON property customer
28192 28193 28194 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28192 def customer @customer end |
#label ⇒ String
Output only. The resource name of the label assigned to the customer. This
field should not be set when creating a new CustomerLabel. Note: the
Customer ID portion of the label resource name is not validated when creating
a new CustomerLabel.
Corresponds to the JSON property label
28200 28201 28202 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28200 def label @label end |
#resource_name ⇒ String
Immutable. Name of the resource. Customer label resource names have the form:
customers/customer_id/customerLabels/label_id`
Corresponds to the JSON propertyresourceName`
28206 28207 28208 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28206 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28213 28214 28215 28216 28217 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28213 def update!(**args) @customer = args[:customer] if args.key?(:customer) @label = args[:label] if args.key?(:label) @resource_name = args[:resource_name] if args.key?(:resource_name) end |