Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A negative criterion for exclusions at the customer level.
Instance Attribute Summary collapse
-
#content_label ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonContentLabelInfo
Content Label for category exclusion.
-
#id ⇒ Fixnum
Output only.
-
#ip_block ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIpBlockInfo
An IpBlock criterion used for excluding IP addresses.
-
#mobile_app_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo
A mobile app category criterion.
-
#mobile_application ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo
A mobile application criterion.
-
#negative_keyword_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonNegativeKeywordListInfo
A Negative Keyword List criterion.
-
#placement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo
A placement criterion.
-
#placement_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementListInfo
A Placement List criterion.
-
#resource_name ⇒ String
Immutable.
-
#type ⇒ String
Output only.
-
#youtube_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
A YouTube Channel criterion.
-
#youtube_video ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
A YouTube Video criterion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion.
28289 28290 28291 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_label ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonContentLabelInfo
Content Label for category exclusion.
Corresponds to the JSON property contentLabel
28218 28219 28220 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28218 def content_label @content_label end |
#id ⇒ Fixnum
Output only. The ID of the criterion.
Corresponds to the JSON property id
28223 28224 28225 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28223 def id @id end |
#ip_block ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIpBlockInfo
An IpBlock criterion used for excluding IP addresses. We support excluding
individual IP addresses or CIDR blocks. Create one IpBlockInfo criterion for
each individual IP address or CIDR block you want to exclude. You can exclude
up to 500 IP addresses per campaign. For more details, see Exclude IP
addresses. IPv4 examples: *
Individual address: 192.168.0.1 * Individual address as CIDR block: 192.168.0.
1/32 * CIDR block: 192.168.0.0/24 IPv6 examples: * Individual address: 2001:
db8:a0b:12f0::1 * Individual address as CIDR block: 2001:db8:a0b:12f0::1/128 *
CIDR block: 2001:db8::/48
Corresponds to the JSON property ipBlock
28236 28237 28238 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28236 def ip_block @ip_block end |
#mobile_app_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo
A mobile app category criterion.
Corresponds to the JSON property mobileAppCategory
28241 28242 28243 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28241 def mobile_app_category @mobile_app_category end |
#mobile_application ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo
A mobile application criterion.
Corresponds to the JSON property mobileApplication
28246 28247 28248 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28246 def mobile_application @mobile_application end |
#negative_keyword_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonNegativeKeywordListInfo
A Negative Keyword List criterion. Represents a shared set of negative
keywords that can be excluded at the account-level. Only one negative keyword
list criterion can be attached per account.
Corresponds to the JSON property negativeKeywordList
28253 28254 28255 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28253 def negative_keyword_list @negative_keyword_list end |
#placement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo
A placement criterion. This can be used to modify bids for sites when
targeting the content network.
Corresponds to the JSON property placement
28259 28260 28261 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28259 def placement @placement end |
#placement_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementListInfo
A Placement List criterion. Represents a shared set of placements that can be
excluded at the account-level.
Corresponds to the JSON property placementList
28265 28266 28267 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28265 def placement_list @placement_list end |
#resource_name ⇒ String
Immutable. The resource name of the customer negative criterion. Customer
negative criterion resource names have the form: customers/customer_id/
customerNegativeCriteria/criterion_id`
Corresponds to the JSON propertyresourceName`
28272 28273 28274 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28272 def resource_name @resource_name end |
#type ⇒ String
Output only. The type of the criterion.
Corresponds to the JSON property type
28277 28278 28279 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28277 def type @type end |
#youtube_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
A YouTube Channel criterion.
Corresponds to the JSON property youtubeChannel
28282 28283 28284 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28282 def youtube_channel @youtube_channel end |
#youtube_video ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
A YouTube Video criterion.
Corresponds to the JSON property youtubeVideo
28287 28288 28289 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28287 def youtube_video @youtube_video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28294 28295 28296 28297 28298 28299 28300 28301 28302 28303 28304 28305 28306 28307 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28294 def update!(**args) @content_label = args[:content_label] if args.key?(:content_label) @id = args[:id] if args.key?(:id) @ip_block = args[:ip_block] if args.key?(:ip_block) @mobile_app_category = args[:mobile_app_category] if args.key?(:mobile_app_category) @mobile_application = args[:mobile_application] if args.key?(:mobile_application) @negative_keyword_list = args[:negative_keyword_list] if args.key?(:negative_keyword_list) @placement = args[:placement] if args.key?(:placement) @placement_list = args[:placement_list] if args.key?(:placement_list) @resource_name = args[:resource_name] if args.key?(:resource_name) @type = args[:type] if args.key?(:type) @youtube_channel = args[:youtube_channel] if args.key?(:youtube_channel) @youtube_video = args[:youtube_video] if args.key?(:youtube_video) end |