Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSearchTermInsight

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

This report provides a high-level view of search demand at the customer level by grouping similar search terms into categories and showing their search volume. Historical data is available starting March 2023.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerSearchTermInsight

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerSearchTermInsight.



28334
28335
28336
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_labelString

Output only. The label for the search category. An empty string denotes the catch-all category for search terms that didn't fit into another category. Corresponds to the JSON property categoryLabel

Returns:

  • (String)


28320
28321
28322
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28320

def category_label
  @category_label
end

#idFixnum

Output only. The ID of the insight. Corresponds to the JSON property id

Returns:

  • (Fixnum)


28325
28326
28327
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28325

def id
  @id
end

#resource_nameString

Output only. The resource name of the customer level search term insight. Customer level search term insight resource names have the form: customers/ customer_id/customerSearchTermInsights/category_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28332
28333
28334
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28332

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28339
28340
28341
28342
28343
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28339

def update!(**args)
  @category_label = args[:category_label] if args.key?(:category_label)
  @id = args[:id] if args.key?(:id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end