Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The CustomerLink specific SkAdNetworkConversionValueSchema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchema

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchema.



16974
16975
16976
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

Required. Output only. Apple App Store app ID. Corresponds to the JSON property appId

Returns:

  • (String)


16953
16954
16955
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16953

def app_id
  @app_id
end

#fine_grained_conversion_value_mappingsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaFineGrainedConversionValueMappings>

Output only. Fine grained conversion value mappings. Corresponds to the JSON property fineGrainedConversionValueMappings



16958
16959
16960
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16958

def fine_grained_conversion_value_mappings
  @fine_grained_conversion_value_mappings
end

#measurement_window_hoursFixnum

Output only. A time window (measured in hours) post-install, after which the App Attribution Partner or advertiser stops calling updateConversionValue. Corresponds to the JSON property measurementWindowHours

Returns:

  • (Fixnum)


16966
16967
16968
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16966

def measurement_window_hours
  @measurement_window_hours
end

#postback_mappingsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaPostbackMapping>

Output only. Per-postback conversion value mappings for postbacks in multiple conversion windows. Only applicable for SkAdNetwork versions >= 4.0. Corresponds to the JSON property postbackMappings



16972
16973
16974
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16972

def postback_mappings
  @postback_mappings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16979
16980
16981
16982
16983
16984
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16979

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @fine_grained_conversion_value_mappings = args[:fine_grained_conversion_value_mappings] if args.key?(:fine_grained_conversion_value_mappings)
  @measurement_window_hours = args[:measurement_window_hours] if args.key?(:measurement_window_hours)
  @postback_mappings = args[:postback_mappings] if args.key?(:postback_mappings)
end