Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaCoarseGrainedConversionValueMappings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Mappings for coarse grained conversion values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaCoarseGrainedConversionValueMappings

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaCoarseGrainedConversionValueMappings.



16712
16713
16714
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16712

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#high_conversion_value_mappingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaConversionValueMapping

Represents mapping from one conversion value to one or more conversion events. Corresponds to the JSON property highConversionValueMapping



16700
16701
16702
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16700

def high_conversion_value_mapping
  @high_conversion_value_mapping
end

#low_conversion_value_mappingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaConversionValueMapping

Represents mapping from one conversion value to one or more conversion events. Corresponds to the JSON property lowConversionValueMapping



16705
16706
16707
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16705

def low_conversion_value_mapping
  @low_conversion_value_mapping
end

#medium_conversion_value_mappingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaConversionValueMapping

Represents mapping from one conversion value to one or more conversion events. Corresponds to the JSON property mediumConversionValueMapping



16710
16711
16712
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16710

def medium_conversion_value_mapping
  @medium_conversion_value_mapping
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16717
16718
16719
16720
16721
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16717

def update!(**args)
  @high_conversion_value_mapping = args[:high_conversion_value_mapping] if args.key?(:high_conversion_value_mapping)
  @low_conversion_value_mapping = args[:low_conversion_value_mapping] if args.key?(:low_conversion_value_mapping)
  @medium_conversion_value_mapping = args[:medium_conversion_value_mapping] if args.key?(:medium_conversion_value_mapping)
end