Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaConversionValueMapping
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaConversionValueMapping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents mapping from one conversion value to one or more conversion events.
Instance Attribute Summary collapse
-
#mapped_events ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaEvent>
Output only.
-
#max_time_post_install_hours ⇒ Fixnum
Output only.
-
#min_time_post_install_hours ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaConversionValueMapping
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaConversionValueMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaConversionValueMapping
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaConversionValueMapping.
16812 16813 16814 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16812 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mapped_events ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaEvent>
Output only. The conversion value may be mapped to multiple events with
various attributes.
Corresponds to the JSON property mappedEvents
16798 16799 16800 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16798 def mapped_events @mapped_events end |
#max_time_post_install_hours ⇒ Fixnum
Output only. The maximum of the time range in which a user was last active
during the measurement window.
Corresponds to the JSON property maxTimePostInstallHours
16804 16805 16806 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16804 def max_time_post_install_hours @max_time_post_install_hours end |
#min_time_post_install_hours ⇒ Fixnum
Output only. The minimum of the time range in which a user was last active
during the measurement window.
Corresponds to the JSON property minTimePostInstallHours
16810 16811 16812 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16810 def min_time_post_install_hours @min_time_post_install_hours end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16817 16818 16819 16820 16821 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16817 def update!(**args) @mapped_events = args[:mapped_events] if args.key?(:mapped_events) @max_time_post_install_hours = args[:max_time_post_install_hours] if args.key?(:max_time_post_install_hours) @min_time_post_install_hours = args[:min_time_post_install_hours] if args.key?(:min_time_post_install_hours) end |