Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaEventEventOccurrenceRange
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaEventEventOccurrenceRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Defines a range for event counter values.
Instance Attribute Summary collapse
-
#max_event_count ⇒ Fixnum
Output only.
-
#min_event_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaEventEventOccurrenceRange
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaEventEventOccurrenceRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaEventEventOccurrenceRange
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaEventEventOccurrenceRange.
16653 16654 16655 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16653 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_event_count ⇒ Fixnum
Output only. For event counter ranges, the maximum of the defined range. A
value of 0 will be treated as unset.
Corresponds to the JSON property maxEventCount
16645 16646 16647 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16645 def max_event_count @max_event_count end |
#min_event_count ⇒ Fixnum
Output only. For event counter ranges, the minimum of the defined range. A
value of 0 will be treated as unset.
Corresponds to the JSON property minEventCount
16651 16652 16653 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16651 def min_event_count @min_event_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16658 16659 16660 16661 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16658 def update!(**args) @max_event_count = args[:max_event_count] if args.key?(:max_event_count) @min_event_count = args[:min_event_count] if args.key?(:min_event_count) end |