Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaEventRevenueRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Defines a range for revenue values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaEventRevenueRange

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaEventRevenueRange.



16748
16749
16750
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16748

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_event_revenueFloat

Output only. For revenue ranges, the maximum value in currency_code for which this conversion value would be updated. A value of 0 will be treated as unset. Corresponds to the JSON property maxEventRevenue

Returns:

  • (Float)


16739
16740
16741
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16739

def max_event_revenue
  @max_event_revenue
end

#min_event_revenueFloat

Output only. For revenue ranges, the minimum value in currency_code for which this conversion value would be updated. A value of 0 will be treated as unset. Corresponds to the JSON property minEventRevenue

Returns:

  • (Float)


16746
16747
16748
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16746

def min_event_revenue
  @min_event_revenue
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16753
16754
16755
16756
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16753

def update!(**args)
  @max_event_revenue = args[:max_event_revenue] if args.key?(:max_event_revenue)
  @min_event_revenue = args[:min_event_revenue] if args.key?(:min_event_revenue)
end