Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaEventRevenueRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Defines a range for revenue values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaEventRevenueRange

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerSkAdNetworkConversionValueSchemaSkAdNetworkConversionValueSchemaEventRevenueRange.



16682
16683
16684
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16682

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_event_revenueFloat

Output only. For revenue ranges, the maximum value in currency_code for which this conversion value would be updated. A value of 0 will be treated as unset. Corresponds to the JSON property maxEventRevenue

Returns:

  • (Float)


16673
16674
16675
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16673

def max_event_revenue
  @max_event_revenue
end

#min_event_revenueFloat

Output only. For revenue ranges, the minimum value in currency_code for which this conversion value would be updated. A value of 0 will be treated as unset. Corresponds to the JSON property minEventRevenue

Returns:

  • (Float)


16680
16681
16682
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16680

def min_event_revenue
  @min_event_revenue
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16687
16688
16689
16690
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16687

def update!(**args)
  @max_event_revenue = args[:max_event_revenue] if args.key?(:max_event_revenue)
  @min_event_revenue = args[:min_event_revenue] if args.key?(:min_event_revenue)
end