Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccess

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents the permission of a single user onto a single customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerUserAccess

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerUserAccess.



28499
28500
28501
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28499

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_creation_date_timeString

Output only. The customer user access creation time. Read only field The format is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05 09:15:00" or "2018-02- 01 14:34:30" Corresponds to the JSON property accessCreationDateTime

Returns:

  • (String)


28471
28472
28473
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28471

def access_creation_date_time
  @access_creation_date_time
end

#access_roleString

Access role of the user. Corresponds to the JSON property accessRole

Returns:

  • (String)


28476
28477
28478
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28476

def access_role
  @access_role
end

#email_addressString

Output only. Email address of the user. Read only field Corresponds to the JSON property emailAddress

Returns:

  • (String)


28481
28482
28483
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28481

def email_address
  @email_address
end

#inviter_user_email_addressString

Output only. The email address of the inviter user. Read only field Corresponds to the JSON property inviterUserEmailAddress

Returns:

  • (String)


28486
28487
28488
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28486

def inviter_user_email_address
  @inviter_user_email_address
end

#resource_nameString

Immutable. Name of the resource. Resource names have the form: customers/ customer_id/customerUserAccesses/user_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28492
28493
28494
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28492

def resource_name
  @resource_name
end

#user_idFixnum

Output only. User id of the user with the customer access. Read only field Corresponds to the JSON property userId

Returns:

  • (Fixnum)


28497
28498
28499
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28497

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28504
28505
28506
28507
28508
28509
28510
28511
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28504

def update!(**args)
  @access_creation_date_time = args[:access_creation_date_time] if args.key?(:access_creation_date_time)
  @access_role = args[:access_role] if args.key?(:access_role)
  @email_address = args[:email_address] if args.key?(:email_address)
  @inviter_user_email_address = args[:inviter_user_email_address] if args.key?(:inviter_user_email_address)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @user_id = args[:user_id] if args.key?(:user_id)
end