Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccess

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents the permission of a single user onto a single customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerUserAccess

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerUserAccess.



28411
28412
28413
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28411

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_creation_date_timeString

Output only. The customer user access creation time. Read only field The format is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05 09:15:00" or "2018-02- 01 14:34:30" Corresponds to the JSON property accessCreationDateTime

Returns:

  • (String)


28383
28384
28385
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28383

def access_creation_date_time
  @access_creation_date_time
end

#access_roleString

Access role of the user. Corresponds to the JSON property accessRole

Returns:

  • (String)


28388
28389
28390
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28388

def access_role
  @access_role
end

#email_addressString

Output only. Email address of the user. Read only field Corresponds to the JSON property emailAddress

Returns:

  • (String)


28393
28394
28395
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28393

def email_address
  @email_address
end

#inviter_user_email_addressString

Output only. The email address of the inviter user. Read only field Corresponds to the JSON property inviterUserEmailAddress

Returns:

  • (String)


28398
28399
28400
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28398

def inviter_user_email_address
  @inviter_user_email_address
end

#resource_nameString

Immutable. Name of the resource. Resource names have the form: customers/ customer_id/customerUserAccesses/user_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28404
28405
28406
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28404

def resource_name
  @resource_name
end

#user_idFixnum

Output only. User id of the user with the customer access. Read only field Corresponds to the JSON property userId

Returns:

  • (Fixnum)


28409
28410
28411
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28409

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28416
28417
28418
28419
28420
28421
28422
28423
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28416

def update!(**args)
  @access_creation_date_time = args[:access_creation_date_time] if args.key?(:access_creation_date_time)
  @access_role = args[:access_role] if args.key?(:access_role)
  @email_address = args[:email_address] if args.key?(:email_address)
  @inviter_user_email_address = args[:inviter_user_email_address] if args.key?(:inviter_user_email_address)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @user_id = args[:user_id] if args.key?(:user_id)
end