Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccess
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccess
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents the permission of a single user onto a single customer.
Instance Attribute Summary collapse
-
#access_creation_date_time ⇒ String
Output only.
-
#access_role ⇒ String
Access role of the user.
-
#email_address ⇒ String
Output only.
-
#inviter_user_email_address ⇒ String
Output only.
-
#resource_name ⇒ String
Immutable.
-
#user_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerUserAccess
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomerUserAccess.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerUserAccess
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerUserAccess.
28411 28412 28413 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28411 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_creation_date_time ⇒ String
Output only. The customer user access creation time. Read only field The
format is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05 09:15:00" or "2018-02-
01 14:34:30"
Corresponds to the JSON property accessCreationDateTime
28383 28384 28385 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28383 def access_creation_date_time @access_creation_date_time end |
#access_role ⇒ String
Access role of the user.
Corresponds to the JSON property accessRole
28388 28389 28390 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28388 def access_role @access_role end |
#email_address ⇒ String
Output only. Email address of the user. Read only field
Corresponds to the JSON property emailAddress
28393 28394 28395 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28393 def email_address @email_address end |
#inviter_user_email_address ⇒ String
Output only. The email address of the inviter user. Read only field
Corresponds to the JSON property inviterUserEmailAddress
28398 28399 28400 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28398 def inviter_user_email_address @inviter_user_email_address end |
#resource_name ⇒ String
Immutable. Name of the resource. Resource names have the form: customers/
customer_id/customerUserAccesses/user_id`
Corresponds to the JSON propertyresourceName`
28404 28405 28406 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28404 def resource_name @resource_name end |
#user_id ⇒ Fixnum
Output only. User id of the user with the customer access. Read only field
Corresponds to the JSON property userId
28409 28410 28411 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28409 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28416 28417 28418 28419 28420 28421 28422 28423 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28416 def update!(**args) @access_creation_date_time = args[:access_creation_date_time] if args.key?(:access_creation_date_time) @access_role = args[:access_role] if args.key?(:access_role) @email_address = args[:email_address] if args.key?(:email_address) @inviter_user_email_address = args[:inviter_user_email_address] if args.key?(:inviter_user_email_address) @resource_name = args[:resource_name] if args.key?(:resource_name) @user_id = args[:user_id] if args.key?(:user_id) end |