Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represent an invitation to a new user on this customer account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation.



28552
28553
28554
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28552

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_roleString

Immutable. Access role of the user. Corresponds to the JSON property accessRole

Returns:

  • (String)


28521
28522
28523
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28521

def access_role
  @access_role
end

#creation_date_timeString

Output only. Time invitation was created. This field is read-only. The format is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34: 30" Corresponds to the JSON property creationDateTime

Returns:

  • (String)


28528
28529
28530
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28528

def creation_date_time
  @creation_date_time
end

#email_addressString

Immutable. Email address the invitation was sent to. This can differ from the email address of the account that accepts the invite. Corresponds to the JSON property emailAddress

Returns:

  • (String)


28534
28535
28536
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28534

def email_address
  @email_address
end

#invitation_idFixnum

Output only. The ID of the invitation. This field is read-only. Corresponds to the JSON property invitationId

Returns:

  • (Fixnum)


28539
28540
28541
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28539

def invitation_id
  @invitation_id
end

#invitation_statusString

Output only. Invitation status of the user. Corresponds to the JSON property invitationStatus

Returns:

  • (String)


28544
28545
28546
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28544

def invitation_status
  @invitation_status
end

#resource_nameString

Immutable. Name of the resource. Resource names have the form: customers/ customer_id/customerUserAccessInvitations/invitation_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28550
28551
28552
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28550

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28557
28558
28559
28560
28561
28562
28563
28564
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28557

def update!(**args)
  @access_role = args[:access_role] if args.key?(:access_role)
  @creation_date_time = args[:creation_date_time] if args.key?(:creation_date_time)
  @email_address = args[:email_address] if args.key?(:email_address)
  @invitation_id = args[:invitation_id] if args.key?(:invitation_id)
  @invitation_status = args[:invitation_status] if args.key?(:invitation_status)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end