Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represent an invitation to a new user on this customer account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation

Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation.



28464
28465
28466
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_roleString

Immutable. Access role of the user. Corresponds to the JSON property accessRole

Returns:

  • (String)


28433
28434
28435
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28433

def access_role
  @access_role
end

#creation_date_timeString

Output only. Time invitation was created. This field is read-only. The format is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34: 30" Corresponds to the JSON property creationDateTime

Returns:

  • (String)


28440
28441
28442
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28440

def creation_date_time
  @creation_date_time
end

#email_addressString

Immutable. Email address the invitation was sent to. This can differ from the email address of the account that accepts the invite. Corresponds to the JSON property emailAddress

Returns:

  • (String)


28446
28447
28448
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28446

def email_address
  @email_address
end

#invitation_idFixnum

Output only. The ID of the invitation. This field is read-only. Corresponds to the JSON property invitationId

Returns:

  • (Fixnum)


28451
28452
28453
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28451

def invitation_id
  @invitation_id
end

#invitation_statusString

Output only. Invitation status of the user. Corresponds to the JSON property invitationStatus

Returns:

  • (String)


28456
28457
28458
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28456

def invitation_status
  @invitation_status
end

#resource_nameString

Immutable. Name of the resource. Resource names have the form: customers/ customer_id/customerUserAccessInvitations/invitation_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28462
28463
28464
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28462

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28469
28470
28471
28472
28473
28474
28475
28476
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28469

def update!(**args)
  @access_role = args[:access_role] if args.key?(:access_role)
  @creation_date_time = args[:creation_date_time] if args.key?(:creation_date_time)
  @email_address = args[:email_address] if args.key?(:email_address)
  @invitation_id = args[:invitation_id] if args.key?(:invitation_id)
  @invitation_status = args[:invitation_status] if args.key?(:invitation_status)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end