Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomizerAttribute
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomizerAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A customizer attribute. Use CustomerCustomizer, CampaignCustomizer, AdGroupCustomizer, or AdGroupCriterionCustomizer to associate a customizer attribute and set its value at the customer, campaign, ad group, or ad group criterion level, respectively.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Required.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#type ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomizerAttribute
constructor
A new instance of GoogleAdsSearchads360V23ResourcesCustomizerAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesCustomizerAttribute
Returns a new instance of GoogleAdsSearchads360V23ResourcesCustomizerAttribute.
28603 28604 28605 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28603 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. The ID of the customizer attribute.
Corresponds to the JSON property id
28577 28578 28579 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28577 def id @id end |
#name ⇒ String
Required. Immutable. Name of the customizer attribute. Required. It must have
a minimum length of 1 and maximum length of 40. Name of an enabled customizer
attribute must be unique (case insensitive).
Corresponds to the JSON property name
28584 28585 28586 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28584 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the customizer attribute. Customizer Attribute
resource names have the form: customers/customer_id/customizerAttributes/
customizer_attribute_id`
Corresponds to the JSON propertyresourceName`
28591 28592 28593 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28591 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the customizer attribute.
Corresponds to the JSON property status
28596 28597 28598 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28596 def status @status end |
#type ⇒ String
Immutable. The type of the customizer attribute.
Corresponds to the JSON property type
28601 28602 28603 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28601 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28608 28609 28610 28611 28612 28613 28614 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28608 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) end |