Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDetailContentSuitabilityPlacementView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A detail content suitability placement view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDetailContentSuitabilityPlacementView

Returns a new instance of GoogleAdsSearchads360V23ResourcesDetailContentSuitabilityPlacementView.



28636
28637
28638
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28636

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name is URL for websites, YouTube video name for YouTube videos, and translated mobile app name for mobile apps. Corresponds to the JSON property displayName

Returns:

  • (String)


28608
28609
28610
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28608

def display_name
  @display_name
end

#placementString

Output only. The automatic placement string at detail level, for example. website url, mobile application id, or a YouTube video id. Corresponds to the JSON property placement

Returns:

  • (String)


28614
28615
28616
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28614

def placement
  @placement
end

#placement_typeString

Output only. Represents the type of the placement, for example, Website, YouTubeVideo and MobileApplication. Corresponds to the JSON property placementType

Returns:

  • (String)


28620
28621
28622
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28620

def placement_type
  @placement_type
end

#resource_nameString

Output only. The resource name of the detail content suitability placement view. Detail content suitability placement view resource names have the form: customers/customer_id/detailContentSuitabilityPlacementViews/ placement_fingerprint` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28628
28629
28630
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28628

def resource_name
  @resource_name
end

#target_urlString

Output only. URL of the placement, for example, website, link to the mobile application in app store, or a YouTube video URL. Corresponds to the JSON property targetUrl

Returns:

  • (String)


28634
28635
28636
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28634

def target_url
  @target_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28641
28642
28643
28644
28645
28646
28647
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28641

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @placement = args[:placement] if args.key?(:placement)
  @placement_type = args[:placement_type] if args.key?(:placement_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @target_url = args[:target_url] if args.key?(:target_url)
end