Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDetailPlacementView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDetailPlacementView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A view with metrics aggregated by ad group and URL or YouTube video. Provides
granular performance data about specific URLs, YouTube videos, and apps where
your ads showed. This offers a more detailed breakdown compared to the
group_placement_view. This view primarily surfaces placement data from the
Google Display Network. While you can select segments like segments.
ad_network_type, this view generally does not include placement data from
other networks, such as the Search Partners network. To understand performance
on Search Partners, consider other reports and segmentations. Data for low-
traffic placements may be aggregated.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#group_placement_target_url ⇒ String
Output only.
-
#placement ⇒ String
Output only.
-
#placement_type ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#target_url ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDetailPlacementView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesDetailPlacementView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDetailPlacementView
Returns a new instance of GoogleAdsSearchads360V23ResourcesDetailPlacementView.
28787 28788 28789 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. The display name is URL name for websites, YouTube video name for
YouTube videos, and translated mobile app name for mobile apps.
Corresponds to the JSON property displayName
28754 28755 28756 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28754 def display_name @display_name end |
#group_placement_target_url ⇒ String
Output only. URL of the group placement, for example, domain, link to the
mobile application in app store, or a YouTube channel URL.
Corresponds to the JSON property groupPlacementTargetUrl
28760 28761 28762 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28760 def group_placement_target_url @group_placement_target_url end |
#placement ⇒ String
Output only. The automatic placement string at detail level, e. g. website URL,
mobile application ID, or a YouTube video ID.
Corresponds to the JSON property placement
28766 28767 28768 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28766 def placement @placement end |
#placement_type ⇒ String
Output only. Type of the placement, for example, Website, YouTube Video, and
Mobile Application.
Corresponds to the JSON property placementType
28772 28773 28774 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28772 def placement_type @placement_type end |
#resource_name ⇒ String
Output only. The resource name of the detail placement view. Detail placement
view resource names have the form: customers/customer_id/
detailPlacementViews/ad_group_id~base64_placement`
Corresponds to the JSON propertyresourceName`
28779 28780 28781 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28779 def resource_name @resource_name end |
#target_url ⇒ String
Output only. URL of the placement, for example, website, link to the mobile
application in app store, or a YouTube video URL.
Corresponds to the JSON property targetUrl
28785 28786 28787 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28785 def target_url @target_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28792 28793 28794 28795 28796 28797 28798 28799 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28792 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @group_placement_target_url = args[:group_placement_target_url] if args.key?(:group_placement_target_url) @placement = args[:placement] if args.key?(:placement) @placement_type = args[:placement_type] if args.key?(:placement_type) @resource_name = args[:resource_name] if args.key?(:resource_name) @target_url = args[:target_url] if args.key?(:target_url) end |