Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDetailPlacementView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A view with metrics aggregated by ad group and URL or YouTube video. This view primarily surfaces placement data from the Google Display Network. While you can select segments like segments.ad_network_type, this view generally does not include placement data from other networks, such as the Search Partners network. To understand performance on Search Partners, consider other reports and segmentations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDetailPlacementView

Returns a new instance of GoogleAdsSearchads360V23ResourcesDetailPlacementView.



28696
28697
28698
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28696

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name is URL name for websites, YouTube video name for YouTube videos, and translated mobile app name for mobile apps. Corresponds to the JSON property displayName

Returns:

  • (String)


28663
28664
28665
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28663

def display_name
  @display_name
end

#group_placement_target_urlString

Output only. URL of the group placement, for example, domain, link to the mobile application in app store, or a YouTube channel URL. Corresponds to the JSON property groupPlacementTargetUrl

Returns:

  • (String)


28669
28670
28671
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28669

def group_placement_target_url
  @group_placement_target_url
end

#placementString

Output only. The automatic placement string at detail level, e. g. website URL, mobile application ID, or a YouTube video ID. Corresponds to the JSON property placement

Returns:

  • (String)


28675
28676
28677
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28675

def placement
  @placement
end

#placement_typeString

Output only. Type of the placement, for example, Website, YouTube Video, and Mobile Application. Corresponds to the JSON property placementType

Returns:

  • (String)


28681
28682
28683
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28681

def placement_type
  @placement_type
end

#resource_nameString

Output only. The resource name of the detail placement view. Detail placement view resource names have the form: customers/customer_id/ detailPlacementViews/ad_group_id~base64_placement` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28688
28689
28690
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28688

def resource_name
  @resource_name
end

#target_urlString

Output only. URL of the placement, for example, website, link to the mobile application in app store, or a YouTube video URL. Corresponds to the JSON property targetUrl

Returns:

  • (String)


28694
28695
28696
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28694

def target_url
  @target_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28701
28702
28703
28704
28705
28706
28707
28708
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28701

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @group_placement_target_url = args[:group_placement_target_url] if args.key?(:group_placement_target_url)
  @placement = args[:placement] if args.key?(:placement)
  @placement_type = args[:placement_type] if args.key?(:placement_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @target_url = args[:target_url] if args.key?(:target_url)
end