Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDetailedDemographic

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A detailed demographic: a particular interest-based vertical to be targeted to reach users based on long-term life facts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDetailedDemographic

Returns a new instance of GoogleAdsSearchads360V23ResourcesDetailedDemographic.



28842
28843
28844
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availabilitiesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryAvailability>

Output only. Availability information of the detailed demographic. Corresponds to the JSON property availabilities



28810
28811
28812
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28810

def availabilities
  @availabilities
end

#idFixnum

Output only. The ID of the detailed demographic. Corresponds to the JSON property id

Returns:

  • (Fixnum)


28815
28816
28817
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28815

def id
  @id
end

#launched_to_allBoolean Also known as: launched_to_all?

Output only. True if the detailed demographic is launched to all channels and locales. Corresponds to the JSON property launchedToAll

Returns:

  • (Boolean)


28821
28822
28823
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28821

def launched_to_all
  @launched_to_all
end

#nameString

Output only. The name of the detailed demographic. For example,"Highest Level of Educational Attainment" Corresponds to the JSON property name

Returns:

  • (String)


28828
28829
28830
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28828

def name
  @name
end

#parentString

Output only. The parent of the detailed_demographic. Corresponds to the JSON property parent

Returns:

  • (String)


28833
28834
28835
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28833

def parent
  @parent
end

#resource_nameString

Output only. The resource name of the detailed demographic. Detailed demographic resource names have the form: customers/customer_id/ detailedDemographics/detailed_demographic_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28840
28841
28842
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28840

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28847
28848
28849
28850
28851
28852
28853
28854
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28847

def update!(**args)
  @availabilities = args[:availabilities] if args.key?(:availabilities)
  @id = args[:id] if args.key?(:id)
  @launched_to_all = args[:launched_to_all] if args.key?(:launched_to_all)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end