Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDetailedDemographic

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A detailed demographic: a particular interest-based vertical to be targeted to reach users based on long-term life facts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDetailedDemographic

Returns a new instance of GoogleAdsSearchads360V23ResourcesDetailedDemographic.



28751
28752
28753
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availabilitiesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryAvailability>

Output only. Availability information of the detailed demographic. Corresponds to the JSON property availabilities



28719
28720
28721
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28719

def availabilities
  @availabilities
end

#idFixnum

Output only. The ID of the detailed demographic. Corresponds to the JSON property id

Returns:

  • (Fixnum)


28724
28725
28726
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28724

def id
  @id
end

#launched_to_allBoolean Also known as: launched_to_all?

Output only. True if the detailed demographic is launched to all channels and locales. Corresponds to the JSON property launchedToAll

Returns:

  • (Boolean)


28730
28731
28732
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28730

def launched_to_all
  @launched_to_all
end

#nameString

Output only. The name of the detailed demographic. For example,"Highest Level of Educational Attainment" Corresponds to the JSON property name

Returns:

  • (String)


28737
28738
28739
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28737

def name
  @name
end

#parentString

Output only. The parent of the detailed_demographic. Corresponds to the JSON property parent

Returns:

  • (String)


28742
28743
28744
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28742

def parent
  @parent
end

#resource_nameString

Output only. The resource name of the detailed demographic. Detailed demographic resource names have the form: customers/customer_id/ detailedDemographics/detailed_demographic_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28749
28750
28751
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28749

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28756
28757
28758
28759
28760
28761
28762
28763
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28756

def update!(**args)
  @availabilities = args[:availabilities] if args.key?(:availabilities)
  @id = args[:id] if args.key?(:id)
  @launched_to_all = args[:launched_to_all] if args.key?(:launched_to_all)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end