Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDisplayKeywordView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A display keyword view. Provides performance data for keywords used in Display Network campaigns. This view lets you analyze how your display keywords are performing across various segments. This view is primarily used to track the effectiveness of keyword targeting within your Display campaigns. To understand which network the metrics apply to, you can select the segments. ad_network_type field in your query. This field will segment the data by networks such as the Google Display Network, YouTube, Gmail, and so on. You can select fields from this resource along with metrics like impressions, clicks, and conversions to gauge performance. Attributed resources like ad_group and campaign can also be selected without segmenting metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDisplayKeywordView

Returns a new instance of GoogleAdsSearchads360V23ResourcesDisplayKeywordView.



28786
28787
28788
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28786

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_nameString

Output only. The resource name of the display keyword view. Display Keyword view resource names have the form: customers/customer_id/ displayKeywordViews/ad_group_id~criterion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28784
28785
28786
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28784

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28791
28792
28793
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28791

def update!(**args)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end