Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDistanceView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A distance view with metrics aggregated by the user's distance from an advertiser's location extensions. Each DistanceBucket includes all impressions that fall within its distance and a single impression will contribute to the metrics for all DistanceBuckets that include the user's distance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDistanceView

Returns a new instance of GoogleAdsSearchads360V23ResourcesDistanceView.



28913
28914
28915
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28913

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#distance_bucketString

Output only. Grouping of user distance from location extensions. Corresponds to the JSON property distanceBucket

Returns:

  • (String)


28897
28898
28899
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28897

def distance_bucket
  @distance_bucket
end

#metric_systemBoolean Also known as: metric_system?

Output only. True if the DistanceBucket is using the metric system, false otherwise. Corresponds to the JSON property metricSystem

Returns:

  • (Boolean)


28903
28904
28905
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28903

def metric_system
  @metric_system
end

#resource_nameString

Output only. The resource name of the distance view. Distance view resource names have the form: customers/customer_id/distanceViews/1~distance_bucket Corresponds to the JSON property resourceName

Returns:

  • (String)


28911
28912
28913
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28911

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28918
28919
28920
28921
28922
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28918

def update!(**args)
  @distance_bucket = args[:distance_bucket] if args.key?(:distance_bucket)
  @metric_system = args[:metric_system] if args.key?(:metric_system)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end