Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDistanceView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDistanceView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A distance view with metrics aggregated by the user's distance from an advertiser's location extensions. Each DistanceBucket includes all impressions that fall within its distance and a single impression will contribute to the metrics for all DistanceBuckets that include the user's distance.
Instance Attribute Summary collapse
-
#distance_bucket ⇒ String
Output only.
-
#metric_system ⇒ Boolean
(also: #metric_system?)
Output only.
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDistanceView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesDistanceView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDistanceView
Returns a new instance of GoogleAdsSearchads360V23ResourcesDistanceView.
28822 28823 28824 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28822 def initialize(**args) update!(**args) end |
Instance Attribute Details
#distance_bucket ⇒ String
Output only. Grouping of user distance from location extensions.
Corresponds to the JSON property distanceBucket
28806 28807 28808 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28806 def distance_bucket @distance_bucket end |
#metric_system ⇒ Boolean Also known as: metric_system?
Output only. True if the DistanceBucket is using the metric system, false
otherwise.
Corresponds to the JSON property metricSystem
28812 28813 28814 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28812 def metric_system @metric_system end |
#resource_name ⇒ String
Output only. The resource name of the distance view. Distance view resource
names have the form: customers/customer_id/distanceViews/1~distance_bucket
Corresponds to the JSON property resourceName
28820 28821 28822 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28820 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28827 28828 28829 28830 28831 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28827 def update!(**args) @distance_bucket = args[:distance_bucket] if args.key?(:distance_bucket) @metric_system = args[:metric_system] if args.key?(:metric_system) @resource_name = args[:resource_name] if args.key?(:resource_name) end |