Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
DoubleClick Campaign Manager (DCM) setting for a manager customer.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Output only.
-
#network_id ⇒ Fixnum
Output only.
-
#time_zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting
constructor
A new instance of GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting
Returns a new instance of GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting.
28946 28947 28948 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28946 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Output only. ID of the Campaign Manager advertiser associated with this
customer.
Corresponds to the JSON property advertiserId
28933 28934 28935 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28933 def advertiser_id @advertiser_id end |
#network_id ⇒ Fixnum
Output only. ID of the Campaign Manager network associated with this customer.
Corresponds to the JSON property networkId
28938 28939 28940 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28938 def network_id @network_id end |
#time_zone ⇒ String
Output only. Time zone of the Campaign Manager network associated with this
customer in IANA Time Zone Database format, such as America/New_York.
Corresponds to the JSON property timeZone
28944 28945 28946 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28944 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28951 28952 28953 28954 28955 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28951 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @network_id = args[:network_id] if args.key?(:network_id) @time_zone = args[:time_zone] if args.key?(:time_zone) end |