Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

DoubleClick Campaign Manager (DCM) setting for a manager customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting

Returns a new instance of GoogleAdsSearchads360V23ResourcesDoubleClickCampaignManagerSetting.



28855
28856
28857
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. ID of the Campaign Manager advertiser associated with this customer. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


28842
28843
28844
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28842

def advertiser_id
  @advertiser_id
end

#network_idFixnum

Output only. ID of the Campaign Manager network associated with this customer. Corresponds to the JSON property networkId

Returns:

  • (Fixnum)


28847
28848
28849
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28847

def network_id
  @network_id
end

#time_zoneString

Output only. Time zone of the Campaign Manager network associated with this customer in IANA Time Zone Database format, such as America/New_York. Corresponds to the JSON property timeZone

Returns:

  • (String)


28853
28854
28855
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28853

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28860
28861
28862
28863
28864
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28860

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @network_id = args[:network_id] if args.key?(:network_id)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end