Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDynamicSearchAdsSearchTermView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDynamicSearchAdsSearchTermView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A dynamic search ads search term view.
Instance Attribute Summary collapse
-
#has_matching_keyword ⇒ Boolean
(also: #has_matching_keyword?)
Output only.
-
#has_negative_keyword ⇒ Boolean
(also: #has_negative_keyword?)
Output only.
-
#has_negative_url ⇒ Boolean
(also: #has_negative_url?)
Output only.
-
#headline ⇒ String
Output only.
-
#landing_page ⇒ String
Output only.
-
#page_url ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#search_term ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDynamicSearchAdsSearchTermView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesDynamicSearchAdsSearchTermView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDynamicSearchAdsSearchTermView
Returns a new instance of GoogleAdsSearchads360V23ResourcesDynamicSearchAdsSearchTermView.
29085 29086 29087 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29085 def initialize(**args) update!(**args) end |
Instance Attribute Details
#has_matching_keyword ⇒ Boolean Also known as: has_matching_keyword?
Output only. True if query is added to targeted keywords. This field is read-
only.
Corresponds to the JSON property hasMatchingKeyword
29038 29039 29040 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29038 def has_matching_keyword @has_matching_keyword end |
#has_negative_keyword ⇒ Boolean Also known as: has_negative_keyword?
Output only. True if query matches a negative keyword. This field is read-only.
Corresponds to the JSON property hasNegativeKeyword
29044 29045 29046 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29044 def has_negative_keyword @has_negative_keyword end |
#has_negative_url ⇒ Boolean Also known as: has_negative_url?
Output only. True if query matches a negative url. This field is read-only.
Corresponds to the JSON property hasNegativeUrl
29050 29051 29052 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29050 def has_negative_url @has_negative_url end |
#headline ⇒ String
Output only. The dynamically generated headline of the Dynamic Search Ad. This
field is read-only.
Corresponds to the JSON property headline
29057 29058 29059 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29057 def headline @headline end |
#landing_page ⇒ String
Output only. The dynamically selected landing page URL of the impression. This
field is read-only.
Corresponds to the JSON property landingPage
29063 29064 29065 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29063 def landing_page @landing_page end |
#page_url ⇒ String
Output only. The URL of page feed item served for the impression. This field
is read-only.
Corresponds to the JSON property pageUrl
29069 29070 29071 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29069 def page_url @page_url end |
#resource_name ⇒ String
Output only. The resource name of the dynamic search ads search term view.
Dynamic search ads search term view resource names have the form: customers/
customer_id/dynamicSearchAdsSearchTermViews/ad_group_id~
search_term_fingerprint~headline_fingerprint~landing_page_fingerprint~
page_url_fingerprint`
Corresponds to the JSON propertyresourceName`
29078 29079 29080 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29078 def resource_name @resource_name end |
#search_term ⇒ String
Output only. Search term This field is read-only.
Corresponds to the JSON property searchTerm
29083 29084 29085 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29083 def search_term @search_term end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29090 29091 29092 29093 29094 29095 29096 29097 29098 29099 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29090 def update!(**args) @has_matching_keyword = args[:has_matching_keyword] if args.key?(:has_matching_keyword) @has_negative_keyword = args[:has_negative_keyword] if args.key?(:has_negative_keyword) @has_negative_url = args[:has_negative_url] if args.key?(:has_negative_url) @headline = args[:headline] if args.key?(:headline) @landing_page = args[:landing_page] if args.key?(:landing_page) @page_url = args[:page_url] if args.key?(:page_url) @resource_name = args[:resource_name] if args.key?(:resource_name) @search_term = args[:search_term] if args.key?(:search_term) end |