Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDynamicSearchAdsSearchTermView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A dynamic search ads search term view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesDynamicSearchAdsSearchTermView

Returns a new instance of GoogleAdsSearchads360V23ResourcesDynamicSearchAdsSearchTermView.



29013
29014
29015
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29013

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#has_matching_keywordBoolean Also known as: has_matching_keyword?

Output only. True if query is added to targeted keywords. This field is read- only. Corresponds to the JSON property hasMatchingKeyword

Returns:

  • (Boolean)


28966
28967
28968
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28966

def has_matching_keyword
  @has_matching_keyword
end

#has_negative_keywordBoolean Also known as: has_negative_keyword?

Output only. True if query matches a negative keyword. This field is read-only. Corresponds to the JSON property hasNegativeKeyword

Returns:

  • (Boolean)


28972
28973
28974
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28972

def has_negative_keyword
  @has_negative_keyword
end

#has_negative_urlBoolean Also known as: has_negative_url?

Output only. True if query matches a negative url. This field is read-only. Corresponds to the JSON property hasNegativeUrl

Returns:

  • (Boolean)


28978
28979
28980
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28978

def has_negative_url
  @has_negative_url
end

#headlineString

Output only. The dynamically generated headline of the Dynamic Search Ad. This field is read-only. Corresponds to the JSON property headline

Returns:

  • (String)


28985
28986
28987
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28985

def headline
  @headline
end

#landing_pageString

Output only. The dynamically selected landing page URL of the impression. This field is read-only. Corresponds to the JSON property landingPage

Returns:

  • (String)


28991
28992
28993
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28991

def landing_page
  @landing_page
end

#page_urlString

Output only. The URL of page feed item served for the impression. This field is read-only. Corresponds to the JSON property pageUrl

Returns:

  • (String)


28997
28998
28999
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28997

def page_url
  @page_url
end

#resource_nameString

Output only. The resource name of the dynamic search ads search term view. Dynamic search ads search term view resource names have the form: customers/ customer_id/dynamicSearchAdsSearchTermViews/ad_group_id~ search_term_fingerprint~headline_fingerprint~landing_page_fingerprint~ page_url_fingerprint` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


29006
29007
29008
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29006

def resource_name
  @resource_name
end

#search_termString

Output only. Search term This field is read-only. Corresponds to the JSON property searchTerm

Returns:

  • (String)


29011
29012
29013
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29011

def search_term
  @search_term
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29018
29019
29020
29021
29022
29023
29024
29025
29026
29027
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29018

def update!(**args)
  @has_matching_keyword = args[:has_matching_keyword] if args.key?(:has_matching_keyword)
  @has_negative_keyword = args[:has_negative_keyword] if args.key?(:has_negative_keyword)
  @has_negative_url = args[:has_negative_url] if args.key?(:has_negative_url)
  @headline = args[:headline] if args.key?(:headline)
  @landing_page = args[:landing_page] if args.key?(:landing_page)
  @page_url = args[:page_url] if args.key?(:page_url)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @search_term = args[:search_term] if args.key?(:search_term)
end