Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExpandedLandingPageView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExpandedLandingPageView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A landing page view with metrics aggregated at the expanded final URL level.
Instance Attribute Summary collapse
-
#expanded_final_url ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesExpandedLandingPageView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesExpandedLandingPageView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesExpandedLandingPageView
Returns a new instance of GoogleAdsSearchads360V23ResourcesExpandedLandingPageView.
29046 29047 29048 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29046 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expanded_final_url ⇒ String
Output only. The final URL that clicks are directed to.
Corresponds to the JSON property expandedFinalUrl
29037 29038 29039 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29037 def @expanded_final_url end |
#resource_name ⇒ String
Output only. The resource name of the expanded landing page view. Expanded
landing page view resource names have the form: customers/customer_id/
expandedLandingPageViews/expanded_final_url_fingerprint`
Corresponds to the JSON propertyresourceName`
29044 29045 29046 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29044 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29051 29052 29053 29054 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29051 def update!(**args) @expanded_final_url = args[:expanded_final_url] if args.key?(:expanded_final_url) @resource_name = args[:resource_name] if args.key?(:resource_name) end |