Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExpandedLandingPageView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A landing page view with metrics aggregated at the expanded final URL level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesExpandedLandingPageView

Returns a new instance of GoogleAdsSearchads360V23ResourcesExpandedLandingPageView.



28955
28956
28957
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28955

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expanded_final_urlString

Output only. The final URL that clicks are directed to. Corresponds to the JSON property expandedFinalUrl

Returns:

  • (String)


28946
28947
28948
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28946

def expanded_final_url
  @expanded_final_url
end

#resource_nameString

Output only. The resource name of the expanded landing page view. Expanded landing page view resource names have the form: customers/customer_id/ expandedLandingPageViews/expanded_final_url_fingerprint` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


28953
28954
28955
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28953

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28960
28961
28962
28963
# File 'lib/google/apis/searchads360_v23/classes.rb', line 28960

def update!(**args)
  @expanded_final_url = args[:expanded_final_url] if args.key?(:expanded_final_url)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end