Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperiment
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperiment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Google ads experiment for users to experiment changes on multiple campaigns, compare the performance, and apply the effective changes.
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the experiment.
-
#end_date ⇒ String
Date when the experiment ends.
-
#experiment_id ⇒ Fixnum
Output only.
-
#goals ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMetricGoal>
The goals of this experiment.
-
#long_running_operation ⇒ String
Output only.
-
#name ⇒ String
Required.
-
#promote_status ⇒ String
Output only.
-
#resource_name ⇒ String
Immutable.
-
#start_date ⇒ String
Date when the experiment starts.
-
#status ⇒ String
The Advertiser-chosen status of this experiment.
-
#suffix ⇒ String
For system managed experiments, the advertiser must provide a suffix during construction, in the setup stage before moving to initiated.
-
#sync_enabled ⇒ Boolean
(also: #sync_enabled?)
Immutable.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesExperiment
constructor
A new instance of GoogleAdsSearchads360V23ResourcesExperiment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesExperiment
Returns a new instance of GoogleAdsSearchads360V23ResourcesExperiment.
29216 29217 29218 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29216 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
The description of the experiment. It must have a minimum length of 1 and
maximum length of 2048.
Corresponds to the JSON property description
29138 29139 29140 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29138 def description @description end |
#end_date ⇒ String
Date when the experiment ends. By default, the experiment ends on the campaign'
s end date. If this field is set, then the experiment ends at the end of the
specified date in the customer's time zone. Format: YYYY-MM-DD Example: 2019-
04-18
Corresponds to the JSON property endDate
29146 29147 29148 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29146 def end_date @end_date end |
#experiment_id ⇒ Fixnum
Output only. The ID of the experiment. Read only.
Corresponds to the JSON property experimentId
29151 29152 29153 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29151 def experiment_id @experiment_id end |
#goals ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMetricGoal>
The goals of this experiment.
Corresponds to the JSON property goals
29156 29157 29158 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29156 def goals @goals end |
#long_running_operation ⇒ String
Output only. The resource name of the long-running operation that can be used
to poll for completion of experiment schedule or promote. The most recent long
running operation is returned.
Corresponds to the JSON property longRunningOperation
29163 29164 29165 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29163 def long_running_operation @long_running_operation end |
#name ⇒ String
Required. The name of the experiment. It must have a minimum length of 1 and
maximum length of 1024. It must be unique under a customer.
Corresponds to the JSON property name
29169 29170 29171 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29169 def name @name end |
#promote_status ⇒ String
Output only. The status of the experiment promotion process.
Corresponds to the JSON property promoteStatus
29174 29175 29176 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29174 def promote_status @promote_status end |
#resource_name ⇒ String
Immutable. The resource name of the experiment. Experiment resource names have
the form: customers/customer_id/experiments/experiment_id`
Corresponds to the JSON propertyresourceName`
29180 29181 29182 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29180 def resource_name @resource_name end |
#start_date ⇒ String
Date when the experiment starts. By default, the experiment starts now or on
the campaign's start date, whichever is later. If this field is set, then the
experiment starts at the beginning of the specified date in the customer's
time zone. Format: YYYY-MM-DD Example: 2019-03-14
Corresponds to the JSON property startDate
29188 29189 29190 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29188 def start_date @start_date end |
#status ⇒ String
The Advertiser-chosen status of this experiment.
Corresponds to the JSON property status
29193 29194 29195 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29193 def status @status end |
#suffix ⇒ String
For system managed experiments, the advertiser must provide a suffix during
construction, in the setup stage before moving to initiated. The suffix will
be appended to the in-design and experiment campaign names so that the name is
base campaign name + suffix.
Corresponds to the JSON property suffix
29201 29202 29203 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29201 def suffix @suffix end |
#sync_enabled ⇒ Boolean Also known as: sync_enabled?
Immutable. Set to true if changes to base campaigns should be synced to the
trial campaigns. Any changes made directly to trial campaigns will be
preserved. This field can only be set when the experiment is being created.
Corresponds to the JSON property syncEnabled
29208 29209 29210 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29208 def sync_enabled @sync_enabled end |
#type ⇒ String
Required. The product/feature that uses this experiment.
Corresponds to the JSON property type
29214 29215 29216 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29214 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29221 29222 29223 29224 29225 29226 29227 29228 29229 29230 29231 29232 29233 29234 29235 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29221 def update!(**args) @description = args[:description] if args.key?(:description) @end_date = args[:end_date] if args.key?(:end_date) @experiment_id = args[:experiment_id] if args.key?(:experiment_id) @goals = args[:goals] if args.key?(:goals) @long_running_operation = args[:long_running_operation] if args.key?(:long_running_operation) @name = args[:name] if args.key?(:name) @promote_status = args[:promote_status] if args.key?(:promote_status) @resource_name = args[:resource_name] if args.key?(:resource_name) @start_date = args[:start_date] if args.key?(:start_date) @status = args[:status] if args.key?(:status) @suffix = args[:suffix] if args.key?(:suffix) @sync_enabled = args[:sync_enabled] if args.key?(:sync_enabled) @type = args[:type] if args.key?(:type) end |