Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperiment
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperiment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Google ads experiment for users to experiment changes on multiple campaigns, compare the performance, and apply the effective changes.
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the experiment.
-
#end_date ⇒ String
Date when the experiment ends.
-
#experiment_id ⇒ Fixnum
Output only.
-
#goals ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMetricGoal>
The goals of this experiment.
-
#long_running_operation ⇒ String
Output only.
-
#name ⇒ String
Required.
-
#promote_status ⇒ String
Output only.
-
#resource_name ⇒ String
Immutable.
-
#start_date ⇒ String
Date when the experiment starts.
-
#status ⇒ String
The Advertiser-chosen status of this experiment.
-
#suffix ⇒ String
For system managed experiments, the advertiser must provide a suffix during construction, in the setup stage before moving to initiated.
-
#sync_enabled ⇒ Boolean
(also: #sync_enabled?)
Immutable.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesExperiment
constructor
A new instance of GoogleAdsSearchads360V23ResourcesExperiment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesExperiment
Returns a new instance of GoogleAdsSearchads360V23ResourcesExperiment.
29144 29145 29146 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
The description of the experiment. It must have a minimum length of 1 and
maximum length of 2048.
Corresponds to the JSON property description
29066 29067 29068 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29066 def description @description end |
#end_date ⇒ String
Date when the experiment ends. By default, the experiment ends on the campaign'
s end date. If this field is set, then the experiment ends at the end of the
specified date in the customer's time zone. Format: YYYY-MM-DD Example: 2019-
04-18
Corresponds to the JSON property endDate
29074 29075 29076 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29074 def end_date @end_date end |
#experiment_id ⇒ Fixnum
Output only. The ID of the experiment. Read only.
Corresponds to the JSON property experimentId
29079 29080 29081 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29079 def experiment_id @experiment_id end |
#goals ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMetricGoal>
The goals of this experiment.
Corresponds to the JSON property goals
29084 29085 29086 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29084 def goals @goals end |
#long_running_operation ⇒ String
Output only. The resource name of the long-running operation that can be used
to poll for completion of experiment schedule or promote. The most recent long
running operation is returned.
Corresponds to the JSON property longRunningOperation
29091 29092 29093 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29091 def long_running_operation @long_running_operation end |
#name ⇒ String
Required. The name of the experiment. It must have a minimum length of 1 and
maximum length of 1024. It must be unique under a customer.
Corresponds to the JSON property name
29097 29098 29099 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29097 def name @name end |
#promote_status ⇒ String
Output only. The status of the experiment promotion process.
Corresponds to the JSON property promoteStatus
29102 29103 29104 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29102 def promote_status @promote_status end |
#resource_name ⇒ String
Immutable. The resource name of the experiment. Experiment resource names have
the form: customers/customer_id/experiments/experiment_id`
Corresponds to the JSON propertyresourceName`
29108 29109 29110 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29108 def resource_name @resource_name end |
#start_date ⇒ String
Date when the experiment starts. By default, the experiment starts now or on
the campaign's start date, whichever is later. If this field is set, then the
experiment starts at the beginning of the specified date in the customer's
time zone. Format: YYYY-MM-DD Example: 2019-03-14
Corresponds to the JSON property startDate
29116 29117 29118 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29116 def start_date @start_date end |
#status ⇒ String
The Advertiser-chosen status of this experiment.
Corresponds to the JSON property status
29121 29122 29123 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29121 def status @status end |
#suffix ⇒ String
For system managed experiments, the advertiser must provide a suffix during
construction, in the setup stage before moving to initiated. The suffix will
be appended to the in-design and experiment campaign names so that the name is
base campaign name + suffix.
Corresponds to the JSON property suffix
29129 29130 29131 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29129 def suffix @suffix end |
#sync_enabled ⇒ Boolean Also known as: sync_enabled?
Immutable. Set to true if changes to base campaigns should be synced to the
trial campaigns. Any changes made directly to trial campaigns will be
preserved. This field can only be set when the experiment is being created.
Corresponds to the JSON property syncEnabled
29136 29137 29138 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29136 def sync_enabled @sync_enabled end |
#type ⇒ String
Required. The product/feature that uses this experiment.
Corresponds to the JSON property type
29142 29143 29144 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29142 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29149 29150 29151 29152 29153 29154 29155 29156 29157 29158 29159 29160 29161 29162 29163 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29149 def update!(**args) @description = args[:description] if args.key?(:description) @end_date = args[:end_date] if args.key?(:end_date) @experiment_id = args[:experiment_id] if args.key?(:experiment_id) @goals = args[:goals] if args.key?(:goals) @long_running_operation = args[:long_running_operation] if args.key?(:long_running_operation) @name = args[:name] if args.key?(:name) @promote_status = args[:promote_status] if args.key?(:promote_status) @resource_name = args[:resource_name] if args.key?(:resource_name) @start_date = args[:start_date] if args.key?(:start_date) @status = args[:status] if args.key?(:status) @suffix = args[:suffix] if args.key?(:suffix) @sync_enabled = args[:sync_enabled] if args.key?(:sync_enabled) @type = args[:type] if args.key?(:type) end |