Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArmAssetGroupInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArmAssetGroupInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Holds the asset groups included in an arm of an Optimize Assets experiment.
Instance Attribute Summary collapse
-
#asset_group ⇒ String
Asset group resource name.
-
#asset_group_assets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArmAssetGroupAssetInfo>
List of asset group assets under the asset group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesExperimentArmAssetGroupInfo
constructor
A new instance of GoogleAdsSearchads360V23ResourcesExperimentArmAssetGroupInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesExperimentArmAssetGroupInfo
Returns a new instance of GoogleAdsSearchads360V23ResourcesExperimentArmAssetGroupInfo.
16961 16962 16963 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_group ⇒ String
Asset group resource name.
Corresponds to the JSON property assetGroup
16954 16955 16956 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16954 def asset_group @asset_group end |
#asset_group_assets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArmAssetGroupAssetInfo>
List of asset group assets under the asset group.
Corresponds to the JSON property assetGroupAssets
16959 16960 16961 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16959 def asset_group_assets @asset_group_assets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16966 16967 16968 16969 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16966 def update!(**args) @asset_group = args[:asset_group] if args.key?(:asset_group) @asset_group_assets = args[:asset_group_assets] if args.key?(:asset_group_assets) end |