Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesFellowship
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesFellowship
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Details about the employee's medical Fellowship. Fellowship is a period of medical training that the professional undertakes after finishing their residency.
Instance Attribute Summary collapse
-
#completion_year ⇒ Fixnum
Output only.
-
#institution_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesFellowship
constructor
A new instance of GoogleAdsSearchads360V23ResourcesFellowship.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesFellowship
Returns a new instance of GoogleAdsSearchads360V23ResourcesFellowship.
29159 29160 29161 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29159 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completion_year ⇒ Fixnum
Output only. Year of completion.
Corresponds to the JSON property completionYear
29152 29153 29154 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29152 def completion_year @completion_year end |
#institution_name ⇒ String
Output only. Name of the instutition at which the fellowship was completed.
Corresponds to the JSON property institutionName
29157 29158 29159 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29157 def institution_name @institution_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29164 29165 29166 29167 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29164 def update!(**args) @completion_year = args[:completion_year] if args.key?(:completion_year) @institution_name = args[:institution_name] if args.key?(:institution_name) end |