Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGenderView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGenderView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A gender view. The gender_view resource reflects the effective serving state, rather than what criteria were added. An ad group without gender criteria by default shows to all genders, so all genders appear in gender_view with stats.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGenderView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesGenderView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGenderView
Returns a new instance of GoogleAdsSearchads360V23ResourcesGenderView.
29244 29245 29246 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29244 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Output only. The resource name of the gender view. Gender view resource names
have the form: customers/customer_id/genderViews/ad_group_id~
criterion_id`
Corresponds to the JSON propertyresourceName`
29242 29243 29244 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29242 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29249 29250 29251 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29249 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) end |