Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGeoTargetConstant
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGeoTargetConstant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A geo target constant.
Instance Attribute Summary collapse
-
#canonical_name ⇒ String
Output only.
-
#country_code ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Output only.
-
#parent_geo_target ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#target_type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGeoTargetConstant
constructor
A new instance of GoogleAdsSearchads360V23ResourcesGeoTargetConstant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGeoTargetConstant
Returns a new instance of GoogleAdsSearchads360V23ResourcesGeoTargetConstant.
29303 29304 29305 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canonical_name ⇒ String
Output only. The fully qualified English name, consisting of the target's name
and that of its parent and country.
Corresponds to the JSON property canonicalName
29262 29263 29264 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29262 def canonical_name @canonical_name end |
#country_code ⇒ String
Output only. The ISO-3166-1 alpha-2 country code that is associated with the
target.
Corresponds to the JSON property countryCode
29268 29269 29270 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29268 def country_code @country_code end |
#id ⇒ Fixnum
Output only. The ID of the geo target constant.
Corresponds to the JSON property id
29273 29274 29275 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29273 def id @id end |
#name ⇒ String
Output only. Geo target constant English name.
Corresponds to the JSON property name
29278 29279 29280 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29278 def name @name end |
#parent_geo_target ⇒ String
Output only. The resource name of the parent geo target constant. Geo target
constant resource names have the form: geoTargetConstants/
parent_geo_target_constant_id`
Corresponds to the JSON propertyparentGeoTarget`
29285 29286 29287 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29285 def parent_geo_target @parent_geo_target end |
#resource_name ⇒ String
Output only. The resource name of the geo target constant. Geo target constant
resource names have the form: geoTargetConstants/geo_target_constant_id`
Corresponds to the JSON propertyresourceName`
29291 29292 29293 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29291 def resource_name @resource_name end |
#status ⇒ String
Output only. Geo target constant status.
Corresponds to the JSON property status
29296 29297 29298 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29296 def status @status end |
#target_type ⇒ String
Output only. Geo target constant target type.
Corresponds to the JSON property targetType
29301 29302 29303 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29301 def target_type @target_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29308 29309 29310 29311 29312 29313 29314 29315 29316 29317 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29308 def update!(**args) @canonical_name = args[:canonical_name] if args.key?(:canonical_name) @country_code = args[:country_code] if args.key?(:country_code) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @parent_geo_target = args[:parent_geo_target] if args.key?(:parent_geo_target) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @target_type = args[:target_type] if args.key?(:target_type) end |