Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGeographicView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A geographic view. Geographic View includes all metrics aggregated at the country level, one row per country. It reports metrics at either actual physical location of the user or an area of interest. If other segment fields are used, you may get more than one row per country.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGeographicView

Returns a new instance of GoogleAdsSearchads360V23ResourcesGeographicView.



29344
29345
29346
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_criterion_idFixnum

Output only. Criterion Id for the country. Corresponds to the JSON property countryCriterionId

Returns:

  • (Fixnum)


29330
29331
29332
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29330

def country_criterion_id
  @country_criterion_id
end

#location_typeString

Output only. Type of the geo targeting of the campaign. Corresponds to the JSON property locationType

Returns:

  • (String)


29335
29336
29337
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29335

def location_type
  @location_type
end

#resource_nameString

Output only. The resource name of the geographic view. Geographic view resource names have the form: customers/customer_id/geographicViews/ country_criterion_id~location_type` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


29342
29343
29344
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29342

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29349
29350
29351
29352
29353
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29349

def update!(**args)
  @country_criterion_id = args[:country_criterion_id] if args.key?(:country_criterion_id)
  @location_type = args[:location_type] if args.key?(:location_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end