Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGoogleAdsIdentifier

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The identifier for Google Ads account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGoogleAdsIdentifier

Returns a new instance of GoogleAdsSearchads360V23ResourcesGoogleAdsIdentifier.



29417
29418
29419
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customerString

Immutable. The resource name of the Google Ads account. This field is required and should not be empty when creating a new Google Ads link. It is unable to be modified after the creation of the link. Corresponds to the JSON property customer

Returns:

  • (String)


29415
29416
29417
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29415

def customer
  @customer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29422
29423
29424
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29422

def update!(**args)
  @customer = args[:customer] if args.key?(:customer)
end