Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGroupContentSuitabilityPlacementView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGroupContentSuitabilityPlacementView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A group content suitability placement view.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#placement ⇒ String
Output only.
-
#placement_type ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#target_url ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGroupContentSuitabilityPlacementView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesGroupContentSuitabilityPlacementView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGroupContentSuitabilityPlacementView
Returns a new instance of GoogleAdsSearchads360V23ResourcesGroupContentSuitabilityPlacementView.
29632 29633 29634 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29632 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. The display name is URL for websites, YouTube video name for
YouTube videos, and translated mobile app name for mobile apps.
Corresponds to the JSON property displayName
29604 29605 29606 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29604 def display_name @display_name end |
#placement ⇒ String
Output only. The automatic placement string at group level, for example.
website url, mobile application id, or a YouTube video id.
Corresponds to the JSON property placement
29610 29611 29612 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29610 def placement @placement end |
#placement_type ⇒ String
Output only. Represents the type of the placement, for example, Website,
YouTubeVideo and MobileApplication.
Corresponds to the JSON property placementType
29616 29617 29618 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29616 def placement_type @placement_type end |
#resource_name ⇒ String
Output only. The resource name of the group content suitability placement view.
Group content suitability placement view resource names have the form:
customers/customer_id/groupContentSuitabilityPlacementViews/
placement_fingerprint`
Corresponds to the JSON propertyresourceName`
29624 29625 29626 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29624 def resource_name @resource_name end |
#target_url ⇒ String
Output only. URL of the placement, for example, website, link to the mobile
application in app store, or a YouTube video URL.
Corresponds to the JSON property targetUrl
29630 29631 29632 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29630 def target_url @target_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29637 29638 29639 29640 29641 29642 29643 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29637 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @placement = args[:placement] if args.key?(:placement) @placement_type = args[:placement_type] if args.key?(:placement_type) @resource_name = args[:resource_name] if args.key?(:resource_name) @target_url = args[:target_url] if args.key?(:target_url) end |