Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGroupContentSuitabilityPlacementView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A group content suitability placement view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGroupContentSuitabilityPlacementView

Returns a new instance of GoogleAdsSearchads360V23ResourcesGroupContentSuitabilityPlacementView.



29535
29536
29537
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29535

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name is URL for websites, YouTube video name for YouTube videos, and translated mobile app name for mobile apps. Corresponds to the JSON property displayName

Returns:

  • (String)


29507
29508
29509
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29507

def display_name
  @display_name
end

#placementString

Output only. The automatic placement string at group level, for example. website url, mobile application id, or a YouTube video id. Corresponds to the JSON property placement

Returns:

  • (String)


29513
29514
29515
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29513

def placement
  @placement
end

#placement_typeString

Output only. Represents the type of the placement, for example, Website, YouTubeVideo and MobileApplication. Corresponds to the JSON property placementType

Returns:

  • (String)


29519
29520
29521
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29519

def placement_type
  @placement_type
end

#resource_nameString

Output only. The resource name of the group content suitability placement view. Group content suitability placement view resource names have the form: customers/customer_id/groupContentSuitabilityPlacementViews/ placement_fingerprint` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


29527
29528
29529
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29527

def resource_name
  @resource_name
end

#target_urlString

Output only. URL of the placement, for example, website, link to the mobile application in app store, or a YouTube video URL. Corresponds to the JSON property targetUrl

Returns:

  • (String)


29533
29534
29535
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29533

def target_url
  @target_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29540
29541
29542
29543
29544
29545
29546
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29540

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @placement = args[:placement] if args.key?(:placement)
  @placement_type = args[:placement_type] if args.key?(:placement_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @target_url = args[:target_url] if args.key?(:target_url)
end