Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGroupPlacementView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGroupPlacementView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A view showing performance data for where your ads actually served on the
Display Network and YouTube, including both targeted (managed) and automatic
placements. Data for low-traffic placements may be aggregated. The scope of
placements shown is influenced by the ad group's TargetingSetting for the
PLACEMENT dimension.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#placement ⇒ String
Output only.
-
#placement_type ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#target_url ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGroupPlacementView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesGroupPlacementView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGroupPlacementView
Returns a new instance of GoogleAdsSearchads360V23ResourcesGroupPlacementView.
29757 29758 29759 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. Domain name for websites and YouTube channel name for YouTube
channels.
Corresponds to the JSON property displayName
29730 29731 29732 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29730 def display_name @display_name end |
#placement ⇒ String
Output only. The automatic placement string at group level, e. g. web domain,
mobile app ID, or a YouTube channel ID.
Corresponds to the JSON property placement
29736 29737 29738 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29736 def placement @placement end |
#placement_type ⇒ String
Output only. Type of the placement, for example, Website, YouTube Channel,
Mobile Application.
Corresponds to the JSON property placementType
29742 29743 29744 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29742 def placement_type @placement_type end |
#resource_name ⇒ String
Output only. The resource name of the group placement view. Group placement
view resource names have the form: customers/customer_id/
groupPlacementViews/ad_group_id~base64_placement`
Corresponds to the JSON propertyresourceName`
29749 29750 29751 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29749 def resource_name @resource_name end |
#target_url ⇒ String
Output only. URL of the group placement, for example, domain, link to the
mobile application in app store, or a YouTube channel URL.
Corresponds to the JSON property targetUrl
29755 29756 29757 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29755 def target_url @target_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29762 29763 29764 29765 29766 29767 29768 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29762 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @placement = args[:placement] if args.key?(:placement) @placement_type = args[:placement_type] if args.key?(:placement_type) @resource_name = args[:resource_name] if args.key?(:resource_name) @target_url = args[:target_url] if args.key?(:target_url) end |