Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGroupPlacementView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGroupPlacementView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A view showing performance data for where your ads actually served on the
Display Network and YouTube, including both targeted (managed) and automatic
placements. Data for low-traffic placements may be aggregated. The scope of
placements shown is influenced by the ad group's TargetingSetting for the
PLACEMENT dimension.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#placement ⇒ String
Output only.
-
#placement_type ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#target_url ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGroupPlacementView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesGroupPlacementView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGroupPlacementView
Returns a new instance of GoogleAdsSearchads360V23ResourcesGroupPlacementView.
29685 29686 29687 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29685 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. Domain name for websites and YouTube channel name for YouTube
channels.
Corresponds to the JSON property displayName
29658 29659 29660 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29658 def display_name @display_name end |
#placement ⇒ String
Output only. The automatic placement string at group level, e. g. web domain,
mobile app ID, or a YouTube channel ID.
Corresponds to the JSON property placement
29664 29665 29666 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29664 def placement @placement end |
#placement_type ⇒ String
Output only. Type of the placement, for example, Website, YouTube Channel,
Mobile Application.
Corresponds to the JSON property placementType
29670 29671 29672 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29670 def placement_type @placement_type end |
#resource_name ⇒ String
Output only. The resource name of the group placement view. Group placement
view resource names have the form: customers/customer_id/
groupPlacementViews/ad_group_id~base64_placement`
Corresponds to the JSON propertyresourceName`
29677 29678 29679 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29677 def resource_name @resource_name end |
#target_url ⇒ String
Output only. URL of the group placement, for example, domain, link to the
mobile application in app store, or a YouTube channel URL.
Corresponds to the JSON property targetUrl
29683 29684 29685 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29683 def target_url @target_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29690 29691 29692 29693 29694 29695 29696 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29690 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @placement = args[:placement] if args.key?(:placement) @placement_type = args[:placement_type] if args.key?(:placement_type) @resource_name = args[:resource_name] if args.key?(:resource_name) @target_url = args[:target_url] if args.key?(:target_url) end |