Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGroupPlacementView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A group placement view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesGroupPlacementView

Returns a new instance of GoogleAdsSearchads360V23ResourcesGroupPlacementView.



29584
29585
29586
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. Domain name for websites and YouTube channel name for YouTube channels. Corresponds to the JSON property displayName

Returns:

  • (String)


29557
29558
29559
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29557

def display_name
  @display_name
end

#placementString

Output only. The automatic placement string at group level, e. g. web domain, mobile app ID, or a YouTube channel ID. Corresponds to the JSON property placement

Returns:

  • (String)


29563
29564
29565
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29563

def placement
  @placement
end

#placement_typeString

Output only. Type of the placement, for example, Website, YouTube Channel, Mobile Application. Corresponds to the JSON property placementType

Returns:

  • (String)


29569
29570
29571
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29569

def placement_type
  @placement_type
end

#resource_nameString

Output only. The resource name of the group placement view. Group placement view resource names have the form: customers/customer_id/ groupPlacementViews/ad_group_id~base64_placement` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


29576
29577
29578
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29576

def resource_name
  @resource_name
end

#target_urlString

Output only. URL of the group placement, for example, domain, link to the mobile application in app store, or a YouTube channel URL. Corresponds to the JSON property targetUrl

Returns:

  • (String)


29582
29583
29584
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29582

def target_url
  @target_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29589
29590
29591
29592
29593
29594
29595
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29589

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @placement = args[:placement] if args.key?(:placement)
  @placement_type = args[:placement_type] if args.key?(:placement_type)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @target_url = args[:target_url] if args.key?(:target_url)
end