Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesHotelReconciliation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesHotelReconciliation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A hotel reconciliation. It contains conversion information from Hotel bookings to reconcile with advertiser records. These rows may be updated or canceled before billing through Bulk Uploads.
Instance Attribute Summary collapse
-
#billed ⇒ Boolean
(also: #billed?)
Output only.
-
#campaign ⇒ String
Output only.
-
#check_in_date ⇒ String
Output only.
-
#check_out_date ⇒ String
Output only.
-
#commission_id ⇒ String
Required.
-
#hotel_center_id ⇒ Fixnum
Output only.
-
#hotel_id ⇒ String
Output only.
-
#order_id ⇒ String
Output only.
-
#reconciled_value_micros ⇒ Fixnum
Required.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesHotelReconciliation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesHotelReconciliation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesHotelReconciliation
Returns a new instance of GoogleAdsSearchads360V23ResourcesHotelReconciliation.
29916 29917 29918 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29916 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billed ⇒ Boolean Also known as: billed?
Output only. Whether a given booking has been billed. Once billed, a booking
can't be modified.
Corresponds to the JSON property billed
29842 29843 29844 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29842 def billed @billed end |
#campaign ⇒ String
Output only. The resource name for the Campaign associated with the conversion.
Corresponds to the JSON property campaign
29848 29849 29850 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29848 def campaign @campaign end |
#check_in_date ⇒ String
Output only. Check-in date recorded when the booking is made. If the check-in
date is modified at reconciliation, the revised date will then take the place
of the original date in this column. Format is YYYY-MM-DD.
Corresponds to the JSON property checkInDate
29855 29856 29857 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29855 def check_in_date @check_in_date end |
#check_out_date ⇒ String
Output only. Check-out date recorded when the booking is made. If the check-in
date is modified at reconciliation, the revised date will then take the place
of the original date in this column. Format is YYYY-MM-DD.
Corresponds to the JSON property checkOutDate
29862 29863 29864 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29862 def check_out_date @check_out_date end |
#commission_id ⇒ String
Required. Output only. The commission ID is Google's ID for this booking.
Every booking event is assigned a Commission ID to help you match it to a
guest stay.
Corresponds to the JSON property commissionId
29869 29870 29871 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29869 def commission_id @commission_id end |
#hotel_center_id ⇒ Fixnum
Output only. Identifier for the Hotel Center account which provides the rates
for the Hotel campaign.
Corresponds to the JSON property hotelCenterId
29875 29876 29877 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29875 def hotel_center_id @hotel_center_id end |
#hotel_id ⇒ String
Output only. Unique identifier for the booked property, as provided in the
Hotel Center feed. The hotel ID comes from the 'ID' parameter of the
conversion tracking tag.
Corresponds to the JSON property hotelId
29882 29883 29884 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29882 def hotel_id @hotel_id end |
#order_id ⇒ String
Output only. The order ID is the identifier for this booking as provided in
the 'transaction_id' parameter of the conversion tracking tag.
Corresponds to the JSON property orderId
29888 29889 29890 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29888 def order_id @order_id end |
#reconciled_value_micros ⇒ Fixnum
Required. Output only. Reconciled value is the final value of a booking as
paid by the guest. If original booking value changes for any reason, such as
itinerary changes or room upsells, the reconciled value should be the full
final amount collected. If a booking is canceled, the reconciled value should
include the value of any cancellation fees or non-refundable nights charged.
Value is in millionths of the base unit currency. For example, $12.35 would be
represented as 12350000. Currency unit is in the default customer currency.
Corresponds to the JSON property reconciledValueMicros
29899 29900 29901 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29899 def reconciled_value_micros @reconciled_value_micros end |
#resource_name ⇒ String
Immutable. The resource name of the hotel reconciliation. Hotel reconciliation
resource names have the form: customers/customer_id/hotelReconciliations/
commission_id`
Corresponds to the JSON propertyresourceName`
29906 29907 29908 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29906 def resource_name @resource_name end |
#status ⇒ String
Required. Output only. Current status of a booking with regards to
reconciliation and billing. Bookings should be reconciled within 45 days after
the check-out date. Any booking not reconciled within 45 days will be billed
at its original value.
Corresponds to the JSON property status
29914 29915 29916 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29914 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29921 29922 29923 29924 29925 29926 29927 29928 29929 29930 29931 29932 29933 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29921 def update!(**args) @billed = args[:billed] if args.key?(:billed) @campaign = args[:campaign] if args.key?(:campaign) @check_in_date = args[:check_in_date] if args.key?(:check_in_date) @check_out_date = args[:check_out_date] if args.key?(:check_out_date) @commission_id = args[:commission_id] if args.key?(:commission_id) @hotel_center_id = args[:hotel_center_id] if args.key?(:hotel_center_id) @hotel_id = args[:hotel_id] if args.key?(:hotel_id) @order_id = args[:order_id] if args.key?(:order_id) @reconciled_value_micros = args[:reconciled_value_micros] if args.key?(:reconciled_value_micros) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) end |