Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesHotelReconciliation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A hotel reconciliation. It contains conversion information from Hotel bookings to reconcile with advertiser records. These rows may be updated or canceled before billing through Bulk Uploads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesHotelReconciliation

Returns a new instance of GoogleAdsSearchads360V23ResourcesHotelReconciliation.



29844
29845
29846
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29844

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billedBoolean Also known as: billed?

Output only. Whether a given booking has been billed. Once billed, a booking can't be modified. Corresponds to the JSON property billed

Returns:

  • (Boolean)


29770
29771
29772
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29770

def billed
  @billed
end

#campaignString

Output only. The resource name for the Campaign associated with the conversion. Corresponds to the JSON property campaign

Returns:

  • (String)


29776
29777
29778
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29776

def campaign
  @campaign
end

#check_in_dateString

Output only. Check-in date recorded when the booking is made. If the check-in date is modified at reconciliation, the revised date will then take the place of the original date in this column. Format is YYYY-MM-DD. Corresponds to the JSON property checkInDate

Returns:

  • (String)


29783
29784
29785
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29783

def check_in_date
  @check_in_date
end

#check_out_dateString

Output only. Check-out date recorded when the booking is made. If the check-in date is modified at reconciliation, the revised date will then take the place of the original date in this column. Format is YYYY-MM-DD. Corresponds to the JSON property checkOutDate

Returns:

  • (String)


29790
29791
29792
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29790

def check_out_date
  @check_out_date
end

#commission_idString

Required. Output only. The commission ID is Google's ID for this booking. Every booking event is assigned a Commission ID to help you match it to a guest stay. Corresponds to the JSON property commissionId

Returns:

  • (String)


29797
29798
29799
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29797

def commission_id
  @commission_id
end

#hotel_center_idFixnum

Output only. Identifier for the Hotel Center account which provides the rates for the Hotel campaign. Corresponds to the JSON property hotelCenterId

Returns:

  • (Fixnum)


29803
29804
29805
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29803

def hotel_center_id
  @hotel_center_id
end

#hotel_idString

Output only. Unique identifier for the booked property, as provided in the Hotel Center feed. The hotel ID comes from the 'ID' parameter of the conversion tracking tag. Corresponds to the JSON property hotelId

Returns:

  • (String)


29810
29811
29812
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29810

def hotel_id
  @hotel_id
end

#order_idString

Output only. The order ID is the identifier for this booking as provided in the 'transaction_id' parameter of the conversion tracking tag. Corresponds to the JSON property orderId

Returns:

  • (String)


29816
29817
29818
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29816

def order_id
  @order_id
end

#reconciled_value_microsFixnum

Required. Output only. Reconciled value is the final value of a booking as paid by the guest. If original booking value changes for any reason, such as itinerary changes or room upsells, the reconciled value should be the full final amount collected. If a booking is canceled, the reconciled value should include the value of any cancellation fees or non-refundable nights charged. Value is in millionths of the base unit currency. For example, $12.35 would be represented as 12350000. Currency unit is in the default customer currency. Corresponds to the JSON property reconciledValueMicros

Returns:

  • (Fixnum)


29827
29828
29829
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29827

def reconciled_value_micros
  @reconciled_value_micros
end

#resource_nameString

Immutable. The resource name of the hotel reconciliation. Hotel reconciliation resource names have the form: customers/customer_id/hotelReconciliations/ commission_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


29834
29835
29836
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29834

def resource_name
  @resource_name
end

#statusString

Required. Output only. Current status of a booking with regards to reconciliation and billing. Bookings should be reconciled within 45 days after the check-out date. Any booking not reconciled within 45 days will be billed at its original value. Corresponds to the JSON property status

Returns:

  • (String)


29842
29843
29844
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29842

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29849
29850
29851
29852
29853
29854
29855
29856
29857
29858
29859
29860
29861
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29849

def update!(**args)
  @billed = args[:billed] if args.key?(:billed)
  @campaign = args[:campaign] if args.key?(:campaign)
  @check_in_date = args[:check_in_date] if args.key?(:check_in_date)
  @check_out_date = args[:check_out_date] if args.key?(:check_out_date)
  @commission_id = args[:commission_id] if args.key?(:commission_id)
  @hotel_center_id = args[:hotel_center_id] if args.key?(:hotel_center_id)
  @hotel_id = args[:hotel_id] if args.key?(:hotel_id)
  @order_id = args[:order_id] if args.key?(:order_id)
  @reconciled_value_micros = args[:reconciled_value_micros] if args.key?(:reconciled_value_micros)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end