Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesHotelReconciliation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A hotel reconciliation. It contains conversion information from Hotel bookings to reconcile with advertiser records. These rows may be updated or canceled before billing through Bulk Uploads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesHotelReconciliation

Returns a new instance of GoogleAdsSearchads360V23ResourcesHotelReconciliation.



29743
29744
29745
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29743

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billedBoolean Also known as: billed?

Output only. Whether a given booking has been billed. Once billed, a booking can't be modified. Corresponds to the JSON property billed

Returns:

  • (Boolean)


29669
29670
29671
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29669

def billed
  @billed
end

#campaignString

Output only. The resource name for the Campaign associated with the conversion. Corresponds to the JSON property campaign

Returns:

  • (String)


29675
29676
29677
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29675

def campaign
  @campaign
end

#check_in_dateString

Output only. Check-in date recorded when the booking is made. If the check-in date is modified at reconciliation, the revised date will then take the place of the original date in this column. Format is YYYY-MM-DD. Corresponds to the JSON property checkInDate

Returns:

  • (String)


29682
29683
29684
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29682

def check_in_date
  @check_in_date
end

#check_out_dateString

Output only. Check-out date recorded when the booking is made. If the check-in date is modified at reconciliation, the revised date will then take the place of the original date in this column. Format is YYYY-MM-DD. Corresponds to the JSON property checkOutDate

Returns:

  • (String)


29689
29690
29691
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29689

def check_out_date
  @check_out_date
end

#commission_idString

Required. Output only. The commission ID is Google's ID for this booking. Every booking event is assigned a Commission ID to help you match it to a guest stay. Corresponds to the JSON property commissionId

Returns:

  • (String)


29696
29697
29698
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29696

def commission_id
  @commission_id
end

#hotel_center_idFixnum

Output only. Identifier for the Hotel Center account which provides the rates for the Hotel campaign. Corresponds to the JSON property hotelCenterId

Returns:

  • (Fixnum)


29702
29703
29704
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29702

def hotel_center_id
  @hotel_center_id
end

#hotel_idString

Output only. Unique identifier for the booked property, as provided in the Hotel Center feed. The hotel ID comes from the 'ID' parameter of the conversion tracking tag. Corresponds to the JSON property hotelId

Returns:

  • (String)


29709
29710
29711
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29709

def hotel_id
  @hotel_id
end

#order_idString

Output only. The order ID is the identifier for this booking as provided in the 'transaction_id' parameter of the conversion tracking tag. Corresponds to the JSON property orderId

Returns:

  • (String)


29715
29716
29717
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29715

def order_id
  @order_id
end

#reconciled_value_microsFixnum

Required. Output only. Reconciled value is the final value of a booking as paid by the guest. If original booking value changes for any reason, such as itinerary changes or room upsells, the reconciled value should be the full final amount collected. If a booking is canceled, the reconciled value should include the value of any cancellation fees or non-refundable nights charged. Value is in millionths of the base unit currency. For example, $12.35 would be represented as 12350000. Currency unit is in the default customer currency. Corresponds to the JSON property reconciledValueMicros

Returns:

  • (Fixnum)


29726
29727
29728
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29726

def reconciled_value_micros
  @reconciled_value_micros
end

#resource_nameString

Immutable. The resource name of the hotel reconciliation. Hotel reconciliation resource names have the form: customers/customer_id/hotelReconciliations/ commission_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


29733
29734
29735
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29733

def resource_name
  @resource_name
end

#statusString

Required. Output only. Current status of a booking with regards to reconciliation and billing. Bookings should be reconciled within 45 days after the check-out date. Any booking not reconciled within 45 days will be billed at its original value. Corresponds to the JSON property status

Returns:

  • (String)


29741
29742
29743
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29741

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29748
29749
29750
29751
29752
29753
29754
29755
29756
29757
29758
29759
29760
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29748

def update!(**args)
  @billed = args[:billed] if args.key?(:billed)
  @campaign = args[:campaign] if args.key?(:campaign)
  @check_in_date = args[:check_in_date] if args.key?(:check_in_date)
  @check_out_date = args[:check_out_date] if args.key?(:check_out_date)
  @commission_id = args[:commission_id] if args.key?(:commission_id)
  @hotel_center_id = args[:hotel_center_id] if args.key?(:hotel_center_id)
  @hotel_id = args[:hotel_id] if args.key?(:hotel_id)
  @order_id = args[:order_id] if args.key?(:order_id)
  @reconciled_value_micros = args[:reconciled_value_micros] if args.key?(:reconciled_value_micros)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
end