Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInsuranceVerificationArtifact
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInsuranceVerificationArtifact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
specific to a local services insurance.
Instance Attribute Summary collapse
-
#amount_micros ⇒ Fixnum
Output only.
-
#expiration_date_time ⇒ String
Output only.
-
#insurance_document_readonly ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalServicesDocumentReadOnly
A Local Services Document with read only accessible data.
-
#rejection_reason ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesInsuranceVerificationArtifact
constructor
A new instance of GoogleAdsSearchads360V23ResourcesInsuranceVerificationArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesInsuranceVerificationArtifact
Returns a new instance of GoogleAdsSearchads360V23ResourcesInsuranceVerificationArtifact.
29811 29812 29813 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29811 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amount_micros ⇒ Fixnum
Output only. Insurance amount. This is measured in "micros" of the currency
mentioned in the insurance document.
Corresponds to the JSON property amountMicros
29792 29793 29794 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29792 def amount_micros @amount_micros end |
#expiration_date_time ⇒ String
Output only. The timestamp when this insurance expires. The format is "YYYY-MM-
DD HH:MM:SS" in the Google Ads account's timezone. Examples: "2018-03-05 09:15:
00" or "2018-02-01 14:34:30"
Corresponds to the JSON property expirationDateTime
29799 29800 29801 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29799 def expiration_date_time @expiration_date_time end |
#insurance_document_readonly ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocalServicesDocumentReadOnly
A Local Services Document with read only accessible data.
Corresponds to the JSON property insuranceDocumentReadonly
29804 29805 29806 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29804 def insurance_document_readonly @insurance_document_readonly end |
#rejection_reason ⇒ String
Output only. Insurance document's rejection reason.
Corresponds to the JSON property rejectionReason
29809 29810 29811 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29809 def rejection_reason @rejection_reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29816 29817 29818 29819 29820 29821 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29816 def update!(**args) @amount_micros = args[:amount_micros] if args.key?(:amount_micros) @expiration_date_time = args[:expiration_date_time] if args.key?(:expiration_date_time) @insurance_document_readonly = args[:insurance_document_readonly] if args.key?(:insurance_document_readonly) @rejection_reason = args[:rejection_reason] if args.key?(:rejection_reason) end |