Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoice
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An invoice. All invoice information is snapshotted to match the PDF invoice. For invoices older than the launch of InvoiceService, the snapshotted information may not match the PDF invoice.
Instance Attribute Summary collapse
-
#account_budget_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceAccountBudgetSummary>
Output only.
-
#account_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceAccountSummary>
Output only.
-
#adjustments_subtotal_amount_micros ⇒ Fixnum
Output only.
-
#adjustments_tax_amount_micros ⇒ Fixnum
Output only.
-
#adjustments_total_amount_micros ⇒ Fixnum
Output only.
-
#billing_setup ⇒ String
Output only.
-
#corrected_invoice ⇒ String
Output only.
-
#currency_code ⇒ String
Output only.
-
#due_date ⇒ String
Output only.
-
#export_charge_subtotal_amount_micros ⇒ Fixnum
Output only.
-
#export_charge_tax_amount_micros ⇒ Fixnum
Output only.
-
#export_charge_total_amount_micros ⇒ Fixnum
Output only.
-
#id ⇒ String
Output only.
-
#issue_date ⇒ String
Output only.
-
#payments_account_id ⇒ String
Output only.
-
#payments_profile_id ⇒ String
Output only.
-
#pdf_url ⇒ String
Output only.
-
#regulatory_costs_subtotal_amount_micros ⇒ Fixnum
Output only.
-
#regulatory_costs_tax_amount_micros ⇒ Fixnum
Output only.
-
#regulatory_costs_total_amount_micros ⇒ Fixnum
Output only.
-
#replaced_invoices ⇒ Array<String>
Output only.
-
#resource_name ⇒ String
Output only.
-
#service_date_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDateRange
A date range.
-
#subtotal_amount_micros ⇒ Fixnum
Output only.
-
#tax_amount_micros ⇒ Fixnum
Output only.
-
#total_amount_micros ⇒ Fixnum
Output only.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesInvoice
constructor
A new instance of GoogleAdsSearchads360V23ResourcesInvoice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesInvoice
Returns a new instance of GoogleAdsSearchads360V23ResourcesInvoice.
29998 29999 30000 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29998 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_budget_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceAccountBudgetSummary>
Output only. The list of summarized account budget information associated with
this invoice.
Corresponds to the JSON property accountBudgetSummaries
29834 29835 29836 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29834 def account_budget_summaries @account_budget_summaries end |
#account_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceAccountSummary>
Output only. The list of summarized account information associated with this
invoice.
Corresponds to the JSON property accountSummaries
29840 29841 29842 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29840 def account_summaries @account_summaries end |
#adjustments_subtotal_amount_micros ⇒ Fixnum
Output only. The pretax subtotal amount of invoice level adjustments, in
micros.
Corresponds to the JSON property adjustmentsSubtotalAmountMicros
29846 29847 29848 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29846 def adjustments_subtotal_amount_micros @adjustments_subtotal_amount_micros end |
#adjustments_tax_amount_micros ⇒ Fixnum
Output only. The sum of taxes on the invoice level adjustments, in micros.
Corresponds to the JSON property adjustmentsTaxAmountMicros
29851 29852 29853 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29851 def adjustments_tax_amount_micros @adjustments_tax_amount_micros end |
#adjustments_total_amount_micros ⇒ Fixnum
Output only. The total amount of invoice level adjustments, in micros.
Corresponds to the JSON property adjustmentsTotalAmountMicros
29856 29857 29858 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29856 def adjustments_total_amount_micros @adjustments_total_amount_micros end |
#billing_setup ⇒ String
Output only. The resource name of this invoice's billing setup. customers/
customer_id/billingSetups/billing_setup_id`
Corresponds to the JSON propertybillingSetup`
29862 29863 29864 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29862 def billing_setup @billing_setup end |
#corrected_invoice ⇒ String
Output only. The resource name of the original invoice corrected, wrote off,
or canceled by this invoice, if applicable. If corrected_invoice is set,
replaced_invoices will not be set. Invoice resource names have the form:
customers/customer_id/invoices/invoice_id`
Corresponds to the JSON propertycorrectedInvoice`
29870 29871 29872 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29870 def corrected_invoice @corrected_invoice end |
#currency_code ⇒ String
Output only. The currency code. All costs are returned in this currency. A
subset of the currency codes derived from the ISO 4217 standard is supported.
Corresponds to the JSON property currencyCode
29876 29877 29878 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29876 def currency_code @currency_code end |
#due_date ⇒ String
Output only. The due date in yyyy-mm-dd format.
Corresponds to the JSON property dueDate
29881 29882 29883 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29881 def due_date @due_date end |
#export_charge_subtotal_amount_micros ⇒ Fixnum
Output only. The pretax subtotal amount of invoice level export charges, in
micros.
Corresponds to the JSON property exportChargeSubtotalAmountMicros
29887 29888 29889 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29887 def export_charge_subtotal_amount_micros @export_charge_subtotal_amount_micros end |
#export_charge_tax_amount_micros ⇒ Fixnum
Output only. The sum of taxes on the invoice level export charges, in micros.
Corresponds to the JSON property exportChargeTaxAmountMicros
29892 29893 29894 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29892 def export_charge_tax_amount_micros @export_charge_tax_amount_micros end |
#export_charge_total_amount_micros ⇒ Fixnum
Output only. The total amount of invoice level export charges, in micros.
Corresponds to the JSON property exportChargeTotalAmountMicros
29897 29898 29899 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29897 def export_charge_total_amount_micros @export_charge_total_amount_micros end |
#id ⇒ String
Output only. The ID of the invoice. It appears on the invoice PDF as "Invoice
number".
Corresponds to the JSON property id
29903 29904 29905 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29903 def id @id end |
#issue_date ⇒ String
Output only. The issue date in yyyy-mm-dd format. It appears on the invoice
PDF as either "Issue date" or "Invoice date".
Corresponds to the JSON property issueDate
29909 29910 29911 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29909 def issue_date @issue_date end |
#payments_account_id ⇒ String
Output only. A 16 digit ID used to identify the payments account associated
with the billing setup, for example, "1234-5678-9012-3456". It appears on the
invoice PDF as "Billing Account Number".
Corresponds to the JSON property paymentsAccountId
29916 29917 29918 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29916 def payments_account_id @payments_account_id end |
#payments_profile_id ⇒ String
Output only. A 12 digit ID used to identify the payments profile associated
with the billing setup, for example, "1234-5678-9012". It appears on the
invoice PDF as "Billing ID".
Corresponds to the JSON property paymentsProfileId
29923 29924 29925 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29923 def payments_profile_id @payments_profile_id end |
#pdf_url ⇒ String
Output only. The URL to a PDF copy of the invoice. Users need to pass in their
OAuth token to request the PDF with this URL.
Corresponds to the JSON property pdfUrl
29929 29930 29931 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29929 def pdf_url @pdf_url end |
#regulatory_costs_subtotal_amount_micros ⇒ Fixnum
Output only. The pretax subtotal amount of invoice level regulatory costs, in
micros.
Corresponds to the JSON property regulatoryCostsSubtotalAmountMicros
29935 29936 29937 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29935 def regulatory_costs_subtotal_amount_micros @regulatory_costs_subtotal_amount_micros end |
#regulatory_costs_tax_amount_micros ⇒ Fixnum
Output only. The sum of taxes on the invoice level regulatory costs, in micros.
Corresponds to the JSON property regulatoryCostsTaxAmountMicros
29940 29941 29942 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29940 def regulatory_costs_tax_amount_micros @regulatory_costs_tax_amount_micros end |
#regulatory_costs_total_amount_micros ⇒ Fixnum
Output only. The total amount of invoice level regulatory costs, in micros.
Corresponds to the JSON property regulatoryCostsTotalAmountMicros
29945 29946 29947 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29945 def regulatory_costs_total_amount_micros @regulatory_costs_total_amount_micros end |
#replaced_invoices ⇒ Array<String>
Output only. The resource name of the original invoice(s) being rebilled or
replaced by this invoice, if applicable. There might be multiple replaced
invoices due to invoice consolidation. The replaced invoices may not belong to
the same payments account. If replaced_invoices is set, corrected_invoice
will not be set. Invoice resource names have the form: customers/customer_id
/invoices/invoice_id`
Corresponds to the JSON propertyreplacedInvoices`
29955 29956 29957 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29955 def replaced_invoices @replaced_invoices end |
#resource_name ⇒ String
Output only. The resource name of the invoice. Multiple customers can share a
given invoice, so multiple resource names may point to the same invoice.
Invoice resource names have the form: customers/customer_id/invoices/
invoice_id`
Corresponds to the JSON propertyresourceName`
29963 29964 29965 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29963 def resource_name @resource_name end |
#service_date_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDateRange
A date range.
Corresponds to the JSON property serviceDateRange
29968 29969 29970 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29968 def service_date_range @service_date_range end |
#subtotal_amount_micros ⇒ Fixnum
Output only. The pretax subtotal amount, in micros. This is equal to the sum
of the AccountBudgetSummary subtotal amounts and Invoice.
adjustments_subtotal_amount_micros.
Corresponds to the JSON property subtotalAmountMicros
29975 29976 29977 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29975 def subtotal_amount_micros @subtotal_amount_micros end |
#tax_amount_micros ⇒ Fixnum
Output only. The sum of all taxes on the invoice, in micros. This equals the
sum of the AccountBudgetSummary tax amounts, plus taxes not associated with a
specific account budget.
Corresponds to the JSON property taxAmountMicros
29982 29983 29984 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29982 def tax_amount_micros @tax_amount_micros end |
#total_amount_micros ⇒ Fixnum
Output only. The total amount, in micros. This equals the sum of Invoice.
subtotal_amount_micros, Invoice.tax_amount_micros, Invoice.
regulatory_costs_subtotal_amount_micros, and Invoice.
export_charge_subtotal_amount_micros (which is separated into a separate line
item starting with V14.1).
Corresponds to the JSON property totalAmountMicros
29991 29992 29993 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29991 def total_amount_micros @total_amount_micros end |
#type ⇒ String
Output only. The type of invoice.
Corresponds to the JSON property type
29996 29997 29998 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 29996 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30003 30004 30005 30006 30007 30008 30009 30010 30011 30012 30013 30014 30015 30016 30017 30018 30019 30020 30021 30022 30023 30024 30025 30026 30027 30028 30029 30030 30031 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30003 def update!(**args) @account_budget_summaries = args[:account_budget_summaries] if args.key?(:account_budget_summaries) @account_summaries = args[:account_summaries] if args.key?(:account_summaries) @adjustments_subtotal_amount_micros = args[:adjustments_subtotal_amount_micros] if args.key?(:adjustments_subtotal_amount_micros) @adjustments_tax_amount_micros = args[:adjustments_tax_amount_micros] if args.key?(:adjustments_tax_amount_micros) @adjustments_total_amount_micros = args[:adjustments_total_amount_micros] if args.key?(:adjustments_total_amount_micros) @billing_setup = args[:billing_setup] if args.key?(:billing_setup) @corrected_invoice = args[:corrected_invoice] if args.key?(:corrected_invoice) @currency_code = args[:currency_code] if args.key?(:currency_code) @due_date = args[:due_date] if args.key?(:due_date) @export_charge_subtotal_amount_micros = args[:export_charge_subtotal_amount_micros] if args.key?(:export_charge_subtotal_amount_micros) @export_charge_tax_amount_micros = args[:export_charge_tax_amount_micros] if args.key?(:export_charge_tax_amount_micros) @export_charge_total_amount_micros = args[:export_charge_total_amount_micros] if args.key?(:export_charge_total_amount_micros) @id = args[:id] if args.key?(:id) @issue_date = args[:issue_date] if args.key?(:issue_date) @payments_account_id = args[:payments_account_id] if args.key?(:payments_account_id) @payments_profile_id = args[:payments_profile_id] if args.key?(:payments_profile_id) @pdf_url = args[:pdf_url] if args.key?(:pdf_url) @regulatory_costs_subtotal_amount_micros = args[:regulatory_costs_subtotal_amount_micros] if args.key?(:regulatory_costs_subtotal_amount_micros) @regulatory_costs_tax_amount_micros = args[:regulatory_costs_tax_amount_micros] if args.key?(:regulatory_costs_tax_amount_micros) @regulatory_costs_total_amount_micros = args[:regulatory_costs_total_amount_micros] if args.key?(:regulatory_costs_total_amount_micros) @replaced_invoices = args[:replaced_invoices] if args.key?(:replaced_invoices) @resource_name = args[:resource_name] if args.key?(:resource_name) @service_date_range = args[:service_date_range] if args.key?(:service_date_range) @subtotal_amount_micros = args[:subtotal_amount_micros] if args.key?(:subtotal_amount_micros) @tax_amount_micros = args[:tax_amount_micros] if args.key?(:tax_amount_micros) @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros) @type = args[:type] if args.key?(:type) end |