Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceAccountBudgetSummary
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceAccountBudgetSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents a summarized account budget billable cost.
Instance Attribute Summary collapse
-
#account_budget ⇒ String
Output only.
-
#account_budget_name ⇒ String
Output only.
-
#billable_activity_date_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDateRange
A date range.
-
#billed_amount_micros ⇒ Fixnum
Output only.
-
#campaign_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceCampaignSummary>
Output only.
-
#customer ⇒ String
Output only.
-
#customer_descriptive_name ⇒ String
Output only.
-
#invalid_activity_amount_micros ⇒ Fixnum
Output only.
-
#invalid_activity_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceInvalidActivitySummary>
Output only.
-
#overdelivery_amount_micros ⇒ Fixnum
Output only.
-
#purchase_order_number ⇒ String
Output only.
-
#served_amount_micros ⇒ Fixnum
Output only.
-
#subtotal_amount_micros ⇒ Fixnum
Output only.
-
#tax_amount_micros ⇒ Fixnum
Output only.
-
#total_amount_micros ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesInvoiceAccountBudgetSummary
constructor
A new instance of GoogleAdsSearchads360V23ResourcesInvoiceAccountBudgetSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesInvoiceAccountBudgetSummary
Returns a new instance of GoogleAdsSearchads360V23ResourcesInvoiceAccountBudgetSummary.
17195 17196 17197 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_budget ⇒ String
Output only. The resource name of the account budget associated with this
summarized billable cost. AccountBudget resource names have the form:
customers/customer_id/accountBudgets/account_budget_id`
Corresponds to the JSON propertyaccountBudget`
17107 17108 17109 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17107 def account_budget @account_budget end |
#account_budget_name ⇒ String
Output only. The name of the account budget. It appears on the invoice PDF as "
Account budget".
Corresponds to the JSON property accountBudgetName
17113 17114 17115 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17113 def account_budget_name @account_budget_name end |
#billable_activity_date_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDateRange
A date range.
Corresponds to the JSON property billableActivityDateRange
17118 17119 17120 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17118 def billable_activity_date_range @billable_activity_date_range end |
#billed_amount_micros ⇒ Fixnum
Output only. The pretax billed amount attributable to this budget during the
service period, in micros. This does not account for any adjustments.
Corresponds to the JSON property billedAmountMicros
17124 17125 17126 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17124 def billed_amount_micros @billed_amount_micros end |
#campaign_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceCampaignSummary>
Output only. The list of summarized campaign level information associated with
this account budget.
Corresponds to the JSON property campaignSummaries
17130 17131 17132 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17130 def campaign_summaries @campaign_summaries end |
#customer ⇒ String
Output only. The resource name of the customer associated with this account
budget. This contains the customer ID, which appears on the invoice PDF as "
Account ID". Customer resource names have the form: customers/customer_id`
Corresponds to the JSON propertycustomer`
17137 17138 17139 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17137 def customer @customer end |
#customer_descriptive_name ⇒ String
Output only. The descriptive name of the account budget's customer. It appears
on the invoice PDF as "Account".
Corresponds to the JSON property customerDescriptiveName
17143 17144 17145 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17143 def customer_descriptive_name @customer_descriptive_name end |
#invalid_activity_amount_micros ⇒ Fixnum
Output only. The pretax invalid activity amount attributable to this budget in
previous months, in micros (negative value).
Corresponds to the JSON property invalidActivityAmountMicros
17149 17150 17151 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17149 def invalid_activity_amount_micros @invalid_activity_amount_micros end |
#invalid_activity_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceInvalidActivitySummary>
Output only. The list of summarized invalid activity credits with original
linkages.
Corresponds to the JSON property invalidActivitySummaries
17155 17156 17157 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17155 def invalid_activity_summaries @invalid_activity_summaries end |
#overdelivery_amount_micros ⇒ Fixnum
Output only. The pretax overdelivery amount attributable to this budget during
the service period, in micros (negative value).
Corresponds to the JSON property overdeliveryAmountMicros
17161 17162 17163 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17161 def overdelivery_amount_micros @overdelivery_amount_micros end |
#purchase_order_number ⇒ String
Output only. The purchase order number of the account budget. It appears on
the invoice PDF as "Purchase order".
Corresponds to the JSON property purchaseOrderNumber
17167 17168 17169 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17167 def purchase_order_number @purchase_order_number end |
#served_amount_micros ⇒ Fixnum
Output only. The pretax served amount attributable to this budget during the
service period, in micros. This is only useful to reconcile invoice and
delivery data.
Corresponds to the JSON property servedAmountMicros
17174 17175 17176 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17174 def served_amount_micros @served_amount_micros end |
#subtotal_amount_micros ⇒ Fixnum
Output only. The pretax subtotal amount attributable to this budget during the
service period, in micros.
Corresponds to the JSON property subtotalAmountMicros
17180 17181 17182 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17180 def subtotal_amount_micros @subtotal_amount_micros end |
#tax_amount_micros ⇒ Fixnum
Output only. The tax amount attributable to this budget during the service
period, in micros.
Corresponds to the JSON property taxAmountMicros
17186 17187 17188 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17186 def tax_amount_micros @tax_amount_micros end |
#total_amount_micros ⇒ Fixnum
Output only. The total amount attributable to this budget during the service
period, in micros. This equals the sum of the account budget subtotal amount
and the account budget tax amount.
Corresponds to the JSON property totalAmountMicros
17193 17194 17195 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17193 def total_amount_micros @total_amount_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17200 17201 17202 17203 17204 17205 17206 17207 17208 17209 17210 17211 17212 17213 17214 17215 17216 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17200 def update!(**args) @account_budget = args[:account_budget] if args.key?(:account_budget) @account_budget_name = args[:account_budget_name] if args.key?(:account_budget_name) @billable_activity_date_range = args[:billable_activity_date_range] if args.key?(:billable_activity_date_range) @billed_amount_micros = args[:billed_amount_micros] if args.key?(:billed_amount_micros) @campaign_summaries = args[:campaign_summaries] if args.key?(:campaign_summaries) @customer = args[:customer] if args.key?(:customer) @customer_descriptive_name = args[:customer_descriptive_name] if args.key?(:customer_descriptive_name) @invalid_activity_amount_micros = args[:invalid_activity_amount_micros] if args.key?(:invalid_activity_amount_micros) @invalid_activity_summaries = args[:invalid_activity_summaries] if args.key?(:invalid_activity_summaries) @overdelivery_amount_micros = args[:overdelivery_amount_micros] if args.key?(:overdelivery_amount_micros) @purchase_order_number = args[:purchase_order_number] if args.key?(:purchase_order_number) @served_amount_micros = args[:served_amount_micros] if args.key?(:served_amount_micros) @subtotal_amount_micros = args[:subtotal_amount_micros] if args.key?(:subtotal_amount_micros) @tax_amount_micros = args[:tax_amount_micros] if args.key?(:tax_amount_micros) @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros) end |