Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceAccountBudgetSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a summarized account budget billable cost.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesInvoiceAccountBudgetSummary

Returns a new instance of GoogleAdsSearchads360V23ResourcesInvoiceAccountBudgetSummary.



17069
17070
17071
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_budgetString

Output only. The resource name of the account budget associated with this summarized billable cost. AccountBudget resource names have the form: customers/customer_id/accountBudgets/account_budget_id` Corresponds to the JSON propertyaccountBudget`

Returns:

  • (String)


16981
16982
16983
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16981

def 
  @account_budget
end

#account_budget_nameString

Output only. The name of the account budget. It appears on the invoice PDF as " Account budget". Corresponds to the JSON property accountBudgetName

Returns:

  • (String)


16987
16988
16989
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16987

def 
  @account_budget_name
end

#billable_activity_date_rangeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDateRange

A date range. Corresponds to the JSON property billableActivityDateRange



16992
16993
16994
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16992

def billable_activity_date_range
  @billable_activity_date_range
end

#billed_amount_microsFixnum

Output only. The pretax billed amount attributable to this budget during the service period, in micros. This does not account for any adjustments. Corresponds to the JSON property billedAmountMicros

Returns:

  • (Fixnum)


16998
16999
17000
# File 'lib/google/apis/searchads360_v23/classes.rb', line 16998

def billed_amount_micros
  @billed_amount_micros
end

#campaign_summariesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceCampaignSummary>

Output only. The list of summarized campaign level information associated with this account budget. Corresponds to the JSON property campaignSummaries



17004
17005
17006
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17004

def campaign_summaries
  @campaign_summaries
end

#customerString

Output only. The resource name of the customer associated with this account budget. This contains the customer ID, which appears on the invoice PDF as " Account ID". Customer resource names have the form: customers/customer_id` Corresponds to the JSON propertycustomer`

Returns:

  • (String)


17011
17012
17013
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17011

def customer
  @customer
end

#customer_descriptive_nameString

Output only. The descriptive name of the account budget's customer. It appears on the invoice PDF as "Account". Corresponds to the JSON property customerDescriptiveName

Returns:

  • (String)


17017
17018
17019
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17017

def customer_descriptive_name
  @customer_descriptive_name
end

#invalid_activity_amount_microsFixnum

Output only. The pretax invalid activity amount attributable to this budget in previous months, in micros (negative value). Corresponds to the JSON property invalidActivityAmountMicros

Returns:

  • (Fixnum)


17023
17024
17025
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17023

def invalid_activity_amount_micros
  @invalid_activity_amount_micros
end

#invalid_activity_summariesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceInvalidActivitySummary>

Output only. The list of summarized invalid activity credits with original linkages. Corresponds to the JSON property invalidActivitySummaries



17029
17030
17031
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17029

def invalid_activity_summaries
  @invalid_activity_summaries
end

#overdelivery_amount_microsFixnum

Output only. The pretax overdelivery amount attributable to this budget during the service period, in micros (negative value). Corresponds to the JSON property overdeliveryAmountMicros

Returns:

  • (Fixnum)


17035
17036
17037
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17035

def overdelivery_amount_micros
  @overdelivery_amount_micros
end

#purchase_order_numberString

Output only. The purchase order number of the account budget. It appears on the invoice PDF as "Purchase order". Corresponds to the JSON property purchaseOrderNumber

Returns:

  • (String)


17041
17042
17043
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17041

def purchase_order_number
  @purchase_order_number
end

#served_amount_microsFixnum

Output only. The pretax served amount attributable to this budget during the service period, in micros. This is only useful to reconcile invoice and delivery data. Corresponds to the JSON property servedAmountMicros

Returns:

  • (Fixnum)


17048
17049
17050
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17048

def served_amount_micros
  @served_amount_micros
end

#subtotal_amount_microsFixnum

Output only. The pretax subtotal amount attributable to this budget during the service period, in micros. Corresponds to the JSON property subtotalAmountMicros

Returns:

  • (Fixnum)


17054
17055
17056
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17054

def subtotal_amount_micros
  @subtotal_amount_micros
end

#tax_amount_microsFixnum

Output only. The tax amount attributable to this budget during the service period, in micros. Corresponds to the JSON property taxAmountMicros

Returns:

  • (Fixnum)


17060
17061
17062
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17060

def tax_amount_micros
  @tax_amount_micros
end

#total_amount_microsFixnum

Output only. The total amount attributable to this budget during the service period, in micros. This equals the sum of the account budget subtotal amount and the account budget tax amount. Corresponds to the JSON property totalAmountMicros

Returns:

  • (Fixnum)


17067
17068
17069
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17067

def total_amount_micros
  @total_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
17088
17089
17090
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17074

def update!(**args)
  @account_budget = args[:account_budget] if args.key?(:account_budget)
  @account_budget_name = args[:account_budget_name] if args.key?(:account_budget_name)
  @billable_activity_date_range = args[:billable_activity_date_range] if args.key?(:billable_activity_date_range)
  @billed_amount_micros = args[:billed_amount_micros] if args.key?(:billed_amount_micros)
  @campaign_summaries = args[:campaign_summaries] if args.key?(:campaign_summaries)
  @customer = args[:customer] if args.key?(:customer)
  @customer_descriptive_name = args[:customer_descriptive_name] if args.key?(:customer_descriptive_name)
  @invalid_activity_amount_micros = args[:invalid_activity_amount_micros] if args.key?(:invalid_activity_amount_micros)
  @invalid_activity_summaries = args[:invalid_activity_summaries] if args.key?(:invalid_activity_summaries)
  @overdelivery_amount_micros = args[:overdelivery_amount_micros] if args.key?(:overdelivery_amount_micros)
  @purchase_order_number = args[:purchase_order_number] if args.key?(:purchase_order_number)
  @served_amount_micros = args[:served_amount_micros] if args.key?(:served_amount_micros)
  @subtotal_amount_micros = args[:subtotal_amount_micros] if args.key?(:subtotal_amount_micros)
  @tax_amount_micros = args[:tax_amount_micros] if args.key?(:tax_amount_micros)
  @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros)
end