Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceAccountSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a summarized view at account level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesInvoiceAccountSummary

Returns a new instance of GoogleAdsSearchads360V23ResourcesInvoiceAccountSummary.



17273
17274
17275
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adjustment_summariesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceAdjustmentSummary>

Output only. The list of adjustment information associated with this account. Corresponds to the JSON property adjustmentSummaries



17166
17167
17168
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17166

def adjustment_summaries
  @adjustment_summaries
end

#billing_correction_subtotal_amount_microsFixnum

Output only. Pretax billing correction subtotal amount, in micros. Corresponds to the JSON property billingCorrectionSubtotalAmountMicros

Returns:

  • (Fixnum)


17171
17172
17173
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17171

def billing_correction_subtotal_amount_micros
  @billing_correction_subtotal_amount_micros
end

#billing_correction_tax_amount_microsFixnum

Output only. Tax on billing correction, in micros. Corresponds to the JSON property billingCorrectionTaxAmountMicros

Returns:

  • (Fixnum)


17176
17177
17178
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17176

def billing_correction_tax_amount_micros
  @billing_correction_tax_amount_micros
end

#billing_correction_total_amount_microsFixnum

Output only. Total billing correction amount, in micros. Corresponds to the JSON property billingCorrectionTotalAmountMicros

Returns:

  • (Fixnum)


17181
17182
17183
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17181

def billing_correction_total_amount_micros
  @billing_correction_total_amount_micros
end

#coupon_adjustment_subtotal_amount_microsFixnum

Output only. Pretax coupon adjustment subtotal amount, in micros. Corresponds to the JSON property couponAdjustmentSubtotalAmountMicros

Returns:

  • (Fixnum)


17186
17187
17188
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17186

def coupon_adjustment_subtotal_amount_micros
  @coupon_adjustment_subtotal_amount_micros
end

#coupon_adjustment_tax_amount_microsFixnum

Output only. Tax on coupon adjustment, in micros. Corresponds to the JSON property couponAdjustmentTaxAmountMicros

Returns:

  • (Fixnum)


17191
17192
17193
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17191

def coupon_adjustment_tax_amount_micros
  @coupon_adjustment_tax_amount_micros
end

#coupon_adjustment_total_amount_microsFixnum

Output only. Total coupon adjustment amount, in micros. Corresponds to the JSON property couponAdjustmentTotalAmountMicros

Returns:

  • (Fixnum)


17196
17197
17198
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17196

def coupon_adjustment_total_amount_micros
  @coupon_adjustment_total_amount_micros
end

#customerString

Output only. The account associated with the account summary. Corresponds to the JSON property customer

Returns:

  • (String)


17201
17202
17203
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17201

def customer
  @customer
end

#excess_credit_adjustment_subtotal_amount_microsFixnum

Output only. Pretax excess credit adjustment subtotal amount, in micros. Corresponds to the JSON property excessCreditAdjustmentSubtotalAmountMicros

Returns:

  • (Fixnum)


17206
17207
17208
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17206

def excess_credit_adjustment_subtotal_amount_micros
  @excess_credit_adjustment_subtotal_amount_micros
end

#excess_credit_adjustment_tax_amount_microsFixnum

Output only. Tax on excess credit adjustment, in micros. Corresponds to the JSON property excessCreditAdjustmentTaxAmountMicros

Returns:

  • (Fixnum)


17211
17212
17213
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17211

def excess_credit_adjustment_tax_amount_micros
  @excess_credit_adjustment_tax_amount_micros
end

#excess_credit_adjustment_total_amount_microsFixnum

Output only. Total excess credit adjustment amount, in micros. Corresponds to the JSON property excessCreditAdjustmentTotalAmountMicros

Returns:

  • (Fixnum)


17216
17217
17218
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17216

def excess_credit_adjustment_total_amount_micros
  @excess_credit_adjustment_total_amount_micros
end

#export_charge_subtotal_amount_microsFixnum

Output only. Pretax export charge subtotal amount, in micros. Corresponds to the JSON property exportChargeSubtotalAmountMicros

Returns:

  • (Fixnum)


17221
17222
17223
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17221

def export_charge_subtotal_amount_micros
  @export_charge_subtotal_amount_micros
end

#export_charge_tax_amount_microsFixnum

Output only. Tax on export charge, in micros. Corresponds to the JSON property exportChargeTaxAmountMicros

Returns:

  • (Fixnum)


17226
17227
17228
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17226

def export_charge_tax_amount_micros
  @export_charge_tax_amount_micros
end

#export_charge_total_amount_microsFixnum

Output only. Total export charge amount, in micros. Corresponds to the JSON property exportChargeTotalAmountMicros

Returns:

  • (Fixnum)


17231
17232
17233
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17231

def export_charge_total_amount_micros
  @export_charge_total_amount_micros
end

#regulatory_cost_summariesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceRegulatoryCostSummary>

Output only. The list of regulatory cost information associated with this account. Corresponds to the JSON property regulatoryCostSummaries



17237
17238
17239
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17237

def regulatory_cost_summaries
  @regulatory_cost_summaries
end

#regulatory_costs_subtotal_amount_microsFixnum

Output only. Pretax regulatory costs subtotal amount, in micros. Corresponds to the JSON property regulatoryCostsSubtotalAmountMicros

Returns:

  • (Fixnum)


17242
17243
17244
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17242

def regulatory_costs_subtotal_amount_micros
  @regulatory_costs_subtotal_amount_micros
end

#regulatory_costs_tax_amount_microsFixnum

Output only. Tax on regulatory costs, in micros. Corresponds to the JSON property regulatoryCostsTaxAmountMicros

Returns:

  • (Fixnum)


17247
17248
17249
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17247

def regulatory_costs_tax_amount_micros
  @regulatory_costs_tax_amount_micros
end

#regulatory_costs_total_amount_microsFixnum

Output only. Total regulatory costs amount, in micros. Corresponds to the JSON property regulatoryCostsTotalAmountMicros

Returns:

  • (Fixnum)


17252
17253
17254
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17252

def regulatory_costs_total_amount_micros
  @regulatory_costs_total_amount_micros
end

#subtotal_amount_microsFixnum

Output only. Total pretax subtotal amount attributable to the account during the service period, in micros. Corresponds to the JSON property subtotalAmountMicros

Returns:

  • (Fixnum)


17258
17259
17260
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17258

def subtotal_amount_micros
  @subtotal_amount_micros
end

#tax_amount_microsFixnum

Output only. Total tax amount attributable to the account during the service period, in micros. Corresponds to the JSON property taxAmountMicros

Returns:

  • (Fixnum)


17264
17265
17266
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17264

def tax_amount_micros
  @tax_amount_micros
end

#total_amount_microsFixnum

Output only. Total amount attributable to the account during the service period, in micros. This equals the sum of the subtotal_amount_micros and tax_amount_micros. Corresponds to the JSON property totalAmountMicros

Returns:

  • (Fixnum)


17271
17272
17273
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17271

def total_amount_micros
  @total_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17278
17279
17280
17281
17282
17283
17284
17285
17286
17287
17288
17289
17290
17291
17292
17293
17294
17295
17296
17297
17298
17299
17300
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17278

def update!(**args)
  @adjustment_summaries = args[:adjustment_summaries] if args.key?(:adjustment_summaries)
  @billing_correction_subtotal_amount_micros = args[:billing_correction_subtotal_amount_micros] if args.key?(:billing_correction_subtotal_amount_micros)
  @billing_correction_tax_amount_micros = args[:billing_correction_tax_amount_micros] if args.key?(:billing_correction_tax_amount_micros)
  @billing_correction_total_amount_micros = args[:billing_correction_total_amount_micros] if args.key?(:billing_correction_total_amount_micros)
  @coupon_adjustment_subtotal_amount_micros = args[:coupon_adjustment_subtotal_amount_micros] if args.key?(:coupon_adjustment_subtotal_amount_micros)
  @coupon_adjustment_tax_amount_micros = args[:coupon_adjustment_tax_amount_micros] if args.key?(:coupon_adjustment_tax_amount_micros)
  @coupon_adjustment_total_amount_micros = args[:coupon_adjustment_total_amount_micros] if args.key?(:coupon_adjustment_total_amount_micros)
  @customer = args[:customer] if args.key?(:customer)
  @excess_credit_adjustment_subtotal_amount_micros = args[:excess_credit_adjustment_subtotal_amount_micros] if args.key?(:excess_credit_adjustment_subtotal_amount_micros)
  @excess_credit_adjustment_tax_amount_micros = args[:excess_credit_adjustment_tax_amount_micros] if args.key?(:excess_credit_adjustment_tax_amount_micros)
  @excess_credit_adjustment_total_amount_micros = args[:excess_credit_adjustment_total_amount_micros] if args.key?(:excess_credit_adjustment_total_amount_micros)
  @export_charge_subtotal_amount_micros = args[:export_charge_subtotal_amount_micros] if args.key?(:export_charge_subtotal_amount_micros)
  @export_charge_tax_amount_micros = args[:export_charge_tax_amount_micros] if args.key?(:export_charge_tax_amount_micros)
  @export_charge_total_amount_micros = args[:export_charge_total_amount_micros] if args.key?(:export_charge_total_amount_micros)
  @regulatory_cost_summaries = args[:regulatory_cost_summaries] if args.key?(:regulatory_cost_summaries)
  @regulatory_costs_subtotal_amount_micros = args[:regulatory_costs_subtotal_amount_micros] if args.key?(:regulatory_costs_subtotal_amount_micros)
  @regulatory_costs_tax_amount_micros = args[:regulatory_costs_tax_amount_micros] if args.key?(:regulatory_costs_tax_amount_micros)
  @regulatory_costs_total_amount_micros = args[:regulatory_costs_total_amount_micros] if args.key?(:regulatory_costs_total_amount_micros)
  @subtotal_amount_micros = args[:subtotal_amount_micros] if args.key?(:subtotal_amount_micros)
  @tax_amount_micros = args[:tax_amount_micros] if args.key?(:tax_amount_micros)
  @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros)
end