Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceAccountSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a summarized view at account level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesInvoiceAccountSummary

Returns a new instance of GoogleAdsSearchads360V23ResourcesInvoiceAccountSummary.



17207
17208
17209
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17207

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adjustment_summariesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceAdjustmentSummary>

Output only. The list of adjustment information associated with this account. Corresponds to the JSON property adjustmentSummaries



17100
17101
17102
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17100

def adjustment_summaries
  @adjustment_summaries
end

#billing_correction_subtotal_amount_microsFixnum

Output only. Pretax billing correction subtotal amount, in micros. Corresponds to the JSON property billingCorrectionSubtotalAmountMicros

Returns:

  • (Fixnum)


17105
17106
17107
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17105

def billing_correction_subtotal_amount_micros
  @billing_correction_subtotal_amount_micros
end

#billing_correction_tax_amount_microsFixnum

Output only. Tax on billing correction, in micros. Corresponds to the JSON property billingCorrectionTaxAmountMicros

Returns:

  • (Fixnum)


17110
17111
17112
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17110

def billing_correction_tax_amount_micros
  @billing_correction_tax_amount_micros
end

#billing_correction_total_amount_microsFixnum

Output only. Total billing correction amount, in micros. Corresponds to the JSON property billingCorrectionTotalAmountMicros

Returns:

  • (Fixnum)


17115
17116
17117
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17115

def billing_correction_total_amount_micros
  @billing_correction_total_amount_micros
end

#coupon_adjustment_subtotal_amount_microsFixnum

Output only. Pretax coupon adjustment subtotal amount, in micros. Corresponds to the JSON property couponAdjustmentSubtotalAmountMicros

Returns:

  • (Fixnum)


17120
17121
17122
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17120

def coupon_adjustment_subtotal_amount_micros
  @coupon_adjustment_subtotal_amount_micros
end

#coupon_adjustment_tax_amount_microsFixnum

Output only. Tax on coupon adjustment, in micros. Corresponds to the JSON property couponAdjustmentTaxAmountMicros

Returns:

  • (Fixnum)


17125
17126
17127
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17125

def coupon_adjustment_tax_amount_micros
  @coupon_adjustment_tax_amount_micros
end

#coupon_adjustment_total_amount_microsFixnum

Output only. Total coupon adjustment amount, in micros. Corresponds to the JSON property couponAdjustmentTotalAmountMicros

Returns:

  • (Fixnum)


17130
17131
17132
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17130

def coupon_adjustment_total_amount_micros
  @coupon_adjustment_total_amount_micros
end

#customerString

Output only. The account associated with the account summary. Corresponds to the JSON property customer

Returns:

  • (String)


17135
17136
17137
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17135

def customer
  @customer
end

#excess_credit_adjustment_subtotal_amount_microsFixnum

Output only. Pretax excess credit adjustment subtotal amount, in micros. Corresponds to the JSON property excessCreditAdjustmentSubtotalAmountMicros

Returns:

  • (Fixnum)


17140
17141
17142
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17140

def excess_credit_adjustment_subtotal_amount_micros
  @excess_credit_adjustment_subtotal_amount_micros
end

#excess_credit_adjustment_tax_amount_microsFixnum

Output only. Tax on excess credit adjustment, in micros. Corresponds to the JSON property excessCreditAdjustmentTaxAmountMicros

Returns:

  • (Fixnum)


17145
17146
17147
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17145

def excess_credit_adjustment_tax_amount_micros
  @excess_credit_adjustment_tax_amount_micros
end

#excess_credit_adjustment_total_amount_microsFixnum

Output only. Total excess credit adjustment amount, in micros. Corresponds to the JSON property excessCreditAdjustmentTotalAmountMicros

Returns:

  • (Fixnum)


17150
17151
17152
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17150

def excess_credit_adjustment_total_amount_micros
  @excess_credit_adjustment_total_amount_micros
end

#export_charge_subtotal_amount_microsFixnum

Output only. Pretax export charge subtotal amount, in micros. Corresponds to the JSON property exportChargeSubtotalAmountMicros

Returns:

  • (Fixnum)


17155
17156
17157
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17155

def export_charge_subtotal_amount_micros
  @export_charge_subtotal_amount_micros
end

#export_charge_tax_amount_microsFixnum

Output only. Tax on export charge, in micros. Corresponds to the JSON property exportChargeTaxAmountMicros

Returns:

  • (Fixnum)


17160
17161
17162
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17160

def export_charge_tax_amount_micros
  @export_charge_tax_amount_micros
end

#export_charge_total_amount_microsFixnum

Output only. Total export charge amount, in micros. Corresponds to the JSON property exportChargeTotalAmountMicros

Returns:

  • (Fixnum)


17165
17166
17167
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17165

def export_charge_total_amount_micros
  @export_charge_total_amount_micros
end

#regulatory_cost_summariesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceRegulatoryCostSummary>

Output only. The list of regulatory cost information associated with this account. Corresponds to the JSON property regulatoryCostSummaries



17171
17172
17173
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17171

def regulatory_cost_summaries
  @regulatory_cost_summaries
end

#regulatory_costs_subtotal_amount_microsFixnum

Output only. Pretax regulatory costs subtotal amount, in micros. Corresponds to the JSON property regulatoryCostsSubtotalAmountMicros

Returns:

  • (Fixnum)


17176
17177
17178
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17176

def regulatory_costs_subtotal_amount_micros
  @regulatory_costs_subtotal_amount_micros
end

#regulatory_costs_tax_amount_microsFixnum

Output only. Tax on regulatory costs, in micros. Corresponds to the JSON property regulatoryCostsTaxAmountMicros

Returns:

  • (Fixnum)


17181
17182
17183
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17181

def regulatory_costs_tax_amount_micros
  @regulatory_costs_tax_amount_micros
end

#regulatory_costs_total_amount_microsFixnum

Output only. Total regulatory costs amount, in micros. Corresponds to the JSON property regulatoryCostsTotalAmountMicros

Returns:

  • (Fixnum)


17186
17187
17188
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17186

def regulatory_costs_total_amount_micros
  @regulatory_costs_total_amount_micros
end

#subtotal_amount_microsFixnum

Output only. Total pretax subtotal amount attributable to the account during the service period, in micros. Corresponds to the JSON property subtotalAmountMicros

Returns:

  • (Fixnum)


17192
17193
17194
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17192

def subtotal_amount_micros
  @subtotal_amount_micros
end

#tax_amount_microsFixnum

Output only. Total tax amount attributable to the account during the service period, in micros. Corresponds to the JSON property taxAmountMicros

Returns:

  • (Fixnum)


17198
17199
17200
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17198

def tax_amount_micros
  @tax_amount_micros
end

#total_amount_microsFixnum

Output only. Total amount attributable to the account during the service period, in micros. This equals the sum of the subtotal_amount_micros and tax_amount_micros. Corresponds to the JSON property totalAmountMicros

Returns:

  • (Fixnum)


17205
17206
17207
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17205

def total_amount_micros
  @total_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17212
17213
17214
17215
17216
17217
17218
17219
17220
17221
17222
17223
17224
17225
17226
17227
17228
17229
17230
17231
17232
17233
17234
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17212

def update!(**args)
  @adjustment_summaries = args[:adjustment_summaries] if args.key?(:adjustment_summaries)
  @billing_correction_subtotal_amount_micros = args[:billing_correction_subtotal_amount_micros] if args.key?(:billing_correction_subtotal_amount_micros)
  @billing_correction_tax_amount_micros = args[:billing_correction_tax_amount_micros] if args.key?(:billing_correction_tax_amount_micros)
  @billing_correction_total_amount_micros = args[:billing_correction_total_amount_micros] if args.key?(:billing_correction_total_amount_micros)
  @coupon_adjustment_subtotal_amount_micros = args[:coupon_adjustment_subtotal_amount_micros] if args.key?(:coupon_adjustment_subtotal_amount_micros)
  @coupon_adjustment_tax_amount_micros = args[:coupon_adjustment_tax_amount_micros] if args.key?(:coupon_adjustment_tax_amount_micros)
  @coupon_adjustment_total_amount_micros = args[:coupon_adjustment_total_amount_micros] if args.key?(:coupon_adjustment_total_amount_micros)
  @customer = args[:customer] if args.key?(:customer)
  @excess_credit_adjustment_subtotal_amount_micros = args[:excess_credit_adjustment_subtotal_amount_micros] if args.key?(:excess_credit_adjustment_subtotal_amount_micros)
  @excess_credit_adjustment_tax_amount_micros = args[:excess_credit_adjustment_tax_amount_micros] if args.key?(:excess_credit_adjustment_tax_amount_micros)
  @excess_credit_adjustment_total_amount_micros = args[:excess_credit_adjustment_total_amount_micros] if args.key?(:excess_credit_adjustment_total_amount_micros)
  @export_charge_subtotal_amount_micros = args[:export_charge_subtotal_amount_micros] if args.key?(:export_charge_subtotal_amount_micros)
  @export_charge_tax_amount_micros = args[:export_charge_tax_amount_micros] if args.key?(:export_charge_tax_amount_micros)
  @export_charge_total_amount_micros = args[:export_charge_total_amount_micros] if args.key?(:export_charge_total_amount_micros)
  @regulatory_cost_summaries = args[:regulatory_cost_summaries] if args.key?(:regulatory_cost_summaries)
  @regulatory_costs_subtotal_amount_micros = args[:regulatory_costs_subtotal_amount_micros] if args.key?(:regulatory_costs_subtotal_amount_micros)
  @regulatory_costs_tax_amount_micros = args[:regulatory_costs_tax_amount_micros] if args.key?(:regulatory_costs_tax_amount_micros)
  @regulatory_costs_total_amount_micros = args[:regulatory_costs_total_amount_micros] if args.key?(:regulatory_costs_total_amount_micros)
  @subtotal_amount_micros = args[:subtotal_amount_micros] if args.key?(:subtotal_amount_micros)
  @tax_amount_micros = args[:tax_amount_micros] if args.key?(:tax_amount_micros)
  @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros)
end