Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesInvoiceCampaignSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents campaign level billable cost information associated with an account budget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesInvoiceCampaignSummary

Returns a new instance of GoogleAdsSearchads360V23ResourcesInvoiceCampaignSummary.



17358
17359
17360
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amount_microsFixnum

Output only. The amount attributable to this campaign for the given unit of measure during the service period, in micros. The currency code for this amount is the same as the Invoice.currency_code. Corresponds to the JSON property amountMicros

Returns:

  • (Fixnum)


17340
17341
17342
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17340

def amount_micros
  @amount_micros
end

#campaign_descriptionString

Output only. The description of the campaign. This is generally the same as the campaign name, but may differ. Corresponds to the JSON property campaignDescription

Returns:

  • (String)


17346
17347
17348
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17346

def campaign_description
  @campaign_description
end

#quantityFixnum

Output only. The quantity served for the given unit of measure. Corresponds to the JSON property quantity

Returns:

  • (Fixnum)


17351
17352
17353
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17351

def quantity
  @quantity
end

#unit_of_measureString

Output only. The unit of measure for the quantity served. Corresponds to the JSON property unitOfMeasure

Returns:

  • (String)


17356
17357
17358
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17356

def unit_of_measure
  @unit_of_measure
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17363
17364
17365
17366
17367
17368
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17363

def update!(**args)
  @amount_micros = args[:amount_micros] if args.key?(:amount_micros)
  @campaign_description = args[:campaign_description] if args.key?(:campaign_description)
  @quantity = args[:quantity] if args.key?(:quantity)
  @unit_of_measure = args[:unit_of_measure] if args.key?(:unit_of_measure)
end