Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlan
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlan
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Keyword Planner plan. Max number of saved keyword plans: 10000. It's possible to remove plans if limit is reached.
Instance Attribute Summary collapse
-
#forecast_period ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanForecastPeriod
The forecasting period associated with the keyword plan.
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
The name of the keyword plan.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlan
constructor
A new instance of GoogleAdsSearchads360V23ResourcesKeywordPlan.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlan
Returns a new instance of GoogleAdsSearchads360V23ResourcesKeywordPlan.
30162 30163 30164 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#forecast_period ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanForecastPeriod
The forecasting period associated with the keyword plan.
Corresponds to the JSON property forecastPeriod
30143 30144 30145 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30143 def forecast_period @forecast_period end |
#id ⇒ Fixnum
Output only. The ID of the keyword plan.
Corresponds to the JSON property id
30148 30149 30150 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30148 def id @id end |
#name ⇒ String
The name of the keyword plan. This field is required and should not be empty
when creating new keyword plans.
Corresponds to the JSON property name
30154 30155 30156 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30154 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the Keyword Planner plan. KeywordPlan resource
names have the form: customers/customer_id/keywordPlans/kp_plan_id`
Corresponds to the JSON propertyresourceName`
30160 30161 30162 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30160 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30167 30168 30169 30170 30171 30172 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30167 def update!(**args) @forecast_period = args[:forecast_period] if args.key?(:forecast_period) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) end |