Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Keyword Planner ad group. Max number of keyword plan ad groups per plan: 200.
Instance Attribute Summary collapse
-
#cpc_bid_micros ⇒ Fixnum
A default ad group max cpc bid in micros in account currency for all biddable keywords under the keyword plan ad group.
-
#id ⇒ Fixnum
Output only.
-
#keyword_plan_campaign ⇒ String
The keyword plan campaign to which this ad group belongs.
-
#name ⇒ String
The name of the keyword plan ad group.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
constructor
A new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
Returns a new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup.
30209 30210 30211 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30209 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpc_bid_micros ⇒ Fixnum
A default ad group max cpc bid in micros in account currency for all biddable
keywords under the keyword plan ad group. If not set, will inherit from parent
campaign.
Corresponds to the JSON property cpcBidMicros
30184 30185 30186 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30184 def cpc_bid_micros @cpc_bid_micros end |
#id ⇒ Fixnum
Output only. The ID of the keyword plan ad group.
Corresponds to the JSON property id
30189 30190 30191 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30189 def id @id end |
#keyword_plan_campaign ⇒ String
The keyword plan campaign to which this ad group belongs.
Corresponds to the JSON property keywordPlanCampaign
30194 30195 30196 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30194 def keyword_plan_campaign @keyword_plan_campaign end |
#name ⇒ String
The name of the keyword plan ad group. This field is required and should not
be empty when creating keyword plan ad group.
Corresponds to the JSON property name
30200 30201 30202 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30200 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the Keyword Planner ad group.
KeywordPlanAdGroup resource names have the form: customers/customer_id/
keywordPlanAdGroups/kp_ad_group_id`
Corresponds to the JSON propertyresourceName`
30207 30208 30209 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30207 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30214 30215 30216 30217 30218 30219 30220 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30214 def update!(**args) @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros) @id = args[:id] if args.key?(:id) @keyword_plan_campaign = args[:keyword_plan_campaign] if args.key?(:keyword_plan_campaign) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) end |