Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Keyword Planner ad group. Max number of keyword plan ad groups per plan: 200.
Instance Attribute Summary collapse
-
#cpc_bid_micros ⇒ Fixnum
A default ad group max cpc bid in micros in account currency for all biddable keywords under the keyword plan ad group.
-
#id ⇒ Fixnum
Output only.
-
#keyword_plan_campaign ⇒ String
The keyword plan campaign to which this ad group belongs.
-
#name ⇒ String
The name of the keyword plan ad group.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
constructor
A new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
Returns a new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup.
30108 30109 30110 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpc_bid_micros ⇒ Fixnum
A default ad group max cpc bid in micros in account currency for all biddable
keywords under the keyword plan ad group. If not set, will inherit from parent
campaign.
Corresponds to the JSON property cpcBidMicros
30083 30084 30085 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30083 def cpc_bid_micros @cpc_bid_micros end |
#id ⇒ Fixnum
Output only. The ID of the keyword plan ad group.
Corresponds to the JSON property id
30088 30089 30090 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30088 def id @id end |
#keyword_plan_campaign ⇒ String
The keyword plan campaign to which this ad group belongs.
Corresponds to the JSON property keywordPlanCampaign
30093 30094 30095 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30093 def keyword_plan_campaign @keyword_plan_campaign end |
#name ⇒ String
The name of the keyword plan ad group. This field is required and should not
be empty when creating keyword plan ad group.
Corresponds to the JSON property name
30099 30100 30101 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30099 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the Keyword Planner ad group.
KeywordPlanAdGroup resource names have the form: customers/customer_id/
keywordPlanAdGroups/kp_ad_group_id`
Corresponds to the JSON propertyresourceName`
30106 30107 30108 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30106 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30113 30114 30115 30116 30117 30118 30119 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30113 def update!(**args) @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros) @id = args[:id] if args.key?(:id) @keyword_plan_campaign = args[:keyword_plan_campaign] if args.key?(:keyword_plan_campaign) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) end |