Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Keyword Plan ad group keyword. Max number of keyword plan keywords per plan: 10000.
Instance Attribute Summary collapse
-
#cpc_bid_micros ⇒ Fixnum
A keyword level max cpc bid in micros (for example, $1 = 1mm).
-
#id ⇒ Fixnum
Output only.
-
#keyword_plan_ad_group ⇒ String
The Keyword Plan ad group to which this keyword belongs.
-
#match_type ⇒ String
The keyword match type.
-
#negative ⇒ Boolean
(also: #negative?)
Immutable.
-
#resource_name ⇒ String
Immutable.
-
#text ⇒ String
The keyword text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword
constructor
A new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword
Returns a new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword.
30269 30270 30271 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30269 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpc_bid_micros ⇒ Fixnum
A keyword level max cpc bid in micros (for example, $1 = 1mm). The currency is
the same as the account currency code. This will override any CPC bid set at
the keyword plan ad group level. Not applicable for negative keywords. (
negative = true) This field is Optional.
Corresponds to the JSON property cpcBidMicros
30234 30235 30236 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30234 def cpc_bid_micros @cpc_bid_micros end |
#id ⇒ Fixnum
Output only. The ID of the Keyword Plan keyword.
Corresponds to the JSON property id
30239 30240 30241 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30239 def id @id end |
#keyword_plan_ad_group ⇒ String
The Keyword Plan ad group to which this keyword belongs.
Corresponds to the JSON property keywordPlanAdGroup
30244 30245 30246 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30244 def keyword_plan_ad_group @keyword_plan_ad_group end |
#match_type ⇒ String
The keyword match type.
Corresponds to the JSON property matchType
30249 30250 30251 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30249 def match_type @match_type end |
#negative ⇒ Boolean Also known as: negative?
Immutable. If true, the keyword is negative.
Corresponds to the JSON property negative
30254 30255 30256 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30254 def negative @negative end |
#resource_name ⇒ String
Immutable. The resource name of the Keyword Plan ad group keyword.
KeywordPlanAdGroupKeyword resource names have the form: customers/
customer_id/keywordPlanAdGroupKeywords/kp_ad_group_keyword_id`
Corresponds to the JSON propertyresourceName`
30262 30263 30264 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30262 def resource_name @resource_name end |
#text ⇒ String
The keyword text.
Corresponds to the JSON property text
30267 30268 30269 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30267 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30274 30275 30276 30277 30278 30279 30280 30281 30282 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30274 def update!(**args) @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros) @id = args[:id] if args.key?(:id) @keyword_plan_ad_group = args[:keyword_plan_ad_group] if args.key?(:keyword_plan_ad_group) @match_type = args[:match_type] if args.key?(:match_type) @negative = args[:negative] if args.key?(:negative) @resource_name = args[:resource_name] if args.key?(:resource_name) @text = args[:text] if args.key?(:text) end |