Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Keyword Plan ad group keyword. Max number of keyword plan keywords per plan: 10000.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword

Returns a new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword.



30168
30169
30170
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30168

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpc_bid_microsFixnum

A keyword level max cpc bid in micros (for example, $1 = 1mm). The currency is the same as the account currency code. This will override any CPC bid set at the keyword plan ad group level. Not applicable for negative keywords. ( negative = true) This field is Optional. Corresponds to the JSON property cpcBidMicros

Returns:

  • (Fixnum)


30133
30134
30135
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30133

def cpc_bid_micros
  @cpc_bid_micros
end

#idFixnum

Output only. The ID of the Keyword Plan keyword. Corresponds to the JSON property id

Returns:

  • (Fixnum)


30138
30139
30140
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30138

def id
  @id
end

#keyword_plan_ad_groupString

The Keyword Plan ad group to which this keyword belongs. Corresponds to the JSON property keywordPlanAdGroup

Returns:

  • (String)


30143
30144
30145
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30143

def keyword_plan_ad_group
  @keyword_plan_ad_group
end

#match_typeString

The keyword match type. Corresponds to the JSON property matchType

Returns:

  • (String)


30148
30149
30150
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30148

def match_type
  @match_type
end

#negativeBoolean Also known as: negative?

Immutable. If true, the keyword is negative. Corresponds to the JSON property negative

Returns:

  • (Boolean)


30153
30154
30155
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30153

def negative
  @negative
end

#resource_nameString

Immutable. The resource name of the Keyword Plan ad group keyword. KeywordPlanAdGroupKeyword resource names have the form: customers/ customer_id/keywordPlanAdGroupKeywords/kp_ad_group_keyword_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


30161
30162
30163
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30161

def resource_name
  @resource_name
end

#textString

The keyword text. Corresponds to the JSON property text

Returns:

  • (String)


30166
30167
30168
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30166

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30173
30174
30175
30176
30177
30178
30179
30180
30181
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30173

def update!(**args)
  @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros)
  @id = args[:id] if args.key?(:id)
  @keyword_plan_ad_group = args[:keyword_plan_ad_group] if args.key?(:keyword_plan_ad_group)
  @match_type = args[:match_type] if args.key?(:match_type)
  @negative = args[:negative] if args.key?(:negative)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @text = args[:text] if args.key?(:text)
end