Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A Keyword Plan ad group keyword. Max number of keyword plan keywords per plan: 10000.
Instance Attribute Summary collapse
-
#cpc_bid_micros ⇒ Fixnum
A keyword level max cpc bid in micros (for example, $1 = 1mm).
-
#id ⇒ Fixnum
Output only.
-
#keyword_plan_ad_group ⇒ String
The Keyword Plan ad group to which this keyword belongs.
-
#match_type ⇒ String
The keyword match type.
-
#negative ⇒ Boolean
(also: #negative?)
Immutable.
-
#resource_name ⇒ String
Immutable.
-
#text ⇒ String
The keyword text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword
constructor
A new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword
Returns a new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword.
30168 30169 30170 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpc_bid_micros ⇒ Fixnum
A keyword level max cpc bid in micros (for example, $1 = 1mm). The currency is
the same as the account currency code. This will override any CPC bid set at
the keyword plan ad group level. Not applicable for negative keywords. (
negative = true) This field is Optional.
Corresponds to the JSON property cpcBidMicros
30133 30134 30135 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30133 def cpc_bid_micros @cpc_bid_micros end |
#id ⇒ Fixnum
Output only. The ID of the Keyword Plan keyword.
Corresponds to the JSON property id
30138 30139 30140 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30138 def id @id end |
#keyword_plan_ad_group ⇒ String
The Keyword Plan ad group to which this keyword belongs.
Corresponds to the JSON property keywordPlanAdGroup
30143 30144 30145 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30143 def keyword_plan_ad_group @keyword_plan_ad_group end |
#match_type ⇒ String
The keyword match type.
Corresponds to the JSON property matchType
30148 30149 30150 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30148 def match_type @match_type end |
#negative ⇒ Boolean Also known as: negative?
Immutable. If true, the keyword is negative.
Corresponds to the JSON property negative
30153 30154 30155 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30153 def negative @negative end |
#resource_name ⇒ String
Immutable. The resource name of the Keyword Plan ad group keyword.
KeywordPlanAdGroupKeyword resource names have the form: customers/
customer_id/keywordPlanAdGroupKeywords/kp_ad_group_keyword_id`
Corresponds to the JSON propertyresourceName`
30161 30162 30163 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30161 def resource_name @resource_name end |
#text ⇒ String
The keyword text.
Corresponds to the JSON property text
30166 30167 30168 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30166 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30173 30174 30175 30176 30177 30178 30179 30180 30181 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30173 def update!(**args) @cpc_bid_micros = args[:cpc_bid_micros] if args.key?(:cpc_bid_micros) @id = args[:id] if args.key?(:id) @keyword_plan_ad_group = args[:keyword_plan_ad_group] if args.key?(:keyword_plan_ad_group) @match_type = args[:match_type] if args.key?(:match_type) @negative = args[:negative] if args.key?(:negative) @resource_name = args[:resource_name] if args.key?(:resource_name) @text = args[:text] if args.key?(:text) end |