Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaignKeyword

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Keyword Plan Campaign keyword. Only negative keywords are supported for Campaign Keyword.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanCampaignKeyword

Returns a new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanCampaignKeyword.



30291
30292
30293
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30291

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. The ID of the Keyword Plan negative keyword. Corresponds to the JSON property id

Returns:

  • (Fixnum)


30260
30261
30262
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30260

def id
  @id
end

#keyword_plan_campaignString

The Keyword Plan campaign to which this negative keyword belongs. Corresponds to the JSON property keywordPlanCampaign

Returns:

  • (String)


30265
30266
30267
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30265

def keyword_plan_campaign
  @keyword_plan_campaign
end

#match_typeString

The keyword match type. Corresponds to the JSON property matchType

Returns:

  • (String)


30270
30271
30272
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30270

def match_type
  @match_type
end

#negativeBoolean Also known as: negative?

Immutable. If true, the keyword is negative. Must be set to true. Only negative campaign keywords are supported. Corresponds to the JSON property negative

Returns:

  • (Boolean)


30276
30277
30278
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30276

def negative
  @negative
end

#resource_nameString

Immutable. The resource name of the Keyword Plan Campaign keyword. KeywordPlanCampaignKeyword resource names have the form: customers/ customer_id/keywordPlanCampaignKeywords/kp_campaign_keyword_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


30284
30285
30286
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30284

def resource_name
  @resource_name
end

#textString

The keyword text. Corresponds to the JSON property text

Returns:

  • (String)


30289
30290
30291
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30289

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30296
30297
30298
30299
30300
30301
30302
30303
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30296

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @keyword_plan_campaign = args[:keyword_plan_campaign] if args.key?(:keyword_plan_campaign)
  @match_type = args[:match_type] if args.key?(:match_type)
  @negative = args[:negative] if args.key?(:negative)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @text = args[:text] if args.key?(:text)
end