Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanForecastPeriod
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanForecastPeriod
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The forecasting period associated with the keyword plan.
Instance Attribute Summary collapse
-
#date_interval ⇒ String
A future date range relative to the current date used for forecasting.
-
#date_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDateRange
A date range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanForecastPeriod
constructor
A new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanForecastPeriod.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesKeywordPlanForecastPeriod
Returns a new instance of GoogleAdsSearchads360V23ResourcesKeywordPlanForecastPeriod.
30320 30321 30322 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30320 def initialize(**args) update!(**args) end |
Instance Attribute Details
#date_interval ⇒ String
A future date range relative to the current date used for forecasting.
Corresponds to the JSON property dateInterval
30313 30314 30315 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30313 def date_interval @date_interval end |
#date_range ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDateRange
A date range.
Corresponds to the JSON property dateRange
30318 30319 30320 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30318 def date_range @date_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30325 30326 30327 30328 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30325 def update!(**args) @date_interval = args[:date_interval] if args.key?(:date_interval) @date_range = args[:date_range] if args.key?(:date_range) end |