Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLabel
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLabel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A label.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
The name of the label.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#text_label ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTextLabel
A type of label displaying text on a colored background.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLabel
constructor
A new instance of GoogleAdsSearchads360V23ResourcesLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLabel
Returns a new instance of GoogleAdsSearchads360V23ResourcesLabel.
30445 30446 30447 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30445 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. ID of the label. Read only.
Corresponds to the JSON property id
30420 30421 30422 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30420 def id @id end |
#name ⇒ String
The name of the label. This field is required and should not be empty when
creating a new label. The length of this string should be between 1 and 80,
inclusive.
Corresponds to the JSON property name
30427 30428 30429 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30427 def name @name end |
#resource_name ⇒ String
Immutable. Name of the resource. Label resource names have the form:
customers/owner_customer_id/labels/label_id`
Corresponds to the JSON propertyresourceName`
30433 30434 30435 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30433 def resource_name @resource_name end |
#status ⇒ String
Output only. Status of the label. Read only.
Corresponds to the JSON property status
30438 30439 30440 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30438 def status @status end |
#text_label ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTextLabel
A type of label displaying text on a colored background.
Corresponds to the JSON property textLabel
30443 30444 30445 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30443 def text_label @text_label end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30450 30451 30452 30453 30454 30455 30456 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30450 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @text_label = args[:text_label] if args.key?(:text_label) end |