Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Data from lead form submissions.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Output only.
-
#ad_group_ad ⇒ String
Output only.
-
#asset ⇒ String
Output only.
-
#campaign ⇒ String
Output only.
-
#custom_lead_form_submission_fields ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomLeadFormSubmissionField>
Output only.
-
#gclid ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#lead_form_submission_fields ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLeadFormSubmissionField>
Output only.
-
#resource_name ⇒ String
Output only.
-
#submission_date_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData
constructor
A new instance of GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData
Returns a new instance of GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData.
30763 30764 30765 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30763 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Output only. AdGroup associated with the submitted lead form.
Corresponds to the JSON property adGroup
30712 30713 30714 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30712 def ad_group @ad_group end |
#ad_group_ad ⇒ String
Output only. AdGroupAd associated with the submitted lead form.
Corresponds to the JSON property adGroupAd
30717 30718 30719 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30717 def ad_group_ad @ad_group_ad end |
#asset ⇒ String
Output only. Asset associated with the submitted lead form.
Corresponds to the JSON property asset
30722 30723 30724 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30722 def asset @asset end |
#campaign ⇒ String
Output only. Campaign associated with the submitted lead form.
Corresponds to the JSON property campaign
30727 30728 30729 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30727 def campaign @campaign end |
#custom_lead_form_submission_fields ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomLeadFormSubmissionField>
Output only. Submission data associated with a custom lead form.
Corresponds to the JSON property customLeadFormSubmissionFields
30732 30733 30734 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30732 def custom_lead_form_submission_fields @custom_lead_form_submission_fields end |
#gclid ⇒ String
Output only. Google Click Id associated with the submissed lead form.
Corresponds to the JSON property gclid
30737 30738 30739 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30737 def gclid @gclid end |
#id ⇒ String
Output only. ID of this lead form submission.
Corresponds to the JSON property id
30742 30743 30744 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30742 def id @id end |
#lead_form_submission_fields ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLeadFormSubmissionField>
Output only. Submission data associated with a lead form.
Corresponds to the JSON property leadFormSubmissionFields
30747 30748 30749 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30747 def lead_form_submission_fields @lead_form_submission_fields end |
#resource_name ⇒ String
Output only. The resource name of the lead form submission data. Lead form
submission data resource names have the form: customers/customer_id/
leadFormSubmissionData/lead_form_submission_data_id`
Corresponds to the JSON propertyresourceName`
30754 30755 30756 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30754 def resource_name @resource_name end |
#submission_date_time ⇒ String
Output only. The date and time at which the lead form was submitted. The
format is "yyyy-mm-dd hh:mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08:
00".
Corresponds to the JSON property submissionDateTime
30761 30762 30763 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30761 def submission_date_time @submission_date_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30768 30769 30770 30771 30772 30773 30774 30775 30776 30777 30778 30779 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30768 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad) @asset = args[:asset] if args.key?(:asset) @campaign = args[:campaign] if args.key?(:campaign) @custom_lead_form_submission_fields = args[:custom_lead_form_submission_fields] if args.key?(:custom_lead_form_submission_fields) @gclid = args[:gclid] if args.key?(:gclid) @id = args[:id] if args.key?(:id) @lead_form_submission_fields = args[:lead_form_submission_fields] if args.key?(:lead_form_submission_fields) @resource_name = args[:resource_name] if args.key?(:resource_name) @submission_date_time = args[:submission_date_time] if args.key?(:submission_date_time) end |