Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Data from lead form submissions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData

Returns a new instance of GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData.



30691
30692
30693
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Output only. AdGroup associated with the submitted lead form. Corresponds to the JSON property adGroup

Returns:

  • (String)


30640
30641
30642
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30640

def ad_group
  @ad_group
end

#ad_group_adString

Output only. AdGroupAd associated with the submitted lead form. Corresponds to the JSON property adGroupAd

Returns:

  • (String)


30645
30646
30647
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30645

def ad_group_ad
  @ad_group_ad
end

#assetString

Output only. Asset associated with the submitted lead form. Corresponds to the JSON property asset

Returns:

  • (String)


30650
30651
30652
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30650

def asset
  @asset
end

#campaignString

Output only. Campaign associated with the submitted lead form. Corresponds to the JSON property campaign

Returns:

  • (String)


30655
30656
30657
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30655

def campaign
  @campaign
end

#custom_lead_form_submission_fieldsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomLeadFormSubmissionField>

Output only. Submission data associated with a custom lead form. Corresponds to the JSON property customLeadFormSubmissionFields



30660
30661
30662
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30660

def custom_lead_form_submission_fields
  @custom_lead_form_submission_fields
end

#gclidString

Output only. Google Click Id associated with the submissed lead form. Corresponds to the JSON property gclid

Returns:

  • (String)


30665
30666
30667
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30665

def gclid
  @gclid
end

#idString

Output only. ID of this lead form submission. Corresponds to the JSON property id

Returns:

  • (String)


30670
30671
30672
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30670

def id
  @id
end

#lead_form_submission_fieldsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLeadFormSubmissionField>

Output only. Submission data associated with a lead form. Corresponds to the JSON property leadFormSubmissionFields



30675
30676
30677
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30675

def lead_form_submission_fields
  @lead_form_submission_fields
end

#resource_nameString

Output only. The resource name of the lead form submission data. Lead form submission data resource names have the form: customers/customer_id/ leadFormSubmissionData/lead_form_submission_data_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


30682
30683
30684
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30682

def resource_name
  @resource_name
end

#submission_date_timeString

Output only. The date and time at which the lead form was submitted. The format is "yyyy-mm-dd hh:mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08: 00". Corresponds to the JSON property submissionDateTime

Returns:

  • (String)


30689
30690
30691
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30689

def submission_date_time
  @submission_date_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30696
30697
30698
30699
30700
30701
30702
30703
30704
30705
30706
30707
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30696

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad)
  @asset = args[:asset] if args.key?(:asset)
  @campaign = args[:campaign] if args.key?(:campaign)
  @custom_lead_form_submission_fields = args[:custom_lead_form_submission_fields] if args.key?(:custom_lead_form_submission_fields)
  @gclid = args[:gclid] if args.key?(:gclid)
  @id = args[:id] if args.key?(:id)
  @lead_form_submission_fields = args[:lead_form_submission_fields] if args.key?(:lead_form_submission_fields)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @submission_date_time = args[:submission_date_time] if args.key?(:submission_date_time)
end