Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Data from lead form submissions.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Output only.
-
#ad_group_ad ⇒ String
Output only.
-
#asset ⇒ String
Output only.
-
#campaign ⇒ String
Output only.
-
#custom_lead_form_submission_fields ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomLeadFormSubmissionField>
Output only.
-
#gclid ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#lead_form_submission_fields ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLeadFormSubmissionField>
Output only.
-
#resource_name ⇒ String
Output only.
-
#submission_date_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData
constructor
A new instance of GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData
Returns a new instance of GoogleAdsSearchads360V23ResourcesLeadFormSubmissionData.
30590 30591 30592 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30590 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Output only. AdGroup associated with the submitted lead form.
Corresponds to the JSON property adGroup
30539 30540 30541 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30539 def ad_group @ad_group end |
#ad_group_ad ⇒ String
Output only. AdGroupAd associated with the submitted lead form.
Corresponds to the JSON property adGroupAd
30544 30545 30546 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30544 def ad_group_ad @ad_group_ad end |
#asset ⇒ String
Output only. Asset associated with the submitted lead form.
Corresponds to the JSON property asset
30549 30550 30551 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30549 def asset @asset end |
#campaign ⇒ String
Output only. Campaign associated with the submitted lead form.
Corresponds to the JSON property campaign
30554 30555 30556 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30554 def campaign @campaign end |
#custom_lead_form_submission_fields ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomLeadFormSubmissionField>
Output only. Submission data associated with a custom lead form.
Corresponds to the JSON property customLeadFormSubmissionFields
30559 30560 30561 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30559 def custom_lead_form_submission_fields @custom_lead_form_submission_fields end |
#gclid ⇒ String
Output only. Google Click Id associated with the submissed lead form.
Corresponds to the JSON property gclid
30564 30565 30566 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30564 def gclid @gclid end |
#id ⇒ String
Output only. ID of this lead form submission.
Corresponds to the JSON property id
30569 30570 30571 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30569 def id @id end |
#lead_form_submission_fields ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLeadFormSubmissionField>
Output only. Submission data associated with a lead form.
Corresponds to the JSON property leadFormSubmissionFields
30574 30575 30576 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30574 def lead_form_submission_fields @lead_form_submission_fields end |
#resource_name ⇒ String
Output only. The resource name of the lead form submission data. Lead form
submission data resource names have the form: customers/customer_id/
leadFormSubmissionData/lead_form_submission_data_id`
Corresponds to the JSON propertyresourceName`
30581 30582 30583 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30581 def resource_name @resource_name end |
#submission_date_time ⇒ String
Output only. The date and time at which the lead form was submitted. The
format is "yyyy-mm-dd hh:mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08:
00".
Corresponds to the JSON property submissionDateTime
30588 30589 30590 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30588 def submission_date_time @submission_date_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30595 30596 30597 30598 30599 30600 30601 30602 30603 30604 30605 30606 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30595 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @ad_group_ad = args[:ad_group_ad] if args.key?(:ad_group_ad) @asset = args[:asset] if args.key?(:asset) @campaign = args[:campaign] if args.key?(:campaign) @custom_lead_form_submission_fields = args[:custom_lead_form_submission_fields] if args.key?(:custom_lead_form_submission_fields) @gclid = args[:gclid] if args.key?(:gclid) @id = args[:id] if args.key?(:id) @lead_form_submission_fields = args[:lead_form_submission_fields] if args.key?(:lead_form_submission_fields) @resource_name = args[:resource_name] if args.key?(:resource_name) @submission_date_time = args[:submission_date_time] if args.key?(:submission_date_time) end |