Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLifeEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A life event: a particular interest-based vertical to be targeted to reach users when they are in the midst of important life milestones.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLifeEvent

Returns a new instance of GoogleAdsSearchads360V23ResourcesLifeEvent.



30829
30830
30831
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30829

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availabilitiesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryAvailability>

Output only. Availability information of the life event. Corresponds to the JSON property availabilities



30800
30801
30802
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30800

def availabilities
  @availabilities
end

#idFixnum

Output only. The ID of the life event. Corresponds to the JSON property id

Returns:

  • (Fixnum)


30805
30806
30807
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30805

def id
  @id
end

#launched_to_allBoolean Also known as: launched_to_all?

Output only. True if the life event is launched to all channels and locales. Corresponds to the JSON property launchedToAll

Returns:

  • (Boolean)


30810
30811
30812
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30810

def launched_to_all
  @launched_to_all
end

#nameString

Output only. The name of the life event, for example,"Recently Moved" Corresponds to the JSON property name

Returns:

  • (String)


30816
30817
30818
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30816

def name
  @name
end

#parentString

Output only. The parent of the life_event. Corresponds to the JSON property parent

Returns:

  • (String)


30821
30822
30823
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30821

def parent
  @parent
end

#resource_nameString

Output only. The resource name of the life event. Life event resource names have the form: customers/customer_id/lifeEvents/life_event_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


30827
30828
30829
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30827

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30834
30835
30836
30837
30838
30839
30840
30841
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30834

def update!(**args)
  @availabilities = args[:availabilities] if args.key?(:availabilities)
  @id = args[:id] if args.key?(:id)
  @launched_to_all = args[:launched_to_all] if args.key?(:launched_to_all)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end