Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLifeEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A life event: a particular interest-based vertical to be targeted to reach users when they are in the midst of important life milestones.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLifeEvent

Returns a new instance of GoogleAdsSearchads360V23ResourcesLifeEvent.



30728
30729
30730
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30728

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availabilitiesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCriterionCategoryAvailability>

Output only. Availability information of the life event. Corresponds to the JSON property availabilities



30699
30700
30701
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30699

def availabilities
  @availabilities
end

#idFixnum

Output only. The ID of the life event. Corresponds to the JSON property id

Returns:

  • (Fixnum)


30704
30705
30706
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30704

def id
  @id
end

#launched_to_allBoolean Also known as: launched_to_all?

Output only. True if the life event is launched to all channels and locales. Corresponds to the JSON property launchedToAll

Returns:

  • (Boolean)


30709
30710
30711
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30709

def launched_to_all
  @launched_to_all
end

#nameString

Output only. The name of the life event, for example,"Recently Moved" Corresponds to the JSON property name

Returns:

  • (String)


30715
30716
30717
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30715

def name
  @name
end

#parentString

Output only. The parent of the life_event. Corresponds to the JSON property parent

Returns:

  • (String)


30720
30721
30722
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30720

def parent
  @parent
end

#resource_nameString

Output only. The resource name of the life event. Life event resource names have the form: customers/customer_id/lifeEvents/life_event_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


30726
30727
30728
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30726

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30733
30734
30735
30736
30737
30738
30739
30740
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30733

def update!(**args)
  @availabilities = args[:availabilities] if args.key?(:availabilities)
  @id = args[:id] if args.key?(:id)
  @launched_to_all = args[:launched_to_all] if args.key?(:launched_to_all)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end