Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLocalServicesLead

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Data from Local Services Lead. Contains details of Lead which is generated when user calls, messages or books service from advertiser. More info: https:// ads.google.com/local-services-ads

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLocalServicesLead

Returns a new instance of GoogleAdsSearchads360V23ResourcesLocalServicesLead.



31140
31141
31142
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31140

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_idString

Output only. Service category of the lead. For example: xcat: service_area_business_hvac, xcat:service_area_business_real_estate_agent, etc. For more details see: https://developers.google.com/google-ads/api/data/ codes-formats#local_services_ids Corresponds to the JSON property categoryId

Returns:

  • (String)


31068
31069
31070
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31068

def category_id
  @category_id
end

#contact_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesContactDetails

Fields containing consumer contact details. Corresponds to the JSON property contactDetails



31073
31074
31075
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31073

def contact_details
  @contact_details
end

#creation_date_timeString

Output only. The date time at which lead was created by Local Services Ads. The format is "YYYY-MM-DD HH:MM:SS" in the Google Ads account's timezone. Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34:30" Corresponds to the JSON property creationDateTime

Returns:

  • (String)


31080
31081
31082
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31080

def creation_date_time
  @creation_date_time
end

#credit_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCreditDetails

Represents the credit details of a lead. Corresponds to the JSON property creditDetails



31085
31086
31087
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31085

def credit_details
  @credit_details
end

#idFixnum

Output only. ID of this Lead. Corresponds to the JSON property id

Returns:

  • (Fixnum)


31090
31091
31092
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31090

def id
  @id
end

#lead_chargedBoolean Also known as: lead_charged?

Output only. True if the advertiser was charged for the lead. Corresponds to the JSON property leadCharged

Returns:

  • (Boolean)


31095
31096
31097
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31095

def lead_charged
  @lead_charged
end

#lead_feedback_submittedBoolean Also known as: lead_feedback_submitted?

Output only. True if the advertiser submitted feedback for the lead. Corresponds to the JSON property leadFeedbackSubmitted

Returns:

  • (Boolean)


31101
31102
31103
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31101

def 
  @lead_feedback_submitted
end

#lead_statusString

Output only. Current status of lead. Corresponds to the JSON property leadStatus

Returns:

  • (String)


31107
31108
31109
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31107

def lead_status
  @lead_status
end

#lead_typeString

Output only. Type of Local Services lead: phone, message, booking, etc. Corresponds to the JSON property leadType

Returns:

  • (String)


31112
31113
31114
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31112

def lead_type
  @lead_type
end

#localeString

Output only. Language used by the Local Services provider linked to lead. See https://developers.google.com/google-ads/api/data/codes-formats#locales Corresponds to the JSON property locale

Returns:

  • (String)


31118
31119
31120
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31118

def locale
  @locale
end

#noteGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesNote

Represents a note added to a lead by the advertiser. Advertisers can edit notes, which will reset edit time and change description. Corresponds to the JSON property note



31124
31125
31126
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31124

def note
  @note
end

#resource_nameString

Immutable. The resource name of the local services lead data. Local Services Lead resource name have the form customers/customer_id/localServicesLead/ local_services_lead_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


31131
31132
31133
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31131

def resource_name
  @resource_name
end

#service_idString

Output only. Service for the category. For example: buyer_agent, seller_agent for the category of xcat: service_area_business_real_estate_agent. Corresponds to the JSON property serviceId

Returns:

  • (String)


31138
31139
31140
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31138

def service_id
  @service_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31145
31146
31147
31148
31149
31150
31151
31152
31153
31154
31155
31156
31157
31158
31159
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31145

def update!(**args)
  @category_id = args[:category_id] if args.key?(:category_id)
  @contact_details = args[:contact_details] if args.key?(:contact_details)
  @creation_date_time = args[:creation_date_time] if args.key?(:creation_date_time)
  @credit_details = args[:credit_details] if args.key?(:credit_details)
  @id = args[:id] if args.key?(:id)
  @lead_charged = args[:lead_charged] if args.key?(:lead_charged)
  @lead_feedback_submitted = args[:lead_feedback_submitted] if args.key?(:lead_feedback_submitted)
  @lead_status = args[:lead_status] if args.key?(:lead_status)
  @lead_type = args[:lead_type] if args.key?(:lead_type)
  @locale = args[:locale] if args.key?(:locale)
  @note = args[:note] if args.key?(:note)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @service_id = args[:service_id] if args.key?(:service_id)
end