Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLocalServicesLead

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Data from Local Services Lead. Contains details of Lead which is generated when user calls, messages or books service from advertiser. More info: https:// ads.google.com/local-services-ads

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLocalServicesLead

Returns a new instance of GoogleAdsSearchads360V23ResourcesLocalServicesLead.



31039
31040
31041
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31039

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_idString

Output only. Service category of the lead. For example: xcat: service_area_business_hvac, xcat:service_area_business_real_estate_agent, etc. For more details see: https://developers.google.com/google-ads/api/data/ codes-formats#local_services_ids Corresponds to the JSON property categoryId

Returns:

  • (String)


30967
30968
30969
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30967

def category_id
  @category_id
end

#contact_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesContactDetails

Fields containing consumer contact details. Corresponds to the JSON property contactDetails



30972
30973
30974
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30972

def contact_details
  @contact_details
end

#creation_date_timeString

Output only. The date time at which lead was created by Local Services Ads. The format is "YYYY-MM-DD HH:MM:SS" in the Google Ads account's timezone. Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34:30" Corresponds to the JSON property creationDateTime

Returns:

  • (String)


30979
30980
30981
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30979

def creation_date_time
  @creation_date_time
end

#credit_detailsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCreditDetails

Represents the credit details of a lead. Corresponds to the JSON property creditDetails



30984
30985
30986
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30984

def credit_details
  @credit_details
end

#idFixnum

Output only. ID of this Lead. Corresponds to the JSON property id

Returns:

  • (Fixnum)


30989
30990
30991
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30989

def id
  @id
end

#lead_chargedBoolean Also known as: lead_charged?

Output only. True if the advertiser was charged for the lead. Corresponds to the JSON property leadCharged

Returns:

  • (Boolean)


30994
30995
30996
# File 'lib/google/apis/searchads360_v23/classes.rb', line 30994

def lead_charged
  @lead_charged
end

#lead_feedback_submittedBoolean Also known as: lead_feedback_submitted?

Output only. True if the advertiser submitted feedback for the lead. Corresponds to the JSON property leadFeedbackSubmitted

Returns:

  • (Boolean)


31000
31001
31002
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31000

def 
  @lead_feedback_submitted
end

#lead_statusString

Output only. Current status of lead. Corresponds to the JSON property leadStatus

Returns:

  • (String)


31006
31007
31008
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31006

def lead_status
  @lead_status
end

#lead_typeString

Output only. Type of Local Services lead: phone, message, booking, etc. Corresponds to the JSON property leadType

Returns:

  • (String)


31011
31012
31013
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31011

def lead_type
  @lead_type
end

#localeString

Output only. Language used by the Local Services provider linked to lead. See https://developers.google.com/google-ads/api/data/codes-formats#locales Corresponds to the JSON property locale

Returns:

  • (String)


31017
31018
31019
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31017

def locale
  @locale
end

#noteGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesNote

Represents a note added to a lead by the advertiser. Advertisers can edit notes, which will reset edit time and change description. Corresponds to the JSON property note



31023
31024
31025
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31023

def note
  @note
end

#resource_nameString

Immutable. The resource name of the local services lead data. Local Services Lead resource name have the form customers/customer_id/localServicesLead/ local_services_lead_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


31030
31031
31032
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31030

def resource_name
  @resource_name
end

#service_idString

Output only. Service for the category. For example: buyer_agent, seller_agent for the category of xcat: service_area_business_real_estate_agent. Corresponds to the JSON property serviceId

Returns:

  • (String)


31037
31038
31039
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31037

def service_id
  @service_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31044
31045
31046
31047
31048
31049
31050
31051
31052
31053
31054
31055
31056
31057
31058
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31044

def update!(**args)
  @category_id = args[:category_id] if args.key?(:category_id)
  @contact_details = args[:contact_details] if args.key?(:contact_details)
  @creation_date_time = args[:creation_date_time] if args.key?(:creation_date_time)
  @credit_details = args[:credit_details] if args.key?(:credit_details)
  @id = args[:id] if args.key?(:id)
  @lead_charged = args[:lead_charged] if args.key?(:lead_charged)
  @lead_feedback_submitted = args[:lead_feedback_submitted] if args.key?(:lead_feedback_submitted)
  @lead_status = args[:lead_status] if args.key?(:lead_status)
  @lead_type = args[:lead_type] if args.key?(:lead_type)
  @locale = args[:locale] if args.key?(:locale)
  @note = args[:note] if args.key?(:note)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @service_id = args[:service_id] if args.key?(:service_id)
end