Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLocalServicesLeadConversation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLocalServicesLeadConversation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Data from Local Services Lead Conversation. Contains details of Lead Conversation which is generated when user calls, messages or books service from advertiser. These are appended to a Lead. More info: https://ads.google. com/local-services-ads
Instance Attribute Summary collapse
-
#conversation_channel ⇒ String
Output only.
-
#event_date_time ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#lead ⇒ String
Output only.
-
#message_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMessageDetails
Represents details of text message in case of email, message or SMS.
-
#participant_type ⇒ String
Output only.
-
#phone_call_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesPhoneCallDetails
Represents details of a phone call conversation.
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLocalServicesLeadConversation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesLocalServicesLeadConversation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesLocalServicesLeadConversation
Returns a new instance of GoogleAdsSearchads360V23ResourcesLocalServicesLeadConversation.
31115 31116 31117 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_channel ⇒ String
Output only. Type of GLS lead conversation, EMAIL, MESSAGE, PHONE_CALL, SMS,
etc.
Corresponds to the JSON property conversationChannel
31072 31073 31074 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31072 def conversation_channel @conversation_channel end |
#event_date_time ⇒ String
Output only. The date time at which lead conversation was created by Local
Services Ads. The format is "YYYY-MM-DD HH:MM:SS" in the Google Ads account's
timezone. Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34:30"
Corresponds to the JSON property eventDateTime
31079 31080 31081 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31079 def event_date_time @event_date_time end |
#id ⇒ Fixnum
Output only. ID of this Lead Conversation.
Corresponds to the JSON property id
31084 31085 31086 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31084 def id @id end |
#lead ⇒ String
Output only. Resource name of Lead associated to the Lead Conversation.
Corresponds to the JSON property lead
31089 31090 31091 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31089 def lead @lead end |
#message_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMessageDetails
Represents details of text message in case of email, message or SMS.
Corresponds to the JSON property messageDetails
31094 31095 31096 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31094 def @message_details end |
#participant_type ⇒ String
Output only. Type of participant in the lead conversation, ADVERTISER or
CONSUMER.
Corresponds to the JSON property participantType
31100 31101 31102 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31100 def participant_type @participant_type end |
#phone_call_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesPhoneCallDetails
Represents details of a phone call conversation.
Corresponds to the JSON property phoneCallDetails
31105 31106 31107 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31105 def phone_call_details @phone_call_details end |
#resource_name ⇒ String
Output only. The resource name of the local services lead conversation data.
Local Services Lead Conversation resource name have the form customers/
customer_id/localServicesLeadConversation/
local_services_lead_conversation_id`
Corresponds to the JSON propertyresourceName`
31113 31114 31115 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31113 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31120 31121 31122 31123 31124 31125 31126 31127 31128 31129 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31120 def update!(**args) @conversation_channel = args[:conversation_channel] if args.key?(:conversation_channel) @event_date_time = args[:event_date_time] if args.key?(:event_date_time) @id = args[:id] if args.key?(:id) @lead = args[:lead] if args.key?(:lead) @message_details = args[:message_details] if args.key?(:message_details) @participant_type = args[:participant_type] if args.key?(:participant_type) @phone_call_details = args[:phone_call_details] if args.key?(:phone_call_details) @resource_name = args[:resource_name] if args.key?(:resource_name) end |