Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMatchedLocationInterestView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMatchedLocationInterestView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A view that reports metrics for locations where users showed interest, and which matched the advertiser's location interest targeting (defined as geo targets at the AdGroup level). The data is aggregated at the country level by default. This view is currently only available for AI Max campaigns.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMatchedLocationInterestView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesMatchedLocationInterestView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMatchedLocationInterestView
Returns a new instance of GoogleAdsSearchads360V23ResourcesMatchedLocationInterestView.
31481 31482 31483 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31481 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Output only. The resource name of the matched location interest view. Matched
location interest view resource names have the form: customers/customer_id/
matchedLocationInterestViews/country_criterion_id`
Corresponds to the JSON propertyresourceName`
31479 31480 31481 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31479 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31486 31487 31488 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31486 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) end |