Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMediaFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A media file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMediaFile

Returns a new instance of GoogleAdsSearchads360V23ResourcesMediaFile.



31425
31426
31427
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audioGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMediaAudio

Encapsulates an Audio. Corresponds to the JSON property audio



31370
31371
31372
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31370

def audio
  @audio
end

#file_sizeFixnum

Output only. The size of the media file in bytes. Corresponds to the JSON property fileSize

Returns:

  • (Fixnum)


31375
31376
31377
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31375

def file_size
  @file_size
end

#idFixnum

Output only. The ID of the media file. Corresponds to the JSON property id

Returns:

  • (Fixnum)


31380
31381
31382
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31380

def id
  @id
end

#imageGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMediaImage

Encapsulates an Image. Corresponds to the JSON property image



31385
31386
31387
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31385

def image
  @image
end

#media_bundleGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMediaBundle

Represents a ZIP archive media the content of which contains HTML5 assets. Corresponds to the JSON property mediaBundle



31390
31391
31392
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31390

def media_bundle
  @media_bundle
end

#mime_typeString

Output only. The mime type of the media file. Corresponds to the JSON property mimeType

Returns:

  • (String)


31395
31396
31397
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31395

def mime_type
  @mime_type
end

#nameString

Immutable. The name of the media file. The name can be used by clients to help identify previously uploaded media. Corresponds to the JSON property name

Returns:

  • (String)


31401
31402
31403
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31401

def name
  @name
end

#resource_nameString

Immutable. The resource name of the media file. Media file resource names have the form: customers/customer_id/mediaFiles/media_file_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


31407
31408
31409
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31407

def resource_name
  @resource_name
end

#source_urlString

Immutable. The URL of where the original media file was downloaded from (or a file name). Only used for media of type AUDIO and IMAGE. Corresponds to the JSON property sourceUrl

Returns:

  • (String)


31413
31414
31415
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31413

def source_url
  @source_url
end

#typeString

Immutable. Type of the media file. Corresponds to the JSON property type

Returns:

  • (String)


31418
31419
31420
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31418

def type
  @type
end

#videoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMediaVideo

Encapsulates a Video. Corresponds to the JSON property video



31423
31424
31425
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31423

def video
  @video
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31430
31431
31432
31433
31434
31435
31436
31437
31438
31439
31440
31441
31442
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31430

def update!(**args)
  @audio = args[:audio] if args.key?(:audio)
  @file_size = args[:file_size] if args.key?(:file_size)
  @id = args[:id] if args.key?(:id)
  @image = args[:image] if args.key?(:image)
  @media_bundle = args[:media_bundle] if args.key?(:media_bundle)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @source_url = args[:source_url] if args.key?(:source_url)
  @type = args[:type] if args.key?(:type)
  @video = args[:video] if args.key?(:video)
end