Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMediaImage
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMediaImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Encapsulates an Image.
Instance Attribute Summary collapse
-
#data ⇒ String
Immutable.
-
#full_size_image_url ⇒ String
Output only.
-
#preview_size_image_url ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMediaImage
constructor
A new instance of GoogleAdsSearchads360V23ResourcesMediaImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMediaImage
Returns a new instance of GoogleAdsSearchads360V23ResourcesMediaImage.
31567 31568 31569 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31567 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ String
Immutable. Raw image data.
Corresponds to the JSON property data
NOTE: Values are automatically base64 encoded/decoded in the client library.
31555 31556 31557 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31555 def data @data end |
#full_size_image_url ⇒ String
Output only. The url to the full size version of the image.
Corresponds to the JSON property fullSizeImageUrl
31560 31561 31562 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31560 def full_size_image_url @full_size_image_url end |
#preview_size_image_url ⇒ String
Output only. The url to the preview size version of the image.
Corresponds to the JSON property previewSizeImageUrl
31565 31566 31567 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31565 def preview_size_image_url @preview_size_image_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31572 31573 31574 31575 31576 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31572 def update!(**args) @data = args[:data] if args.key?(:data) @full_size_image_url = args[:full_size_image_url] if args.key?(:full_size_image_url) @preview_size_image_url = args[:preview_size_image_url] if args.key?(:preview_size_image_url) end |