Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMediaVideo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMediaVideo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Encapsulates a Video.
Instance Attribute Summary collapse
-
#ad_duration_millis ⇒ Fixnum
Output only.
-
#advertising_id_code ⇒ String
Output only.
-
#isci_code ⇒ String
Output only.
-
#youtube_video_id ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMediaVideo
constructor
A new instance of GoogleAdsSearchads360V23ResourcesMediaVideo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMediaVideo
Returns a new instance of GoogleAdsSearchads360V23ResourcesMediaVideo.
31608 31609 31610 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31608 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_duration_millis ⇒ Fixnum
Output only. The duration of the Video in milliseconds.
Corresponds to the JSON property adDurationMillis
31586 31587 31588 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31586 def ad_duration_millis @ad_duration_millis end |
#advertising_id_code ⇒ String
Output only. The Advertising Digital Identification code for this video, as
defined by the American Association of Advertising Agencies, used mainly for
television commercials.
Corresponds to the JSON property advertisingIdCode
31593 31594 31595 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31593 def advertising_id_code @advertising_id_code end |
#isci_code ⇒ String
Output only. The Industry Standard Commercial Identifier code for this video,
used mainly for television commercials.
Corresponds to the JSON property isciCode
31599 31600 31601 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31599 def isci_code @isci_code end |
#youtube_video_id ⇒ String
Immutable. The YouTube video ID (as seen in YouTube URLs). Adding prefix "
https://www.youtube.com/watch?v=" to this ID will get the YouTube streaming
URL for this video.
Corresponds to the JSON property youtubeVideoId
31606 31607 31608 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31606 def youtube_video_id @youtube_video_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31613 31614 31615 31616 31617 31618 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31613 def update!(**args) @ad_duration_millis = args[:ad_duration_millis] if args.key?(:ad_duration_millis) @advertising_id_code = args[:advertising_id_code] if args.key?(:advertising_id_code) @isci_code = args[:isci_code] if args.key?(:isci_code) @youtube_video_id = args[:youtube_video_id] if args.key?(:youtube_video_id) end |