Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMediaVideo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Encapsulates a Video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMediaVideo

Returns a new instance of GoogleAdsSearchads360V23ResourcesMediaVideo.



31506
31507
31508
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_duration_millisFixnum

Output only. The duration of the Video in milliseconds. Corresponds to the JSON property adDurationMillis

Returns:

  • (Fixnum)


31484
31485
31486
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31484

def ad_duration_millis
  @ad_duration_millis
end

#advertising_id_codeString

Output only. The Advertising Digital Identification code for this video, as defined by the American Association of Advertising Agencies, used mainly for television commercials. Corresponds to the JSON property advertisingIdCode

Returns:

  • (String)


31491
31492
31493
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31491

def advertising_id_code
  @advertising_id_code
end

#isci_codeString

Output only. The Industry Standard Commercial Identifier code for this video, used mainly for television commercials. Corresponds to the JSON property isciCode

Returns:

  • (String)


31497
31498
31499
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31497

def isci_code
  @isci_code
end

#youtube_video_idString

Immutable. The YouTube video ID (as seen in YouTube URLs). Adding prefix " https://www.youtube.com/watch?v=" to this ID will get the YouTube streaming URL for this video. Corresponds to the JSON property youtubeVideoId

Returns:

  • (String)


31504
31505
31506
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31504

def youtube_video_id
  @youtube_video_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31511
31512
31513
31514
31515
31516
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31511

def update!(**args)
  @ad_duration_millis = args[:ad_duration_millis] if args.key?(:ad_duration_millis)
  @advertising_id_code = args[:advertising_id_code] if args.key?(:advertising_id_code)
  @isci_code = args[:isci_code] if args.key?(:isci_code)
  @youtube_video_id = args[:youtube_video_id] if args.key?(:youtube_video_id)
end