Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMerchantCenterIdentifier
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMerchantCenterIdentifier
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The identifier for Google Merchant Center account
Instance Attribute Summary collapse
-
#merchant_center_id ⇒ Fixnum
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMerchantCenterIdentifier
constructor
A new instance of GoogleAdsSearchads360V23ResourcesMerchantCenterIdentifier.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMerchantCenterIdentifier
Returns a new instance of GoogleAdsSearchads360V23ResourcesMerchantCenterIdentifier.
31530 31531 31532 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#merchant_center_id ⇒ Fixnum
Immutable. The customer ID of the Google Merchant Center account. This field
is required and should not be empty when creating a new Merchant Center link.
It is unable to be modified after the creation of the link.
Corresponds to the JSON property merchantCenterId
31528 31529 31530 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31528 def merchant_center_id @merchant_center_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31535 31536 31537 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31535 def update!(**args) @merchant_center_id = args[:merchant_center_id] if args.key?(:merchant_center_id) end |