Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMessageDetails
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMessageDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents details of text message in case of email, message or SMS.
Instance Attribute Summary collapse
-
#attachment_urls ⇒ Array<String>
Output only.
-
#text ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMessageDetails
constructor
A new instance of GoogleAdsSearchads360V23ResourcesMessageDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMessageDetails
Returns a new instance of GoogleAdsSearchads360V23ResourcesMessageDetails.
31749 31750 31751 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_urls ⇒ Array<String>
Output only. URL to the SMS or email attachments. These URLs can be used to
download the contents of the attachment by using the developer token.
Corresponds to the JSON property attachmentUrls
31742 31743 31744 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31742 def @attachment_urls end |
#text ⇒ String
Output only. Textual content of the message.
Corresponds to the JSON property text
31747 31748 31749 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31747 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31754 31755 31756 31757 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31754 def update!(**args) @attachment_urls = args[:attachment_urls] if args.key?(:attachment_urls) @text = args[:text] if args.key?(:text) end |