Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMessageDetails
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMessageDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents details of text message in case of email, message or SMS.
Instance Attribute Summary collapse
-
#attachment_urls ⇒ Array<String>
Output only.
-
#text ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMessageDetails
constructor
A new instance of GoogleAdsSearchads360V23ResourcesMessageDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMessageDetails
Returns a new instance of GoogleAdsSearchads360V23ResourcesMessageDetails.
31677 31678 31679 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31677 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_urls ⇒ Array<String>
Output only. URL to the SMS or email attachments. These URLs can be used to
download the contents of the attachment by using the developer token.
Corresponds to the JSON property attachmentUrls
31670 31671 31672 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31670 def @attachment_urls end |
#text ⇒ String
Output only. Textual content of the message.
Corresponds to the JSON property text
31675 31676 31677 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31675 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31682 31683 31684 31685 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31682 def update!(**args) @attachment_urls = args[:attachment_urls] if args.key?(:attachment_urls) @text = args[:text] if args.key?(:text) end |