Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMobileAppCategoryConstant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A mobile application category constant.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesMobileAppCategoryConstant

Returns a new instance of GoogleAdsSearchads360V23ResourcesMobileAppCategoryConstant.



31607
31608
31609
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. The ID of the mobile app category constant. Corresponds to the JSON property id

Returns:

  • (Fixnum)


31593
31594
31595
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31593

def id
  @id
end

#nameString

Output only. Mobile app category name. Corresponds to the JSON property name

Returns:

  • (String)


31598
31599
31600
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31598

def name
  @name
end

#resource_nameString

Output only. The resource name of the mobile app category constant. Mobile app category constant resource names have the form: mobileAppCategoryConstants/ mobile_app_category_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


31605
31606
31607
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31605

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31612
31613
31614
31615
31616
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31612

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end