Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesNote

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents a note added to a lead by the advertiser. Advertisers can edit notes, which will reset edit time and change description.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesNote

Returns a new instance of GoogleAdsSearchads360V23ResourcesNote.



31686
31687
31688
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Output only. Content of lead note. Corresponds to the JSON property description

Returns:

  • (String)


31677
31678
31679
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31677

def description
  @description
end

#edit_date_timeString

Output only. The date time when lead note was edited. The format is "YYYY-MM- DD HH:MM:SS" in the Google Ads account's timezone. Examples: "2018-03-05 09:15: 00" or "2018-02-01 14:34:30" Corresponds to the JSON property editDateTime

Returns:

  • (String)


31684
31685
31686
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31684

def edit_date_time
  @edit_date_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31691
31692
31693
31694
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31691

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @edit_date_time = args[:edit_date_time] if args.key?(:edit_date_time)
end