Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionUploadClientSummary
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionUploadClientSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Offline conversion upload summary at customer level.
Instance Attribute Summary collapse
-
#alerts ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionAlert>
Output only.
-
#client ⇒ String
Output only.
-
#daily_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionSummary>
Output only.
-
#job_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionSummary>
Output only.
-
#last_upload_date_time ⇒ String
Output only.
-
#pending_event_count ⇒ Fixnum
Output only.
-
#pending_rate ⇒ Float
Output only.
-
#resource_name ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#success_rate ⇒ Float
Output only.
-
#successful_event_count ⇒ Fixnum
Output only.
-
#total_event_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOfflineConversionUploadClientSummary
constructor
A new instance of GoogleAdsSearchads360V23ResourcesOfflineConversionUploadClientSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOfflineConversionUploadClientSummary
Returns a new instance of GoogleAdsSearchads360V23ResourcesOfflineConversionUploadClientSummary.
32011 32012 32013 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alerts ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionAlert>
Output only. Details for each error code. Alerts are generated from most
recent calendar day with upload stats.
Corresponds to the JSON property alerts
31949 31950 31951 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31949 def alerts @alerts end |
#client ⇒ String
Output only. Client type of the upload event.
Corresponds to the JSON property client
31954 31955 31956 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31954 def client @client end |
#daily_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionSummary>
Output only. Summary of history stats by last N days.
Corresponds to the JSON property dailySummaries
31959 31960 31961 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31959 def daily_summaries @daily_summaries end |
#job_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionSummary>
Output only. Summary of history stats by last N jobs.
Corresponds to the JSON property jobSummaries
31964 31965 31966 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31964 def job_summaries @job_summaries end |
#last_upload_date_time ⇒ String
Output only. Date for the latest upload batch. The format is "yyyy-mm-dd hh:mm:
ss", and it's in the time zone of the Google Ads account.
Corresponds to the JSON property lastUploadDateTime
31970 31971 31972 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31970 def last_upload_date_time @last_upload_date_time end |
#pending_event_count ⇒ Fixnum
Output only. Total count of pending uploaded events.
Corresponds to the JSON property pendingEventCount
31975 31976 31977 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31975 def pending_event_count @pending_event_count end |
#pending_rate ⇒ Float
Output only. The ratio of total pending events to total events.
Corresponds to the JSON property pendingRate
31980 31981 31982 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31980 def pending_rate @pending_rate end |
#resource_name ⇒ String
Output only. The resource name of the offline conversion upload summary at
customer level. Offline conversion upload client summary resource names have
the form: customers/customer_id/offlineConversionUploadClientSummaries/
client`
Corresponds to the JSON propertyresourceName`
31988 31989 31990 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31988 def resource_name @resource_name end |
#status ⇒ String
Output only. Overall status for offline conversion client summary. Status is
generated from most recent calendar day with upload stats.
Corresponds to the JSON property status
31994 31995 31996 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31994 def status @status end |
#success_rate ⇒ Float
Output only. Successful rate.
Corresponds to the JSON property successRate
31999 32000 32001 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31999 def success_rate @success_rate end |
#successful_event_count ⇒ Fixnum
Output only. Total count of successful uploaded events.
Corresponds to the JSON property successfulEventCount
32004 32005 32006 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32004 def successful_event_count @successful_event_count end |
#total_event_count ⇒ Fixnum
Output only. Total count of uploaded events.
Corresponds to the JSON property totalEventCount
32009 32010 32011 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32009 def total_event_count @total_event_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32016 32017 32018 32019 32020 32021 32022 32023 32024 32025 32026 32027 32028 32029 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32016 def update!(**args) @alerts = args[:alerts] if args.key?(:alerts) @client = args[:client] if args.key?(:client) @daily_summaries = args[:daily_summaries] if args.key?(:daily_summaries) @job_summaries = args[:job_summaries] if args.key?(:job_summaries) @last_upload_date_time = args[:last_upload_date_time] if args.key?(:last_upload_date_time) @pending_event_count = args[:pending_event_count] if args.key?(:pending_event_count) @pending_rate = args[:pending_rate] if args.key?(:pending_rate) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @success_rate = args[:success_rate] if args.key?(:success_rate) @successful_event_count = args[:successful_event_count] if args.key?(:successful_event_count) @total_event_count = args[:total_event_count] if args.key?(:total_event_count) end |