Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionUploadConversionActionSummary
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionUploadConversionActionSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Offline conversion upload summary at conversion action level.
Instance Attribute Summary collapse
-
#alerts ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionAlert>
Output only.
-
#client ⇒ String
Output only.
-
#conversion_action_id ⇒ Fixnum
Output only.
-
#conversion_action_name ⇒ String
Output only.
-
#daily_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionSummary>
Output only.
-
#job_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionSummary>
Output only.
-
#last_upload_date_time ⇒ String
Output only.
-
#pending_event_count ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#successful_event_count ⇒ Fixnum
Output only.
-
#total_event_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOfflineConversionUploadConversionActionSummary
constructor
A new instance of GoogleAdsSearchads360V23ResourcesOfflineConversionUploadConversionActionSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOfflineConversionUploadConversionActionSummary
Returns a new instance of GoogleAdsSearchads360V23ResourcesOfflineConversionUploadConversionActionSummary.
32175 32176 32177 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alerts ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionAlert>
Output only. Details for each error code. Alerts are generated from most
recent calendar day with upload stats.
Corresponds to the JSON property alerts
32112 32113 32114 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32112 def alerts @alerts end |
#client ⇒ String
Output only. Client type of the upload event.
Corresponds to the JSON property client
32117 32118 32119 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32117 def client @client end |
#conversion_action_id ⇒ Fixnum
Output only. Conversion action id.
Corresponds to the JSON property conversionActionId
32122 32123 32124 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32122 def conversion_action_id @conversion_action_id end |
#conversion_action_name ⇒ String
Output only. The name of the conversion action.
Corresponds to the JSON property conversionActionName
32127 32128 32129 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32127 def conversion_action_name @conversion_action_name end |
#daily_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionSummary>
Output only. Summary of history stats by last N days.
Corresponds to the JSON property dailySummaries
32132 32133 32134 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32132 def daily_summaries @daily_summaries end |
#job_summaries ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionSummary>
Output only. Summary of history stats by last N jobs.
Corresponds to the JSON property jobSummaries
32137 32138 32139 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32137 def job_summaries @job_summaries end |
#last_upload_date_time ⇒ String
Output only. Date for the latest upload batch. The format is "yyyy-mm-dd hh:mm:
ss", and it's in the time zone of the Google Ads account.
Corresponds to the JSON property lastUploadDateTime
32143 32144 32145 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32143 def last_upload_date_time @last_upload_date_time end |
#pending_event_count ⇒ Fixnum
Output only. Total count of pending uploaded events.
Corresponds to the JSON property pendingEventCount
32148 32149 32150 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32148 def pending_event_count @pending_event_count end |
#resource_name ⇒ String
Output only. The resource name of the offline conversion upload summary at
conversion action level. Offline conversion upload conversion action summary
resource names have the form: customers/customer_id/
offlineConversionUploadConversionActionSummaries/conversion_action_id~
client`
Corresponds to the JSON propertyresourceName`
32157 32158 32159 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32157 def resource_name @resource_name end |
#status ⇒ String
Output only. Overall status for offline conversion upload conversion action
summary. Status is generated from most recent calendar day with upload stats.
Corresponds to the JSON property status
32163 32164 32165 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32163 def status @status end |
#successful_event_count ⇒ Fixnum
Output only. Total count of successful uploaded events.
Corresponds to the JSON property successfulEventCount
32168 32169 32170 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32168 def successful_event_count @successful_event_count end |
#total_event_count ⇒ Fixnum
Output only. Total count of uploaded events.
Corresponds to the JSON property totalEventCount
32173 32174 32175 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32173 def total_event_count @total_event_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32180 32181 32182 32183 32184 32185 32186 32187 32188 32189 32190 32191 32192 32193 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32180 def update!(**args) @alerts = args[:alerts] if args.key?(:alerts) @client = args[:client] if args.key?(:client) @conversion_action_id = args[:conversion_action_id] if args.key?(:conversion_action_id) @conversion_action_name = args[:conversion_action_name] if args.key?(:conversion_action_name) @daily_summaries = args[:daily_summaries] if args.key?(:daily_summaries) @job_summaries = args[:job_summaries] if args.key?(:job_summaries) @last_upload_date_time = args[:last_upload_date_time] if args.key?(:last_upload_date_time) @pending_event_count = args[:pending_event_count] if args.key?(:pending_event_count) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @successful_event_count = args[:successful_event_count] if args.key?(:successful_event_count) @total_event_count = args[:total_event_count] if args.key?(:total_event_count) end |