Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionUploadConversionActionSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Offline conversion upload summary at conversion action level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOfflineConversionUploadConversionActionSummary

Returns a new instance of GoogleAdsSearchads360V23ResourcesOfflineConversionUploadConversionActionSummary.



32001
32002
32003
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alertsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionAlert>

Output only. Details for each error code. Alerts are generated from most recent calendar day with upload stats. Corresponds to the JSON property alerts



31938
31939
31940
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31938

def alerts
  @alerts
end

#clientString

Output only. Client type of the upload event. Corresponds to the JSON property client

Returns:

  • (String)


31943
31944
31945
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31943

def client
  @client
end

#conversion_action_idFixnum

Output only. Conversion action id. Corresponds to the JSON property conversionActionId

Returns:

  • (Fixnum)


31948
31949
31950
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31948

def conversion_action_id
  @conversion_action_id
end

#conversion_action_nameString

Output only. The name of the conversion action. Corresponds to the JSON property conversionActionName

Returns:

  • (String)


31953
31954
31955
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31953

def conversion_action_name
  @conversion_action_name
end

#daily_summariesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionSummary>

Output only. Summary of history stats by last N days. Corresponds to the JSON property dailySummaries



31958
31959
31960
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31958

def daily_summaries
  @daily_summaries
end

#job_summariesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineConversionSummary>

Output only. Summary of history stats by last N jobs. Corresponds to the JSON property jobSummaries



31963
31964
31965
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31963

def job_summaries
  @job_summaries
end

#last_upload_date_timeString

Output only. Date for the latest upload batch. The format is "yyyy-mm-dd hh:mm: ss", and it's in the time zone of the Google Ads account. Corresponds to the JSON property lastUploadDateTime

Returns:

  • (String)


31969
31970
31971
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31969

def last_upload_date_time
  @last_upload_date_time
end

#pending_event_countFixnum

Output only. Total count of pending uploaded events. Corresponds to the JSON property pendingEventCount

Returns:

  • (Fixnum)


31974
31975
31976
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31974

def pending_event_count
  @pending_event_count
end

#resource_nameString

Output only. The resource name of the offline conversion upload summary at conversion action level. Offline conversion upload conversion action summary resource names have the form: customers/customer_id/ offlineConversionUploadConversionActionSummaries/conversion_action_id~ client` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


31983
31984
31985
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31983

def resource_name
  @resource_name
end

#statusString

Output only. Overall status for offline conversion upload conversion action summary. Status is generated from most recent calendar day with upload stats. Corresponds to the JSON property status

Returns:

  • (String)


31989
31990
31991
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31989

def status
  @status
end

#successful_event_countFixnum

Output only. Total count of successful uploaded events. Corresponds to the JSON property successfulEventCount

Returns:

  • (Fixnum)


31994
31995
31996
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31994

def successful_event_count
  @successful_event_count
end

#total_event_countFixnum

Output only. Total count of uploaded events. Corresponds to the JSON property totalEventCount

Returns:

  • (Fixnum)


31999
32000
32001
# File 'lib/google/apis/searchads360_v23/classes.rb', line 31999

def total_event_count
  @total_event_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32006
32007
32008
32009
32010
32011
32012
32013
32014
32015
32016
32017
32018
32019
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32006

def update!(**args)
  @alerts = args[:alerts] if args.key?(:alerts)
  @client = args[:client] if args.key?(:client)
  @conversion_action_id = args[:conversion_action_id] if args.key?(:conversion_action_id)
  @conversion_action_name = args[:conversion_action_name] if args.key?(:conversion_action_name)
  @daily_summaries = args[:daily_summaries] if args.key?(:daily_summaries)
  @job_summaries = args[:job_summaries] if args.key?(:job_summaries)
  @last_upload_date_time = args[:last_upload_date_time] if args.key?(:last_upload_date_time)
  @pending_event_count = args[:pending_event_count] if args.key?(:pending_event_count)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @successful_event_count = args[:successful_event_count] if args.key?(:successful_event_count)
  @total_event_count = args[:total_event_count] if args.key?(:total_event_count)
end