Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineUserDataJob
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineUserDataJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A job containing offline user data of store visitors, or user list members that will be processed asynchronously. The uploaded data isn't readable and the processing results of the job can only be read using
Instance Attribute Summary collapse
-
#customer_match_user_list_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata
Metadata for customer match user list.
-
#external_id ⇒ Fixnum
Immutable.
-
#failure_reason ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#operation_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineUserDataJobMetadata
Metadata of offline user data job.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#store_sales_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStoreSalesMetadata
Metadata for Store Sales Direct.
-
#type ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOfflineUserDataJob
constructor
A new instance of GoogleAdsSearchads360V23ResourcesOfflineUserDataJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOfflineUserDataJob
Returns a new instance of GoogleAdsSearchads360V23ResourcesOfflineUserDataJob.
32249 32250 32251 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32249 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer_match_user_list_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata
Metadata for customer match user list.
Corresponds to the JSON property customerMatchUserListMetadata
32205 32206 32207 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32205 def @customer_match_user_list_metadata end |
#external_id ⇒ Fixnum
Immutable. User specified job ID.
Corresponds to the JSON property externalId
32210 32211 32212 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32210 def external_id @external_id end |
#failure_reason ⇒ String
Output only. Reason for the processing failure, if status is FAILED.
Corresponds to the JSON property failureReason
32215 32216 32217 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32215 def failure_reason @failure_reason end |
#id ⇒ Fixnum
Output only. ID of this offline user data job.
Corresponds to the JSON property id
32220 32221 32222 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32220 def id @id end |
#operation_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineUserDataJobMetadata
Metadata of offline user data job.
Corresponds to the JSON property operationMetadata
32225 32226 32227 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32225 def @operation_metadata end |
#resource_name ⇒ String
Immutable. The resource name of the offline user data job. Offline user data
job resource names have the form: customers/customer_id/offlineUserDataJobs/
offline_user_data_job_id`
Corresponds to the JSON propertyresourceName`
32232 32233 32234 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32232 def resource_name @resource_name end |
#status ⇒ String
Output only. Status of the job.
Corresponds to the JSON property status
32237 32238 32239 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32237 def status @status end |
#store_sales_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStoreSalesMetadata
Metadata for Store Sales Direct.
Corresponds to the JSON property storeSalesMetadata
32242 32243 32244 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32242 def @store_sales_metadata end |
#type ⇒ String
Immutable. Type of the job.
Corresponds to the JSON property type
32247 32248 32249 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32247 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32254 32255 32256 32257 32258 32259 32260 32261 32262 32263 32264 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32254 def update!(**args) @customer_match_user_list_metadata = args[:customer_match_user_list_metadata] if args.key?(:customer_match_user_list_metadata) @external_id = args[:external_id] if args.key?(:external_id) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @id = args[:id] if args.key?(:id) @operation_metadata = args[:operation_metadata] if args.key?(:operation_metadata) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @store_sales_metadata = args[:store_sales_metadata] if args.key?(:store_sales_metadata) @type = args[:type] if args.key?(:type) end |