Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineUserDataJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A job containing offline user data of store visitors, or user list members that will be processed asynchronously. The uploaded data isn't readable and the processing results of the job can only be read using

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOfflineUserDataJob

Returns a new instance of GoogleAdsSearchads360V23ResourcesOfflineUserDataJob.



32177
32178
32179
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32177

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customer_match_user_list_metadataGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata

Metadata for customer match user list. Corresponds to the JSON property customerMatchUserListMetadata



32133
32134
32135
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32133

def 
  @customer_match_user_list_metadata
end

#external_idFixnum

Immutable. User specified job ID. Corresponds to the JSON property externalId

Returns:

  • (Fixnum)


32138
32139
32140
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32138

def external_id
  @external_id
end

#failure_reasonString

Output only. Reason for the processing failure, if status is FAILED. Corresponds to the JSON property failureReason

Returns:

  • (String)


32143
32144
32145
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32143

def failure_reason
  @failure_reason
end

#idFixnum

Output only. ID of this offline user data job. Corresponds to the JSON property id

Returns:

  • (Fixnum)


32148
32149
32150
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32148

def id
  @id
end

#operation_metadataGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineUserDataJobMetadata

Metadata of offline user data job. Corresponds to the JSON property operationMetadata



32153
32154
32155
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32153

def 
  @operation_metadata
end

#resource_nameString

Immutable. The resource name of the offline user data job. Offline user data job resource names have the form: customers/customer_id/offlineUserDataJobs/ offline_user_data_job_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


32160
32161
32162
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32160

def resource_name
  @resource_name
end

#statusString

Output only. Status of the job. Corresponds to the JSON property status

Returns:

  • (String)


32165
32166
32167
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32165

def status
  @status
end

#store_sales_metadataGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStoreSalesMetadata

Metadata for Store Sales Direct. Corresponds to the JSON property storeSalesMetadata



32170
32171
32172
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32170

def 
  @store_sales_metadata
end

#typeString

Immutable. Type of the job. Corresponds to the JSON property type

Returns:

  • (String)


32175
32176
32177
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32175

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32182
32183
32184
32185
32186
32187
32188
32189
32190
32191
32192
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32182

def update!(**args)
  @customer_match_user_list_metadata = args[:customer_match_user_list_metadata] if args.key?(:customer_match_user_list_metadata)
  @external_id = args[:external_id] if args.key?(:external_id)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @id = args[:id] if args.key?(:id)
  @operation_metadata = args[:operation_metadata] if args.key?(:operation_metadata)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @store_sales_metadata = args[:store_sales_metadata] if args.key?(:store_sales_metadata)
  @type = args[:type] if args.key?(:type)
end