Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineUserDataJob
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineUserDataJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A job containing offline user data of store visitors, or user list members that will be processed asynchronously. The uploaded data isn't readable and the processing results of the job can only be read using
Instance Attribute Summary collapse
-
#customer_match_user_list_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata
Metadata for customer match user list.
-
#external_id ⇒ Fixnum
Immutable.
-
#failure_reason ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#operation_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineUserDataJobMetadata
Metadata of offline user data job.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#store_sales_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStoreSalesMetadata
Metadata for Store Sales Direct.
-
#type ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOfflineUserDataJob
constructor
A new instance of GoogleAdsSearchads360V23ResourcesOfflineUserDataJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOfflineUserDataJob
Returns a new instance of GoogleAdsSearchads360V23ResourcesOfflineUserDataJob.
32075 32076 32077 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer_match_user_list_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCustomerMatchUserListMetadata
Metadata for customer match user list.
Corresponds to the JSON property customerMatchUserListMetadata
32031 32032 32033 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32031 def @customer_match_user_list_metadata end |
#external_id ⇒ Fixnum
Immutable. User specified job ID.
Corresponds to the JSON property externalId
32036 32037 32038 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32036 def external_id @external_id end |
#failure_reason ⇒ String
Output only. Reason for the processing failure, if status is FAILED.
Corresponds to the JSON property failureReason
32041 32042 32043 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32041 def failure_reason @failure_reason end |
#id ⇒ Fixnum
Output only. ID of this offline user data job.
Corresponds to the JSON property id
32046 32047 32048 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32046 def id @id end |
#operation_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineUserDataJobMetadata
Metadata of offline user data job.
Corresponds to the JSON property operationMetadata
32051 32052 32053 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32051 def @operation_metadata end |
#resource_name ⇒ String
Immutable. The resource name of the offline user data job. Offline user data
job resource names have the form: customers/customer_id/offlineUserDataJobs/
offline_user_data_job_id`
Corresponds to the JSON propertyresourceName`
32058 32059 32060 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32058 def resource_name @resource_name end |
#status ⇒ String
Output only. Status of the job.
Corresponds to the JSON property status
32063 32064 32065 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32063 def status @status end |
#store_sales_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonStoreSalesMetadata
Metadata for Store Sales Direct.
Corresponds to the JSON property storeSalesMetadata
32068 32069 32070 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32068 def @store_sales_metadata end |
#type ⇒ String
Immutable. Type of the job.
Corresponds to the JSON property type
32073 32074 32075 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32073 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32080 32081 32082 32083 32084 32085 32086 32087 32088 32089 32090 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32080 def update!(**args) @customer_match_user_list_metadata = args[:customer_match_user_list_metadata] if args.key?(:customer_match_user_list_metadata) @external_id = args[:external_id] if args.key?(:external_id) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @id = args[:id] if args.key?(:id) @operation_metadata = args[:operation_metadata] if args.key?(:operation_metadata) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @store_sales_metadata = args[:store_sales_metadata] if args.key?(:store_sales_metadata) @type = args[:type] if args.key?(:type) end |