Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOperatingSystemVersionConstant
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOperatingSystemVersionConstant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A mobile operating system version or a range of versions, depending on
operator_type. List of available mobile platforms at https://developers.
google.com/google-ads/api/reference/data/codes-formats#mobile-platforms
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
Output only.
-
#operator_type ⇒ String
Output only.
-
#os_major_version ⇒ Fixnum
Output only.
-
#os_minor_version ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOperatingSystemVersionConstant
constructor
A new instance of GoogleAdsSearchads360V23ResourcesOperatingSystemVersionConstant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOperatingSystemVersionConstant
Returns a new instance of GoogleAdsSearchads360V23ResourcesOperatingSystemVersionConstant.
32256 32257 32258 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32256 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. The ID of the operating system version.
Corresponds to the JSON property id
32226 32227 32228 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32226 def id @id end |
#name ⇒ String
Output only. Name of the operating system.
Corresponds to the JSON property name
32231 32232 32233 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32231 def name @name end |
#operator_type ⇒ String
Output only. Determines whether this constant represents a single version or a
range of versions.
Corresponds to the JSON property operatorType
32237 32238 32239 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32237 def operator_type @operator_type end |
#os_major_version ⇒ Fixnum
Output only. The OS Major Version number.
Corresponds to the JSON property osMajorVersion
32242 32243 32244 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32242 def os_major_version @os_major_version end |
#os_minor_version ⇒ Fixnum
Output only. The OS Minor Version number.
Corresponds to the JSON property osMinorVersion
32247 32248 32249 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32247 def os_minor_version @os_minor_version end |
#resource_name ⇒ String
Output only. The resource name of the operating system version constant.
Operating system version constant resource names have the form:
operatingSystemVersionConstants/criterion_id`
Corresponds to the JSON propertyresourceName`
32254 32255 32256 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32254 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32261 32262 32263 32264 32265 32266 32267 32268 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32261 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @operator_type = args[:operator_type] if args.key?(:operator_type) @os_major_version = args[:os_major_version] if args.key?(:os_major_version) @os_minor_version = args[:os_minor_version] if args.key?(:os_minor_version) @resource_name = args[:resource_name] if args.key?(:resource_name) end |