Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOperatingSystemVersionConstant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A mobile operating system version or a range of versions, depending on operator_type. List of available mobile platforms at https://developers. google.com/google-ads/api/reference/data/codes-formats#mobile-platforms

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesOperatingSystemVersionConstant

Returns a new instance of GoogleAdsSearchads360V23ResourcesOperatingSystemVersionConstant.



32154
32155
32156
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32154

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. The ID of the operating system version. Corresponds to the JSON property id

Returns:

  • (Fixnum)


32124
32125
32126
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32124

def id
  @id
end

#nameString

Output only. Name of the operating system. Corresponds to the JSON property name

Returns:

  • (String)


32129
32130
32131
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32129

def name
  @name
end

#operator_typeString

Output only. Determines whether this constant represents a single version or a range of versions. Corresponds to the JSON property operatorType

Returns:

  • (String)


32135
32136
32137
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32135

def operator_type
  @operator_type
end

#os_major_versionFixnum

Output only. The OS Major Version number. Corresponds to the JSON property osMajorVersion

Returns:

  • (Fixnum)


32140
32141
32142
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32140

def os_major_version
  @os_major_version
end

#os_minor_versionFixnum

Output only. The OS Minor Version number. Corresponds to the JSON property osMinorVersion

Returns:

  • (Fixnum)


32145
32146
32147
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32145

def os_minor_version
  @os_minor_version
end

#resource_nameString

Output only. The resource name of the operating system version constant. Operating system version constant resource names have the form: operatingSystemVersionConstants/criterion_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


32152
32153
32154
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32152

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32159
32160
32161
32162
32163
32164
32165
32166
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32159

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @operator_type = args[:operator_type] if args.key?(:operator_type)
  @os_major_version = args[:os_major_version] if args.key?(:os_major_version)
  @os_minor_version = args[:os_minor_version] if args.key?(:os_minor_version)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end