Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesPaidOrganicSearchTermView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesPaidOrganicSearchTermView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A paid organic search term view providing a view of search stats across ads and organic listings aggregated by search term at the ad group level.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Output only.
-
#search_term ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesPaidOrganicSearchTermView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesPaidOrganicSearchTermView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesPaidOrganicSearchTermView
Returns a new instance of GoogleAdsSearchads360V23ResourcesPaidOrganicSearchTermView.
32289 32290 32291 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Output only. The resource name of the search term view. Search term view
resource names have the form: customers/customer_id/
paidOrganicSearchTermViews/campaign_id~ad_group_id~URL-base64 search
term`
Corresponds to the JSON propertyresourceName`
32282 32283 32284 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32282 def resource_name @resource_name end |
#search_term ⇒ String
Output only. The search term.
Corresponds to the JSON property searchTerm
32287 32288 32289 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32287 def search_term @search_term end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32294 32295 32296 32297 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32294 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) @search_term = args[:search_term] if args.key?(:search_term) end |