Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesPaidOrganicSearchTermView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A paid organic search term view providing a view of search stats across ads and organic listings aggregated by search term at the ad group level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesPaidOrganicSearchTermView

Returns a new instance of GoogleAdsSearchads360V23ResourcesPaidOrganicSearchTermView.



32187
32188
32189
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32187

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_nameString

Output only. The resource name of the search term view. Search term view resource names have the form: customers/customer_id/ paidOrganicSearchTermViews/campaign_id~ad_group_id~URL-base64 search term` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


32180
32181
32182
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32180

def resource_name
  @resource_name
end

#search_termString

Output only. The search term. Corresponds to the JSON property searchTerm

Returns:

  • (String)


32185
32186
32187
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32185

def search_term
  @search_term
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32192
32193
32194
32195
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32192

def update!(**args)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @search_term = args[:search_term] if args.key?(:search_term)
end