Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesPaymentsAccount
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesPaymentsAccount
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A payments account, which can be used to set up billing for an Ads customer.
Instance Attribute Summary collapse
-
#currency_code ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#paying_manager_customer ⇒ String
Output only.
-
#payments_account_id ⇒ String
Output only.
-
#payments_profile_id ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#secondary_payments_profile_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesPaymentsAccount
constructor
A new instance of GoogleAdsSearchads360V23ResourcesPaymentsAccount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesPaymentsAccount
Returns a new instance of GoogleAdsSearchads360V23ResourcesPaymentsAccount.
32437 32438 32439 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32437 def initialize(**args) update!(**args) end |
Instance Attribute Details
#currency_code ⇒ String
Output only. The currency code of the payments account. A subset of the
currency codes derived from the ISO 4217 standard is supported.
Corresponds to the JSON property currencyCode
32401 32402 32403 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32401 def currency_code @currency_code end |
#name ⇒ String
Output only. The name of the payments account.
Corresponds to the JSON property name
32406 32407 32408 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32406 def name @name end |
#paying_manager_customer ⇒ String
Output only. Paying manager of this payment account.
Corresponds to the JSON property payingManagerCustomer
32411 32412 32413 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32411 def @paying_manager_customer end |
#payments_account_id ⇒ String
Output only. A 16 digit ID used to identify a payments account.
Corresponds to the JSON property paymentsAccountId
32416 32417 32418 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32416 def payments_account_id @payments_account_id end |
#payments_profile_id ⇒ String
Output only. A 12 digit ID used to identify the payments profile associated
with the payments account.
Corresponds to the JSON property paymentsProfileId
32422 32423 32424 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32422 def payments_profile_id @payments_profile_id end |
#resource_name ⇒ String
Output only. The resource name of the payments account. PaymentsAccount
resource names have the form: customers/customer_id/paymentsAccounts/
payments_account_id`
Corresponds to the JSON propertyresourceName`
32429 32430 32431 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32429 def resource_name @resource_name end |
#secondary_payments_profile_id ⇒ String
Output only. A secondary payments profile ID present in uncommon situations,
for example, when a sequential liability agreement has been arranged.
Corresponds to the JSON property secondaryPaymentsProfileId
32435 32436 32437 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32435 def secondary_payments_profile_id @secondary_payments_profile_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32442 32443 32444 32445 32446 32447 32448 32449 32450 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32442 def update!(**args) @currency_code = args[:currency_code] if args.key?(:currency_code) @name = args[:name] if args.key?(:name) @paying_manager_customer = args[:paying_manager_customer] if args.key?(:paying_manager_customer) @payments_account_id = args[:payments_account_id] if args.key?(:payments_account_id) @payments_profile_id = args[:payments_profile_id] if args.key?(:payments_profile_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @secondary_payments_profile_id = args[:secondary_payments_profile_id] if args.key?(:secondary_payments_profile_id) end |