Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesPaymentsAccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A payments account, which can be used to set up billing for an Ads customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesPaymentsAccount

Returns a new instance of GoogleAdsSearchads360V23ResourcesPaymentsAccount.



32263
32264
32265
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32263

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#currency_codeString

Output only. The currency code of the payments account. A subset of the currency codes derived from the ISO 4217 standard is supported. Corresponds to the JSON property currencyCode

Returns:

  • (String)


32227
32228
32229
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32227

def currency_code
  @currency_code
end

#nameString

Output only. The name of the payments account. Corresponds to the JSON property name

Returns:

  • (String)


32232
32233
32234
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32232

def name
  @name
end

#paying_manager_customerString

Output only. Paying manager of this payment account. Corresponds to the JSON property payingManagerCustomer

Returns:

  • (String)


32237
32238
32239
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32237

def paying_manager_customer
  @paying_manager_customer
end

#payments_account_idString

Output only. A 16 digit ID used to identify a payments account. Corresponds to the JSON property paymentsAccountId

Returns:

  • (String)


32242
32243
32244
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32242

def 
  @payments_account_id
end

#payments_profile_idString

Output only. A 12 digit ID used to identify the payments profile associated with the payments account. Corresponds to the JSON property paymentsProfileId

Returns:

  • (String)


32248
32249
32250
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32248

def payments_profile_id
  @payments_profile_id
end

#resource_nameString

Output only. The resource name of the payments account. PaymentsAccount resource names have the form: customers/customer_id/paymentsAccounts/ payments_account_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


32255
32256
32257
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32255

def resource_name
  @resource_name
end

#secondary_payments_profile_idString

Output only. A secondary payments profile ID present in uncommon situations, for example, when a sequential liability agreement has been arranged. Corresponds to the JSON property secondaryPaymentsProfileId

Returns:

  • (String)


32261
32262
32263
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32261

def secondary_payments_profile_id
  @secondary_payments_profile_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32268
32269
32270
32271
32272
32273
32274
32275
32276
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32268

def update!(**args)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @name = args[:name] if args.key?(:name)
  @paying_manager_customer = args[:paying_manager_customer] if args.key?(:paying_manager_customer)
  @payments_account_id = args[:payments_account_id] if args.key?(:payments_account_id)
  @payments_profile_id = args[:payments_profile_id] if args.key?(:payments_profile_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @secondary_payments_profile_id = args[:secondary_payments_profile_id] if args.key?(:secondary_payments_profile_id)
end