Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesPerformanceMaxPlacementView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesPerformanceMaxPlacementView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A view with impression metrics for Performance Max campaign placements.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#placement ⇒ String
Output only.
-
#placement_type ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#target_url ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesPerformanceMaxPlacementView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesPerformanceMaxPlacementView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesPerformanceMaxPlacementView
Returns a new instance of GoogleAdsSearchads360V23ResourcesPerformanceMaxPlacementView.
32492 32493 32494 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. The name displayed to represent the placement, such as the URL
name for websites, YouTube video name for YouTube videos, and translated
mobile app name for mobile apps.
Corresponds to the JSON property displayName
32465 32466 32467 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32465 def display_name @display_name end |
#placement ⇒ String
Output only. The default placement string, such as the website URL, mobile
application ID, or a YouTube video ID.
Corresponds to the JSON property placement
32471 32472 32473 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32471 def placement @placement end |
#placement_type ⇒ String
Output only. Type of the placement. Possible values for Performance Max
placements are WEBSITE, MOBILE_APPLICATION, or YOUTUBE_VIDEO.
Corresponds to the JSON property placementType
32477 32478 32479 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32477 def placement_type @placement_type end |
#resource_name ⇒ String
Output only. The resource name of the Performance Max placement view.
Performance Max placement view resource names have the form: customers/
customer_id/performanceMaxPlacementViews/base_64_placement`
Corresponds to the JSON propertyresourceName`
32484 32485 32486 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32484 def resource_name @resource_name end |
#target_url ⇒ String
Output only. URL of the placement, for example, website, link to the mobile
application in app store, or a YouTube video URL.
Corresponds to the JSON property targetUrl
32490 32491 32492 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32490 def target_url @target_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32497 32498 32499 32500 32501 32502 32503 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32497 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @placement = args[:placement] if args.key?(:placement) @placement_type = args[:placement_type] if args.key?(:placement_type) @resource_name = args[:resource_name] if args.key?(:resource_name) @target_url = args[:target_url] if args.key?(:target_url) end |