Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesPerformanceMaxPlacementView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesPerformanceMaxPlacementView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A view with impression metrics for Performance Max campaign placements.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#placement ⇒ String
Output only.
-
#placement_type ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#target_url ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesPerformanceMaxPlacementView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesPerformanceMaxPlacementView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesPerformanceMaxPlacementView
Returns a new instance of GoogleAdsSearchads360V23ResourcesPerformanceMaxPlacementView.
32390 32391 32392 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32390 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. The name displayed to represent the placement, such as the URL
name for websites, YouTube video name for YouTube videos, and translated
mobile app name for mobile apps.
Corresponds to the JSON property displayName
32363 32364 32365 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32363 def display_name @display_name end |
#placement ⇒ String
Output only. The default placement string, such as the website URL, mobile
application ID, or a YouTube video ID.
Corresponds to the JSON property placement
32369 32370 32371 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32369 def placement @placement end |
#placement_type ⇒ String
Output only. Type of the placement. Possible values for Performance Max
placements are WEBSITE, MOBILE_APPLICATION, or YOUTUBE_VIDEO.
Corresponds to the JSON property placementType
32375 32376 32377 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32375 def placement_type @placement_type end |
#resource_name ⇒ String
Output only. The resource name of the Performance Max placement view.
Performance Max placement view resource names have the form: customers/
customer_id/performanceMaxPlacementViews/base_64_placement`
Corresponds to the JSON propertyresourceName`
32382 32383 32384 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32382 def resource_name @resource_name end |
#target_url ⇒ String
Output only. URL of the placement, for example, website, link to the mobile
application in app store, or a YouTube video URL.
Corresponds to the JSON property targetUrl
32388 32389 32390 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32388 def target_url @target_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32395 32396 32397 32398 32399 32400 32401 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32395 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @placement = args[:placement] if args.key?(:placement) @placement_type = args[:placement_type] if args.key?(:placement_type) @resource_name = args[:resource_name] if args.key?(:resource_name) @target_url = args[:target_url] if args.key?(:target_url) end |