Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesProductLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents the data sharing connection between

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesProductLink

Returns a new instance of GoogleAdsSearchads360V23ResourcesProductLink.



32644
32645
32646
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertising_partnerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdvertisingPartnerIdentifier

The identifier for the Advertising Partner Google Ads account. Corresponds to the JSON property advertisingPartner



32611
32612
32613
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32611

def advertising_partner
  @advertising_partner
end

#data_partnerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDataPartnerIdentifier

The identifier for Data Partner account. Corresponds to the JSON property dataPartner



32616
32617
32618
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32616

def data_partner
  @data_partner
end

The identifier for Google Ads account. Corresponds to the JSON property googleAds



32621
32622
32623
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32621

def google_ads
  @google_ads
end

#merchant_centerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMerchantCenterIdentifier

The identifier for Google Merchant Center account Corresponds to the JSON property merchantCenter



32626
32627
32628
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32626

def merchant_center
  @merchant_center
end

Output only. The ID of the link. This field is read only. Corresponds to the JSON property productLinkId

Returns:

  • (Fixnum)


32631
32632
32633
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32631

def product_link_id
  @product_link_id
end

#resource_nameString

Immutable. Resource name of the product link. ProductLink resource names have the form: Corresponds to the JSON property resourceName

Returns:

  • (String)


32637
32638
32639
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32637

def resource_name
  @resource_name
end

#typeString

Output only. The type of the linked product. Corresponds to the JSON property type

Returns:

  • (String)


32642
32643
32644
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32642

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32649
32650
32651
32652
32653
32654
32655
32656
32657
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32649

def update!(**args)
  @advertising_partner = args[:advertising_partner] if args.key?(:advertising_partner)
  @data_partner = args[:data_partner] if args.key?(:data_partner)
  @google_ads = args[:google_ads] if args.key?(:google_ads)
  @merchant_center = args[:merchant_center] if args.key?(:merchant_center)
  @product_link_id = args[:product_link_id] if args.key?(:product_link_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @type = args[:type] if args.key?(:type)
end