Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesProductLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents the data sharing connection between

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesProductLink

Returns a new instance of GoogleAdsSearchads360V23ResourcesProductLink.



32542
32543
32544
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32542

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertising_partnerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdvertisingPartnerIdentifier

The identifier for the Advertising Partner Google Ads account. Corresponds to the JSON property advertisingPartner



32509
32510
32511
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32509

def advertising_partner
  @advertising_partner
end

#data_partnerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesDataPartnerIdentifier

The identifier for Data Partner account. Corresponds to the JSON property dataPartner



32514
32515
32516
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32514

def data_partner
  @data_partner
end

The identifier for Google Ads account. Corresponds to the JSON property googleAds



32519
32520
32521
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32519

def google_ads
  @google_ads
end

#merchant_centerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMerchantCenterIdentifier

The identifier for Google Merchant Center account Corresponds to the JSON property merchantCenter



32524
32525
32526
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32524

def merchant_center
  @merchant_center
end

Output only. The ID of the link. This field is read only. Corresponds to the JSON property productLinkId

Returns:

  • (Fixnum)


32529
32530
32531
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32529

def product_link_id
  @product_link_id
end

#resource_nameString

Immutable. Resource name of the product link. ProductLink resource names have the form: Corresponds to the JSON property resourceName

Returns:

  • (String)


32535
32536
32537
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32535

def resource_name
  @resource_name
end

#typeString

Output only. The type of the linked product. Corresponds to the JSON property type

Returns:

  • (String)


32540
32541
32542
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32540

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32547
32548
32549
32550
32551
32552
32553
32554
32555
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32547

def update!(**args)
  @advertising_partner = args[:advertising_partner] if args.key?(:advertising_partner)
  @data_partner = args[:data_partner] if args.key?(:data_partner)
  @google_ads = args[:google_ads] if args.key?(:google_ads)
  @merchant_center = args[:merchant_center] if args.key?(:merchant_center)
  @product_link_id = args[:product_link_id] if args.key?(:product_link_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @type = args[:type] if args.key?(:type)
end