Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesProductLinkInvitation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesProductLinkInvitation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Represents an invitation for data sharing connection between a Google Ads account and another account.
Instance Attribute Summary collapse
-
#advertising_partner ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdvertisingPartnerLinkInvitationIdentifier
The identifier for the Advertising Partner Google Ads account.
-
#hotel_center ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesHotelCenterLinkInvitationIdentifier
The identifier for Hotel account.
-
#merchant_center ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMerchantCenterLinkInvitationIdentifier
The identifier for Merchant Center Account.
-
#product_link_invitation_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesProductLinkInvitation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesProductLinkInvitation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesProductLinkInvitation
Returns a new instance of GoogleAdsSearchads360V23ResourcesProductLinkInvitation.
32705 32706 32707 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertising_partner ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdvertisingPartnerLinkInvitationIdentifier
The identifier for the Advertising Partner Google Ads account.
Corresponds to the JSON property advertisingPartner
32668 32669 32670 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32668 def advertising_partner @advertising_partner end |
#hotel_center ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesHotelCenterLinkInvitationIdentifier
The identifier for Hotel account.
Corresponds to the JSON property hotelCenter
32673 32674 32675 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32673 def hotel_center @hotel_center end |
#merchant_center ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMerchantCenterLinkInvitationIdentifier
The identifier for Merchant Center Account.
Corresponds to the JSON property merchantCenter
32678 32679 32680 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32678 def merchant_center @merchant_center end |
#product_link_invitation_id ⇒ Fixnum
Output only. The ID of the product link invitation. This field is read only.
Corresponds to the JSON property productLinkInvitationId
32683 32684 32685 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32683 def product_link_invitation_id @product_link_invitation_id end |
#resource_name ⇒ String
Immutable. The resource name of a product link invitation. Product link
invitation resource names have the form: customers/customer_id/
productLinkInvitations/product_link_invitation_id`
Corresponds to the JSON propertyresourceName`
32690 32691 32692 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32690 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of the product link invitation. This field is read
only.
Corresponds to the JSON property status
32696 32697 32698 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32696 def status @status end |
#type ⇒ String
Output only. The type of the invited account. This field is read only and can
be used for filtering invitations with @code GoogleAdsService.
SearchGoogleAdsRequest.
Corresponds to the JSON property type
32703 32704 32705 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32703 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32710 32711 32712 32713 32714 32715 32716 32717 32718 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32710 def update!(**args) @advertising_partner = args[:advertising_partner] if args.key?(:advertising_partner) @hotel_center = args[:hotel_center] if args.key?(:hotel_center) @merchant_center = args[:merchant_center] if args.key?(:merchant_center) @product_link_invitation_id = args[:product_link_invitation_id] if args.key?(:product_link_invitation_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) end |