Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesProductLinkInvitation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Represents an invitation for data sharing connection between a Google Ads account and another account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesProductLinkInvitation

Returns a new instance of GoogleAdsSearchads360V23ResourcesProductLinkInvitation.



32603
32604
32605
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32603

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertising_partnerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdvertisingPartnerLinkInvitationIdentifier

The identifier for the Advertising Partner Google Ads account. Corresponds to the JSON property advertisingPartner



32566
32567
32568
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32566

def advertising_partner
  @advertising_partner
end

#hotel_centerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesHotelCenterLinkInvitationIdentifier

The identifier for Hotel account. Corresponds to the JSON property hotelCenter



32571
32572
32573
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32571

def hotel_center
  @hotel_center
end

#merchant_centerGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesMerchantCenterLinkInvitationIdentifier

The identifier for Merchant Center Account. Corresponds to the JSON property merchantCenter



32576
32577
32578
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32576

def merchant_center
  @merchant_center
end

Output only. The ID of the product link invitation. This field is read only. Corresponds to the JSON property productLinkInvitationId

Returns:

  • (Fixnum)


32581
32582
32583
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32581

def product_link_invitation_id
  @product_link_invitation_id
end

#resource_nameString

Immutable. The resource name of a product link invitation. Product link invitation resource names have the form: customers/customer_id/ productLinkInvitations/product_link_invitation_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


32588
32589
32590
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32588

def resource_name
  @resource_name
end

#statusString

Output only. The status of the product link invitation. This field is read only. Corresponds to the JSON property status

Returns:

  • (String)


32594
32595
32596
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32594

def status
  @status
end

#typeString

Output only. The type of the invited account. This field is read only and can be used for filtering invitations with @code GoogleAdsService. SearchGoogleAdsRequest. Corresponds to the JSON property type

Returns:

  • (String)


32601
32602
32603
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32601

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32608
32609
32610
32611
32612
32613
32614
32615
32616
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32608

def update!(**args)
  @advertising_partner = args[:advertising_partner] if args.key?(:advertising_partner)
  @hotel_center = args[:hotel_center] if args.key?(:hotel_center)
  @merchant_center = args[:merchant_center] if args.key?(:merchant_center)
  @product_link_invitation_id = args[:product_link_invitation_id] if args.key?(:product_link_invitation_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end