Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A recommendation.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Output only.
-
#call_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCallAssetRecommendation
The call asset recommendation.
-
#callout_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCalloutAssetRecommendation
The callout asset recommendation.
-
#campaign ⇒ String
Output only.
-
#campaign_budget ⇒ String
Output only.
-
#campaign_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendation
The budget recommendation for budget constrained campaigns.
-
#campaigns ⇒ Array<String>
Output only.
-
#custom_audience_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCustomAudienceOptInRecommendation
The Custom Audience Opt In recommendation.
-
#dismissed ⇒ Boolean
(also: #dismissed?)
Output only.
-
#display_expansion_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationDisplayExpansionOptInRecommendation
The Display Expansion opt-in recommendation.
-
#dynamic_image_extension_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationDynamicImageExtensionOptInRecommendation
Recommendation to enable dynamic image extensions on the account, allowing Google to find the best images from ad landing pages and complement text ads.
-
#enhanced_cpc_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationEnhancedCpcOptInRecommendation
The Enhanced Cost-Per-Click Opt-In recommendation.
-
#forecasting_campaign_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendation
The budget recommendation for budget constrained campaigns.
-
#forecasting_set_target_cpa_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetCpaRecommendation
The set target CPA recommendations.
-
#forecasting_set_target_roas_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetRoasRecommendation
The forecasting set target ROAS recommendation.
-
#impact ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationImpact
The impact of making the change as described in the recommendation.
-
#improve_demand_gen_ad_strength_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImproveDemandGenAdStrengthRecommendation
The improve Demand Gen ad strength recommendation.
-
#improve_google_tag_coverage_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImproveGoogleTagCoverageRecommendation
Recommendation to deploy Google Tag on more pages.
-
#improve_performance_max_ad_strength_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImprovePerformanceMaxAdStrengthRecommendation
Recommendation to improve the asset group strength of a Performance Max campaign to an "Excellent" rating.
-
#keyword_match_type_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationKeywordMatchTypeRecommendation
The keyword match type recommendation.
-
#keyword_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationKeywordRecommendation
The keyword recommendation.
-
#lead_form_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationLeadFormAssetRecommendation
The lead form asset recommendation.
-
#lower_target_roas_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationLowerTargetRoasRecommendation
Recommendation to lower Target ROAS.
-
#marginal_roi_campaign_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendation
The budget recommendation for budget constrained campaigns.
-
#maximize_clicks_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMaximizeClicksOptInRecommendation
The Maximize Clicks opt-in recommendation.
-
#maximize_conversion_value_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMaximizeConversionValueOptInRecommendation
Recommendation to opt into Maximize Conversion Value bidding strategy.
-
#maximize_conversions_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMaximizeConversionsOptInRecommendation
The Maximize Conversions Opt-In recommendation.
-
#migrate_dynamic_search_ads_campaign_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMigrateDynamicSearchAdsCampaignToPerformanceMaxRecommendation
The Dynamic Search Ads to Performance Max migration recommendation.
-
#move_unused_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMoveUnusedBudgetRecommendation
The move unused budget recommendation.
-
#optimize_ad_rotation_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationOptimizeAdRotationRecommendation
The Optimize Ad Rotation recommendation.
-
#performance_max_final_url_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationPerformanceMaxFinalUrlOptInRecommendation
Recommendation to turn on Final URL expansion for your Performance Max campaigns.
-
#performance_max_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationPerformanceMaxOptInRecommendation
The Performance Max Opt In recommendation.
-
#raise_target_cpa_bid_too_low_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRaiseTargetCpaBidTooLowRecommendation
The raise target CPA bid too low recommendation.
-
#raise_target_cpa_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRaiseTargetCpaRecommendation
Recommendation to raise Target CPA.
-
#refresh_customer_match_list_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRefreshCustomerMatchListRecommendation
The recommendation to update a customer list that hasn't been updated in the last 90 days.
-
#resource_name ⇒ String
Immutable.
-
#responsive_search_ad_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationResponsiveSearchAdAssetRecommendation
The add responsive search ad asset recommendation.
-
#responsive_search_ad_improve_ad_strength_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationResponsiveSearchAdImproveAdStrengthRecommendation
The responsive search ad improve ad strength recommendation.
-
#responsive_search_ad_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationResponsiveSearchAdRecommendation
The add responsive search ad recommendation.
-
#search_partners_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationSearchPartnersOptInRecommendation
The Search Partners Opt-In recommendation.
-
#set_target_cpa_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetCpaRecommendation
The set target CPA recommendations.
-
#set_target_roas_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetRoasRecommendation
The forecasting set target ROAS recommendation.
-
#shopping_add_age_group_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted because it is missing.
-
#shopping_add_color_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted because it is missing.
-
#shopping_add_gender_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted because it is missing.
-
#shopping_add_gtin_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted because it is missing.
-
#shopping_add_more_identifiers_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted because it is missing.
-
#shopping_add_products_to_campaign_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingAddProductsToCampaignRecommendation
The shopping recommendation to add products to a Shopping Campaign Inventory.
-
#shopping_add_size_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted because it is missing.
-
#shopping_fix_disapproved_products_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingFixDisapprovedProductsRecommendation
The shopping recommendation to fix disapproved products in a Shopping Campaign Inventory.
-
#shopping_fix_merchant_center_account_suspension_warning_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMerchantCenterAccountSuspensionRecommendation
The shopping recommendation to fix Merchant Center account suspension issues.
-
#shopping_fix_suspended_merchant_center_account_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMerchantCenterAccountSuspensionRecommendation
The shopping recommendation to fix Merchant Center account suspension issues.
-
#shopping_migrate_regular_shopping_campaign_offers_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation
The shopping recommendation to migrate Regular Shopping Campaign targeted offers to Performance Max campaigns.
-
#shopping_target_all_offers_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingTargetAllOffersRecommendation
The shopping recommendation to create a catch-all campaign that targets all offers.
-
#sitelink_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationSitelinkAssetRecommendation
The sitelink asset recommendation.
-
#target_cpa_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendation
The Target CPA opt-in recommendation.
-
#target_roas_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetRoasOptInRecommendation
The Target ROAS opt-in recommendation.
-
#text_ad_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTextAdRecommendation
The text ad recommendation.
-
#type ⇒ String
Output only.
-
#upgrade_local_campaign_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationUpgradeLocalCampaignToPerformanceMaxRecommendation
The Upgrade Local campaign to Performance Max campaign recommendation.
-
#upgrade_smart_shopping_campaign_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationUpgradeSmartShoppingCampaignToPerformanceMaxRecommendation
The upgrade a Smart Shopping campaign to a Performance Max campaign recommendation.
-
#use_broad_match_keyword_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationUseBroadMatchKeywordRecommendation
The use broad match keyword recommendation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendation
Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendation.
33001 33002 33003 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33001 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Output only. The ad group targeted by this recommendation. This will be set
only when the recommendation affects a single ad group. This field will be set
for the following recommendation types: KEYWORD, OPTIMIZE_AD_ROTATION, TEXT_AD
Corresponds to the JSON property adGroup
32666 32667 32668 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32666 def ad_group @ad_group end |
#call_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCallAssetRecommendation
The call asset recommendation.
Corresponds to the JSON property callAssetRecommendation
32671 32672 32673 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32671 def call_asset_recommendation @call_asset_recommendation end |
#callout_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCalloutAssetRecommendation
The callout asset recommendation.
Corresponds to the JSON property calloutAssetRecommendation
32676 32677 32678 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32676 def callout_asset_recommendation @callout_asset_recommendation end |
#campaign ⇒ String
Output only. The campaign targeted by this recommendation. This field will be
set for the following recommendation types: CALL_EXTENSION, CALLOUT_EXTENSION,
ENHANCED_CPC_OPT_IN, KEYWORD, KEYWORD_MATCH_TYPE, MAXIMIZE_CLICKS_OPT_IN,
MAXIMIZE_CONVERSIONS_OPT_IN, OPTIMIZE_AD_ROTATION, SEARCH_PARTNERS_OPT_IN,
SITELINK_EXTENSION, TARGET_CPA_OPT_IN, TARGET_ROAS_OPT_IN, TEXT_AD,
Corresponds to the JSON property campaign
32685 32686 32687 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32685 def campaign @campaign end |
#campaign_budget ⇒ String
Output only. The budget targeted by this recommendation. This will be set only
when the recommendation affects a single campaign budget. This field will be
set for the following recommendation types: CAMPAIGN_BUDGET,
FORECASTING_CAMPAIGN_BUDGET, MOVE_UNUSED_BUDGET
Corresponds to the JSON property campaignBudget
32693 32694 32695 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32693 def campaign_budget @campaign_budget end |
#campaign_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendation
The budget recommendation for budget constrained campaigns.
Corresponds to the JSON property campaignBudgetRecommendation
32698 32699 32700 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32698 def campaign_budget_recommendation @campaign_budget_recommendation end |
#campaigns ⇒ Array<String>
Output only. The campaigns targeted by this recommendation. This field will be
set for the following recommendation types: CAMPAIGN_BUDGET,
FORECASTING_CAMPAIGN_BUDGET, MARGINAL_ROI_CAMPAIGN_BUDGET and
MOVE_UNUSED_BUDGET
Corresponds to the JSON property campaigns
32706 32707 32708 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32706 def campaigns @campaigns end |
#custom_audience_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCustomAudienceOptInRecommendation
The Custom Audience Opt In recommendation.
Corresponds to the JSON property customAudienceOptInRecommendation
32711 32712 32713 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32711 def custom_audience_opt_in_recommendation @custom_audience_opt_in_recommendation end |
#dismissed ⇒ Boolean Also known as: dismissed?
Output only. Whether the recommendation is dismissed or not.
Corresponds to the JSON property dismissed
32716 32717 32718 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32716 def dismissed @dismissed end |
#display_expansion_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationDisplayExpansionOptInRecommendation
The Display Expansion opt-in recommendation.
Corresponds to the JSON property displayExpansionOptInRecommendation
32722 32723 32724 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32722 def display_expansion_opt_in_recommendation @display_expansion_opt_in_recommendation end |
#dynamic_image_extension_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationDynamicImageExtensionOptInRecommendation
Recommendation to enable dynamic image extensions on the account, allowing
Google to find the best images from ad landing pages and complement text ads.
Corresponds to the JSON property dynamicImageExtensionOptInRecommendation
32728 32729 32730 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32728 def dynamic_image_extension_opt_in_recommendation @dynamic_image_extension_opt_in_recommendation end |
#enhanced_cpc_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationEnhancedCpcOptInRecommendation
The Enhanced Cost-Per-Click Opt-In recommendation.
Corresponds to the JSON property enhancedCpcOptInRecommendation
32733 32734 32735 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32733 def enhanced_cpc_opt_in_recommendation @enhanced_cpc_opt_in_recommendation end |
#forecasting_campaign_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendation
The budget recommendation for budget constrained campaigns.
Corresponds to the JSON property forecastingCampaignBudgetRecommendation
32738 32739 32740 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32738 def forecasting_campaign_budget_recommendation @forecasting_campaign_budget_recommendation end |
#forecasting_set_target_cpa_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetCpaRecommendation
The set target CPA recommendations.
Corresponds to the JSON property forecastingSetTargetCpaRecommendation
32743 32744 32745 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32743 def forecasting_set_target_cpa_recommendation @forecasting_set_target_cpa_recommendation end |
#forecasting_set_target_roas_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetRoasRecommendation
The forecasting set target ROAS recommendation.
Corresponds to the JSON property forecastingSetTargetRoasRecommendation
32748 32749 32750 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32748 def forecasting_set_target_roas_recommendation @forecasting_set_target_roas_recommendation end |
#impact ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationImpact
The impact of making the change as described in the recommendation. Some types
of recommendations may not have impact information.
Corresponds to the JSON property impact
32754 32755 32756 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32754 def impact @impact end |
#improve_demand_gen_ad_strength_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImproveDemandGenAdStrengthRecommendation
The improve Demand Gen ad strength recommendation.
Corresponds to the JSON property improveDemandGenAdStrengthRecommendation
32759 32760 32761 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32759 def improve_demand_gen_ad_strength_recommendation @improve_demand_gen_ad_strength_recommendation end |
#improve_google_tag_coverage_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImproveGoogleTagCoverageRecommendation
Recommendation to deploy Google Tag on more pages.
Corresponds to the JSON property improveGoogleTagCoverageRecommendation
32764 32765 32766 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32764 def improve_google_tag_coverage_recommendation @improve_google_tag_coverage_recommendation end |
#improve_performance_max_ad_strength_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImprovePerformanceMaxAdStrengthRecommendation
Recommendation to improve the asset group strength of a Performance Max
campaign to an "Excellent" rating.
Corresponds to the JSON property improvePerformanceMaxAdStrengthRecommendation
32770 32771 32772 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32770 def improve_performance_max_ad_strength_recommendation @improve_performance_max_ad_strength_recommendation end |
#keyword_match_type_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationKeywordMatchTypeRecommendation
The keyword match type recommendation.
Corresponds to the JSON property keywordMatchTypeRecommendation
32775 32776 32777 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32775 def keyword_match_type_recommendation @keyword_match_type_recommendation end |
#keyword_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationKeywordRecommendation
The keyword recommendation.
Corresponds to the JSON property keywordRecommendation
32780 32781 32782 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32780 def keyword_recommendation @keyword_recommendation end |
#lead_form_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationLeadFormAssetRecommendation
The lead form asset recommendation.
Corresponds to the JSON property leadFormAssetRecommendation
32785 32786 32787 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32785 def lead_form_asset_recommendation @lead_form_asset_recommendation end |
#lower_target_roas_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationLowerTargetRoasRecommendation
Recommendation to lower Target ROAS.
Corresponds to the JSON property lowerTargetRoasRecommendation
32790 32791 32792 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32790 def lower_target_roas_recommendation @lower_target_roas_recommendation end |
#marginal_roi_campaign_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendation
The budget recommendation for budget constrained campaigns.
Corresponds to the JSON property marginalRoiCampaignBudgetRecommendation
32795 32796 32797 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32795 def marginal_roi_campaign_budget_recommendation @marginal_roi_campaign_budget_recommendation end |
#maximize_clicks_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMaximizeClicksOptInRecommendation
The Maximize Clicks opt-in recommendation.
Corresponds to the JSON property maximizeClicksOptInRecommendation
32800 32801 32802 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32800 def maximize_clicks_opt_in_recommendation @maximize_clicks_opt_in_recommendation end |
#maximize_conversion_value_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMaximizeConversionValueOptInRecommendation
Recommendation to opt into Maximize Conversion Value bidding strategy.
Corresponds to the JSON property maximizeConversionValueOptInRecommendation
32805 32806 32807 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32805 def maximize_conversion_value_opt_in_recommendation @maximize_conversion_value_opt_in_recommendation end |
#maximize_conversions_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMaximizeConversionsOptInRecommendation
The Maximize Conversions Opt-In recommendation.
Corresponds to the JSON property maximizeConversionsOptInRecommendation
32810 32811 32812 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32810 def maximize_conversions_opt_in_recommendation @maximize_conversions_opt_in_recommendation end |
#migrate_dynamic_search_ads_campaign_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMigrateDynamicSearchAdsCampaignToPerformanceMaxRecommendation
The Dynamic Search Ads to Performance Max migration recommendation.
Corresponds to the JSON property migrateDynamicSearchAdsCampaignToPerformanceMaxRecommendation
32815 32816 32817 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32815 def migrate_dynamic_search_ads_campaign_to_performance_max_recommendation @migrate_dynamic_search_ads_campaign_to_performance_max_recommendation end |
#move_unused_budget_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMoveUnusedBudgetRecommendation
The move unused budget recommendation.
Corresponds to the JSON property moveUnusedBudgetRecommendation
32820 32821 32822 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32820 def move_unused_budget_recommendation @move_unused_budget_recommendation end |
#optimize_ad_rotation_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationOptimizeAdRotationRecommendation
The Optimize Ad Rotation recommendation.
Corresponds to the JSON property optimizeAdRotationRecommendation
32825 32826 32827 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32825 def optimize_ad_rotation_recommendation @optimize_ad_rotation_recommendation end |
#performance_max_final_url_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationPerformanceMaxFinalUrlOptInRecommendation
Recommendation to turn on Final URL expansion for your Performance Max
campaigns.
Corresponds to the JSON property performanceMaxFinalUrlOptInRecommendation
32831 32832 32833 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32831 def performance_max_final_url_opt_in_recommendation @performance_max_final_url_opt_in_recommendation end |
#performance_max_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationPerformanceMaxOptInRecommendation
The Performance Max Opt In recommendation.
Corresponds to the JSON property performanceMaxOptInRecommendation
32836 32837 32838 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32836 def performance_max_opt_in_recommendation @performance_max_opt_in_recommendation end |
#raise_target_cpa_bid_too_low_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRaiseTargetCpaBidTooLowRecommendation
The raise target CPA bid too low recommendation.
Corresponds to the JSON property raiseTargetCpaBidTooLowRecommendation
32841 32842 32843 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32841 def raise_target_cpa_bid_too_low_recommendation @raise_target_cpa_bid_too_low_recommendation end |
#raise_target_cpa_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRaiseTargetCpaRecommendation
Recommendation to raise Target CPA.
Corresponds to the JSON property raiseTargetCpaRecommendation
32846 32847 32848 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32846 def raise_target_cpa_recommendation @raise_target_cpa_recommendation end |
#refresh_customer_match_list_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRefreshCustomerMatchListRecommendation
The recommendation to update a customer list that hasn't been updated in the
last 90 days. The customer receiving the recommendation is not necessarily the
owner account. The owner account should update the customer list.
Corresponds to the JSON property refreshCustomerMatchListRecommendation
32853 32854 32855 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32853 def refresh_customer_match_list_recommendation @refresh_customer_match_list_recommendation end |
#resource_name ⇒ String
Immutable. The resource name of the recommendation. customers/customer_id/
recommendations/recommendation_id`
Corresponds to the JSON propertyresourceName`
32859 32860 32861 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32859 def resource_name @resource_name end |
#responsive_search_ad_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationResponsiveSearchAdAssetRecommendation
The add responsive search ad asset recommendation.
Corresponds to the JSON property responsiveSearchAdAssetRecommendation
32864 32865 32866 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32864 def responsive_search_ad_asset_recommendation @responsive_search_ad_asset_recommendation end |
#responsive_search_ad_improve_ad_strength_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationResponsiveSearchAdImproveAdStrengthRecommendation
The responsive search ad improve ad strength recommendation.
Corresponds to the JSON property responsiveSearchAdImproveAdStrengthRecommendation
32869 32870 32871 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32869 def responsive_search_ad_improve_ad_strength_recommendation @responsive_search_ad_improve_ad_strength_recommendation end |
#responsive_search_ad_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationResponsiveSearchAdRecommendation
The add responsive search ad recommendation.
Corresponds to the JSON property responsiveSearchAdRecommendation
32874 32875 32876 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32874 def responsive_search_ad_recommendation @responsive_search_ad_recommendation end |
#search_partners_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationSearchPartnersOptInRecommendation
The Search Partners Opt-In recommendation.
Corresponds to the JSON property searchPartnersOptInRecommendation
32879 32880 32881 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32879 def search_partners_opt_in_recommendation @search_partners_opt_in_recommendation end |
#set_target_cpa_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetCpaRecommendation
The set target CPA recommendations.
Corresponds to the JSON property setTargetCpaRecommendation
32884 32885 32886 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32884 def set_target_cpa_recommendation @set_target_cpa_recommendation end |
#set_target_roas_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationForecastingSetTargetRoasRecommendation
The forecasting set target ROAS recommendation.
Corresponds to the JSON property setTargetRoasRecommendation
32889 32890 32891 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32889 def set_target_roas_recommendation @set_target_roas_recommendation end |
#shopping_add_age_group_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted
because it is missing.
Corresponds to the JSON property shoppingAddAgeGroupRecommendation
32895 32896 32897 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32895 def shopping_add_age_group_recommendation @shopping_add_age_group_recommendation end |
#shopping_add_color_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted
because it is missing.
Corresponds to the JSON property shoppingAddColorRecommendation
32901 32902 32903 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32901 def shopping_add_color_recommendation @shopping_add_color_recommendation end |
#shopping_add_gender_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted
because it is missing.
Corresponds to the JSON property shoppingAddGenderRecommendation
32907 32908 32909 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32907 def shopping_add_gender_recommendation @shopping_add_gender_recommendation end |
#shopping_add_gtin_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted
because it is missing.
Corresponds to the JSON property shoppingAddGtinRecommendation
32913 32914 32915 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32913 def shopping_add_gtin_recommendation @shopping_add_gtin_recommendation end |
#shopping_add_more_identifiers_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted
because it is missing.
Corresponds to the JSON property shoppingAddMoreIdentifiersRecommendation
32919 32920 32921 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32919 def shopping_add_more_identifiers_recommendation @shopping_add_more_identifiers_recommendation end |
#shopping_add_products_to_campaign_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingAddProductsToCampaignRecommendation
The shopping recommendation to add products to a Shopping Campaign Inventory.
Corresponds to the JSON property shoppingAddProductsToCampaignRecommendation
32924 32925 32926 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32924 def shopping_add_products_to_campaign_recommendation @shopping_add_products_to_campaign_recommendation end |
#shopping_add_size_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
The shopping recommendation to add an attribute to offers that are demoted
because it is missing.
Corresponds to the JSON property shoppingAddSizeRecommendation
32930 32931 32932 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32930 def shopping_add_size_recommendation @shopping_add_size_recommendation end |
#shopping_fix_disapproved_products_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingFixDisapprovedProductsRecommendation
The shopping recommendation to fix disapproved products in a Shopping Campaign
Inventory.
Corresponds to the JSON property shoppingFixDisapprovedProductsRecommendation
32936 32937 32938 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32936 def shopping_fix_disapproved_products_recommendation @shopping_fix_disapproved_products_recommendation end |
#shopping_fix_merchant_center_account_suspension_warning_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMerchantCenterAccountSuspensionRecommendation
The shopping recommendation to fix Merchant Center account suspension issues.
Corresponds to the JSON property shoppingFixMerchantCenterAccountSuspensionWarningRecommendation
32941 32942 32943 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32941 def shopping_fix_merchant_center_account_suspension_warning_recommendation @shopping_fix_merchant_center_account_suspension_warning_recommendation end |
#shopping_fix_suspended_merchant_center_account_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMerchantCenterAccountSuspensionRecommendation
The shopping recommendation to fix Merchant Center account suspension issues.
Corresponds to the JSON property shoppingFixSuspendedMerchantCenterAccountRecommendation
32946 32947 32948 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32946 def shopping_fix_suspended_merchant_center_account_recommendation @shopping_fix_suspended_merchant_center_account_recommendation end |
#shopping_migrate_regular_shopping_campaign_offers_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation
The shopping recommendation to migrate Regular Shopping Campaign targeted
offers to Performance Max campaigns.
Corresponds to the JSON property shoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation
32952 32953 32954 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32952 def shopping_migrate_regular_shopping_campaign_offers_to_performance_max_recommendation @shopping_migrate_regular_shopping_campaign_offers_to_performance_max_recommendation end |
#shopping_target_all_offers_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingTargetAllOffersRecommendation
The shopping recommendation to create a catch-all campaign that targets all
offers.
Corresponds to the JSON property shoppingTargetAllOffersRecommendation
32958 32959 32960 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32958 def shopping_target_all_offers_recommendation @shopping_target_all_offers_recommendation end |
#sitelink_asset_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationSitelinkAssetRecommendation
The sitelink asset recommendation.
Corresponds to the JSON property sitelinkAssetRecommendation
32963 32964 32965 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32963 def sitelink_asset_recommendation @sitelink_asset_recommendation end |
#target_cpa_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendation
The Target CPA opt-in recommendation.
Corresponds to the JSON property targetCpaOptInRecommendation
32968 32969 32970 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32968 def target_cpa_opt_in_recommendation @target_cpa_opt_in_recommendation end |
#target_roas_opt_in_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetRoasOptInRecommendation
The Target ROAS opt-in recommendation.
Corresponds to the JSON property targetRoasOptInRecommendation
32973 32974 32975 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32973 def target_roas_opt_in_recommendation @target_roas_opt_in_recommendation end |
#text_ad_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTextAdRecommendation
The text ad recommendation.
Corresponds to the JSON property textAdRecommendation
32978 32979 32980 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32978 def text_ad_recommendation @text_ad_recommendation end |
#type ⇒ String
Output only. The type of recommendation.
Corresponds to the JSON property type
32983 32984 32985 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32983 def type @type end |
#upgrade_local_campaign_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationUpgradeLocalCampaignToPerformanceMaxRecommendation
The Upgrade Local campaign to Performance Max campaign recommendation.
Corresponds to the JSON property upgradeLocalCampaignToPerformanceMaxRecommendation
32988 32989 32990 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32988 def upgrade_local_campaign_to_performance_max_recommendation @upgrade_local_campaign_to_performance_max_recommendation end |
#upgrade_smart_shopping_campaign_to_performance_max_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationUpgradeSmartShoppingCampaignToPerformanceMaxRecommendation
The upgrade a Smart Shopping campaign to a Performance Max campaign
recommendation.
Corresponds to the JSON property upgradeSmartShoppingCampaignToPerformanceMaxRecommendation
32994 32995 32996 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32994 def upgrade_smart_shopping_campaign_to_performance_max_recommendation @upgrade_smart_shopping_campaign_to_performance_max_recommendation end |
#use_broad_match_keyword_recommendation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationUseBroadMatchKeywordRecommendation
The use broad match keyword recommendation.
Corresponds to the JSON property useBroadMatchKeywordRecommendation
32999 33000 33001 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 32999 def use_broad_match_keyword_recommendation @use_broad_match_keyword_recommendation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33006 33007 33008 33009 33010 33011 33012 33013 33014 33015 33016 33017 33018 33019 33020 33021 33022 33023 33024 33025 33026 33027 33028 33029 33030 33031 33032 33033 33034 33035 33036 33037 33038 33039 33040 33041 33042 33043 33044 33045 33046 33047 33048 33049 33050 33051 33052 33053 33054 33055 33056 33057 33058 33059 33060 33061 33062 33063 33064 33065 33066 33067 33068 33069 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33006 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @call_asset_recommendation = args[:call_asset_recommendation] if args.key?(:call_asset_recommendation) @callout_asset_recommendation = args[:callout_asset_recommendation] if args.key?(:callout_asset_recommendation) @campaign = args[:campaign] if args.key?(:campaign) @campaign_budget = args[:campaign_budget] if args.key?(:campaign_budget) @campaign_budget_recommendation = args[:campaign_budget_recommendation] if args.key?(:campaign_budget_recommendation) @campaigns = args[:campaigns] if args.key?(:campaigns) @custom_audience_opt_in_recommendation = args[:custom_audience_opt_in_recommendation] if args.key?(:custom_audience_opt_in_recommendation) @dismissed = args[:dismissed] if args.key?(:dismissed) @display_expansion_opt_in_recommendation = args[:display_expansion_opt_in_recommendation] if args.key?(:display_expansion_opt_in_recommendation) @dynamic_image_extension_opt_in_recommendation = args[:dynamic_image_extension_opt_in_recommendation] if args.key?(:dynamic_image_extension_opt_in_recommendation) @enhanced_cpc_opt_in_recommendation = args[:enhanced_cpc_opt_in_recommendation] if args.key?(:enhanced_cpc_opt_in_recommendation) @forecasting_campaign_budget_recommendation = args[:forecasting_campaign_budget_recommendation] if args.key?(:forecasting_campaign_budget_recommendation) @forecasting_set_target_cpa_recommendation = args[:forecasting_set_target_cpa_recommendation] if args.key?(:forecasting_set_target_cpa_recommendation) @forecasting_set_target_roas_recommendation = args[:forecasting_set_target_roas_recommendation] if args.key?(:forecasting_set_target_roas_recommendation) @impact = args[:impact] if args.key?(:impact) @improve_demand_gen_ad_strength_recommendation = args[:improve_demand_gen_ad_strength_recommendation] if args.key?(:improve_demand_gen_ad_strength_recommendation) @improve_google_tag_coverage_recommendation = args[:improve_google_tag_coverage_recommendation] if args.key?(:improve_google_tag_coverage_recommendation) @improve_performance_max_ad_strength_recommendation = args[:improve_performance_max_ad_strength_recommendation] if args.key?(:improve_performance_max_ad_strength_recommendation) @keyword_match_type_recommendation = args[:keyword_match_type_recommendation] if args.key?(:keyword_match_type_recommendation) @keyword_recommendation = args[:keyword_recommendation] if args.key?(:keyword_recommendation) @lead_form_asset_recommendation = args[:lead_form_asset_recommendation] if args.key?(:lead_form_asset_recommendation) @lower_target_roas_recommendation = args[:lower_target_roas_recommendation] if args.key?(:lower_target_roas_recommendation) @marginal_roi_campaign_budget_recommendation = args[:marginal_roi_campaign_budget_recommendation] if args.key?(:marginal_roi_campaign_budget_recommendation) @maximize_clicks_opt_in_recommendation = args[:maximize_clicks_opt_in_recommendation] if args.key?(:maximize_clicks_opt_in_recommendation) @maximize_conversion_value_opt_in_recommendation = args[:maximize_conversion_value_opt_in_recommendation] if args.key?(:maximize_conversion_value_opt_in_recommendation) @maximize_conversions_opt_in_recommendation = args[:maximize_conversions_opt_in_recommendation] if args.key?(:maximize_conversions_opt_in_recommendation) @migrate_dynamic_search_ads_campaign_to_performance_max_recommendation = args[:migrate_dynamic_search_ads_campaign_to_performance_max_recommendation] if args.key?(:migrate_dynamic_search_ads_campaign_to_performance_max_recommendation) @move_unused_budget_recommendation = args[:move_unused_budget_recommendation] if args.key?(:move_unused_budget_recommendation) @optimize_ad_rotation_recommendation = args[:optimize_ad_rotation_recommendation] if args.key?(:optimize_ad_rotation_recommendation) @performance_max_final_url_opt_in_recommendation = args[:performance_max_final_url_opt_in_recommendation] if args.key?(:performance_max_final_url_opt_in_recommendation) @performance_max_opt_in_recommendation = args[:performance_max_opt_in_recommendation] if args.key?(:performance_max_opt_in_recommendation) @raise_target_cpa_bid_too_low_recommendation = args[:raise_target_cpa_bid_too_low_recommendation] if args.key?(:raise_target_cpa_bid_too_low_recommendation) @raise_target_cpa_recommendation = args[:raise_target_cpa_recommendation] if args.key?(:raise_target_cpa_recommendation) @refresh_customer_match_list_recommendation = args[:refresh_customer_match_list_recommendation] if args.key?(:refresh_customer_match_list_recommendation) @resource_name = args[:resource_name] if args.key?(:resource_name) @responsive_search_ad_asset_recommendation = args[:responsive_search_ad_asset_recommendation] if args.key?(:responsive_search_ad_asset_recommendation) @responsive_search_ad_improve_ad_strength_recommendation = args[:responsive_search_ad_improve_ad_strength_recommendation] if args.key?(:responsive_search_ad_improve_ad_strength_recommendation) @responsive_search_ad_recommendation = args[:responsive_search_ad_recommendation] if args.key?(:responsive_search_ad_recommendation) @search_partners_opt_in_recommendation = args[:search_partners_opt_in_recommendation] if args.key?(:search_partners_opt_in_recommendation) @set_target_cpa_recommendation = args[:set_target_cpa_recommendation] if args.key?(:set_target_cpa_recommendation) @set_target_roas_recommendation = args[:set_target_roas_recommendation] if args.key?(:set_target_roas_recommendation) @shopping_add_age_group_recommendation = args[:shopping_add_age_group_recommendation] if args.key?(:shopping_add_age_group_recommendation) @shopping_add_color_recommendation = args[:shopping_add_color_recommendation] if args.key?(:shopping_add_color_recommendation) @shopping_add_gender_recommendation = args[:shopping_add_gender_recommendation] if args.key?(:shopping_add_gender_recommendation) @shopping_add_gtin_recommendation = args[:shopping_add_gtin_recommendation] if args.key?(:shopping_add_gtin_recommendation) @shopping_add_more_identifiers_recommendation = args[:shopping_add_more_identifiers_recommendation] if args.key?(:shopping_add_more_identifiers_recommendation) @shopping_add_products_to_campaign_recommendation = args[:shopping_add_products_to_campaign_recommendation] if args.key?(:shopping_add_products_to_campaign_recommendation) @shopping_add_size_recommendation = args[:shopping_add_size_recommendation] if args.key?(:shopping_add_size_recommendation) @shopping_fix_disapproved_products_recommendation = args[:shopping_fix_disapproved_products_recommendation] if args.key?(:shopping_fix_disapproved_products_recommendation) @shopping_fix_merchant_center_account_suspension_warning_recommendation = args[:shopping_fix_merchant_center_account_suspension_warning_recommendation] if args.key?(:shopping_fix_merchant_center_account_suspension_warning_recommendation) @shopping_fix_suspended_merchant_center_account_recommendation = args[:shopping_fix_suspended_merchant_center_account_recommendation] if args.key?(:shopping_fix_suspended_merchant_center_account_recommendation) @shopping_migrate_regular_shopping_campaign_offers_to_performance_max_recommendation = args[:shopping_migrate_regular_shopping_campaign_offers_to_performance_max_recommendation] if args.key?(:shopping_migrate_regular_shopping_campaign_offers_to_performance_max_recommendation) @shopping_target_all_offers_recommendation = args[:shopping_target_all_offers_recommendation] if args.key?(:shopping_target_all_offers_recommendation) @sitelink_asset_recommendation = args[:sitelink_asset_recommendation] if args.key?(:sitelink_asset_recommendation) @target_cpa_opt_in_recommendation = args[:target_cpa_opt_in_recommendation] if args.key?(:target_cpa_opt_in_recommendation) @target_roas_opt_in_recommendation = args[:target_roas_opt_in_recommendation] if args.key?(:target_roas_opt_in_recommendation) @text_ad_recommendation = args[:text_ad_recommendation] if args.key?(:text_ad_recommendation) @type = args[:type] if args.key?(:type) @upgrade_local_campaign_to_performance_max_recommendation = args[:upgrade_local_campaign_to_performance_max_recommendation] if args.key?(:upgrade_local_campaign_to_performance_max_recommendation) @upgrade_smart_shopping_campaign_to_performance_max_recommendation = args[:upgrade_smart_shopping_campaign_to_performance_max_recommendation] if args.key?(:upgrade_smart_shopping_campaign_to_performance_max_recommendation) @use_broad_match_keyword_recommendation = args[:use_broad_match_keyword_recommendation] if args.key?(:use_broad_match_keyword_recommendation) end |