Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A campaign budget shared amongst various budget recommendation types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudget

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudget.



17804
17805
17806
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_amount_microsFixnum

Output only. Current budget amount. Corresponds to the JSON property currentAmountMicros

Returns:

  • (Fixnum)


17790
17791
17792
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17790

def current_amount_micros
  @current_amount_micros
end

#new_start_dateString

Output only. The date when the new budget would start being used. This field will be set for the following recommendation types: FORECASTING_SET_TARGET_ROAS YYYY-MM-DD format, for example, 2018-04-17. Corresponds to the JSON property newStartDate

Returns:

  • (String)


17797
17798
17799
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17797

def new_start_date
  @new_start_date
end

Output only. Recommended budget amount. Corresponds to the JSON property recommendedNewAmountMicros

Returns:

  • (Fixnum)


17802
17803
17804
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17802

def recommended_new_amount_micros
  @recommended_new_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17809
17810
17811
17812
17813
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17809

def update!(**args)
  @current_amount_micros = args[:current_amount_micros] if args.key?(:current_amount_micros)
  @new_start_date = args[:new_start_date] if args.key?(:new_start_date)
  @recommended_new_amount_micros = args[:recommended_new_amount_micros] if args.key?(:recommended_new_amount_micros)
end