Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendationCampaignBudgetRecommendationOption
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendationCampaignBudgetRecommendationOption
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The impact estimates for a given budget amount.
Instance Attribute Summary collapse
-
#budget_amount_micros ⇒ Fixnum
Output only.
-
#impact ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationImpact
The impact of making the change as described in the recommendation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendationCampaignBudgetRecommendationOption
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendationCampaignBudgetRecommendationOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendationCampaignBudgetRecommendationOption
Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationCampaignBudgetRecommendationCampaignBudgetRecommendationOption.
17643 17644 17645 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17643 def initialize(**args) update!(**args) end |
Instance Attribute Details
#budget_amount_micros ⇒ Fixnum
Output only. The budget amount for this option.
Corresponds to the JSON property budgetAmountMicros
17635 17636 17637 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17635 def budget_amount_micros @budget_amount_micros end |
#impact ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationImpact
The impact of making the change as described in the recommendation. Some types
of recommendations may not have impact information.
Corresponds to the JSON property impact
17641 17642 17643 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17641 def impact @impact end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17648 17649 17650 17651 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17648 def update!(**args) @budget_amount_micros = args[:budget_amount_micros] if args.key?(:budget_amount_micros) @impact = args[:impact] if args.key?(:impact) end |