Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationDynamicImageExtensionOptInRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Recommendation to enable dynamic image extensions on the account, allowing Google to find the best images from ad landing pages and complement text ads.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationDynamicImageExtensionOptInRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationDynamicImageExtensionOptInRecommendation.



17951
17952
17953
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17951

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17956
17957
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17956

def update!(**args)
end