Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationDynamicImageExtensionOptInRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Recommendation to enable dynamic image extensions on the account, allowing Google to find the best images from ad landing pages and complement text ads.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationDynamicImageExtensionOptInRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationDynamicImageExtensionOptInRecommendation.



17885
17886
17887
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17885

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17890
17891
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17890

def update!(**args)
end