Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImproveDemandGenAdStrengthRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImproveDemandGenAdStrengthRecommendation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The improve Demand Gen ad strength recommendation.
Instance Attribute Summary collapse
-
#ad ⇒ String
Output only.
-
#ad_strength ⇒ String
Output only.
-
#demand_gen_asset_action_items ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationImproveDemandGenAdStrengthRecommendation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRecommendationImproveDemandGenAdStrengthRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationImproveDemandGenAdStrengthRecommendation
Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationImproveDemandGenAdStrengthRecommendation.
17977 17978 17979 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17977 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad ⇒ String
Output only. The resource name of the ad that can be improved.
Corresponds to the JSON property ad
17965 17966 17967 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17965 def ad @ad end |
#ad_strength ⇒ String
Output only. The current ad strength.
Corresponds to the JSON property adStrength
17970 17971 17972 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17970 def ad_strength @ad_strength end |
#demand_gen_asset_action_items ⇒ Array<String>
Output only. A list of recommendations to improve the ad strength.
Corresponds to the JSON property demandGenAssetActionItems
17975 17976 17977 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17975 def demand_gen_asset_action_items @demand_gen_asset_action_items end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17982 17983 17984 17985 17986 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17982 def update!(**args) @ad = args[:ad] if args.key?(:ad) @ad_strength = args[:ad_strength] if args.key?(:ad_strength) @demand_gen_asset_action_items = args[:demand_gen_asset_action_items] if args.key?(:demand_gen_asset_action_items) end |