Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImprovePerformanceMaxAdStrengthRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationImprovePerformanceMaxAdStrengthRecommendation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Recommendation to improve the asset group strength of a Performance Max campaign to an "Excellent" rating.
Instance Attribute Summary collapse
-
#ad_strength ⇒ String
Output only.
-
#asset_group ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationImprovePerformanceMaxAdStrengthRecommendation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRecommendationImprovePerformanceMaxAdStrengthRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationImprovePerformanceMaxAdStrengthRecommendation
Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationImprovePerformanceMaxAdStrengthRecommendation.
18017 18018 18019 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_strength ⇒ String
Output only. The current ad strength score of the asset group.
Corresponds to the JSON property adStrength
18010 18011 18012 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18010 def ad_strength @ad_strength end |
#asset_group ⇒ String
Output only. The asset group resource name.
Corresponds to the JSON property assetGroup
18015 18016 18017 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18015 def asset_group @asset_group end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18022 18023 18024 18025 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18022 def update!(**args) @ad_strength = args[:ad_strength] if args.key?(:ad_strength) @asset_group = args[:asset_group] if args.key?(:asset_group) end |