Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationKeywordRecommendationSearchTerm

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Information about a search term as related to a keyword recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationKeywordRecommendationSearchTerm

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationKeywordRecommendationSearchTerm.



17735
17736
17737
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#estimated_weekly_search_countFixnum

Output only. Estimated number of historical weekly searches for this search term. Corresponds to the JSON property estimatedWeeklySearchCount

Returns:

  • (Fixnum)


17728
17729
17730
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17728

def estimated_weekly_search_count
  @estimated_weekly_search_count
end

#textString

Output only. The text of the search term. Corresponds to the JSON property text

Returns:

  • (String)


17733
17734
17735
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17733

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17740
17741
17742
17743
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17740

def update!(**args)
  @estimated_weekly_search_count = args[:estimated_weekly_search_count] if args.key?(:estimated_weekly_search_count)
  @text = args[:text] if args.key?(:text)
end