Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationKeywordRecommendationSearchTerm
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationKeywordRecommendationSearchTerm
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Information about a search term as related to a keyword recommendation.
Instance Attribute Summary collapse
-
#estimated_weekly_search_count ⇒ Fixnum
Output only.
-
#text ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationKeywordRecommendationSearchTerm
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRecommendationKeywordRecommendationSearchTerm.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationKeywordRecommendationSearchTerm
Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationKeywordRecommendationSearchTerm.
17669 17670 17671 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17669 def initialize(**args) update!(**args) end |
Instance Attribute Details
#estimated_weekly_search_count ⇒ Fixnum
Output only. Estimated number of historical weekly searches for this search
term.
Corresponds to the JSON property estimatedWeeklySearchCount
17662 17663 17664 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17662 def estimated_weekly_search_count @estimated_weekly_search_count end |
#text ⇒ String
Output only. The text of the search term.
Corresponds to the JSON property text
17667 17668 17669 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17667 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17674 17675 17676 17677 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17674 def update!(**args) @estimated_weekly_search_count = args[:estimated_weekly_search_count] if args.key?(:estimated_weekly_search_count) @text = args[:text] if args.key?(:text) end |