Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationImpact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The impact of making the change as described in the recommendation. Some types of recommendations may not have impact information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationRecommendationImpact

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationRecommendationImpact.



18357
18358
18359
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18357

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_metricsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationMetrics

Weekly account performance metrics. For some recommendation types, these are averaged over the past 90-day period and hence can be fractional. Corresponds to the JSON property baseMetrics



18349
18350
18351
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18349

def base_metrics
  @base_metrics
end

#potential_metricsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationMetrics

Weekly account performance metrics. For some recommendation types, these are averaged over the past 90-day period and hence can be fractional. Corresponds to the JSON property potentialMetrics



18355
18356
18357
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18355

def potential_metrics
  @potential_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18362
18363
18364
18365
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18362

def update!(**args)
  @base_metrics = args[:base_metrics] if args.key?(:base_metrics)
  @potential_metrics = args[:potential_metrics] if args.key?(:potential_metrics)
end