Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Weekly account performance metrics. For some recommendation types, these are averaged over the past 90-day period and hence can be fractional.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationRecommendationMetrics

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationRecommendationMetrics.



18470
18471
18472
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18470

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clicksFloat

Output only. Number of ad clicks. Corresponds to the JSON property clicks

Returns:

  • (Float)


18442
18443
18444
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18442

def clicks
  @clicks
end

#conversionsFloat

Output only. Number of conversions. Corresponds to the JSON property conversions

Returns:

  • (Float)


18447
18448
18449
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18447

def conversions
  @conversions
end

#conversions_valueFloat

Output only. Sum of the conversion value of the conversions. Corresponds to the JSON property conversionsValue

Returns:

  • (Float)


18452
18453
18454
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18452

def conversions_value
  @conversions_value
end

#cost_microsFixnum

Output only. Cost (in micros) for advertising, in the local currency for the account. Corresponds to the JSON property costMicros

Returns:

  • (Fixnum)


18458
18459
18460
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18458

def cost_micros
  @cost_micros
end

#impressionsFloat

Output only. Number of ad impressions. Corresponds to the JSON property impressions

Returns:

  • (Float)


18463
18464
18465
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18463

def impressions
  @impressions
end

#video_viewsFloat

Output only. Number of video views for a video ad campaign. Corresponds to the JSON property videoViews

Returns:

  • (Float)


18468
18469
18470
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18468

def video_views
  @video_views
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18475
18476
18477
18478
18479
18480
18481
18482
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18475

def update!(**args)
  @clicks = args[:clicks] if args.key?(:clicks)
  @conversions = args[:conversions] if args.key?(:conversions)
  @conversions_value = args[:conversions_value] if args.key?(:conversions_value)
  @cost_micros = args[:cost_micros] if args.key?(:cost_micros)
  @impressions = args[:impressions] if args.key?(:impressions)
  @video_views = args[:video_views] if args.key?(:video_views)
end