Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Weekly account performance metrics. For some recommendation types, these are averaged over the past 90-day period and hence can be fractional.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationRecommendationMetrics

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationRecommendationMetrics.



18404
18405
18406
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18404

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clicksFloat

Output only. Number of ad clicks. Corresponds to the JSON property clicks

Returns:

  • (Float)


18376
18377
18378
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18376

def clicks
  @clicks
end

#conversionsFloat

Output only. Number of conversions. Corresponds to the JSON property conversions

Returns:

  • (Float)


18381
18382
18383
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18381

def conversions
  @conversions
end

#conversions_valueFloat

Output only. Sum of the conversion value of the conversions. Corresponds to the JSON property conversionsValue

Returns:

  • (Float)


18386
18387
18388
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18386

def conversions_value
  @conversions_value
end

#cost_microsFixnum

Output only. Cost (in micros) for advertising, in the local currency for the account. Corresponds to the JSON property costMicros

Returns:

  • (Fixnum)


18392
18393
18394
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18392

def cost_micros
  @cost_micros
end

#impressionsFloat

Output only. Number of ad impressions. Corresponds to the JSON property impressions

Returns:

  • (Float)


18397
18398
18399
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18397

def impressions
  @impressions
end

#video_viewsFloat

Output only. Number of video views for a video ad campaign. Corresponds to the JSON property videoViews

Returns:

  • (Float)


18402
18403
18404
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18402

def video_views
  @video_views
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18409
18410
18411
18412
18413
18414
18415
18416
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18409

def update!(**args)
  @clicks = args[:clicks] if args.key?(:clicks)
  @conversions = args[:conversions] if args.key?(:conversions)
  @conversions_value = args[:conversions_value] if args.key?(:conversions_value)
  @cost_micros = args[:cost_micros] if args.key?(:cost_micros)
  @impressions = args[:impressions] if args.key?(:impressions)
  @video_views = args[:video_views] if args.key?(:video_views)
end