Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRefreshCustomerMatchListRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRefreshCustomerMatchListRecommendation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The recommendation to update a customer list that hasn't been updated in the last 90 days. The customer receiving the recommendation is not necessarily the owner account. The owner account should update the customer list.
Instance Attribute Summary collapse
-
#days_since_last_refresh ⇒ Fixnum
Output only.
-
#owner_account ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationAccountInfo
Wrapper for information about a Google Ads account.
-
#targeting_accounts_count ⇒ Fixnum
Output only.
-
#top_spending_account ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationAccountInfo>
Output only.
-
#user_list_id ⇒ Fixnum
Output only.
-
#user_list_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationRefreshCustomerMatchListRecommendation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRecommendationRefreshCustomerMatchListRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationRefreshCustomerMatchListRecommendation
Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationRefreshCustomerMatchListRecommendation.
18583 18584 18585 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18583 def initialize(**args) update!(**args) end |
Instance Attribute Details
#days_since_last_refresh ⇒ Fixnum
Output only. Days since last refresh.
Corresponds to the JSON property daysSinceLastRefresh
18554 18555 18556 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18554 def days_since_last_refresh @days_since_last_refresh end |
#owner_account ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationAccountInfo
Wrapper for information about a Google Ads account.
Corresponds to the JSON property ownerAccount
18559 18560 18561 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18559 def owner_account @owner_account end |
#targeting_accounts_count ⇒ Fixnum
Output only. User lists can be shared with other accounts by the owner.
targeting_accounts_count is the number of those accounts that can use it for
targeting.
Corresponds to the JSON property targetingAccountsCount
18566 18567 18568 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18566 def targeting_accounts_count @targeting_accounts_count end |
#top_spending_account ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationAccountInfo>
Output only. The top spending account.
Corresponds to the JSON property topSpendingAccount
18571 18572 18573 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18571 def top_spending_account @top_spending_account end |
#user_list_id ⇒ Fixnum
Output only. The user list ID.
Corresponds to the JSON property userListId
18576 18577 18578 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18576 def user_list_id @user_list_id end |
#user_list_name ⇒ String
Output only. The name of the list.
Corresponds to the JSON property userListName
18581 18582 18583 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18581 def user_list_name @user_list_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18588 18589 18590 18591 18592 18593 18594 18595 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18588 def update!(**args) @days_since_last_refresh = args[:days_since_last_refresh] if args.key?(:days_since_last_refresh) @owner_account = args[:owner_account] if args.key?(:owner_account) @targeting_accounts_count = args[:targeting_accounts_count] if args.key?(:targeting_accounts_count) @top_spending_account = args[:top_spending_account] if args.key?(:top_spending_account) @user_list_id = args[:user_list_id] if args.key?(:user_list_id) @user_list_name = args[:user_list_name] if args.key?(:user_list_name) end |