Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRefreshCustomerMatchListRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The recommendation to update a customer list that hasn't been updated in the last 90 days. The customer receiving the recommendation is not necessarily the owner account. The owner account should update the customer list.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationRefreshCustomerMatchListRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationRefreshCustomerMatchListRecommendation.



18457
18458
18459
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18457

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#days_since_last_refreshFixnum

Output only. Days since last refresh. Corresponds to the JSON property daysSinceLastRefresh

Returns:

  • (Fixnum)


18428
18429
18430
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18428

def days_since_last_refresh
  @days_since_last_refresh
end

#owner_accountGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationAccountInfo

Wrapper for information about a Google Ads account. Corresponds to the JSON property ownerAccount



18433
18434
18435
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18433

def 
  @owner_account
end

#targeting_accounts_countFixnum

Output only. User lists can be shared with other accounts by the owner. targeting_accounts_count is the number of those accounts that can use it for targeting. Corresponds to the JSON property targetingAccountsCount

Returns:

  • (Fixnum)


18440
18441
18442
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18440

def targeting_accounts_count
  @targeting_accounts_count
end

#top_spending_accountArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationAccountInfo>

Output only. The top spending account. Corresponds to the JSON property topSpendingAccount



18445
18446
18447
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18445

def 
  @top_spending_account
end

#user_list_idFixnum

Output only. The user list ID. Corresponds to the JSON property userListId

Returns:

  • (Fixnum)


18450
18451
18452
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18450

def user_list_id
  @user_list_id
end

#user_list_nameString

Output only. The name of the list. Corresponds to the JSON property userListName

Returns:

  • (String)


18455
18456
18457
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18455

def user_list_name
  @user_list_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18462
18463
18464
18465
18466
18467
18468
18469
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18462

def update!(**args)
  @days_since_last_refresh = args[:days_since_last_refresh] if args.key?(:days_since_last_refresh)
  @owner_account = args[:owner_account] if args.key?(:owner_account)
  @targeting_accounts_count = args[:targeting_accounts_count] if args.key?(:targeting_accounts_count)
  @top_spending_account = args[:top_spending_account] if args.key?(:top_spending_account)
  @user_list_id = args[:user_list_id] if args.key?(:user_list_id)
  @user_list_name = args[:user_list_name] if args.key?(:user_list_name)
end