Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingAddProductsToCampaignRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingAddProductsToCampaignRecommendation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The shopping recommendation to add products to a Shopping Campaign Inventory.
Instance Attribute Summary collapse
-
#feed_label ⇒ String
Output only.
-
#merchant ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMerchantInfo
The Merchant Center account details.
-
#reason ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationShoppingAddProductsToCampaignRecommendation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRecommendationShoppingAddProductsToCampaignRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationShoppingAddProductsToCampaignRecommendation
Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationShoppingAddProductsToCampaignRecommendation.
18639 18640 18641 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18639 def initialize(**args) update!(**args) end |
Instance Attribute Details
#feed_label ⇒ String
Output only. The feed label for the campaign.
Corresponds to the JSON property feedLabel
18627 18628 18629 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18627 def feed_label @feed_label end |
#merchant ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMerchantInfo
The Merchant Center account details.
Corresponds to the JSON property merchant
18632 18633 18634 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18632 def merchant @merchant end |
#reason ⇒ String
Output only. The reason why no products are attached to the campaign.
Corresponds to the JSON property reason
18637 18638 18639 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18637 def reason @reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18644 18645 18646 18647 18648 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18644 def update!(**args) @feed_label = args[:feed_label] if args.key?(:feed_label) @merchant = args[:merchant] if args.key?(:merchant) @reason = args[:reason] if args.key?(:reason) end |