Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingFixDisapprovedProductsRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The shopping recommendation to fix disapproved products in a Shopping Campaign Inventory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationShoppingFixDisapprovedProductsRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationShoppingFixDisapprovedProductsRecommendation.



18676
18677
18678
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18676

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disapproved_products_countFixnum

Output only. The numbers of products of the campaign that are disapproved. Corresponds to the JSON property disapprovedProductsCount

Returns:

  • (Fixnum)


18659
18660
18661
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18659

def disapproved_products_count
  @disapproved_products_count
end

#feed_labelString

Output only. The feed label for the campaign. Corresponds to the JSON property feedLabel

Returns:

  • (String)


18664
18665
18666
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18664

def feed_label
  @feed_label
end

#merchantGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMerchantInfo

The Merchant Center account details. Corresponds to the JSON property merchant



18669
18670
18671
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18669

def merchant
  @merchant
end

#products_countFixnum

Output only. The number of products of the campaign. Corresponds to the JSON property productsCount

Returns:

  • (Fixnum)


18674
18675
18676
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18674

def products_count
  @products_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18681
18682
18683
18684
18685
18686
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18681

def update!(**args)
  @disapproved_products_count = args[:disapproved_products_count] if args.key?(:disapproved_products_count)
  @feed_label = args[:feed_label] if args.key?(:feed_label)
  @merchant = args[:merchant] if args.key?(:merchant)
  @products_count = args[:products_count] if args.key?(:products_count)
end