Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The shopping recommendation to migrate Regular Shopping Campaign targeted offers to Performance Max campaigns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation.



18730
18731
18732
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18730

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feed_labelString

Output only. The feed label of the offers targeted by the campaigns sharing this suggestion. Corresponds to the JSON property feedLabel

Returns:

  • (String)


18723
18724
18725
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18723

def feed_label
  @feed_label
end

#merchantGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMerchantInfo

The Merchant Center account details. Corresponds to the JSON property merchant



18728
18729
18730
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18728

def merchant
  @merchant
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18735
18736
18737
18738
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18735

def update!(**args)
  @feed_label = args[:feed_label] if args.key?(:feed_label)
  @merchant = args[:merchant] if args.key?(:merchant)
end