Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The shopping recommendation to migrate Regular Shopping Campaign targeted offers to Performance Max campaigns.
Instance Attribute Summary collapse
-
#feed_label ⇒ String
Output only.
-
#merchant ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMerchantInfo
The Merchant Center account details.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation
Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationShoppingMigrateRegularShoppingCampaignOffersToPerformanceMaxRecommendation.
18664 18665 18666 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18664 def initialize(**args) update!(**args) end |
Instance Attribute Details
#feed_label ⇒ String
Output only. The feed label of the offers targeted by the campaigns sharing
this suggestion.
Corresponds to the JSON property feedLabel
18657 18658 18659 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18657 def feed_label @feed_label end |
#merchant ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMerchantInfo
The Merchant Center account details.
Corresponds to the JSON property merchant
18662 18663 18664 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18662 def merchant @merchant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18669 18670 18671 18672 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18669 def update!(**args) @feed_label = args[:feed_label] if args.key?(:feed_label) @merchant = args[:merchant] if args.key?(:merchant) end |