Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The shopping recommendation to add an attribute to offers that are demoted because it is missing.
Instance Attribute Summary collapse
-
#demoted_offers_count ⇒ Fixnum
Output only.
-
#feed_label ⇒ String
Output only.
-
#merchant ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMerchantInfo
The Merchant Center account details.
-
#offers_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation
Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation.
18827 18828 18829 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18827 def initialize(**args) update!(**args) end |
Instance Attribute Details
#demoted_offers_count ⇒ Fixnum
Output only. The number of online, servable offers that are demoted for
missing attributes. Visit the Merchant Center for more details.
Corresponds to the JSON property demotedOffersCount
18810 18811 18812 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18810 def demoted_offers_count @demoted_offers_count end |
#feed_label ⇒ String
Output only. The campaign feed label.
Corresponds to the JSON property feedLabel
18815 18816 18817 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18815 def feed_label @feed_label end |
#merchant ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMerchantInfo
The Merchant Center account details.
Corresponds to the JSON property merchant
18820 18821 18822 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18820 def merchant @merchant end |
#offers_count ⇒ Fixnum
Output only. The number of online, servable offers.
Corresponds to the JSON property offersCount
18825 18826 18827 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18825 def offers_count @offers_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18832 18833 18834 18835 18836 18837 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18832 def update!(**args) @demoted_offers_count = args[:demoted_offers_count] if args.key?(:demoted_offers_count) @feed_label = args[:feed_label] if args.key?(:feed_label) @merchant = args[:merchant] if args.key?(:merchant) @offers_count = args[:offers_count] if args.key?(:offers_count) end |