Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The shopping recommendation to add an attribute to offers that are demoted because it is missing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationShoppingOfferAttributeRecommendation.



18701
18702
18703
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18701

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#demoted_offers_countFixnum

Output only. The number of online, servable offers that are demoted for missing attributes. Visit the Merchant Center for more details. Corresponds to the JSON property demotedOffersCount

Returns:

  • (Fixnum)


18684
18685
18686
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18684

def demoted_offers_count
  @demoted_offers_count
end

#feed_labelString

Output only. The campaign feed label. Corresponds to the JSON property feedLabel

Returns:

  • (String)


18689
18690
18691
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18689

def feed_label
  @feed_label
end

#merchantGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationMerchantInfo

The Merchant Center account details. Corresponds to the JSON property merchant



18694
18695
18696
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18694

def merchant
  @merchant
end

#offers_countFixnum

Output only. The number of online, servable offers. Corresponds to the JSON property offersCount

Returns:

  • (Fixnum)


18699
18700
18701
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18699

def offers_count
  @offers_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18706
18707
18708
18709
18710
18711
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18706

def update!(**args)
  @demoted_offers_count = args[:demoted_offers_count] if args.key?(:demoted_offers_count)
  @feed_label = args[:feed_label] if args.key?(:feed_label)
  @merchant = args[:merchant] if args.key?(:merchant)
  @offers_count = args[:offers_count] if args.key?(:offers_count)
end