Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationSubscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Recommendation Subscription resource

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationSubscription

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationSubscription.



33105
33106
33107
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_date_timeString

Output only. Time in seconds when the subscription was first created. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss" format. Corresponds to the JSON property createDateTime

Returns:

  • (String)


33080
33081
33082
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33080

def create_date_time
  @create_date_time
end

#modify_date_timeString

Output only. Contains the time in microseconds, when the Recommendation Subscription was last updated. The datetime is in the customer's time zone and in "yyyy-MM-dd HH:mm:ss.ssssss" format. Corresponds to the JSON property modifyDateTime

Returns:

  • (String)


33087
33088
33089
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33087

def modify_date_time
  @modify_date_time
end

#resource_nameString

Immutable. The resource name of the recommendation subscription. customers/ customer_id/recommendationSubscriptions/recommendation_type` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


33093
33094
33095
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33093

def resource_name
  @resource_name
end

#statusString

Required. Status of the subscription, either enabled or paused. Corresponds to the JSON property status

Returns:

  • (String)


33098
33099
33100
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33098

def status
  @status
end

#typeString

Required. Immutable. The type of recommendation subscribed to. Corresponds to the JSON property type

Returns:

  • (String)


33103
33104
33105
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33103

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33110
33111
33112
33113
33114
33115
33116
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33110

def update!(**args)
  @create_date_time = args[:create_date_time] if args.key?(:create_date_time)
  @modify_date_time = args[:modify_date_time] if args.key?(:modify_date_time)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end