Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetAdjustmentInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetAdjustmentInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Information of a target adjustment recommendation.
Instance Attribute Summary collapse
-
#current_average_target_micros ⇒ Fixnum
Output only.
-
#recommended_target_multiplier ⇒ Float
Output only.
-
#shared_set ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationTargetAdjustmentInfo
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRecommendationTargetAdjustmentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationTargetAdjustmentInfo
Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationTargetAdjustmentInfo.
18859 18860 18861 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18859 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_average_target_micros ⇒ Fixnum
Output only. The current average target of the campaign or portfolio targeted
by this recommendation.
Corresponds to the JSON property currentAverageTargetMicros
18845 18846 18847 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18845 def current_average_target_micros @current_average_target_micros end |
#recommended_target_multiplier ⇒ Float
Output only. The factor by which we recommend the target to be adjusted by.
Corresponds to the JSON property recommendedTargetMultiplier
18850 18851 18852 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18850 def recommended_target_multiplier @recommended_target_multiplier end |
#shared_set ⇒ String
Output only. The shared set resource name of the portfolio bidding strategy
where the target is defined. Only populated if the recommendation is portfolio
level.
Corresponds to the JSON property sharedSet
18857 18858 18859 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18857 def shared_set @shared_set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18864 18865 18866 18867 18868 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18864 def update!(**args) @current_average_target_micros = args[:current_average_target_micros] if args.key?(:current_average_target_micros) @recommended_target_multiplier = args[:recommended_target_multiplier] if args.key?(:recommended_target_multiplier) @shared_set = args[:shared_set] if args.key?(:shared_set) end |