Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetAdjustmentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Information of a target adjustment recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationTargetAdjustmentInfo

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationTargetAdjustmentInfo.



18793
18794
18795
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_average_target_microsFixnum

Output only. The current average target of the campaign or portfolio targeted by this recommendation. Corresponds to the JSON property currentAverageTargetMicros

Returns:

  • (Fixnum)


18779
18780
18781
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18779

def current_average_target_micros
  @current_average_target_micros
end

Output only. The factor by which we recommend the target to be adjusted by. Corresponds to the JSON property recommendedTargetMultiplier

Returns:

  • (Float)


18784
18785
18786
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18784

def recommended_target_multiplier
  @recommended_target_multiplier
end

#shared_setString

Output only. The shared set resource name of the portfolio bidding strategy where the target is defined. Only populated if the recommendation is portfolio level. Corresponds to the JSON property sharedSet

Returns:

  • (String)


18791
18792
18793
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18791

def shared_set
  @shared_set
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18798
18799
18800
18801
18802
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18798

def update!(**args)
  @current_average_target_micros = args[:current_average_target_micros] if args.key?(:current_average_target_micros)
  @recommended_target_multiplier = args[:recommended_target_multiplier] if args.key?(:recommended_target_multiplier)
  @shared_set = args[:shared_set] if args.key?(:shared_set)
end