Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The Target CPA opt-in recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendation.



18887
18888
18889
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#optionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendationTargetCpaOptInRecommendationOption>

Output only. The available goals and corresponding options for Target CPA strategy. Corresponds to the JSON property options



18879
18880
18881
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18879

def options
  @options
end

Output only. The recommended average CPA target. See required budget amount and impact of using this recommendation in options list. Corresponds to the JSON property recommendedTargetCpaMicros

Returns:

  • (Fixnum)


18885
18886
18887
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18885

def recommended_target_cpa_micros
  @recommended_target_cpa_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18892
18893
18894
18895
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18892

def update!(**args)
  @options = args[:options] if args.key?(:options)
  @recommended_target_cpa_micros = args[:recommended_target_cpa_micros] if args.key?(:recommended_target_cpa_micros)
end