Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendationTargetCpaOptInRecommendationOption
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendationTargetCpaOptInRecommendationOption
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The Target CPA opt-in option with impact estimate.
Instance Attribute Summary collapse
-
#goal ⇒ String
Output only.
-
#impact ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationImpact
The impact of making the change as described in the recommendation.
-
#required_campaign_budget_amount_micros ⇒ Fixnum
Output only.
-
#target_cpa_micros ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendationTargetCpaOptInRecommendationOption
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendationTargetCpaOptInRecommendationOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendationTargetCpaOptInRecommendationOption
Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendationTargetCpaOptInRecommendationOption.
17773 17774 17775 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17773 def initialize(**args) update!(**args) end |
Instance Attribute Details
#goal ⇒ String
Output only. The goal achieved by this option.
Corresponds to the JSON property goal
17753 17754 17755 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17753 def goal @goal end |
#impact ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationImpact
The impact of making the change as described in the recommendation. Some types
of recommendations may not have impact information.
Corresponds to the JSON property impact
17759 17760 17761 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17759 def impact @impact end |
#required_campaign_budget_amount_micros ⇒ Fixnum
Output only. The minimum campaign budget, in local currency for the account,
required to achieve the target CPA. Amount is specified in micros, where one
million is equivalent to one currency unit.
Corresponds to the JSON property requiredCampaignBudgetAmountMicros
17766 17767 17768 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17766 def required_campaign_budget_amount_micros @required_campaign_budget_amount_micros end |
#target_cpa_micros ⇒ Fixnum
Output only. Average CPA target.
Corresponds to the JSON property targetCpaMicros
17771 17772 17773 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17771 def target_cpa_micros @target_cpa_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17778 17779 17780 17781 17782 17783 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17778 def update!(**args) @goal = args[:goal] if args.key?(:goal) @impact = args[:impact] if args.key?(:impact) @required_campaign_budget_amount_micros = args[:required_campaign_budget_amount_micros] if args.key?(:required_campaign_budget_amount_micros) @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros) end |