Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendationTargetCpaOptInRecommendationOption
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendationTargetCpaOptInRecommendationOption
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The Target CPA opt-in option with impact estimate.
Instance Attribute Summary collapse
-
#goal ⇒ String
Output only.
-
#impact ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationImpact
The impact of making the change as described in the recommendation.
-
#required_campaign_budget_amount_micros ⇒ Fixnum
Output only.
-
#target_cpa_micros ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendationTargetCpaOptInRecommendationOption
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendationTargetCpaOptInRecommendationOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendationTargetCpaOptInRecommendationOption
Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationTargetCpaOptInRecommendationTargetCpaOptInRecommendationOption.
17707 17708 17709 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17707 def initialize(**args) update!(**args) end |
Instance Attribute Details
#goal ⇒ String
Output only. The goal achieved by this option.
Corresponds to the JSON property goal
17687 17688 17689 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17687 def goal @goal end |
#impact ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationRecommendationImpact
The impact of making the change as described in the recommendation. Some types
of recommendations may not have impact information.
Corresponds to the JSON property impact
17693 17694 17695 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17693 def impact @impact end |
#required_campaign_budget_amount_micros ⇒ Fixnum
Output only. The minimum campaign budget, in local currency for the account,
required to achieve the target CPA. Amount is specified in micros, where one
million is equivalent to one currency unit.
Corresponds to the JSON property requiredCampaignBudgetAmountMicros
17700 17701 17702 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17700 def required_campaign_budget_amount_micros @required_campaign_budget_amount_micros end |
#target_cpa_micros ⇒ Fixnum
Output only. Average CPA target.
Corresponds to the JSON property targetCpaMicros
17705 17706 17707 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17705 def target_cpa_micros @target_cpa_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17712 17713 17714 17715 17716 17717 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 17712 def update!(**args) @goal = args[:goal] if args.key?(:goal) @impact = args[:impact] if args.key?(:impact) @required_campaign_budget_amount_micros = args[:required_campaign_budget_amount_micros] if args.key?(:required_campaign_budget_amount_micros) @target_cpa_micros = args[:target_cpa_micros] if args.key?(:target_cpa_micros) end |