Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendationUseBroadMatchKeywordRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The use broad match keyword recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRecommendationUseBroadMatchKeywordRecommendation

Returns a new instance of GoogleAdsSearchads360V23ResourcesRecommendationUseBroadMatchKeywordRecommendation.



18965
18966
18967
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaign_keywords_countFixnum

Output only. Total number of keywords in the campaign. Corresponds to the JSON property campaignKeywordsCount

Returns:

  • (Fixnum)


18940
18941
18942
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18940

def campaign_keywords_count
  @campaign_keywords_count
end

#campaign_uses_shared_budgetBoolean Also known as: campaign_uses_shared_budget?

Output only. Whether the associated campaign uses a shared budget. Corresponds to the JSON property campaignUsesSharedBudget

Returns:

  • (Boolean)


18945
18946
18947
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18945

def campaign_uses_shared_budget
  @campaign_uses_shared_budget
end

#keywordArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo>

Output only. Sample of keywords to be expanded to Broad Match. Corresponds to the JSON property keyword



18951
18952
18953
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18951

def keyword
  @keyword
end

#required_campaign_budget_amount_microsFixnum

Output only. The budget recommended to avoid becoming budget constrained after applying the recommendation. Corresponds to the JSON property requiredCampaignBudgetAmountMicros

Returns:

  • (Fixnum)


18957
18958
18959
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18957

def required_campaign_budget_amount_micros
  @required_campaign_budget_amount_micros
end

#suggested_keywords_countFixnum

Output only. Total number of keywords to be expanded to Broad Match in the campaign. Corresponds to the JSON property suggestedKeywordsCount

Returns:

  • (Fixnum)


18963
18964
18965
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18963

def suggested_keywords_count
  @suggested_keywords_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18970
18971
18972
18973
18974
18975
18976
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18970

def update!(**args)
  @campaign_keywords_count = args[:campaign_keywords_count] if args.key?(:campaign_keywords_count)
  @campaign_uses_shared_budget = args[:campaign_uses_shared_budget] if args.key?(:campaign_uses_shared_budget)
  @keyword = args[:keyword] if args.key?(:keyword)
  @required_campaign_budget_amount_micros = args[:required_campaign_budget_amount_micros] if args.key?(:required_campaign_budget_amount_micros)
  @suggested_keywords_count = args[:suggested_keywords_count] if args.key?(:suggested_keywords_count)
end