Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRemarketingAction
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRemarketingAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A remarketing action. A snippet of JavaScript code that will collect the product id and the type of page people visited (product page, shopping cart page, purchase page, general site visit) on an advertiser's website.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#name ⇒ String
The name of the remarketing action.
-
#resource_name ⇒ String
Immutable.
-
#tag_snippets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTagSnippet>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRemarketingAction
constructor
A new instance of GoogleAdsSearchads360V23ResourcesRemarketingAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRemarketingAction
Returns a new instance of GoogleAdsSearchads360V23ResourcesRemarketingAction.
33250 33251 33252 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33250 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. Id of the remarketing action.
Corresponds to the JSON property id
33230 33231 33232 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33230 def id @id end |
#name ⇒ String
The name of the remarketing action. This field is required and should not be
empty when creating new remarketing actions.
Corresponds to the JSON property name
33236 33237 33238 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33236 def name @name end |
#resource_name ⇒ String
Immutable. The resource name of the remarketing action. Remarketing action
resource names have the form: customers/customer_id/remarketingActions/
remarketing_action_id`
Corresponds to the JSON propertyresourceName`
33243 33244 33245 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33243 def resource_name @resource_name end |
#tag_snippets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTagSnippet>
Output only. The snippets used for tracking remarketing actions.
Corresponds to the JSON property tagSnippets
33248 33249 33250 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33248 def tag_snippets @tag_snippets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33255 33256 33257 33258 33259 33260 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33255 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @tag_snippets = args[:tag_snippets] if args.key?(:tag_snippets) end |