Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRemarketingAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A remarketing action. A snippet of JavaScript code that will collect the product id and the type of page people visited (product page, shopping cart page, purchase page, general site visit) on an advertiser's website.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesRemarketingAction

Returns a new instance of GoogleAdsSearchads360V23ResourcesRemarketingAction.



33148
33149
33150
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33148

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Output only. Id of the remarketing action. Corresponds to the JSON property id

Returns:

  • (Fixnum)


33128
33129
33130
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33128

def id
  @id
end

#nameString

The name of the remarketing action. This field is required and should not be empty when creating new remarketing actions. Corresponds to the JSON property name

Returns:

  • (String)


33134
33135
33136
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33134

def name
  @name
end

#resource_nameString

Immutable. The resource name of the remarketing action. Remarketing action resource names have the form: customers/customer_id/remarketingActions/ remarketing_action_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


33141
33142
33143
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33141

def resource_name
  @resource_name
end

#tag_snippetsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonTagSnippet>

Output only. The snippets used for tracking remarketing actions. Corresponds to the JSON property tagSnippets



33146
33147
33148
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33146

def tag_snippets
  @tag_snippets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33153
33154
33155
33156
33157
33158
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33153

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @tag_snippets = args[:tag_snippets] if args.key?(:tag_snippets)
end