Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesResidency
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesResidency
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Details about the employee's medical residency. Residency is a stage of graduate medical education in which a qualified medical professional practices under the supervision of a senior clinician.
Instance Attribute Summary collapse
-
#completion_year ⇒ Fixnum
Output only.
-
#institution_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesResidency
constructor
A new instance of GoogleAdsSearchads360V23ResourcesResidency.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesResidency
Returns a new instance of GoogleAdsSearchads360V23ResourcesResidency.
33298 33299 33300 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completion_year ⇒ Fixnum
Output only. Year of completion.
Corresponds to the JSON property completionYear
33291 33292 33293 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33291 def completion_year @completion_year end |
#institution_name ⇒ String
Output only. Name of the institution at which the residency was completed.
Corresponds to the JSON property institutionName
33296 33297 33298 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33296 def institution_name @institution_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33303 33304 33305 33306 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33303 def update!(**args) @completion_year = args[:completion_year] if args.key?(:completion_year) @institution_name = args[:institution_name] if args.key?(:institution_name) end |