Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesResidency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Details about the employee's medical residency. Residency is a stage of graduate medical education in which a qualified medical professional practices under the supervision of a senior clinician.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesResidency

Returns a new instance of GoogleAdsSearchads360V23ResourcesResidency.



33196
33197
33198
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33196

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completion_yearFixnum

Output only. Year of completion. Corresponds to the JSON property completionYear

Returns:

  • (Fixnum)


33189
33190
33191
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33189

def completion_year
  @completion_year
end

#institution_nameString

Output only. Name of the institution at which the residency was completed. Corresponds to the JSON property institutionName

Returns:

  • (String)


33194
33195
33196
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33194

def institution_name
  @institution_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33201
33202
33203
33204
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33201

def update!(**args)
  @completion_year = args[:completion_year] if args.key?(:completion_year)
  @institution_name = args[:institution_name] if args.key?(:institution_name)
end