Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSearchAds360Field
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSearchAds360Field
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A field or resource (artifact) used by SearchAds360Service.
Instance Attribute Summary collapse
-
#attribute_resources ⇒ Array<String>
Output only.
-
#category ⇒ String
Output only.
-
#data_type ⇒ String
Output only.
-
#enum_values ⇒ Array<String>
Output only.
-
#filterable ⇒ Boolean
(also: #filterable?)
Output only.
-
#is_repeated ⇒ Boolean
(also: #is_repeated?)
Output only.
-
#metrics ⇒ Array<String>
Output only.
-
#name ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#segments ⇒ Array<String>
Output only.
-
#selectable ⇒ Boolean
(also: #selectable?)
Output only.
-
#selectable_with ⇒ Array<String>
Output only.
-
#sortable ⇒ Boolean
(also: #sortable?)
Output only.
-
#type_url ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSearchAds360Field
constructor
A new instance of GoogleAdsSearchads360V23ResourcesSearchAds360Field.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSearchAds360Field
Returns a new instance of GoogleAdsSearchads360V23ResourcesSearchAds360Field.
33429 33430 33431 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33429 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribute_resources ⇒ Array<String>
Output only. The names of all resources that are selectable with the described
artifact. Fields from these resources do not segment metrics when included in
search queries. This field is only set for artifacts whose category is
RESOURCE.
Corresponds to the JSON property attributeResources
33346 33347 33348 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33346 def attribute_resources @attribute_resources end |
#category ⇒ String
Output only. The category of the artifact.
Corresponds to the JSON property category
33351 33352 33353 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33351 def category @category end |
#data_type ⇒ String
Output only. This field determines the operators that can be used with the
artifact in WHERE clauses.
Corresponds to the JSON property dataType
33357 33358 33359 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33357 def data_type @data_type end |
#enum_values ⇒ Array<String>
Output only. Values the artifact can assume if it is a field of type ENUM.
This field is only set for artifacts of category SEGMENT or ATTRIBUTE.
Corresponds to the JSON property enumValues
33363 33364 33365 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33363 def enum_values @enum_values end |
#filterable ⇒ Boolean Also known as: filterable?
Output only. Whether the artifact can be used in a WHERE clause in search
queries.
Corresponds to the JSON property filterable
33369 33370 33371 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33369 def filterable @filterable end |
#is_repeated ⇒ Boolean Also known as: is_repeated?
Output only. Whether the field artifact is repeated.
Corresponds to the JSON property isRepeated
33375 33376 33377 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33375 def is_repeated @is_repeated end |
#metrics ⇒ Array<String>
Output only. This field lists the names of all metrics that are selectable
with the described artifact when it is used in the FROM clause. It is only set
for artifacts whose category is RESOURCE.
Corresponds to the JSON property metrics
33383 33384 33385 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33383 def metrics @metrics end |
#name ⇒ String
Output only. The name of the artifact.
Corresponds to the JSON property name
33388 33389 33390 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33388 def name @name end |
#resource_name ⇒ String
Output only. The resource name of the artifact. Artifact resource names have
the form: SearchAds360Fields/name`
Corresponds to the JSON propertyresourceName`
33394 33395 33396 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33394 def resource_name @resource_name end |
#segments ⇒ Array<String>
Output only. This field lists the names of all artifacts, whether a segment or
another resource, that segment metrics when included in search queries and
when the described artifact is used in the FROM clause. It is only set for
artifacts whose category is RESOURCE.
Corresponds to the JSON property segments
33402 33403 33404 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33402 def segments @segments end |
#selectable ⇒ Boolean Also known as: selectable?
Output only. Whether the artifact can be used in a SELECT clause in search
queries.
Corresponds to the JSON property selectable
33408 33409 33410 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33408 def selectable @selectable end |
#selectable_with ⇒ Array<String>
Output only. The names of all resources, segments, and metrics that are
selectable with the described artifact.
Corresponds to the JSON property selectableWith
33415 33416 33417 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33415 def selectable_with @selectable_with end |
#sortable ⇒ Boolean Also known as: sortable?
Output only. Whether the artifact can be used in a ORDER BY clause in search
queries.
Corresponds to the JSON property sortable
33421 33422 33423 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33421 def sortable @sortable end |
#type_url ⇒ String
Output only. The URL of proto describing the artifact's data type.
Corresponds to the JSON property typeUrl
33427 33428 33429 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33427 def type_url @type_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33434 33435 33436 33437 33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33434 def update!(**args) @attribute_resources = args[:attribute_resources] if args.key?(:attribute_resources) @category = args[:category] if args.key?(:category) @data_type = args[:data_type] if args.key?(:data_type) @enum_values = args[:enum_values] if args.key?(:enum_values) @filterable = args[:filterable] if args.key?(:filterable) @is_repeated = args[:is_repeated] if args.key?(:is_repeated) @metrics = args[:metrics] if args.key?(:metrics) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @segments = args[:segments] if args.key?(:segments) @selectable = args[:selectable] if args.key?(:selectable) @selectable_with = args[:selectable_with] if args.key?(:selectable_with) @sortable = args[:sortable] if args.key?(:sortable) @type_url = args[:type_url] if args.key?(:type_url) end |