Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSearchAds360Field
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSearchAds360Field
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A field or resource (artifact) used by SearchAds360Service.
Instance Attribute Summary collapse
-
#attribute_resources ⇒ Array<String>
Output only.
-
#category ⇒ String
Output only.
-
#data_type ⇒ String
Output only.
-
#enum_values ⇒ Array<String>
Output only.
-
#filterable ⇒ Boolean
(also: #filterable?)
Output only.
-
#is_repeated ⇒ Boolean
(also: #is_repeated?)
Output only.
-
#metrics ⇒ Array<String>
Output only.
-
#name ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#segments ⇒ Array<String>
Output only.
-
#selectable ⇒ Boolean
(also: #selectable?)
Output only.
-
#selectable_with ⇒ Array<String>
Output only.
-
#sortable ⇒ Boolean
(also: #sortable?)
Output only.
-
#type_url ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSearchAds360Field
constructor
A new instance of GoogleAdsSearchads360V23ResourcesSearchAds360Field.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSearchAds360Field
Returns a new instance of GoogleAdsSearchads360V23ResourcesSearchAds360Field.
33327 33328 33329 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33327 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribute_resources ⇒ Array<String>
Output only. The names of all resources that are selectable with the described
artifact. Fields from these resources do not segment metrics when included in
search queries. This field is only set for artifacts whose category is
RESOURCE.
Corresponds to the JSON property attributeResources
33244 33245 33246 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33244 def attribute_resources @attribute_resources end |
#category ⇒ String
Output only. The category of the artifact.
Corresponds to the JSON property category
33249 33250 33251 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33249 def category @category end |
#data_type ⇒ String
Output only. This field determines the operators that can be used with the
artifact in WHERE clauses.
Corresponds to the JSON property dataType
33255 33256 33257 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33255 def data_type @data_type end |
#enum_values ⇒ Array<String>
Output only. Values the artifact can assume if it is a field of type ENUM.
This field is only set for artifacts of category SEGMENT or ATTRIBUTE.
Corresponds to the JSON property enumValues
33261 33262 33263 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33261 def enum_values @enum_values end |
#filterable ⇒ Boolean Also known as: filterable?
Output only. Whether the artifact can be used in a WHERE clause in search
queries.
Corresponds to the JSON property filterable
33267 33268 33269 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33267 def filterable @filterable end |
#is_repeated ⇒ Boolean Also known as: is_repeated?
Output only. Whether the field artifact is repeated.
Corresponds to the JSON property isRepeated
33273 33274 33275 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33273 def is_repeated @is_repeated end |
#metrics ⇒ Array<String>
Output only. This field lists the names of all metrics that are selectable
with the described artifact when it is used in the FROM clause. It is only set
for artifacts whose category is RESOURCE.
Corresponds to the JSON property metrics
33281 33282 33283 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33281 def metrics @metrics end |
#name ⇒ String
Output only. The name of the artifact.
Corresponds to the JSON property name
33286 33287 33288 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33286 def name @name end |
#resource_name ⇒ String
Output only. The resource name of the artifact. Artifact resource names have
the form: SearchAds360Fields/name`
Corresponds to the JSON propertyresourceName`
33292 33293 33294 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33292 def resource_name @resource_name end |
#segments ⇒ Array<String>
Output only. This field lists the names of all artifacts, whether a segment or
another resource, that segment metrics when included in search queries and
when the described artifact is used in the FROM clause. It is only set for
artifacts whose category is RESOURCE.
Corresponds to the JSON property segments
33300 33301 33302 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33300 def segments @segments end |
#selectable ⇒ Boolean Also known as: selectable?
Output only. Whether the artifact can be used in a SELECT clause in search
queries.
Corresponds to the JSON property selectable
33306 33307 33308 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33306 def selectable @selectable end |
#selectable_with ⇒ Array<String>
Output only. The names of all resources, segments, and metrics that are
selectable with the described artifact.
Corresponds to the JSON property selectableWith
33313 33314 33315 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33313 def selectable_with @selectable_with end |
#sortable ⇒ Boolean Also known as: sortable?
Output only. Whether the artifact can be used in a ORDER BY clause in search
queries.
Corresponds to the JSON property sortable
33319 33320 33321 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33319 def sortable @sortable end |
#type_url ⇒ String
Output only. The URL of proto describing the artifact's data type.
Corresponds to the JSON property typeUrl
33325 33326 33327 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33325 def type_url @type_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33332 33333 33334 33335 33336 33337 33338 33339 33340 33341 33342 33343 33344 33345 33346 33347 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33332 def update!(**args) @attribute_resources = args[:attribute_resources] if args.key?(:attribute_resources) @category = args[:category] if args.key?(:category) @data_type = args[:data_type] if args.key?(:data_type) @enum_values = args[:enum_values] if args.key?(:enum_values) @filterable = args[:filterable] if args.key?(:filterable) @is_repeated = args[:is_repeated] if args.key?(:is_repeated) @metrics = args[:metrics] if args.key?(:metrics) @name = args[:name] if args.key?(:name) @resource_name = args[:resource_name] if args.key?(:resource_name) @segments = args[:segments] if args.key?(:segments) @selectable = args[:selectable] if args.key?(:selectable) @selectable_with = args[:selectable_with] if args.key?(:selectable_with) @sortable = args[:sortable] if args.key?(:sortable) @type_url = args[:type_url] if args.key?(:type_url) end |