Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSearchTermView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A search term view with metrics aggregated by search term at the ad group level. This view does not include Performance Max data. If you are looking for Performance Max search term data, use the CampaignSearchTermView instead.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSearchTermView

Returns a new instance of GoogleAdsSearchads360V23ResourcesSearchTermView.



33481
33482
33483
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33481

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupString

Output only. The ad group the search term served in. Corresponds to the JSON property adGroup

Returns:

  • (String)


33461
33462
33463
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33461

def ad_group
  @ad_group
end

#resource_nameString

Output only. The resource name of the search term view. Search term view resource names have the form: customers/customer_id/searchTermViews/ campaign_id~ad_group_id~URL-base64_search_term` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


33468
33469
33470
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33468

def resource_name
  @resource_name
end

#search_termString

Output only. The search term. Corresponds to the JSON property searchTerm

Returns:

  • (String)


33473
33474
33475
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33473

def search_term
  @search_term
end

#statusString

Output only. Indicates whether the search term is currently one of your targeted or excluded keywords. Corresponds to the JSON property status

Returns:

  • (String)


33479
33480
33481
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33479

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33486
33487
33488
33489
33490
33491
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33486

def update!(**args)
  @ad_group = args[:ad_group] if args.key?(:ad_group)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @search_term = args[:search_term] if args.key?(:search_term)
  @status = args[:status] if args.key?(:status)
end