Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSearchTermView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSearchTermView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A search term view with metrics aggregated by search term at the ad group level. This view does not include Performance Max data. If you are looking for Performance Max search term data, use the CampaignSearchTermView instead.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#search_term ⇒ String
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSearchTermView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesSearchTermView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSearchTermView
Returns a new instance of GoogleAdsSearchads360V23ResourcesSearchTermView.
33379 33380 33381 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Output only. The ad group the search term served in.
Corresponds to the JSON property adGroup
33359 33360 33361 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33359 def ad_group @ad_group end |
#resource_name ⇒ String
Output only. The resource name of the search term view. Search term view
resource names have the form: customers/customer_id/searchTermViews/
campaign_id~ad_group_id~URL-base64_search_term`
Corresponds to the JSON propertyresourceName`
33366 33367 33368 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33366 def resource_name @resource_name end |
#search_term ⇒ String
Output only. The search term.
Corresponds to the JSON property searchTerm
33371 33372 33373 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33371 def search_term @search_term end |
#status ⇒ String
Output only. Indicates whether the search term is currently one of your
targeted or excluded keywords.
Corresponds to the JSON property status
33377 33378 33379 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33377 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33384 33385 33386 33387 33388 33389 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33384 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @resource_name = args[:resource_name] if args.key?(:resource_name) @search_term = args[:search_term] if args.key?(:search_term) @status = args[:status] if args.key?(:status) end |