Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedCriterion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedCriterion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A criterion belonging to a shared set.
Instance Attribute Summary collapse
-
#brand ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandInfo
Represents a Brand Criterion used for targeting based on commercial knowledge graph.
-
#criterion_id ⇒ Fixnum
Output only.
-
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo
A keyword criterion.
-
#mobile_app_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo
A mobile app category criterion.
-
#mobile_application ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo
A mobile application criterion.
-
#negative ⇒ Boolean
(also: #negative?)
Immutable.
-
#placement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo
A placement criterion.
-
#resource_name ⇒ String
Immutable.
-
#shared_set ⇒ String
Immutable.
-
#type ⇒ String
Output only.
-
#vertical_ads_item_group_rule ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo
A criterion to represent a single item group rule in Vertical Ads.
-
#webpage ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageInfo
Represents a criterion for targeting webpages of an advertiser's website.
-
#youtube_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
A YouTube Channel criterion.
-
#youtube_video ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
A YouTube Video criterion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSharedCriterion
constructor
A new instance of GoogleAdsSearchads360V23ResourcesSharedCriterion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSharedCriterion
Returns a new instance of GoogleAdsSearchads360V23ResourcesSharedCriterion.
33574 33575 33576 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33574 def initialize(**args) update!(**args) end |
Instance Attribute Details
#brand ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandInfo
Represents a Brand Criterion used for targeting based on commercial knowledge
graph.
Corresponds to the JSON property brand
33502 33503 33504 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33502 def brand @brand end |
#criterion_id ⇒ Fixnum
Output only. The ID of the criterion. This field is ignored for mutates.
Corresponds to the JSON property criterionId
33507 33508 33509 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33507 def criterion_id @criterion_id end |
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo
A keyword criterion.
Corresponds to the JSON property keyword
33512 33513 33514 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33512 def keyword @keyword end |
#mobile_app_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo
A mobile app category criterion.
Corresponds to the JSON property mobileAppCategory
33517 33518 33519 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33517 def mobile_app_category @mobile_app_category end |
#mobile_application ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo
A mobile application criterion.
Corresponds to the JSON property mobileApplication
33522 33523 33524 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33522 def mobile_application @mobile_application end |
#negative ⇒ Boolean Also known as: negative?
Immutable. If true, the criterion is excluded. If false, the criterion is
targeted.
Corresponds to the JSON property negative
33528 33529 33530 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33528 def negative @negative end |
#placement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo
A placement criterion. This can be used to modify bids for sites when
targeting the content network.
Corresponds to the JSON property placement
33535 33536 33537 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33535 def placement @placement end |
#resource_name ⇒ String
Immutable. The resource name of the shared criterion. Shared set resource
names have the form: customers/customer_id/sharedCriteria/shared_set_id~
criterion_id`
Corresponds to the JSON propertyresourceName`
33542 33543 33544 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33542 def resource_name @resource_name end |
#shared_set ⇒ String
Immutable. The shared set to which the shared criterion belongs.
Corresponds to the JSON property sharedSet
33547 33548 33549 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33547 def shared_set @shared_set end |
#type ⇒ String
Output only. The type of the criterion.
Corresponds to the JSON property type
33552 33553 33554 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33552 def type @type end |
#vertical_ads_item_group_rule ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo
A criterion to represent a single item group rule in Vertical Ads.
Corresponds to the JSON property verticalAdsItemGroupRule
33557 33558 33559 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33557 def vertical_ads_item_group_rule @vertical_ads_item_group_rule end |
#webpage ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageInfo
Represents a criterion for targeting webpages of an advertiser's website.
Corresponds to the JSON property webpage
33562 33563 33564 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33562 def webpage @webpage end |
#youtube_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
A YouTube Channel criterion.
Corresponds to the JSON property youtubeChannel
33567 33568 33569 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33567 def youtube_channel @youtube_channel end |
#youtube_video ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
A YouTube Video criterion.
Corresponds to the JSON property youtubeVideo
33572 33573 33574 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33572 def youtube_video @youtube_video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33579 33580 33581 33582 33583 33584 33585 33586 33587 33588 33589 33590 33591 33592 33593 33594 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33579 def update!(**args) @brand = args[:brand] if args.key?(:brand) @criterion_id = args[:criterion_id] if args.key?(:criterion_id) @keyword = args[:keyword] if args.key?(:keyword) @mobile_app_category = args[:mobile_app_category] if args.key?(:mobile_app_category) @mobile_application = args[:mobile_application] if args.key?(:mobile_application) @negative = args[:negative] if args.key?(:negative) @placement = args[:placement] if args.key?(:placement) @resource_name = args[:resource_name] if args.key?(:resource_name) @shared_set = args[:shared_set] if args.key?(:shared_set) @type = args[:type] if args.key?(:type) @vertical_ads_item_group_rule = args[:vertical_ads_item_group_rule] if args.key?(:vertical_ads_item_group_rule) @webpage = args[:webpage] if args.key?(:webpage) @youtube_channel = args[:youtube_channel] if args.key?(:youtube_channel) @youtube_video = args[:youtube_video] if args.key?(:youtube_video) end |