Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedCriterion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedCriterion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A criterion belonging to a shared set.
Instance Attribute Summary collapse
-
#brand ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandInfo
Represents a Brand Criterion used for targeting based on commercial knowledge graph.
-
#criterion_id ⇒ Fixnum
Output only.
-
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo
A keyword criterion.
-
#mobile_app_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo
A mobile app category criterion.
-
#mobile_application ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo
A mobile application criterion.
-
#negative ⇒ Boolean
(also: #negative?)
Immutable.
-
#placement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo
A placement criterion.
-
#resource_name ⇒ String
Immutable.
-
#shared_set ⇒ String
Immutable.
-
#type ⇒ String
Output only.
-
#vertical_ads_item_group_rule ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo
A criterion to represent a single item group rule in Vertical Ads.
-
#webpage ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageInfo
Represents a criterion for targeting webpages of an advertiser's website.
-
#youtube_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
A YouTube Channel criterion.
-
#youtube_video ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
A YouTube Video criterion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSharedCriterion
constructor
A new instance of GoogleAdsSearchads360V23ResourcesSharedCriterion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSharedCriterion
Returns a new instance of GoogleAdsSearchads360V23ResourcesSharedCriterion.
33472 33473 33474 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33472 def initialize(**args) update!(**args) end |
Instance Attribute Details
#brand ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBrandInfo
Represents a Brand Criterion used for targeting based on commercial knowledge
graph.
Corresponds to the JSON property brand
33400 33401 33402 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33400 def brand @brand end |
#criterion_id ⇒ Fixnum
Output only. The ID of the criterion. This field is ignored for mutates.
Corresponds to the JSON property criterionId
33405 33406 33407 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33405 def criterion_id @criterion_id end |
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo
A keyword criterion.
Corresponds to the JSON property keyword
33410 33411 33412 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33410 def keyword @keyword end |
#mobile_app_category ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileAppCategoryInfo
A mobile app category criterion.
Corresponds to the JSON property mobileAppCategory
33415 33416 33417 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33415 def mobile_app_category @mobile_app_category end |
#mobile_application ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonMobileApplicationInfo
A mobile application criterion.
Corresponds to the JSON property mobileApplication
33420 33421 33422 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33420 def mobile_application @mobile_application end |
#negative ⇒ Boolean Also known as: negative?
Immutable. If true, the criterion is excluded. If false, the criterion is
targeted.
Corresponds to the JSON property negative
33426 33427 33428 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33426 def negative @negative end |
#placement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPlacementInfo
A placement criterion. This can be used to modify bids for sites when
targeting the content network.
Corresponds to the JSON property placement
33433 33434 33435 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33433 def placement @placement end |
#resource_name ⇒ String
Immutable. The resource name of the shared criterion. Shared set resource
names have the form: customers/customer_id/sharedCriteria/shared_set_id~
criterion_id`
Corresponds to the JSON propertyresourceName`
33440 33441 33442 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33440 def resource_name @resource_name end |
#shared_set ⇒ String
Immutable. The shared set to which the shared criterion belongs.
Corresponds to the JSON property sharedSet
33445 33446 33447 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33445 def shared_set @shared_set end |
#type ⇒ String
Output only. The type of the criterion.
Corresponds to the JSON property type
33450 33451 33452 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33450 def type @type end |
#vertical_ads_item_group_rule ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonVerticalAdsItemGroupRuleInfo
A criterion to represent a single item group rule in Vertical Ads.
Corresponds to the JSON property verticalAdsItemGroupRule
33455 33456 33457 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33455 def vertical_ads_item_group_rule @vertical_ads_item_group_rule end |
#webpage ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonWebpageInfo
Represents a criterion for targeting webpages of an advertiser's website.
Corresponds to the JSON property webpage
33460 33461 33462 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33460 def webpage @webpage end |
#youtube_channel ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeChannelInfo
A YouTube Channel criterion.
Corresponds to the JSON property youtubeChannel
33465 33466 33467 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33465 def youtube_channel @youtube_channel end |
#youtube_video ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonYouTubeVideoInfo
A YouTube Video criterion.
Corresponds to the JSON property youtubeVideo
33470 33471 33472 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33470 def youtube_video @youtube_video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33477 33478 33479 33480 33481 33482 33483 33484 33485 33486 33487 33488 33489 33490 33491 33492 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33477 def update!(**args) @brand = args[:brand] if args.key?(:brand) @criterion_id = args[:criterion_id] if args.key?(:criterion_id) @keyword = args[:keyword] if args.key?(:keyword) @mobile_app_category = args[:mobile_app_category] if args.key?(:mobile_app_category) @mobile_application = args[:mobile_application] if args.key?(:mobile_application) @negative = args[:negative] if args.key?(:negative) @placement = args[:placement] if args.key?(:placement) @resource_name = args[:resource_name] if args.key?(:resource_name) @shared_set = args[:shared_set] if args.key?(:shared_set) @type = args[:type] if args.key?(:type) @vertical_ads_item_group_rule = args[:vertical_ads_item_group_rule] if args.key?(:vertical_ads_item_group_rule) @webpage = args[:webpage] if args.key?(:webpage) @youtube_channel = args[:youtube_channel] if args.key?(:youtube_channel) @youtube_video = args[:youtube_video] if args.key?(:youtube_video) end |