Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedSet
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
SharedSets are used for sharing criterion exclusions across multiple campaigns.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#member_count ⇒ Fixnum
Output only.
-
#name ⇒ String
The name of this shared set.
-
#reference_count ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#type ⇒ String
Immutable.
-
#vertical_ads_item_vertical_type ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSharedSet
constructor
A new instance of GoogleAdsSearchads360V23ResourcesSharedSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSharedSet
Returns a new instance of GoogleAdsSearchads360V23ResourcesSharedSet.
33649 33650 33651 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. The ID of this shared set. Read only.
Corresponds to the JSON property id
33604 33605 33606 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33604 def id @id end |
#member_count ⇒ Fixnum
Output only. The number of shared criteria within this shared set. Read only.
Corresponds to the JSON property memberCount
33609 33610 33611 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33609 def member_count @member_count end |
#name ⇒ String
The name of this shared set. Required. Shared Sets must have names that are
unique among active shared sets of the same type. The length of this string
should be between 1 and 255 UTF-8 bytes, inclusive.
Corresponds to the JSON property name
33616 33617 33618 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33616 def name @name end |
#reference_count ⇒ Fixnum
Output only. The number of campaigns associated with this shared set. Read
only.
Corresponds to the JSON property referenceCount
33622 33623 33624 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33622 def reference_count @reference_count end |
#resource_name ⇒ String
Immutable. The resource name of the shared set. Shared set resource names have
the form: customers/customer_id/sharedSets/shared_set_id`
Corresponds to the JSON propertyresourceName`
33628 33629 33630 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33628 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of this shared set. Read only.
Corresponds to the JSON property status
33633 33634 33635 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33633 def status @status end |
#type ⇒ String
Immutable. The type of this shared set: each shared set holds only a single
kind of resource. Required. Immutable.
Corresponds to the JSON property type
33639 33640 33641 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33639 def type @type end |
#vertical_ads_item_vertical_type ⇒ String
Immutable. Shared sets of type VERTICAL_ADS_ITEM_GROUP_RULE_LIST are
associated with a particular vertical (e.g. hotels, things to do, flights, etc.
). This field is required for shared sets of type
VERTICAL_ADS_ITEM_GROUP_RULE_LIST.
Corresponds to the JSON property verticalAdsItemVerticalType
33647 33648 33649 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33647 def vertical_ads_item_vertical_type @vertical_ads_item_vertical_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33654 33655 33656 33657 33658 33659 33660 33661 33662 33663 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33654 def update!(**args) @id = args[:id] if args.key?(:id) @member_count = args[:member_count] if args.key?(:member_count) @name = args[:name] if args.key?(:name) @reference_count = args[:reference_count] if args.key?(:reference_count) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) @vertical_ads_item_vertical_type = args[:vertical_ads_item_vertical_type] if args.key?(:vertical_ads_item_vertical_type) end |