Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedSet
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
SharedSets are used for sharing criterion exclusions across multiple campaigns.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#member_count ⇒ Fixnum
Output only.
-
#name ⇒ String
The name of this shared set.
-
#reference_count ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Immutable.
-
#status ⇒ String
Output only.
-
#type ⇒ String
Immutable.
-
#vertical_ads_item_vertical_type ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSharedSet
constructor
A new instance of GoogleAdsSearchads360V23ResourcesSharedSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSharedSet
Returns a new instance of GoogleAdsSearchads360V23ResourcesSharedSet.
33547 33548 33549 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33547 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. The ID of this shared set. Read only.
Corresponds to the JSON property id
33502 33503 33504 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33502 def id @id end |
#member_count ⇒ Fixnum
Output only. The number of shared criteria within this shared set. Read only.
Corresponds to the JSON property memberCount
33507 33508 33509 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33507 def member_count @member_count end |
#name ⇒ String
The name of this shared set. Required. Shared Sets must have names that are
unique among active shared sets of the same type. The length of this string
should be between 1 and 255 UTF-8 bytes, inclusive.
Corresponds to the JSON property name
33514 33515 33516 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33514 def name @name end |
#reference_count ⇒ Fixnum
Output only. The number of campaigns associated with this shared set. Read
only.
Corresponds to the JSON property referenceCount
33520 33521 33522 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33520 def reference_count @reference_count end |
#resource_name ⇒ String
Immutable. The resource name of the shared set. Shared set resource names have
the form: customers/customer_id/sharedSets/shared_set_id`
Corresponds to the JSON propertyresourceName`
33526 33527 33528 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33526 def resource_name @resource_name end |
#status ⇒ String
Output only. The status of this shared set. Read only.
Corresponds to the JSON property status
33531 33532 33533 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33531 def status @status end |
#type ⇒ String
Immutable. The type of this shared set: each shared set holds only a single
kind of resource. Required. Immutable.
Corresponds to the JSON property type
33537 33538 33539 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33537 def type @type end |
#vertical_ads_item_vertical_type ⇒ String
Immutable. Shared sets of type VERTICAL_ADS_ITEM_GROUP_RULE_LIST are
associated with a particular vertical (e.g. hotels, things to do, flights, etc.
). This field is required for shared sets of type
VERTICAL_ADS_ITEM_GROUP_RULE_LIST.
Corresponds to the JSON property verticalAdsItemVerticalType
33545 33546 33547 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33545 def vertical_ads_item_vertical_type @vertical_ads_item_vertical_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33552 33553 33554 33555 33556 33557 33558 33559 33560 33561 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33552 def update!(**args) @id = args[:id] if args.key?(:id) @member_count = args[:member_count] if args.key?(:member_count) @name = args[:name] if args.key?(:name) @reference_count = args[:reference_count] if args.key?(:reference_count) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) @vertical_ads_item_vertical_type = args[:vertical_ads_item_vertical_type] if args.key?(:vertical_ads_item_vertical_type) end |