Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesShoppingProduct
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesShoppingProduct
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A shopping product from Google Merchant Center that can be advertised by
campaigns. The resource returns currently existing products from Google
Merchant Center accounts linked with the customer. A campaign includes a
product by specifying its merchant id (or, if available, the Multi Client
Account id of the merchant) in the ShoppingSetting, and can limit the
inclusion to products having a specified feed label. Standard Shopping
campaigns can also limit the inclusion through a campaign_criterion.
listing_scope. Queries to this resource specify a scope: * Account: - Filters
on campaigns or ad groups are not specified. - All products from the linked
Google Merchant Center accounts are returned. - Metrics and some fields (see
the per-field documentation) are aggregated across all Shopping and
Performance Max campaigns that include a product. * Campaign: - An equality
filter on campaign is specified. Supported campaign types are Shopping,
Performance Max, Demand Gen, Video, App. - Only products that are included by
the specified campaign are returned. - Metrics and some fields (see the per-
field documentation) are restricted to the specified campaign. - Only the
following metrics are supported for Demand Gen, Video, App campaigns:
impressions, clicks, ctr. * Ad group: - An equality filter on ad_group and
campaign is specified. Supported campaign types are Shopping, Demand Gen,
Video, App. - Only products that are included by the specified campaign are
returned. - Metrics and some fields (see the per-field documentation) are
restricted to the specified ad group. - Only the following metrics are
supported for Demand Gen, Video, App campaigns: impressions, clicks, ctr. Note
that segmentation by date segments is not permitted and will return
UNSUPPORTED_DATE_SEGMENTATION error. On the other hand, filtering on date
segments is allowed.
Instance Attribute Summary collapse
-
#ad_group ⇒ String
Output only.
-
#availability ⇒ String
Output only.
-
#brand ⇒ String
Output only.
-
#campaign ⇒ String
Output only.
-
#category_level1 ⇒ String
Output only.
-
#category_level2 ⇒ String
Output only.
-
#category_level3 ⇒ String
Output only.
-
#category_level4 ⇒ String
Output only.
-
#category_level5 ⇒ String
Output only.
-
#channel ⇒ String
Output only.
-
#channel_exclusivity ⇒ String
Output only.
-
#condition ⇒ String
Output only.
-
#currency_code ⇒ String
Output only.
-
#custom_attribute0 ⇒ String
Output only.
-
#custom_attribute1 ⇒ String
Output only.
-
#custom_attribute2 ⇒ String
Output only.
-
#custom_attribute3 ⇒ String
Output only.
-
#custom_attribute4 ⇒ String
Output only.
-
#effective_max_cpc_micros ⇒ Fixnum
Output only.
-
#feed_label ⇒ String
Output only.
-
#issues ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue>
Output only.
-
#item_id ⇒ String
Output only.
-
#language_code ⇒ String
Output only.
-
#merchant_center_id ⇒ Fixnum
Output only.
-
#multi_client_account_id ⇒ Fixnum
Output only.
-
#price_micros ⇒ Fixnum
Output only.
-
#product_image_uri ⇒ String
Output only.
-
#product_type_level1 ⇒ String
Output only.
-
#product_type_level2 ⇒ String
Output only.
-
#product_type_level3 ⇒ String
Output only.
-
#product_type_level4 ⇒ String
Output only.
-
#product_type_level5 ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#target_countries ⇒ Array<String>
Output only.
-
#title ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesShoppingProduct
constructor
A new instance of GoogleAdsSearchads360V23ResourcesShoppingProduct.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesShoppingProduct
Returns a new instance of GoogleAdsSearchads360V23ResourcesShoppingProduct.
33929 33930 33931 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33929 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group ⇒ String
Output only. An ad group of a campaign that includes the product. This field
is selectable only in the ad group scope, which requires an equality filter on
campaign and ad_group.
Corresponds to the JSON property adGroup
33734 33735 33736 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33734 def ad_group @ad_group end |
#availability ⇒ String
Output only. The availability of the product as provided by the merchant.
Corresponds to the JSON property availability
33739 33740 33741 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33739 def availability @availability end |
#brand ⇒ String
Output only. The brand of the product as provided by the merchant.
Corresponds to the JSON property brand
33744 33745 33746 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33744 def brand @brand end |
#campaign ⇒ String
Output only. A campaign that includes the product. This field is selectable
only in the campaign scope, which requires an equality filter on campaign.
Corresponds to the JSON property campaign
33750 33751 33752 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33750 def campaign @campaign end |
#category_level1 ⇒ String
Output only. The category level 1 of the product.
Corresponds to the JSON property categoryLevel1
33755 33756 33757 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33755 def category_level1 @category_level1 end |
#category_level2 ⇒ String
Output only. The category level 2 of the product.
Corresponds to the JSON property categoryLevel2
33760 33761 33762 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33760 def category_level2 @category_level2 end |
#category_level3 ⇒ String
Output only. The category level 3 of the product.
Corresponds to the JSON property categoryLevel3
33765 33766 33767 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33765 def category_level3 @category_level3 end |
#category_level4 ⇒ String
Output only. The category level 4 of the product.
Corresponds to the JSON property categoryLevel4
33770 33771 33772 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33770 def category_level4 @category_level4 end |
#category_level5 ⇒ String
Output only. The category level 5 of the product.
Corresponds to the JSON property categoryLevel5
33775 33776 33777 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33775 def category_level5 @category_level5 end |
#channel ⇒ String
Output only. The product channel describing the locality of the product.
Corresponds to the JSON property channel
33780 33781 33782 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33780 def channel @channel end |
#channel_exclusivity ⇒ String
Output only. The channel exclusivity of the product as provided by the
merchant.
Corresponds to the JSON property channelExclusivity
33786 33787 33788 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33786 def channel_exclusivity @channel_exclusivity end |
#condition ⇒ String
Output only. The condition of the product as provided by the merchant.
Corresponds to the JSON property condition
33791 33792 33793 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33791 def condition @condition end |
#currency_code ⇒ String
Output only. The currency code as provided by the merchant, in ISO 4217 format.
Corresponds to the JSON property currencyCode
33796 33797 33798 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33796 def currency_code @currency_code end |
#custom_attribute0 ⇒ String
Output only. The custom attribute 0 of the product as provided by the merchant.
Corresponds to the JSON property customAttribute0
33801 33802 33803 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33801 def custom_attribute0 @custom_attribute0 end |
#custom_attribute1 ⇒ String
Output only. The custom attribute 1 of the product as provided by the merchant.
Corresponds to the JSON property customAttribute1
33806 33807 33808 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33806 def custom_attribute1 @custom_attribute1 end |
#custom_attribute2 ⇒ String
Output only. The custom attribute 2 of the product as provided by the merchant.
Corresponds to the JSON property customAttribute2
33811 33812 33813 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33811 def custom_attribute2 @custom_attribute2 end |
#custom_attribute3 ⇒ String
Output only. The custom attribute 3 of the product as provided by the merchant.
Corresponds to the JSON property customAttribute3
33816 33817 33818 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33816 def custom_attribute3 @custom_attribute3 end |
#custom_attribute4 ⇒ String
Output only. The custom attribute 4 of the product as provided by the merchant.
Corresponds to the JSON property customAttribute4
33821 33822 33823 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33821 def custom_attribute4 @custom_attribute4 end |
#effective_max_cpc_micros ⇒ Fixnum
Output only. The effective maximum cost-per-click (effective max. CPC) of the
product. This field is available only if the query specifies the campaign or
ad group scope, and if the campaign uses manual bidding. The value is the
highest bid set for the product in product groups across all enabled ad groups.
It represents the most you're willing to pay for a click on the product. This
field can take up to 24 hours to update.
Corresponds to the JSON property effectiveMaxCpcMicros
33831 33832 33833 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33831 def effective_max_cpc_micros @effective_max_cpc_micros end |
#feed_label ⇒ String
Output only. The product feed label as provided by the merchant.
Corresponds to the JSON property feedLabel
33836 33837 33838 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33836 def feed_label @feed_label end |
#issues ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue>
Output only. The list of issues affecting whether the product can show in ads.
The value of this field is restricted to the scope specified in the query, see
the documentation of the resource. This field can take up to 24 hours to
update. This field is not supported for App campaigns.
Corresponds to the JSON property issues
33844 33845 33846 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33844 def issues @issues end |
#item_id ⇒ String
Output only. The item id of the product as provided by the merchant.
Corresponds to the JSON property itemId
33849 33850 33851 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33849 def item_id @item_id end |
#language_code ⇒ String
Output only. The language code as provided by the merchant, in BCP 47 format.
Corresponds to the JSON property languageCode
33854 33855 33856 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33854 def language_code @language_code end |
#merchant_center_id ⇒ Fixnum
Output only. The id of the merchant that owns the product.
Corresponds to the JSON property merchantCenterId
33859 33860 33861 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33859 def merchant_center_id @merchant_center_id end |
#multi_client_account_id ⇒ Fixnum
Output only. The id of the Multi Client Account of the merchant, if present.
Corresponds to the JSON property multiClientAccountId
33864 33865 33866 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33864 def multi_client_account_id @multi_client_account_id end |
#price_micros ⇒ Fixnum
Output only. The price of the product in micros as provided by the merchant,
in the currency specified in currency_code (e.g. $2.97 is reported as
2970000).
Corresponds to the JSON property priceMicros
33871 33872 33873 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33871 def price_micros @price_micros end |
#product_image_uri ⇒ String
Output only. The URI of the product image as provided by the merchant.
Corresponds to the JSON property productImageUri
33876 33877 33878 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33876 def product_image_uri @product_image_uri end |
#product_type_level1 ⇒ String
Output only. The product type level 1 as provided by the merchant.
Corresponds to the JSON property productTypeLevel1
33881 33882 33883 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33881 def product_type_level1 @product_type_level1 end |
#product_type_level2 ⇒ String
Output only. The product type level 2 as provided by the merchant.
Corresponds to the JSON property productTypeLevel2
33886 33887 33888 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33886 def product_type_level2 @product_type_level2 end |
#product_type_level3 ⇒ String
Output only. The product type level 3 as provided by the merchant.
Corresponds to the JSON property productTypeLevel3
33891 33892 33893 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33891 def product_type_level3 @product_type_level3 end |
#product_type_level4 ⇒ String
Output only. The product type level 4 as provided by the merchant.
Corresponds to the JSON property productTypeLevel4
33896 33897 33898 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33896 def product_type_level4 @product_type_level4 end |
#product_type_level5 ⇒ String
Output only. The product type level 5 as provided by the merchant.
Corresponds to the JSON property productTypeLevel5
33901 33902 33903 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33901 def product_type_level5 @product_type_level5 end |
#resource_name ⇒ String
Output only. The resource name of the shopping product. Shopping product
resource names have the form: customers/customer_id/shoppingProducts/
merchant_center_id~channel~language_code~feed_label~item_id`
Corresponds to the JSON propertyresourceName`
33908 33909 33910 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33908 def resource_name @resource_name end |
#status ⇒ String
Output only. The status that indicates whether the product can show in ads.
The value of this field is restricted to the scope specified in the query, see
the documentation of the resource. This field can take up to 24 hours to
update. This field is not supported for App campaigns.
Corresponds to the JSON property status
33916 33917 33918 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33916 def status @status end |
#target_countries ⇒ Array<String>
Output only. Upper-case two-letter ISO 3166-1 code of the regions where the
product is intended to be shown in ads.
Corresponds to the JSON property targetCountries
33922 33923 33924 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33922 def target_countries @target_countries end |
#title ⇒ String
Output only. The title of the product as provided by the merchant.
Corresponds to the JSON property title
33927 33928 33929 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33927 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33934 33935 33936 33937 33938 33939 33940 33941 33942 33943 33944 33945 33946 33947 33948 33949 33950 33951 33952 33953 33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33934 def update!(**args) @ad_group = args[:ad_group] if args.key?(:ad_group) @availability = args[:availability] if args.key?(:availability) @brand = args[:brand] if args.key?(:brand) @campaign = args[:campaign] if args.key?(:campaign) @category_level1 = args[:category_level1] if args.key?(:category_level1) @category_level2 = args[:category_level2] if args.key?(:category_level2) @category_level3 = args[:category_level3] if args.key?(:category_level3) @category_level4 = args[:category_level4] if args.key?(:category_level4) @category_level5 = args[:category_level5] if args.key?(:category_level5) @channel = args[:channel] if args.key?(:channel) @channel_exclusivity = args[:channel_exclusivity] if args.key?(:channel_exclusivity) @condition = args[:condition] if args.key?(:condition) @currency_code = args[:currency_code] if args.key?(:currency_code) @custom_attribute0 = args[:custom_attribute0] if args.key?(:custom_attribute0) @custom_attribute1 = args[:custom_attribute1] if args.key?(:custom_attribute1) @custom_attribute2 = args[:custom_attribute2] if args.key?(:custom_attribute2) @custom_attribute3 = args[:custom_attribute3] if args.key?(:custom_attribute3) @custom_attribute4 = args[:custom_attribute4] if args.key?(:custom_attribute4) @effective_max_cpc_micros = args[:effective_max_cpc_micros] if args.key?(:effective_max_cpc_micros) @feed_label = args[:feed_label] if args.key?(:feed_label) @issues = args[:issues] if args.key?(:issues) @item_id = args[:item_id] if args.key?(:item_id) @language_code = args[:language_code] if args.key?(:language_code) @merchant_center_id = args[:merchant_center_id] if args.key?(:merchant_center_id) @multi_client_account_id = args[:multi_client_account_id] if args.key?(:multi_client_account_id) @price_micros = args[:price_micros] if args.key?(:price_micros) @product_image_uri = args[:product_image_uri] if args.key?(:product_image_uri) @product_type_level1 = args[:product_type_level1] if args.key?(:product_type_level1) @product_type_level2 = args[:product_type_level2] if args.key?(:product_type_level2) @product_type_level3 = args[:product_type_level3] if args.key?(:product_type_level3) @product_type_level4 = args[:product_type_level4] if args.key?(:product_type_level4) @product_type_level5 = args[:product_type_level5] if args.key?(:product_type_level5) @resource_name = args[:resource_name] if args.key?(:resource_name) @status = args[:status] if args.key?(:status) @target_countries = args[:target_countries] if args.key?(:target_countries) @title = args[:title] if args.key?(:title) end |