Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An issue affecting whether a product can show in ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue

Returns a new instance of GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue.



19086
19087
19088
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19086

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ads_severityString

Output only. The severity of the issue in Google Ads. Corresponds to the JSON property adsSeverity

Returns:

  • (String)


19052
19053
19054
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19052

def ads_severity
  @ads_severity
end

#affected_regionsArray<String>

Output only. List of upper-case two-letter ISO 3166-1 codes of the regions affected by the issue. If empty, all regions are affected. Corresponds to the JSON property affectedRegions

Returns:

  • (Array<String>)


19058
19059
19060
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19058

def affected_regions
  @affected_regions
end

#attribute_nameString

Output only. The name of the product's attribute, if any, that triggered the issue. Corresponds to the JSON property attributeName

Returns:

  • (String)


19064
19065
19066
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19064

def attribute_name
  @attribute_name
end

#descriptionString

Output only. The short description of the issue in English. Corresponds to the JSON property description

Returns:

  • (String)


19069
19070
19071
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19069

def description
  @description
end

#detailString

Output only. The detailed description of the issue in English. Corresponds to the JSON property detail

Returns:

  • (String)


19074
19075
19076
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19074

def detail
  @detail
end

#documentationString

Output only. The URL of the Help Center article for the issue. Corresponds to the JSON property documentation

Returns:

  • (String)


19079
19080
19081
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19079

def documentation
  @documentation
end

#error_codeString

Output only. The error code that identifies the issue. Corresponds to the JSON property errorCode

Returns:

  • (String)


19084
19085
19086
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19084

def error_code
  @error_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19091
19092
19093
19094
19095
19096
19097
19098
19099
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19091

def update!(**args)
  @ads_severity = args[:ads_severity] if args.key?(:ads_severity)
  @affected_regions = args[:affected_regions] if args.key?(:affected_regions)
  @attribute_name = args[:attribute_name] if args.key?(:attribute_name)
  @description = args[:description] if args.key?(:description)
  @detail = args[:detail] if args.key?(:detail)
  @documentation = args[:documentation] if args.key?(:documentation)
  @error_code = args[:error_code] if args.key?(:error_code)
end