Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An issue affecting whether a product can show in ads.
Instance Attribute Summary collapse
-
#ads_severity ⇒ String
Output only.
-
#affected_regions ⇒ Array<String>
Output only.
-
#attribute_name ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#detail ⇒ String
Output only.
-
#documentation ⇒ String
Output only.
-
#error_code ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue
constructor
A new instance of GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue
Returns a new instance of GoogleAdsSearchads360V23ResourcesShoppingProductProductIssue.
19020 19021 19022 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ads_severity ⇒ String
Output only. The severity of the issue in Google Ads.
Corresponds to the JSON property adsSeverity
18986 18987 18988 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18986 def ads_severity @ads_severity end |
#affected_regions ⇒ Array<String>
Output only. List of upper-case two-letter ISO 3166-1 codes of the regions
affected by the issue. If empty, all regions are affected.
Corresponds to the JSON property affectedRegions
18992 18993 18994 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18992 def affected_regions @affected_regions end |
#attribute_name ⇒ String
Output only. The name of the product's attribute, if any, that triggered the
issue.
Corresponds to the JSON property attributeName
18998 18999 19000 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 18998 def attribute_name @attribute_name end |
#description ⇒ String
Output only. The short description of the issue in English.
Corresponds to the JSON property description
19003 19004 19005 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19003 def description @description end |
#detail ⇒ String
Output only. The detailed description of the issue in English.
Corresponds to the JSON property detail
19008 19009 19010 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19008 def detail @detail end |
#documentation ⇒ String
Output only. The URL of the Help Center article for the issue.
Corresponds to the JSON property documentation
19013 19014 19015 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19013 def documentation @documentation end |
#error_code ⇒ String
Output only. The error code that identifies the issue.
Corresponds to the JSON property errorCode
19018 19019 19020 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19018 def error_code @error_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19025 19026 19027 19028 19029 19030 19031 19032 19033 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19025 def update!(**args) @ads_severity = args[:ads_severity] if args.key?(:ads_severity) @affected_regions = args[:affected_regions] if args.key?(:affected_regions) @attribute_name = args[:attribute_name] if args.key?(:attribute_name) @description = args[:description] if args.key?(:description) @detail = args[:detail] if args.key?(:detail) @documentation = args[:documentation] if args.key?(:documentation) @error_code = args[:error_code] if args.key?(:error_code) end |