Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSmartCampaignSearchTermView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A Smart campaign search term view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSmartCampaignSearchTermView

Returns a new instance of GoogleAdsSearchads360V23ResourcesSmartCampaignSearchTermView.



33894
33895
33896
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaignString

Output only. The Smart campaign the search term served in. Corresponds to the JSON property campaign

Returns:

  • (String)


33879
33880
33881
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33879

def campaign
  @campaign
end

#resource_nameString

Output only. The resource name of the Smart campaign search term view. Smart campaign search term view resource names have the form: customers/ customer_id/smartCampaignSearchTermViews/campaign_id~URL- base64_search_term` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


33887
33888
33889
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33887

def resource_name
  @resource_name
end

#search_termString

Output only. The search term. Corresponds to the JSON property searchTerm

Returns:

  • (String)


33892
33893
33894
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33892

def search_term
  @search_term
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33899
33900
33901
33902
33903
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33899

def update!(**args)
  @campaign = args[:campaign] if args.key?(:campaign)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @search_term = args[:search_term] if args.key?(:search_term)
end