Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSmartCampaignSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Settings for configuring Smart campaigns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSmartCampaignSetting

Returns a new instance of GoogleAdsSearchads360V23ResourcesSmartCampaignSetting.



34061
34062
34063
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34061

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_optimized_business_profile_settingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSmartCampaignSettingAdOptimizedBusinessProfileSetting

Settings for configuring a business profile optimized for ads as this campaign' s landing page. Corresponds to the JSON property adOptimizedBusinessProfileSetting



34016
34017
34018
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34016

def ad_optimized_business_profile_setting
  @ad_optimized_business_profile_setting
end

#advertising_language_codeString

The language code to advertise in from the set of supported language codes. Corresponds to the JSON property advertisingLanguageCode

Returns:

  • (String)


34023
34024
34025
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34023

def advertising_language_code
  @advertising_language_code
end

#business_nameString

The name of the business. Corresponds to the JSON property businessName

Returns:

  • (String)


34028
34029
34030
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34028

def business_name
  @business_name
end

#business_profile_locationString

The resource name of a Business Profile location. Business Profile location resource names can be fetched through the Business Profile API and adhere to the following format: locations/locationId`. See the [Business Profile API] (https://developers.google.com/my-business/reference/businessinformation/rest/ v1/accounts.locations) for additional details. Corresponds to the JSON propertybusinessProfileLocation`

Returns:

  • (String)


34037
34038
34039
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34037

def business_profile_location
  @business_profile_location
end

#campaignString

Output only. The campaign to which these settings apply. Corresponds to the JSON property campaign

Returns:

  • (String)


34042
34043
34044
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34042

def campaign
  @campaign
end

#final_urlString

The user-provided landing page URL for this Campaign. Corresponds to the JSON property finalUrl

Returns:

  • (String)


34047
34048
34049
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34047

def final_url
  @final_url
end

#phone_numberGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSmartCampaignSettingPhoneNumber

Phone number and country code in smart campaign settings. Corresponds to the JSON property phoneNumber



34052
34053
34054
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34052

def phone_number
  @phone_number
end

#resource_nameString

Immutable. The resource name of the Smart campaign setting. Smart campaign setting resource names have the form: customers/customer_id/ smartCampaignSettings/campaign_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


34059
34060
34061
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34059

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34066
34067
34068
34069
34070
34071
34072
34073
34074
34075
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34066

def update!(**args)
  @ad_optimized_business_profile_setting = args[:ad_optimized_business_profile_setting] if args.key?(:ad_optimized_business_profile_setting)
  @advertising_language_code = args[:advertising_language_code] if args.key?(:advertising_language_code)
  @business_name = args[:business_name] if args.key?(:business_name)
  @business_profile_location = args[:business_profile_location] if args.key?(:business_profile_location)
  @campaign = args[:campaign] if args.key?(:campaign)
  @final_url = args[:final_url] if args.key?(:final_url)
  @phone_number = args[:phone_number] if args.key?(:phone_number)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end