Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSmartCampaignSetting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSmartCampaignSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Settings for configuring Smart campaigns.
Instance Attribute Summary collapse
-
#ad_optimized_business_profile_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSmartCampaignSettingAdOptimizedBusinessProfileSetting
Settings for configuring a business profile optimized for ads as this campaign' s landing page.
-
#advertising_language_code ⇒ String
The language code to advertise in from the set of supported language codes.
-
#business_name ⇒ String
The name of the business.
-
#business_profile_location ⇒ String
The resource name of a Business Profile location.
-
#campaign ⇒ String
Output only.
-
#final_url ⇒ String
The user-provided landing page URL for this Campaign.
-
#phone_number ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSmartCampaignSettingPhoneNumber
Phone number and country code in smart campaign settings.
-
#resource_name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSmartCampaignSetting
constructor
A new instance of GoogleAdsSearchads360V23ResourcesSmartCampaignSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSmartCampaignSetting
Returns a new instance of GoogleAdsSearchads360V23ResourcesSmartCampaignSetting.
33959 33960 33961 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33959 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_optimized_business_profile_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSmartCampaignSettingAdOptimizedBusinessProfileSetting
Settings for configuring a business profile optimized for ads as this campaign'
s landing page.
Corresponds to the JSON property adOptimizedBusinessProfileSetting
33914 33915 33916 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33914 def ad_optimized_business_profile_setting @ad_optimized_business_profile_setting end |
#advertising_language_code ⇒ String
The language code to advertise in from the set of supported language codes.
Corresponds to the JSON property advertisingLanguageCode
33921 33922 33923 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33921 def advertising_language_code @advertising_language_code end |
#business_name ⇒ String
The name of the business.
Corresponds to the JSON property businessName
33926 33927 33928 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33926 def business_name @business_name end |
#business_profile_location ⇒ String
The resource name of a Business Profile location. Business Profile location
resource names can be fetched through the Business Profile API and adhere to
the following format: locations/locationId`. See the [Business Profile API]
(https://developers.google.com/my-business/reference/businessinformation/rest/
v1/accounts.locations) for additional details.
Corresponds to the JSON propertybusinessProfileLocation`
33935 33936 33937 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33935 def business_profile_location @business_profile_location end |
#campaign ⇒ String
Output only. The campaign to which these settings apply.
Corresponds to the JSON property campaign
33940 33941 33942 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33940 def campaign @campaign end |
#final_url ⇒ String
The user-provided landing page URL for this Campaign.
Corresponds to the JSON property finalUrl
33945 33946 33947 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33945 def final_url @final_url end |
#phone_number ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSmartCampaignSettingPhoneNumber
Phone number and country code in smart campaign settings.
Corresponds to the JSON property phoneNumber
33950 33951 33952 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33950 def phone_number @phone_number end |
#resource_name ⇒ String
Immutable. The resource name of the Smart campaign setting. Smart campaign
setting resource names have the form: customers/customer_id/
smartCampaignSettings/campaign_id`
Corresponds to the JSON propertyresourceName`
33957 33958 33959 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33957 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 33964 def update!(**args) @ad_optimized_business_profile_setting = args[:ad_optimized_business_profile_setting] if args.key?(:ad_optimized_business_profile_setting) @advertising_language_code = args[:advertising_language_code] if args.key?(:advertising_language_code) @business_name = args[:business_name] if args.key?(:business_name) @business_profile_location = args[:business_profile_location] if args.key?(:business_profile_location) @campaign = args[:campaign] if args.key?(:campaign) @final_url = args[:final_url] if args.key?(:final_url) @phone_number = args[:phone_number] if args.key?(:phone_number) @resource_name = args[:resource_name] if args.key?(:resource_name) end |