Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSmartCampaignSettingAdOptimizedBusinessProfileSetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Settings for configuring a business profile optimized for ads as this campaign' s landing page.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesSmartCampaignSettingAdOptimizedBusinessProfileSetting

Returns a new instance of GoogleAdsSearchads360V23ResourcesSmartCampaignSettingAdOptimizedBusinessProfileSetting.



19115
19116
19117
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19115

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_lead_formBoolean Also known as: include_lead_form?

Enabling a lead form on your business profile enables prospective customers to contact your business by filling out a simple form, and you'll receive their information through email. Corresponds to the JSON property includeLeadForm

Returns:

  • (Boolean)


19112
19113
19114
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19112

def include_lead_form
  @include_lead_form
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19120
19121
19122
# File 'lib/google/apis/searchads360_v23/classes.rb', line 19120

def update!(**args)
  @include_lead_form = args[:include_lead_form] if args.key?(:include_lead_form)
end