Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A data sharing connection, allowing the import of third party app analytics into a Google Ads Customer.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Immutable.
-
#shareable_link_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink
constructor
A new instance of GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink
Returns a new instance of GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink.
34191 34192 34193 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34191 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Immutable. The resource name of the third party app analytics link. Third
party app analytics link resource names have the form: customers/customer_id
/thirdPartyAppAnalyticsLinks/account_link_id`
Corresponds to the JSON propertyresourceName`
34182 34183 34184 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34182 def resource_name @resource_name end |
#shareable_link_id ⇒ String
Output only. The shareable link ID that should be provided to the third party
when setting up app analytics. This is able to be regenerated using regenerate
method in the ThirdPartyAppAnalyticsLinkService.
Corresponds to the JSON property shareableLinkId
34189 34190 34191 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34189 def shareable_link_id @shareable_link_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34196 34197 34198 34199 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34196 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) @shareable_link_id = args[:shareable_link_id] if args.key?(:shareable_link_id) end |