Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A data sharing connection, allowing the import of third party app analytics into a Google Ads Customer.
Instance Attribute Summary collapse
-
#resource_name ⇒ String
Immutable.
-
#shareable_link_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink
constructor
A new instance of GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink
Returns a new instance of GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink.
34119 34120 34121 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_name ⇒ String
Immutable. The resource name of the third party app analytics link. Third
party app analytics link resource names have the form: customers/customer_id
/thirdPartyAppAnalyticsLinks/account_link_id`
Corresponds to the JSON propertyresourceName`
34110 34111 34112 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34110 def resource_name @resource_name end |
#shareable_link_id ⇒ String
Output only. The shareable link ID that should be provided to the third party
when setting up app analytics. This is able to be regenerated using regenerate
method in the ThirdPartyAppAnalyticsLinkService.
Corresponds to the JSON property shareableLinkId
34117 34118 34119 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34117 def shareable_link_id @shareable_link_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34124 34125 34126 34127 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34124 def update!(**args) @resource_name = args[:resource_name] if args.key?(:resource_name) @shareable_link_id = args[:shareable_link_id] if args.key?(:shareable_link_id) end |