Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A data sharing connection, allowing the import of third party app analytics into a Google Ads Customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink

Returns a new instance of GoogleAdsSearchads360V23ResourcesThirdPartyAppAnalyticsLink.



34017
34018
34019
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_nameString

Immutable. The resource name of the third party app analytics link. Third party app analytics link resource names have the form: customers/customer_id /thirdPartyAppAnalyticsLinks/account_link_id` Corresponds to the JSON propertyresourceName`

Returns:

  • (String)


34008
34009
34010
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34008

def resource_name
  @resource_name
end

Output only. The shareable link ID that should be provided to the third party when setting up app analytics. This is able to be regenerated using regenerate method in the ThirdPartyAppAnalyticsLinkService. Corresponds to the JSON property shareableLinkId

Returns:

  • (String)


34015
34016
34017
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34015

def shareable_link_id
  @shareable_link_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34022
34023
34024
34025
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34022

def update!(**args)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @shareable_link_id = args[:shareable_link_id] if args.key?(:shareable_link_id)
end