Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesTopicConstant
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesTopicConstant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Use topics to target or exclude placements in the Google Display Network based on the category into which the placement falls (for example, "Pets & Animals/ Pets/Dogs").
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#path ⇒ Array<String>
Output only.
-
#resource_name ⇒ String
Output only.
-
#topic_constant_parent ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesTopicConstant
constructor
A new instance of GoogleAdsSearchads360V23ResourcesTopicConstant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesTopicConstant
Returns a new instance of GoogleAdsSearchads360V23ResourcesTopicConstant.
34103 34104 34105 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34103 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. The ID of the topic.
Corresponds to the JSON property id
34081 34082 34083 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34081 def id @id end |
#path ⇒ Array<String>
Output only. The category to target or exclude. Each subsequent element in the
array describes a more specific sub-category. For example, "Pets & Animals", "
Pets", "Dogs" represents the "Pets & Animals/Pets/Dogs" category. List of
available topic categories at https://developers.google.com/google-ads/api/
reference/data/verticals
Corresponds to the JSON property path
34090 34091 34092 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34090 def path @path end |
#resource_name ⇒ String
Output only. The resource name of the topic constant. topic constant resource
names have the form: topicConstants/topic_id`
Corresponds to the JSON propertyresourceName`
34096 34097 34098 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34096 def resource_name @resource_name end |
#topic_constant_parent ⇒ String
Output only. Resource name of parent of the topic constant.
Corresponds to the JSON property topicConstantParent
34101 34102 34103 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34101 def topic_constant_parent @topic_constant_parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34108 34109 34110 34111 34112 34113 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34108 def update!(**args) @id = args[:id] if args.key?(:id) @path = args[:path] if args.key?(:path) @resource_name = args[:resource_name] if args.key?(:resource_name) @topic_constant_parent = args[:topic_constant_parent] if args.key?(:topic_constant_parent) end |