Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUniversityDegree

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A list of degrees this employee has obtained, and wants to feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesUniversityDegree

Returns a new instance of GoogleAdsSearchads360V23ResourcesUniversityDegree.



34300
34301
34302
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34300

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#degreeString

Output only. Name of the degree obtained. Corresponds to the JSON property degree

Returns:

  • (String)


34288
34289
34290
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34288

def degree
  @degree
end

#graduation_yearFixnum

Output only. Year of graduation. Corresponds to the JSON property graduationYear

Returns:

  • (Fixnum)


34293
34294
34295
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34293

def graduation_year
  @graduation_year
end

#institution_nameString

Output only. Name of the university at which the degree was obtained. Corresponds to the JSON property institutionName

Returns:

  • (String)


34298
34299
34300
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34298

def institution_name
  @institution_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34305
34306
34307
34308
34309
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34305

def update!(**args)
  @degree = args[:degree] if args.key?(:degree)
  @graduation_year = args[:graduation_year] if args.key?(:graduation_year)
  @institution_name = args[:institution_name] if args.key?(:institution_name)
end