Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUniversityDegree
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUniversityDegree
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A list of degrees this employee has obtained, and wants to feature.
Instance Attribute Summary collapse
-
#degree ⇒ String
Output only.
-
#graduation_year ⇒ Fixnum
Output only.
-
#institution_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesUniversityDegree
constructor
A new instance of GoogleAdsSearchads360V23ResourcesUniversityDegree.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesUniversityDegree
Returns a new instance of GoogleAdsSearchads360V23ResourcesUniversityDegree.
34198 34199 34200 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34198 def initialize(**args) update!(**args) end |
Instance Attribute Details
#degree ⇒ String
Output only. Name of the degree obtained.
Corresponds to the JSON property degree
34186 34187 34188 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34186 def degree @degree end |
#graduation_year ⇒ Fixnum
Output only. Year of graduation.
Corresponds to the JSON property graduationYear
34191 34192 34193 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34191 def graduation_year @graduation_year end |
#institution_name ⇒ String
Output only. Name of the university at which the degree was obtained.
Corresponds to the JSON property institutionName
34196 34197 34198 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34196 def institution_name @institution_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34203 34204 34205 34206 34207 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34203 def update!(**args) @degree = args[:degree] if args.key?(:degree) @graduation_year = args[:graduation_year] if args.key?(:graduation_year) @institution_name = args[:institution_name] if args.key?(:institution_name) end |