Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserList
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A user list. This is a list of users a customer may target. The unique key of
a user list consists of the following fields: id. Note that the name must
also be unique for user lists owned by a given customer, except in some cases
where access_reason is set to SHARED. Violating the unique name constraint
produces error: UserListError.INVALID_NAME.
Instance Attribute Summary collapse
-
#access_reason ⇒ String
Output only.
-
#account_user_list_status ⇒ String
Indicates if this share is still enabled.
-
#basic_user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBasicUserListInfo
User list targeting as a collection of conversion or remarketing actions.
-
#closing_reason ⇒ String
Indicating the reason why this user list membership status is closed.
-
#crm_based_user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCrmBasedUserListInfo
UserList of CRM users provided by the advertiser.
-
#description ⇒ String
Description of this user list.
-
#eligible_for_display ⇒ Boolean
(also: #eligible_for_display?)
Output only.
-
#eligible_for_search ⇒ Boolean
(also: #eligible_for_search?)
Indicates if this user list is eligible for Google Search Network.
-
#id ⇒ Fixnum
Output only.
-
#integration_code ⇒ String
An ID from external system.
-
#logical_user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLogicalUserListInfo
Represents a user list that is a custom combination of user lists.
-
#lookalike_user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLookalikeUserListInfo
LookalikeUserlist, composed of users similar to those of a configurable seed ( set of UserLists) Corresponds to the JSON property
lookalikeUserList. -
#match_rate_percentage ⇒ Fixnum
Output only.
-
#membership_life_span ⇒ Fixnum
Number of days a user's cookie stays on your list since its most recent addition to the list.
-
#membership_status ⇒ String
Membership status of this user list.
-
#name ⇒ String
Name of this user list.
-
#read_only ⇒ Boolean
(also: #read_only?)
Output only.
-
#resource_name ⇒ String
Immutable.
-
#rule_based_user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonRuleBasedUserListInfo
Representation of a userlist that is generated by a rule.
-
#similar_user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSimilarUserListInfo
SimilarUserList is a list of users which are similar to users from another UserList.
-
#size_for_display ⇒ Fixnum
Output only.
-
#size_for_search ⇒ Fixnum
Output only.
-
#size_range_for_display ⇒ String
Output only.
-
#size_range_for_search ⇒ String
Output only.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesUserList
constructor
A new instance of GoogleAdsSearchads360V23ResourcesUserList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesUserList
Returns a new instance of GoogleAdsSearchads360V23ResourcesUserList.
34434 34435 34436 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34434 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_reason ⇒ String
Output only. Indicates the reason this account has been granted access to the
list. The reason can be SHARED, OWNED, LICENSED or SUBSCRIBED. This field is
read-only.
Corresponds to the JSON property accessReason
34280 34281 34282 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34280 def access_reason @access_reason end |
#account_user_list_status ⇒ String
Indicates if this share is still enabled. When a UserList is shared with the
user this field is set to ENABLED. Later the userList owner can decide to
revoke the share and make it DISABLED. The default value of this field is set
to ENABLED.
Corresponds to the JSON property accountUserListStatus
34288 34289 34290 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34288 def account_user_list_status @account_user_list_status end |
#basic_user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonBasicUserListInfo
User list targeting as a collection of conversion or remarketing actions.
Corresponds to the JSON property basicUserList
34293 34294 34295 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34293 def basic_user_list @basic_user_list end |
#closing_reason ⇒ String
Indicating the reason why this user list membership status is closed. It is
only populated on lists that were automatically closed due to inactivity, and
will be cleared once the list membership status becomes open.
Corresponds to the JSON property closingReason
34300 34301 34302 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34300 def closing_reason @closing_reason end |
#crm_based_user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonCrmBasedUserListInfo
UserList of CRM users provided by the advertiser.
Corresponds to the JSON property crmBasedUserList
34305 34306 34307 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34305 def crm_based_user_list @crm_based_user_list end |
#description ⇒ String
Description of this user list.
Corresponds to the JSON property description
34310 34311 34312 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34310 def description @description end |
#eligible_for_display ⇒ Boolean Also known as: eligible_for_display?
Output only. Indicates this user list is eligible for Google Display Network.
This field is read-only.
Corresponds to the JSON property eligibleForDisplay
34316 34317 34318 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34316 def eligible_for_display @eligible_for_display end |
#eligible_for_search ⇒ Boolean Also known as: eligible_for_search?
Indicates if this user list is eligible for Google Search Network.
Corresponds to the JSON property eligibleForSearch
34322 34323 34324 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34322 def eligible_for_search @eligible_for_search end |
#id ⇒ Fixnum
Output only. Id of the user list.
Corresponds to the JSON property id
34328 34329 34330 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34328 def id @id end |
#integration_code ⇒ String
An ID from external system. It is used by user list sellers to correlate IDs
on their systems.
Corresponds to the JSON property integrationCode
34334 34335 34336 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34334 def integration_code @integration_code end |
#logical_user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLogicalUserListInfo
Represents a user list that is a custom combination of user lists.
Corresponds to the JSON property logicalUserList
34339 34340 34341 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34339 def logical_user_list @logical_user_list end |
#lookalike_user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLookalikeUserListInfo
LookalikeUserlist, composed of users similar to those of a configurable seed (
set of UserLists)
Corresponds to the JSON property lookalikeUserList
34345 34346 34347 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34345 def lookalike_user_list @lookalike_user_list end |
#match_rate_percentage ⇒ Fixnum
Output only. Indicates match rate for Customer Match lists. The range of this
field is [0-100]. This will be null for other list types or when it's not
possible to calculate the match rate. This field is read-only.
Corresponds to the JSON property matchRatePercentage
34352 34353 34354 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34352 def match_rate_percentage @match_rate_percentage end |
#membership_life_span ⇒ Fixnum
Number of days a user's cookie stays on your list since its most recent
addition to the list. This field must be between 0 and 540 inclusive. However,
for CRM based userlists, this field can be set to 10000 which means no
expiration. Beginning on April 7, 2025, using a value of 10000 to indicate no
expiration will no longer be supported. This field is ignored for
logical_user_list and rule_based_user_list types. Membership to lists of these
types depends on the rules defined by the lists.
Corresponds to the JSON property membershipLifeSpan
34363 34364 34365 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34363 def membership_life_span @membership_life_span end |
#membership_status ⇒ String
Membership status of this user list. Indicates whether a user list is open or
active. Only open user lists can accumulate more users and can be targeted to.
Corresponds to the JSON property membershipStatus
34369 34370 34371 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34369 def membership_status @membership_status end |
#name ⇒ String
Name of this user list. Unique per user list, except in some cases where a
user list of the same name has access_reason set to SHARED.
Corresponds to the JSON property name
34375 34376 34377 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34375 def name @name end |
#read_only ⇒ Boolean Also known as: read_only?
Output only. An option that indicates if a user may edit a list. Depends on
the list ownership and list type. For example, external remarketing user lists
are not editable. This field is -only.
Corresponds to the JSON property readOnly
34382 34383 34384 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34382 def read_only @read_only end |
#resource_name ⇒ String
Immutable. The resource name of the user list. User list resource names have
the form: customers/customer_id/userLists/user_list_id`
Corresponds to the JSON propertyresourceName`
34389 34390 34391 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34389 def resource_name @resource_name end |
#rule_based_user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonRuleBasedUserListInfo
Representation of a userlist that is generated by a rule.
Corresponds to the JSON property ruleBasedUserList
34394 34395 34396 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34394 def rule_based_user_list @rule_based_user_list end |
#similar_user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonSimilarUserListInfo
SimilarUserList is a list of users which are similar to users from another
UserList. These lists are read-only and automatically created by Google.
Corresponds to the JSON property similarUserList
34400 34401 34402 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34400 def similar_user_list @similar_user_list end |
#size_for_display ⇒ Fixnum
Output only. Estimated number of users in this user list, on the Google
Display Network. This value is if the number of users has not yet been
determined. This field is -only.
Corresponds to the JSON property sizeForDisplay
34407 34408 34409 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34407 def size_for_display @size_for_display end |
#size_for_search ⇒ Fixnum
Output only. Estimated number of users in this user list in the google.com
domain. These are the users available for targeting in Search campaigns. This
value is null if the number of users has not yet been determined. This field
is read-only.
Corresponds to the JSON property sizeForSearch
34415 34416 34417 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34415 def size_for_search @size_for_search end |
#size_range_for_display ⇒ String
Output only. Size range in terms of number of users of the UserList, on the
Google Display Network. This field is read-only.
Corresponds to the JSON property sizeRangeForDisplay
34421 34422 34423 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34421 def size_range_for_display @size_range_for_display end |
#size_range_for_search ⇒ String
Output only. Size range in terms of number of users of the UserList, for
Search ads. This field is read-only.
Corresponds to the JSON property sizeRangeForSearch
34427 34428 34429 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34427 def size_range_for_search @size_range_for_search end |
#type ⇒ String
Output only. Type of this list. This field is read-only.
Corresponds to the JSON property type
34432 34433 34434 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34432 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34439 34440 34441 34442 34443 34444 34445 34446 34447 34448 34449 34450 34451 34452 34453 34454 34455 34456 34457 34458 34459 34460 34461 34462 34463 34464 34465 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34439 def update!(**args) @access_reason = args[:access_reason] if args.key?(:access_reason) @account_user_list_status = args[:account_user_list_status] if args.key?(:account_user_list_status) @basic_user_list = args[:basic_user_list] if args.key?(:basic_user_list) @closing_reason = args[:closing_reason] if args.key?(:closing_reason) @crm_based_user_list = args[:crm_based_user_list] if args.key?(:crm_based_user_list) @description = args[:description] if args.key?(:description) @eligible_for_display = args[:eligible_for_display] if args.key?(:eligible_for_display) @eligible_for_search = args[:eligible_for_search] if args.key?(:eligible_for_search) @id = args[:id] if args.key?(:id) @integration_code = args[:integration_code] if args.key?(:integration_code) @logical_user_list = args[:logical_user_list] if args.key?(:logical_user_list) @lookalike_user_list = args[:lookalike_user_list] if args.key?(:lookalike_user_list) @match_rate_percentage = args[:match_rate_percentage] if args.key?(:match_rate_percentage) @membership_life_span = args[:membership_life_span] if args.key?(:membership_life_span) @membership_status = args[:membership_status] if args.key?(:membership_status) @name = args[:name] if args.key?(:name) @read_only = args[:read_only] if args.key?(:read_only) @resource_name = args[:resource_name] if args.key?(:resource_name) @rule_based_user_list = args[:rule_based_user_list] if args.key?(:rule_based_user_list) @similar_user_list = args[:similar_user_list] if args.key?(:similar_user_list) @size_for_display = args[:size_for_display] if args.key?(:size_for_display) @size_for_search = args[:size_for_search] if args.key?(:size_for_search) @size_range_for_display = args[:size_range_for_display] if args.key?(:size_range_for_display) @size_range_for_search = args[:size_range_for_search] if args.key?(:size_range_for_search) @type = args[:type] if args.key?(:type) end |