Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserLocationView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserLocationView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A user location view. User Location View includes all metrics aggregated at the country level, one row per country. It reports metrics at the actual physical location of the user by targeted or not targeted location. If other segment fields are used, you may get more than one row per country.
Instance Attribute Summary collapse
-
#country_criterion_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Output only.
-
#targeting_location ⇒ Boolean
(also: #targeting_location?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesUserLocationView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesUserLocationView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesUserLocationView
Returns a new instance of GoogleAdsSearchads360V23ResourcesUserLocationView.
34629 34630 34631 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_criterion_id ⇒ Fixnum
Output only. Criterion Id for the country.
Corresponds to the JSON property countryCriterionId
34614 34615 34616 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34614 def country_criterion_id @country_criterion_id end |
#resource_name ⇒ String
Output only. The resource name of the user location view. UserLocation view
resource names have the form: customers/customer_id/userLocationViews/
country_criterion_id~targeting_location`
Corresponds to the JSON propertyresourceName`
34621 34622 34623 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34621 def resource_name @resource_name end |
#targeting_location ⇒ Boolean Also known as: targeting_location?
Output only. Indicates whether location was targeted or not.
Corresponds to the JSON property targetingLocation
34626 34627 34628 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34626 def targeting_location @targeting_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34634 34635 34636 34637 34638 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34634 def update!(**args) @country_criterion_id = args[:country_criterion_id] if args.key?(:country_criterion_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @targeting_location = args[:targeting_location] if args.key?(:targeting_location) end |