Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserLocationView
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserLocationView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A user location view. User Location View includes all metrics aggregated at the country level, one row per country. It reports metrics at the actual physical location of the user by targeted or not targeted location. If other segment fields are used, you may get more than one row per country.
Instance Attribute Summary collapse
-
#country_criterion_id ⇒ Fixnum
Output only.
-
#resource_name ⇒ String
Output only.
-
#targeting_location ⇒ Boolean
(also: #targeting_location?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesUserLocationView
constructor
A new instance of GoogleAdsSearchads360V23ResourcesUserLocationView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesUserLocationView
Returns a new instance of GoogleAdsSearchads360V23ResourcesUserLocationView.
34527 34528 34529 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34527 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_criterion_id ⇒ Fixnum
Output only. Criterion Id for the country.
Corresponds to the JSON property countryCriterionId
34512 34513 34514 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34512 def country_criterion_id @country_criterion_id end |
#resource_name ⇒ String
Output only. The resource name of the user location view. UserLocation view
resource names have the form: customers/customer_id/userLocationViews/
country_criterion_id~targeting_location`
Corresponds to the JSON propertyresourceName`
34519 34520 34521 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34519 def resource_name @resource_name end |
#targeting_location ⇒ Boolean Also known as: targeting_location?
Output only. Indicates whether location was targeted or not.
Corresponds to the JSON property targetingLocation
34524 34525 34526 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34524 def targeting_location @targeting_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34532 34533 34534 34535 34536 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34532 def update!(**args) @country_criterion_id = args[:country_criterion_id] if args.key?(:country_criterion_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @targeting_location = args[:targeting_location] if args.key?(:targeting_location) end |