Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesVisit
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesVisit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A visit.
Instance Attribute Summary collapse
-
#ad_id ⇒ Fixnum
Output only.
-
#asset_field_type ⇒ String
Output only.
-
#asset_id ⇒ Fixnum
Output only.
-
#click_id ⇒ String
Output only.
-
#criterion_id ⇒ Fixnum
Output only.
-
#id ⇒ Fixnum
Output only.
-
#merchant_id ⇒ Fixnum
Output only.
-
#product_channel ⇒ String
Output only.
-
#product_country_code ⇒ String
Output only.
-
#product_id ⇒ String
Output only.
-
#product_language_code ⇒ String
Output only.
-
#product_store_id ⇒ String
Output only.
-
#resource_name ⇒ String
Output only.
-
#visit_date_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesVisit
constructor
A new instance of GoogleAdsSearchads360V23ResourcesVisit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ResourcesVisit
Returns a new instance of GoogleAdsSearchads360V23ResourcesVisit.
34861 34862 34863 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34861 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_id ⇒ Fixnum
Output only. Ad ID. A value of 0 indicates that the ad is unattributed.
Corresponds to the JSON property adId
34783 34784 34785 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34783 def ad_id @ad_id end |
#asset_field_type ⇒ String
Output only. Asset field type of the visit event.
Corresponds to the JSON property assetFieldType
34788 34789 34790 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34788 def asset_field_type @asset_field_type end |
#asset_id ⇒ Fixnum
Output only. ID of the asset which was interacted with during the visit event.
Corresponds to the JSON property assetId
34793 34794 34795 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34793 def asset_id @asset_id end |
#click_id ⇒ String
Output only. A unique string for each visit that is passed to the landing page
as the click id URL parameter.
Corresponds to the JSON property clickId
34799 34800 34801 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34799 def click_id @click_id end |
#criterion_id ⇒ Fixnum
Output only. Search Ads 360 keyword ID. A value of 0 indicates that the
keyword is unattributed.
Corresponds to the JSON property criterionId
34805 34806 34807 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34805 def criterion_id @criterion_id end |
#id ⇒ Fixnum
Output only. The ID of the visit.
Corresponds to the JSON property id
34810 34811 34812 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34810 def id @id end |
#merchant_id ⇒ Fixnum
Output only. The Search Ads 360 inventory account ID containing the product
that was clicked on. Search Ads 360 generates this ID when you link an
inventory account in Search Ads 360.
Corresponds to the JSON property merchantId
34817 34818 34819 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34817 def merchant_id @merchant_id end |
#product_channel ⇒ String
Output only. The sales channel of the product that was clicked on: Online or
Local.
Corresponds to the JSON property productChannel
34823 34824 34825 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34823 def product_channel @product_channel end |
#product_country_code ⇒ String
Output only. The country (ISO-3166 format) registered for the inventory feed
that contains the product clicked on.
Corresponds to the JSON property productCountryCode
34829 34830 34831 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34829 def product_country_code @product_country_code end |
#product_id ⇒ String
Output only. The ID of the product clicked on.
Corresponds to the JSON property productId
34834 34835 34836 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34834 def product_id @product_id end |
#product_language_code ⇒ String
Output only. The language (ISO-639-1) that has been set for the Merchant
Center feed containing data about the product.
Corresponds to the JSON property productLanguageCode
34840 34841 34842 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34840 def product_language_code @product_language_code end |
#product_store_id ⇒ String
Output only. The store in the Local Inventory Ad that was clicked on. This
should match the store IDs used in your local products feed.
Corresponds to the JSON property productStoreId
34846 34847 34848 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34846 def product_store_id @product_store_id end |
#resource_name ⇒ String
Output only. The resource name of the visit. Visit resource names have the
form: customers/customer_id/visits/ad_group_id~criterion_id~
ds_visit_id`
Corresponds to the JSON propertyresourceName`
34853 34854 34855 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34853 def resource_name @resource_name end |
#visit_date_time ⇒ String
Output only. The timestamp of the visit event. The timestamp is in the
customer's time zone and in "yyyy-MM-dd HH:mm:ss" format.
Corresponds to the JSON property visitDateTime
34859 34860 34861 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34859 def visit_date_time @visit_date_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34866 34867 34868 34869 34870 34871 34872 34873 34874 34875 34876 34877 34878 34879 34880 34881 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34866 def update!(**args) @ad_id = args[:ad_id] if args.key?(:ad_id) @asset_field_type = args[:asset_field_type] if args.key?(:asset_field_type) @asset_id = args[:asset_id] if args.key?(:asset_id) @click_id = args[:click_id] if args.key?(:click_id) @criterion_id = args[:criterion_id] if args.key?(:criterion_id) @id = args[:id] if args.key?(:id) @merchant_id = args[:merchant_id] if args.key?(:merchant_id) @product_channel = args[:product_channel] if args.key?(:product_channel) @product_country_code = args[:product_country_code] if args.key?(:product_country_code) @product_id = args[:product_id] if args.key?(:product_id) @product_language_code = args[:product_language_code] if args.key?(:product_language_code) @product_store_id = args[:product_store_id] if args.key?(:product_store_id) @resource_name = args[:resource_name] if args.key?(:resource_name) @visit_date_time = args[:visit_date_time] if args.key?(:visit_date_time) end |