Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAccountBudgetProposalOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAccountBudgetProposalOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation to propose the creation of a new account-level budget or edit/end/remove an existing one.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccountBudgetProposal
An account-level budget proposal.
-
#remove ⇒ String
Remove operation: A resource name for the removed proposal is expected, in this format:
customers/customer_id/accountBudgetProposals/account_budget_proposal_id`` A request may be cancelled iff it is pending. -
#update_mask ⇒ String
FieldMask that determines which budget fields are modified.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAccountBudgetProposalOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAccountBudgetProposalOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAccountBudgetProposalOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAccountBudgetProposalOperation.
35951 35952 35953 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35951 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccountBudgetProposal
An account-level budget proposal. All fields prefixed with 'proposed' may not
necessarily be applied directly. For example, proposed spending limits may be
adjusted before their application. This is true if the 'proposed' field has an
'approved' counterpart, for example, spending limits. Note that the proposal
type (proposal_type) changes which fields are required and which must remain
empty.
Corresponds to the JSON property create
35933 35934 35935 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35933 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed proposal is expected, in
this format: customers/customer_id/accountBudgetProposals/
account_budget_proposal_id`A request may be cancelled iff it is pending.
Corresponds to the JSON propertyremove`
35940 35941 35942 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35940 def remove @remove end |
#update_mask ⇒ String
FieldMask that determines which budget fields are modified. While budgets may
be modified, proposals that propose such modifications are final. Therefore,
update operations are not supported for proposals. Proposals that modify
budgets have the 'update' proposal type. Specifying a mask for any other
proposal type is considered an error.
Corresponds to the JSON property updateMask
35949 35950 35951 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35949 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35956 35957 35958 35959 35960 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35956 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update_mask = args[:update_mask] if args.key?(:update_mask) end |