Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on an ad group ad label.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdLabel
A relationship between an ad group ad and a label.
-
#remove ⇒ String
Remove operation: A resource name for the ad group ad label being removed, in this format:
customers/customer_id/adGroupAdLabels/ad_group_id~ad_id~label_id`Corresponds to the JSON propertyremove`.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation.
35877 35878 35879 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35877 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAdLabel
A relationship between an ad group ad and a label.
Corresponds to the JSON property create
35868 35869 35870 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35868 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the ad group ad label being removed, in
this format: customers/customer_id/adGroupAdLabels/ad_group_id~ad_id~
label_id`
Corresponds to the JSON propertyremove`
35875 35876 35877 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35875 def remove @remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35882 35883 35884 35885 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35882 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) end |