Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on an ad group ad.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAd
An ad group ad.
-
#policy_validation_parameter ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyValidationParameter
Parameter for controlling how policy exemption is done.
-
#remove ⇒ String
Remove operation: A resource name for the removed ad is expected, in this format:
customers/customer_id/adGroupAds/ad_group_id~ad_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAd
An ad group ad.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupAdOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAdGroupAdOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupAdOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupAdOperation.
36053 36054 36055 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAd
An ad group ad.
Corresponds to the JSON property create
36030 36031 36032 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36030 def create @create end |
#policy_validation_parameter ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyValidationParameter
Parameter for controlling how policy exemption is done.
Corresponds to the JSON property policyValidationParameter
36035 36036 36037 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36035 def policy_validation_parameter @policy_validation_parameter end |
#remove ⇒ String
Remove operation: A resource name for the removed ad is expected, in this
format: customers/customer_id/adGroupAds/ad_group_id~ad_id`
Corresponds to the JSON propertyremove`
36041 36042 36043 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36041 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAd
An ad group ad.
Corresponds to the JSON property update
36046 36047 36048 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36046 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
36051 36052 36053 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36051 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36058 36059 36060 36061 36062 36063 36064 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36058 def update!(**args) @create = args[:create] if args.key?(:create) @policy_validation_parameter = args[:policy_validation_parameter] if args.key?(:policy_validation_parameter) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |