Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on an ad group ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupAdOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupAdOperation.



35918
35919
35920
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAd

An ad group ad. Corresponds to the JSON property create



35895
35896
35897
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35895

def create
  @create
end

#policy_validation_parameterGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyValidationParameter

Parameter for controlling how policy exemption is done. Corresponds to the JSON property policyValidationParameter



35900
35901
35902
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35900

def policy_validation_parameter
  @policy_validation_parameter
end

#removeString

Remove operation: A resource name for the removed ad is expected, in this format: customers/customer_id/adGroupAds/ad_group_id~ad_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


35906
35907
35908
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35906

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAd

An ad group ad. Corresponds to the JSON property update



35911
35912
35913
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35911

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


35916
35917
35918
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35916

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35923
35924
35925
35926
35927
35928
35929
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35923

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @policy_validation_parameter = args[:policy_validation_parameter] if args.key?(:policy_validation_parameter)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end