Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAssetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on an ad group asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupAssetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupAssetOperation.



35958
35959
35960
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35958

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAsset

A link between an ad group and an asset. Corresponds to the JSON property create



35939
35940
35941
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35939

def create
  @create
end

#removeString

Remove operation: A resource name for the removed ad group asset is expected, in this format: customers/customer_id/adGroupAssets/ad_group_id~asset_id ~field_type` Corresponds to the JSON propertyremove`

Returns:

  • (String)


35946
35947
35948
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35946

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAsset

A link between an ad group and an asset. Corresponds to the JSON property update



35951
35952
35953
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35951

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


35956
35957
35958
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35956

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35963
35964
35965
35966
35967
35968
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35963

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end