Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAssetSetOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAssetSetOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on an ad group asset set.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAssetSet
AdGroupAssetSet is the linkage between an ad group and an asset set.
-
#remove ⇒ String
Remove operation: A resource name for the removed ad group asset set is expected, in this format:
customers/customer_id/adGroupAssetSets/ad_group_id~asset_set_id`Corresponds to the JSON propertyremove`.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupAssetSetOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAdGroupAssetSetOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupAssetSetOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupAssetSetOperation.
36195 36196 36197 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAssetSet
AdGroupAssetSet is the linkage between an ad group and an asset set. Creating
an AdGroupAssetSet links an asset set with an ad group.
Corresponds to the JSON property create
36186 36187 36188 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36186 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed ad group asset set is
expected, in this format: customers/customer_id/adGroupAssetSets/
ad_group_id~asset_set_id`
Corresponds to the JSON propertyremove`
36193 36194 36195 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36193 def remove @remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36200 36201 36202 36203 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36200 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) end |