Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAssetSetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on an ad group asset set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupAssetSetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupAssetSetOperation.



36123
36124
36125
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36123

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAssetSet

AdGroupAssetSet is the linkage between an ad group and an asset set. Creating an AdGroupAssetSet links an asset set with an ad group. Corresponds to the JSON property create



36114
36115
36116
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36114

def create
  @create
end

#removeString

Remove operation: A resource name for the removed ad group asset set is expected, in this format: customers/customer_id/adGroupAssetSets/ ad_group_id~asset_set_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


36121
36122
36123
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36121

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36128
36129
36130
36131
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36128

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end