Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAssetSetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on an ad group asset set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupAssetSetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupAssetSetOperation.



35988
35989
35990
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAssetSet

AdGroupAssetSet is the linkage between an ad group and an asset set. Creating an AdGroupAssetSet links an asset set with an ad group. Corresponds to the JSON property create



35979
35980
35981
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35979

def create
  @create
end

#removeString

Remove operation: A resource name for the removed ad group asset set is expected, in this format: customers/customer_id/adGroupAssetSets/ ad_group_id~asset_set_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


35986
35987
35988
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35986

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35993
35994
35995
35996
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35993

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end