Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove, update) on an ad group bid modifier.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupBidModifier
Represents an ad group bid modifier.
-
#remove ⇒ String
Remove operation: A resource name for the removed ad group bid modifier is expected, in this format:
customers/customer_id/adGroupBidModifiers/ad_group_id~criterion_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupBidModifier
Represents an ad group bid modifier.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation.
36025 36026 36027 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupBidModifier
Represents an ad group bid modifier.
Corresponds to the JSON property create
36006 36007 36008 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36006 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed ad group bid modifier is
expected, in this format: customers/customer_id/adGroupBidModifiers/
ad_group_id~criterion_id`
Corresponds to the JSON propertyremove`
36013 36014 36015 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36013 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupBidModifier
Represents an ad group bid modifier.
Corresponds to the JSON property update
36018 36019 36020 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36018 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
36023 36024 36025 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36023 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36030 36031 36032 36033 36034 36035 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36030 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |