Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove, update) on an ad group criterion.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterion
An ad group criterion.
-
#exempt_policy_violation_keys ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyViolationKey>
The list of policy violation keys that should not cause a PolicyViolationError to be reported.
-
#remove ⇒ String
Remove operation: A resource name for the removed criterion is expected, in this format:
customers/customer_id/adGroupCriteria/ad_group_id~criterion_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterion
An ad group criterion.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupCriterionOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAdGroupCriterionOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupCriterionOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupCriterionOperation.
36267 36268 36269 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterion
An ad group criterion. The ad_group_criterion report only returns criteria
that were explicitly added to the ad group.
Corresponds to the JSON property create
36237 36238 36239 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36237 def create @create end |
#exempt_policy_violation_keys ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyViolationKey>
The list of policy violation keys that should not cause a PolicyViolationError
to be reported. Not all policy violations are exemptable, refer to the
is_exemptible field in the returned PolicyViolationError. Resources violating
these polices will be saved, but will not be eligible to serve. They may begin
serving at a later time due to a change in policies, re-review of the resource,
or a change in advertiser certificates.
Corresponds to the JSON property exemptPolicyViolationKeys
36247 36248 36249 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36247 def exempt_policy_violation_keys @exempt_policy_violation_keys end |
#remove ⇒ String
Remove operation: A resource name for the removed criterion is expected, in
this format: customers/customer_id/adGroupCriteria/ad_group_id~
criterion_id`
Corresponds to the JSON propertyremove`
36254 36255 36256 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36254 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupCriterion
An ad group criterion. The ad_group_criterion report only returns criteria
that were explicitly added to the ad group.
Corresponds to the JSON property update
36260 36261 36262 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36260 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
36265 36266 36267 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36265 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36272 36273 36274 36275 36276 36277 36278 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36272 def update!(**args) @create = args[:create] if args.key?(:create) @exempt_policy_violation_keys = args[:exempt_policy_violation_keys] if args.key?(:exempt_policy_violation_keys) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |