Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupLabelOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupLabelOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on an ad group label.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupLabel
A relationship between an ad group and a label.
-
#remove ⇒ String
Remove operation: A resource name for the ad group label being removed, in this format:
customers/customer_id/adGroupLabels/ad_group_id~label_id`Corresponds to the JSON propertyremove`.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupLabelOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAdGroupLabelOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupLabelOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupLabelOperation.
36233 36234 36235 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36233 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupLabel
A relationship between an ad group and a label.
Corresponds to the JSON property create
36225 36226 36227 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36225 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the ad group label being removed, in
this format: customers/customer_id/adGroupLabels/ad_group_id~label_id`
Corresponds to the JSON propertyremove`
36231 36232 36233 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36231 def remove @remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36238 36239 36240 36241 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36238 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) end |