Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on an ad group.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup
An ad group.
-
#remove ⇒ String
Remove operation: A resource name for the removed ad group is expected, in this format:
customers/customer_id/adGroups/ad_group_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup
An ad group.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAdGroupOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupOperation.
36404 36405 36406 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36404 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup
An ad group.
Corresponds to the JSON property create
36386 36387 36388 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36386 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed ad group is expected, in
this format: customers/customer_id/adGroups/ad_group_id`
Corresponds to the JSON propertyremove`
36392 36393 36394 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36392 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup
An ad group.
Corresponds to the JSON property update
36397 36398 36399 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36397 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
36402 36403 36404 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36402 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36409 36410 36411 36412 36413 36414 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36409 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |