Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on an ad group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdGroupOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAdGroupOperation.



36269
36270
36271
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36269

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup

An ad group. Corresponds to the JSON property create



36251
36252
36253
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36251

def create
  @create
end

#removeString

Remove operation: A resource name for the removed ad group is expected, in this format: customers/customer_id/adGroups/ad_group_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


36257
36258
36259
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36257

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroup

An ad group. Corresponds to the JSON property update



36262
36263
36264
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36262

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


36267
36268
36269
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36267

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36274
36275
36276
36277
36278
36279
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36274

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end