Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdParameterOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdParameterOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on ad parameter.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdParameter
An ad parameter that is used to update numeric values (such as prices or inventory levels) in any text line of an ad (including URLs).
-
#remove ⇒ String
Remove operation: A resource name for the ad parameter to remove is expected in this format:
customers/customer_id/adParameters/ad_group_id~criterion_id~parameter_index`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdParameter
An ad parameter that is used to update numeric values (such as prices or inventory levels) in any text line of an ad (including URLs).
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdParameterOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAdParameterOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAdParameterOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAdParameterOperation.
36347 36348 36349 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36347 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdParameter
An ad parameter that is used to update numeric values (such as prices or
inventory levels) in any text line of an ad (including URLs). There can be a
maximum of two AdParameters per ad group criterion. (One with parameter_index =
1 and one with parameter_index = 2.) In the ad the parameters are referenced
by a placeholder of the form "param#:value". For example, "param1:$17"
Corresponds to the JSON property create
36324 36325 36326 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36324 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the ad parameter to remove is expected
in this format: customers/customer_id/adParameters/ad_group_id~
criterion_id~parameter_index`
Corresponds to the JSON propertyremove`
36331 36332 36333 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36331 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdParameter
An ad parameter that is used to update numeric values (such as prices or
inventory levels) in any text line of an ad (including URLs). There can be a
maximum of two AdParameters per ad group criterion. (One with parameter_index =
1 and one with parameter_index = 2.) In the ad the parameters are referenced
by a placeholder of the form "param#:value". For example, "param1:$17"
Corresponds to the JSON property update
36340 36341 36342 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36340 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
36345 36346 36347 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36345 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36352 36353 36354 36355 36356 36357 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36352 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |