Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAddBatchJobOperationsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for BatchJobService.AddBatchJobOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAddBatchJobOperationsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesAddBatchJobOperationsRequest.



36383
36384
36385
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36383

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mutate_operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperation>

Required. The list of mutates being added. Operations can use negative integers as temp ids to signify dependencies between entities created in this batch job. For example, a customer with id = 1234 can create a campaign and an ad group in that same campaign by creating a campaign in the first operation with the resource name explicitly set to "customers/1234/campaigns/-1", and creating an ad group in the second operation with the campaign field also set to "customers/1234/campaigns/-1". Corresponds to the JSON property mutateOperations



36373
36374
36375
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36373

def mutate_operations
  @mutate_operations
end

#sequence_tokenString

A token used to enforce sequencing. The first AddBatchJobOperations request for a batch job should not set sequence_token. Subsequent requests must set sequence_token to the value of next_sequence_token received in the previous AddBatchJobOperations response. Corresponds to the JSON property sequenceToken

Returns:

  • (String)


36381
36382
36383
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36381

def sequence_token
  @sequence_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36388
36389
36390
36391
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36388

def update!(**args)
  @mutate_operations = args[:mutate_operations] if args.key?(:mutate_operations)
  @sequence_token = args[:sequence_token] if args.key?(:sequence_token)
end