Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAddBatchJobOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for BatchJobService.AddBatchJobOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAddBatchJobOperationsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesAddBatchJobOperationsResponse.



36410
36411
36412
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_sequence_tokenString

The sequence token to be used when calling AddBatchJobOperations again if more operations need to be added. The next AddBatchJobOperations request must set the sequence_token field to the value of this field. Corresponds to the JSON property nextSequenceToken

Returns:

  • (String)


36403
36404
36405
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36403

def next_sequence_token
  @next_sequence_token
end

#total_operationsFixnum

The total number of operations added so far for this batch job. Corresponds to the JSON property totalOperations

Returns:

  • (Fixnum)


36408
36409
36410
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36408

def total_operations
  @total_operations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36415
36416
36417
36418
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36415

def update!(**args)
  @next_sequence_token = args[:next_sequence_token] if args.key?(:next_sequence_token)
  @total_operations = args[:total_operations] if args.key?(:total_operations)
end