Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAddOfflineUserDataJobOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for OfflineUserDataJobService.AddOfflineUserDataJobOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAddOfflineUserDataJobOperationsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesAddOfflineUserDataJobOperationsResponse.



36623
36624
36625
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



36611
36612
36613
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36611

def partial_failure_error
  @partial_failure_error
end

#warningGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property warning



36621
36622
36623
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36621

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36628
36629
36630
36631
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36628

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @warning = args[:warning] if args.key?(:warning)
end