Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyIncentiveRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for applying an incentive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyIncentiveRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesApplyIncentiveRequest.



36583
36584
36585
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Required. User's country code. Required. This field must be equal to the Google Ads account's billing country. Incentive eligibility, terms of service, and reward values are often country-specific. This country code is used to ensure the selected incentive is applicable to the user. Possible country codes: https://developers.google.com/google-ads/api/data/codes-formats# country_codes Corresponds to the JSON property countryCode

Returns:

  • (String)


36581
36582
36583
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36581

def country_code
  @country_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36588
36589
36590
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36588

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
end