Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Information about the operation to apply a recommendation and any parameters to customize it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperation.



36889
36890
36891
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36889

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCallAssetParameters

Parameters to use when applying call asset recommendations. Corresponds to the JSON property callAsset



36764
36765
36766
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36764

def call_asset
  @call_asset
end

#call_extensionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCallExtensionParameters

Parameters to use when applying call extension recommendation. Corresponds to the JSON property callExtension



36769
36770
36771
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36769

def call_extension
  @call_extension
end

#callout_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCalloutAssetParameters

Parameters to use when applying callout asset recommendations. Corresponds to the JSON property calloutAsset



36774
36775
36776
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36774

def callout_asset
  @callout_asset
end

#callout_extensionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCalloutExtensionParameters

Parameters to use when applying callout extension recommendation. Corresponds to the JSON property calloutExtension



36779
36780
36781
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36779

def callout_extension
  @callout_extension
end

#campaign_budgetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCampaignBudgetParameters

Parameters to use when applying a campaign budget recommendation. Corresponds to the JSON property campaignBudget



36784
36785
36786
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36784

def campaign_budget
  @campaign_budget
end

#forecasting_set_target_cpaGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationForecastingSetTargetCpaParameters

Parameters to use when applying a set target CPA recommendation. Corresponds to the JSON property forecastingSetTargetCpa



36789
36790
36791
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36789

def forecasting_set_target_cpa
  @forecasting_set_target_cpa
end

#forecasting_set_target_roasGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationForecastingSetTargetRoasParameters

Parameters to use when applying a forecasting set target roas recommendation. Corresponds to the JSON property forecastingSetTargetRoas



36794
36795
36796
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36794

def forecasting_set_target_roas
  @forecasting_set_target_roas
end

#keywordGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationKeywordParameters

Parameters to use when applying keyword recommendation. Corresponds to the JSON property keyword



36799
36800
36801
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36799

def keyword
  @keyword
end

#lead_form_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationLeadFormAssetParameters

Parameters to use when applying a lead form asset recommendation. Corresponds to the JSON property leadFormAsset



36804
36805
36806
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36804

def lead_form_asset
  @lead_form_asset
end

#lower_target_roasGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationLowerTargetRoasParameters

Parameters to use when applying lower Target ROAS recommendations. Corresponds to the JSON property lowerTargetRoas



36809
36810
36811
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36809

def lower_target_roas
  @lower_target_roas
end

#move_unused_budgetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationMoveUnusedBudgetParameters

Parameters to use when applying move unused budget recommendation. Corresponds to the JSON property moveUnusedBudget



36814
36815
36816
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36814

def move_unused_budget
  @move_unused_budget
end

#raise_target_cpaGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationRaiseTargetCpaParameters

Parameters to use when applying raise Target CPA recommendations. Corresponds to the JSON property raiseTargetCpa



36819
36820
36821
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36819

def raise_target_cpa
  @raise_target_cpa
end

#raise_target_cpa_bid_too_lowGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationRaiseTargetCpaBidTooLowParameters

Parameters to use when applying a raise target CPA bid too low recommendation. The apply is asynchronous and can take minutes depending on the number of ad groups there is in the related campaign.. Corresponds to the JSON property raiseTargetCpaBidTooLow



36826
36827
36828
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36826

def raise_target_cpa_bid_too_low
  @raise_target_cpa_bid_too_low
end

#resource_nameString

The resource name of the recommendation to apply. Corresponds to the JSON property resourceName

Returns:

  • (String)


36831
36832
36833
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36831

def resource_name
  @resource_name
end

#responsive_search_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationResponsiveSearchAdParameters

Parameters to use when applying a responsive search ad recommendation. Corresponds to the JSON property responsiveSearchAd



36836
36837
36838
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36836

def responsive_search_ad
  @responsive_search_ad
end

#responsive_search_ad_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationResponsiveSearchAdAssetParameters

Parameters to use when applying a responsive search ad asset recommendation. Corresponds to the JSON property responsiveSearchAdAsset



36841
36842
36843
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36841

def responsive_search_ad_asset
  @responsive_search_ad_asset
end

#responsive_search_ad_improve_ad_strengthGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationResponsiveSearchAdImproveAdStrengthParameters

Parameters to use when applying a responsive search ad improve ad strength recommendation. Corresponds to the JSON property responsiveSearchAdImproveAdStrength



36847
36848
36849
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36847

def responsive_search_ad_improve_ad_strength
  @responsive_search_ad_improve_ad_strength
end

#set_target_cpaGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationForecastingSetTargetCpaParameters

Parameters to use when applying a set target CPA recommendation. Corresponds to the JSON property setTargetCpa



36852
36853
36854
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36852

def set_target_cpa
  @set_target_cpa
end

#set_target_roasGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationForecastingSetTargetRoasParameters

Parameters to use when applying a forecasting set target roas recommendation. Corresponds to the JSON property setTargetRoas



36857
36858
36859
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36857

def set_target_roas
  @set_target_roas
end

Parameters to use when applying sitelink asset recommendations. Corresponds to the JSON property sitelinkAsset



36862
36863
36864
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36862

def sitelink_asset
  @sitelink_asset
end

Parameters to use when applying sitelink recommendation. Corresponds to the JSON property sitelinkExtension



36867
36868
36869
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36867

def sitelink_extension
  @sitelink_extension
end

#target_cpa_opt_inGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationTargetCpaOptInParameters

Parameters to use when applying Target CPA recommendation. Corresponds to the JSON property targetCpaOptIn



36872
36873
36874
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36872

def target_cpa_opt_in
  @target_cpa_opt_in
end

#target_roas_opt_inGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationTargetRoasOptInParameters

Parameters to use when applying a Target ROAS opt-in recommendation. Corresponds to the JSON property targetRoasOptIn



36877
36878
36879
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36877

def target_roas_opt_in
  @target_roas_opt_in
end

#text_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationTextAdParameters

Parameters to use when applying a text ad recommendation. Corresponds to the JSON property textAd



36882
36883
36884
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36882

def text_ad
  @text_ad
end

#use_broad_match_keywordGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationUseBroadMatchKeywordParameters

Parameters to use when applying a use broad match keyword recommendation. Corresponds to the JSON property useBroadMatchKeyword



36887
36888
36889
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36887

def use_broad_match_keyword
  @use_broad_match_keyword
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36894
36895
36896
36897
36898
36899
36900
36901
36902
36903
36904
36905
36906
36907
36908
36909
36910
36911
36912
36913
36914
36915
36916
36917
36918
36919
36920
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36894

def update!(**args)
  @call_asset = args[:call_asset] if args.key?(:call_asset)
  @call_extension = args[:call_extension] if args.key?(:call_extension)
  @callout_asset = args[:callout_asset] if args.key?(:callout_asset)
  @callout_extension = args[:callout_extension] if args.key?(:callout_extension)
  @campaign_budget = args[:campaign_budget] if args.key?(:campaign_budget)
  @forecasting_set_target_cpa = args[:forecasting_set_target_cpa] if args.key?(:forecasting_set_target_cpa)
  @forecasting_set_target_roas = args[:forecasting_set_target_roas] if args.key?(:forecasting_set_target_roas)
  @keyword = args[:keyword] if args.key?(:keyword)
  @lead_form_asset = args[:lead_form_asset] if args.key?(:lead_form_asset)
  @lower_target_roas = args[:lower_target_roas] if args.key?(:lower_target_roas)
  @move_unused_budget = args[:move_unused_budget] if args.key?(:move_unused_budget)
  @raise_target_cpa = args[:raise_target_cpa] if args.key?(:raise_target_cpa)
  @raise_target_cpa_bid_too_low = args[:raise_target_cpa_bid_too_low] if args.key?(:raise_target_cpa_bid_too_low)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @responsive_search_ad = args[:responsive_search_ad] if args.key?(:responsive_search_ad)
  @responsive_search_ad_asset = args[:responsive_search_ad_asset] if args.key?(:responsive_search_ad_asset)
  @responsive_search_ad_improve_ad_strength = args[:responsive_search_ad_improve_ad_strength] if args.key?(:responsive_search_ad_improve_ad_strength)
  @set_target_cpa = args[:set_target_cpa] if args.key?(:set_target_cpa)
  @set_target_roas = args[:set_target_roas] if args.key?(:set_target_roas)
  @sitelink_asset = args[:sitelink_asset] if args.key?(:sitelink_asset)
  @sitelink_extension = args[:sitelink_extension] if args.key?(:sitelink_extension)
  @target_cpa_opt_in = args[:target_cpa_opt_in] if args.key?(:target_cpa_opt_in)
  @target_roas_opt_in = args[:target_roas_opt_in] if args.key?(:target_roas_opt_in)
  @text_ad = args[:text_ad] if args.key?(:text_ad)
  @use_broad_match_keyword = args[:use_broad_match_keyword] if args.key?(:use_broad_match_keyword)
end