Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Information about the operation to apply a recommendation and any parameters to customize it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperation.



36754
36755
36756
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCallAssetParameters

Parameters to use when applying call asset recommendations. Corresponds to the JSON property callAsset



36629
36630
36631
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36629

def call_asset
  @call_asset
end

#call_extensionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCallExtensionParameters

Parameters to use when applying call extension recommendation. Corresponds to the JSON property callExtension



36634
36635
36636
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36634

def call_extension
  @call_extension
end

#callout_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCalloutAssetParameters

Parameters to use when applying callout asset recommendations. Corresponds to the JSON property calloutAsset



36639
36640
36641
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36639

def callout_asset
  @callout_asset
end

#callout_extensionGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCalloutExtensionParameters

Parameters to use when applying callout extension recommendation. Corresponds to the JSON property calloutExtension



36644
36645
36646
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36644

def callout_extension
  @callout_extension
end

#campaign_budgetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCampaignBudgetParameters

Parameters to use when applying a campaign budget recommendation. Corresponds to the JSON property campaignBudget



36649
36650
36651
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36649

def campaign_budget
  @campaign_budget
end

#forecasting_set_target_cpaGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationForecastingSetTargetCpaParameters

Parameters to use when applying a set target CPA recommendation. Corresponds to the JSON property forecastingSetTargetCpa



36654
36655
36656
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36654

def forecasting_set_target_cpa
  @forecasting_set_target_cpa
end

#forecasting_set_target_roasGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationForecastingSetTargetRoasParameters

Parameters to use when applying a forecasting set target roas recommendation. Corresponds to the JSON property forecastingSetTargetRoas



36659
36660
36661
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36659

def forecasting_set_target_roas
  @forecasting_set_target_roas
end

#keywordGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationKeywordParameters

Parameters to use when applying keyword recommendation. Corresponds to the JSON property keyword



36664
36665
36666
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36664

def keyword
  @keyword
end

#lead_form_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationLeadFormAssetParameters

Parameters to use when applying a lead form asset recommendation. Corresponds to the JSON property leadFormAsset



36669
36670
36671
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36669

def lead_form_asset
  @lead_form_asset
end

#lower_target_roasGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationLowerTargetRoasParameters

Parameters to use when applying lower Target ROAS recommendations. Corresponds to the JSON property lowerTargetRoas



36674
36675
36676
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36674

def lower_target_roas
  @lower_target_roas
end

#move_unused_budgetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationMoveUnusedBudgetParameters

Parameters to use when applying move unused budget recommendation. Corresponds to the JSON property moveUnusedBudget



36679
36680
36681
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36679

def move_unused_budget
  @move_unused_budget
end

#raise_target_cpaGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationRaiseTargetCpaParameters

Parameters to use when applying raise Target CPA recommendations. Corresponds to the JSON property raiseTargetCpa



36684
36685
36686
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36684

def raise_target_cpa
  @raise_target_cpa
end

#raise_target_cpa_bid_too_lowGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationRaiseTargetCpaBidTooLowParameters

Parameters to use when applying a raise target CPA bid too low recommendation. The apply is asynchronous and can take minutes depending on the number of ad groups there is in the related campaign.. Corresponds to the JSON property raiseTargetCpaBidTooLow



36691
36692
36693
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36691

def raise_target_cpa_bid_too_low
  @raise_target_cpa_bid_too_low
end

#resource_nameString

The resource name of the recommendation to apply. Corresponds to the JSON property resourceName

Returns:

  • (String)


36696
36697
36698
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36696

def resource_name
  @resource_name
end

#responsive_search_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationResponsiveSearchAdParameters

Parameters to use when applying a responsive search ad recommendation. Corresponds to the JSON property responsiveSearchAd



36701
36702
36703
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36701

def responsive_search_ad
  @responsive_search_ad
end

#responsive_search_ad_assetGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationResponsiveSearchAdAssetParameters

Parameters to use when applying a responsive search ad asset recommendation. Corresponds to the JSON property responsiveSearchAdAsset



36706
36707
36708
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36706

def responsive_search_ad_asset
  @responsive_search_ad_asset
end

#responsive_search_ad_improve_ad_strengthGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationResponsiveSearchAdImproveAdStrengthParameters

Parameters to use when applying a responsive search ad improve ad strength recommendation. Corresponds to the JSON property responsiveSearchAdImproveAdStrength



36712
36713
36714
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36712

def responsive_search_ad_improve_ad_strength
  @responsive_search_ad_improve_ad_strength
end

#set_target_cpaGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationForecastingSetTargetCpaParameters

Parameters to use when applying a set target CPA recommendation. Corresponds to the JSON property setTargetCpa



36717
36718
36719
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36717

def set_target_cpa
  @set_target_cpa
end

#set_target_roasGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationForecastingSetTargetRoasParameters

Parameters to use when applying a forecasting set target roas recommendation. Corresponds to the JSON property setTargetRoas



36722
36723
36724
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36722

def set_target_roas
  @set_target_roas
end

Parameters to use when applying sitelink asset recommendations. Corresponds to the JSON property sitelinkAsset



36727
36728
36729
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36727

def sitelink_asset
  @sitelink_asset
end

Parameters to use when applying sitelink recommendation. Corresponds to the JSON property sitelinkExtension



36732
36733
36734
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36732

def sitelink_extension
  @sitelink_extension
end

#target_cpa_opt_inGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationTargetCpaOptInParameters

Parameters to use when applying Target CPA recommendation. Corresponds to the JSON property targetCpaOptIn



36737
36738
36739
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36737

def target_cpa_opt_in
  @target_cpa_opt_in
end

#target_roas_opt_inGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationTargetRoasOptInParameters

Parameters to use when applying a Target ROAS opt-in recommendation. Corresponds to the JSON property targetRoasOptIn



36742
36743
36744
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36742

def target_roas_opt_in
  @target_roas_opt_in
end

#text_adGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationTextAdParameters

Parameters to use when applying a text ad recommendation. Corresponds to the JSON property textAd



36747
36748
36749
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36747

def text_ad
  @text_ad
end

#use_broad_match_keywordGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationUseBroadMatchKeywordParameters

Parameters to use when applying a use broad match keyword recommendation. Corresponds to the JSON property useBroadMatchKeyword



36752
36753
36754
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36752

def use_broad_match_keyword
  @use_broad_match_keyword
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36759
36760
36761
36762
36763
36764
36765
36766
36767
36768
36769
36770
36771
36772
36773
36774
36775
36776
36777
36778
36779
36780
36781
36782
36783
36784
36785
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36759

def update!(**args)
  @call_asset = args[:call_asset] if args.key?(:call_asset)
  @call_extension = args[:call_extension] if args.key?(:call_extension)
  @callout_asset = args[:callout_asset] if args.key?(:callout_asset)
  @callout_extension = args[:callout_extension] if args.key?(:callout_extension)
  @campaign_budget = args[:campaign_budget] if args.key?(:campaign_budget)
  @forecasting_set_target_cpa = args[:forecasting_set_target_cpa] if args.key?(:forecasting_set_target_cpa)
  @forecasting_set_target_roas = args[:forecasting_set_target_roas] if args.key?(:forecasting_set_target_roas)
  @keyword = args[:keyword] if args.key?(:keyword)
  @lead_form_asset = args[:lead_form_asset] if args.key?(:lead_form_asset)
  @lower_target_roas = args[:lower_target_roas] if args.key?(:lower_target_roas)
  @move_unused_budget = args[:move_unused_budget] if args.key?(:move_unused_budget)
  @raise_target_cpa = args[:raise_target_cpa] if args.key?(:raise_target_cpa)
  @raise_target_cpa_bid_too_low = args[:raise_target_cpa_bid_too_low] if args.key?(:raise_target_cpa_bid_too_low)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @responsive_search_ad = args[:responsive_search_ad] if args.key?(:responsive_search_ad)
  @responsive_search_ad_asset = args[:responsive_search_ad_asset] if args.key?(:responsive_search_ad_asset)
  @responsive_search_ad_improve_ad_strength = args[:responsive_search_ad_improve_ad_strength] if args.key?(:responsive_search_ad_improve_ad_strength)
  @set_target_cpa = args[:set_target_cpa] if args.key?(:set_target_cpa)
  @set_target_roas = args[:set_target_roas] if args.key?(:set_target_roas)
  @sitelink_asset = args[:sitelink_asset] if args.key?(:sitelink_asset)
  @sitelink_extension = args[:sitelink_extension] if args.key?(:sitelink_extension)
  @target_cpa_opt_in = args[:target_cpa_opt_in] if args.key?(:target_cpa_opt_in)
  @target_roas_opt_in = args[:target_roas_opt_in] if args.key?(:target_roas_opt_in)
  @text_ad = args[:text_ad] if args.key?(:text_ad)
  @use_broad_match_keyword = args[:use_broad_match_keyword] if args.key?(:use_broad_match_keyword)
end