Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationAdAssetApplyParameters
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationAdAssetApplyParameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Common parameters used when applying ad asset recommendations.
Instance Attribute Summary collapse
-
#existing_assets ⇒ Array<String>
The resource names of existing assets to attach to a scope.
-
#new_assets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAsset>
The assets to create and attach to a scope.
-
#scope ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationAdAssetApplyParameters
constructor
A new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationAdAssetApplyParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationAdAssetApplyParameters
Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationAdAssetApplyParameters.
34886 34887 34888 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34886 def initialize(**args) update!(**args) end |
Instance Attribute Details
#existing_assets ⇒ Array<String>
The resource names of existing assets to attach to a scope. This may be
combined with new_assets in the same call.
Corresponds to the JSON property existingAssets
34870 34871 34872 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34870 def existing_assets @existing_assets end |
#new_assets ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAsset>
The assets to create and attach to a scope. This may be combined with
existing_assets in the same call.
Corresponds to the JSON property newAssets
34876 34877 34878 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34876 def new_assets @new_assets end |
#scope ⇒ String
Required. The scope at which to apply the assets. Assets at the campaign scope
level will be applied to the campaign associated with the recommendation.
Assets at the customer scope will apply to the entire account. Assets at the
campaign scope will override any attached at the customer scope.
Corresponds to the JSON property scope
34884 34885 34886 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34884 def scope @scope end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34891 34892 34893 34894 34895 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34891 def update!(**args) @existing_assets = args[:existing_assets] if args.key?(:existing_assets) @new_assets = args[:new_assets] if args.key?(:new_assets) @scope = args[:scope] if args.key?(:scope) end |