Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationAdAssetApplyParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Common parameters used when applying ad asset recommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationAdAssetApplyParameters

Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationAdAssetApplyParameters.



34784
34785
34786
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34784

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#existing_assetsArray<String>

The resource names of existing assets to attach to a scope. This may be combined with new_assets in the same call. Corresponds to the JSON property existingAssets

Returns:

  • (Array<String>)


34768
34769
34770
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34768

def existing_assets
  @existing_assets
end

#new_assetsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAsset>

The assets to create and attach to a scope. This may be combined with existing_assets in the same call. Corresponds to the JSON property newAssets



34774
34775
34776
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34774

def new_assets
  @new_assets
end

#scopeString

Required. The scope at which to apply the assets. Assets at the campaign scope level will be applied to the campaign associated with the recommendation. Assets at the customer scope will apply to the entire account. Assets at the campaign scope will override any attached at the customer scope. Corresponds to the JSON property scope

Returns:

  • (String)


34782
34783
34784
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34782

def scope
  @scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34789
34790
34791
34792
34793
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34789

def update!(**args)
  @existing_assets = args[:existing_assets] if args.key?(:existing_assets)
  @new_assets = args[:new_assets] if args.key?(:new_assets)
  @scope = args[:scope] if args.key?(:scope)
end