Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCampaignBudgetParameters
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCampaignBudgetParameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Parameters to use when applying a campaign budget recommendation.
Instance Attribute Summary collapse
-
#new_budget_amount_micros ⇒ Fixnum
New budget amount to set for target budget resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCampaignBudgetParameters
constructor
A new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCampaignBudgetParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCampaignBudgetParameters
Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationCampaignBudgetParameters.
34881 34882 34883 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34881 def initialize(**args) update!(**args) end |
Instance Attribute Details
#new_budget_amount_micros ⇒ Fixnum
New budget amount to set for target budget resource. This is a required field.
Corresponds to the JSON property newBudgetAmountMicros
34879 34880 34881 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34879 def new_budget_amount_micros @new_budget_amount_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34886 34887 34888 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34886 def update!(**args) @new_budget_amount_micros = args[:new_budget_amount_micros] if args.key?(:new_budget_amount_micros) end |