Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationLeadFormAssetParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Parameters to use when applying a lead form asset recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationLeadFormAssetParameters

Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationLeadFormAssetParameters.



35094
35095
35096
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_asset_apply_parametersGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationAdAssetApplyParameters

Common parameters used when applying ad asset recommendations. Corresponds to the JSON property adAssetApplyParameters



35083
35084
35085
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35083

def ad_asset_apply_parameters
  @ad_asset_apply_parameters
end

#set_submit_lead_form_asset_campaign_goalBoolean Also known as: set_submit_lead_form_asset_campaign_goal?

If true, the "Submit Lead Form" goal will be set on the target campaign. As a result, ads will be shown as lead form creative ads. If false, the "Submit Lead Form" goal will not be set on the campaign and ads will contain lead form assets. Corresponds to the JSON property setSubmitLeadFormAssetCampaignGoal

Returns:

  • (Boolean)


35091
35092
35093
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35091

def set_submit_lead_form_asset_campaign_goal
  @set_submit_lead_form_asset_campaign_goal
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35099
35100
35101
35102
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35099

def update!(**args)
  @ad_asset_apply_parameters = args[:ad_asset_apply_parameters] if args.key?(:ad_asset_apply_parameters)
  @set_submit_lead_form_asset_campaign_goal = args[:set_submit_lead_form_asset_campaign_goal] if args.key?(:set_submit_lead_form_asset_campaign_goal)
end