Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationLeadFormAssetParameters
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationLeadFormAssetParameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Parameters to use when applying a lead form asset recommendation.
Instance Attribute Summary collapse
-
#ad_asset_apply_parameters ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationAdAssetApplyParameters
Common parameters used when applying ad asset recommendations.
-
#set_submit_lead_form_asset_campaign_goal ⇒ Boolean
(also: #set_submit_lead_form_asset_campaign_goal?)
If true, the "Submit Lead Form" goal will be set on the target campaign.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationLeadFormAssetParameters
constructor
A new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationLeadFormAssetParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationLeadFormAssetParameters
Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationLeadFormAssetParameters.
34992 34993 34994 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34992 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_asset_apply_parameters ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationAdAssetApplyParameters
Common parameters used when applying ad asset recommendations.
Corresponds to the JSON property adAssetApplyParameters
34981 34982 34983 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34981 def ad_asset_apply_parameters @ad_asset_apply_parameters end |
#set_submit_lead_form_asset_campaign_goal ⇒ Boolean Also known as: set_submit_lead_form_asset_campaign_goal?
If true, the "Submit Lead Form" goal will be set on the target campaign. As a
result, ads will be shown as lead form creative ads. If false, the "Submit
Lead Form" goal will not be set on the campaign and ads will contain lead form
assets.
Corresponds to the JSON property setSubmitLeadFormAssetCampaignGoal
34989 34990 34991 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34989 def set_submit_lead_form_asset_campaign_goal @set_submit_lead_form_asset_campaign_goal end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34997 34998 34999 35000 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 34997 def update!(**args) @ad_asset_apply_parameters = args[:ad_asset_apply_parameters] if args.key?(:ad_asset_apply_parameters) @set_submit_lead_form_asset_campaign_goal = args[:set_submit_lead_form_asset_campaign_goal] if args.key?(:set_submit_lead_form_asset_campaign_goal) end |