Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationMoveUnusedBudgetParameters
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationMoveUnusedBudgetParameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Parameters to use when applying move unused budget recommendation.
Instance Attribute Summary collapse
-
#budget_micros_to_move ⇒ Fixnum
Budget amount to move from excess budget to constrained budget.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationMoveUnusedBudgetParameters
constructor
A new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationMoveUnusedBudgetParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationMoveUnusedBudgetParameters
Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationMoveUnusedBudgetParameters.
35032 35033 35034 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35032 def initialize(**args) update!(**args) end |
Instance Attribute Details
#budget_micros_to_move ⇒ Fixnum
Budget amount to move from excess budget to constrained budget. This is a
required field.
Corresponds to the JSON property budgetMicrosToMove
35030 35031 35032 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35030 def budget_micros_to_move @budget_micros_to_move end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35037 35038 35039 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35037 def update!(**args) @budget_micros_to_move = args[:budget_micros_to_move] if args.key?(:budget_micros_to_move) end |