Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperationUseBroadMatchKeywordParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Parameters to use when applying a use broad match keyword recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationOperationUseBroadMatchKeywordParameters

Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationOperationUseBroadMatchKeywordParameters.



35259
35260
35261
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35259

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_budget_amount_microsFixnum

New budget amount to set for target budget resource. Corresponds to the JSON property newBudgetAmountMicros

Returns:

  • (Fixnum)


35257
35258
35259
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35257

def new_budget_amount_micros
  @new_budget_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35264
35265
35266
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35264

def update!(**args)
  @new_budget_amount_micros = args[:new_budget_amount_micros] if args.key?(:new_budget_amount_micros)
end