Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for RecommendationService.ApplyRecommendation.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationRequest.
36807 36808 36809 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36807 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationOperation>
Required. The list of operations to apply recommendations. If partial_failure=
false all recommendations should be of the same type There is a limit of 100
operations per request.
Corresponds to the JSON property operations
36797 36798 36799 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36797 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, operations will be carried out as a transaction if
and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
36804 36805 36806 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36804 def partial_failure @partial_failure end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36812 36813 36814 36815 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36812 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) end |