Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for RecommendationService.ApplyRecommendation.
Instance Attribute Summary collapse
-
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationResult>
Results of operations to apply recommendations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesApplyRecommendationResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesApplyRecommendationResponse.
36837 36838 36839 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36837 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property partialFailureError
36830 36831 36832 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36830 def partial_failure_error @partial_failure_error end |
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesApplyRecommendationResult>
Results of operations to apply recommendations.
Corresponds to the JSON property results
36835 36836 36837 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36835 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36842 36843 36844 36845 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36842 def update!(**args) @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error) @results = args[:results] if args.key?(:results) end |