Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on an asset group asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation.



37030
37031
37032
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37030

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupAsset

AssetGroupAsset is the link between an asset and an asset group. Adding an AssetGroupAsset links an asset with an asset group. Corresponds to the JSON property create



37010
37011
37012
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37010

def create
  @create
end

#removeString

Remove operation: A resource name for the removed asset group asset is expected, in this format: customers/customer_id/assetGroupAssets/ asset_group_id~asset_id~field_type` Corresponds to the JSON propertyremove`

Returns:

  • (String)


37017
37018
37019
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37017

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupAsset

AssetGroupAsset is the link between an asset and an asset group. Adding an AssetGroupAsset links an asset with an asset group. Corresponds to the JSON property update



37023
37024
37025
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37023

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


37028
37029
37030
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37028

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37035
37036
37037
37038
37039
37040
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37035

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end