Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on an asset group asset.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupAsset
AssetGroupAsset is the link between an asset and an asset group.
-
#remove ⇒ String
Remove operation: A resource name for the removed asset group asset is expected, in this format:
customers/customer_id/assetGroupAssets/asset_group_id~asset_id~field_type`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupAsset
AssetGroupAsset is the link between an asset and an asset group.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation.
36895 36896 36897 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36895 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupAsset
AssetGroupAsset is the link between an asset and an asset group. Adding an
AssetGroupAsset links an asset with an asset group.
Corresponds to the JSON property create
36875 36876 36877 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36875 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed asset group asset is
expected, in this format: customers/customer_id/assetGroupAssets/
asset_group_id~asset_id~field_type`
Corresponds to the JSON propertyremove`
36882 36883 36884 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36882 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupAsset
AssetGroupAsset is the link between an asset and an asset group. Adding an
AssetGroupAsset links an asset with an asset group.
Corresponds to the JSON property update
36888 36889 36890 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36888 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
36893 36894 36895 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36893 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36900 36901 36902 36903 36904 36905 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36900 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |