Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on an asset group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetGroupOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAssetGroupOperation.



37114
37115
37116
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37114

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroup

An asset group. AssetGroupAsset is used to link an asset to the asset group. AssetGroupSignal is used to associate a signal to an asset group. Corresponds to the JSON property create



37095
37096
37097
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37095

def create
  @create
end

#removeString

Remove operation: A resource name for the removed asset group is expected, in this format: customers/customer_id/assetGroups/asset_group_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


37101
37102
37103
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37101

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroup

An asset group. AssetGroupAsset is used to link an asset to the asset group. AssetGroupSignal is used to associate a signal to an asset group. Corresponds to the JSON property update



37107
37108
37109
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37107

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


37112
37113
37114
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37112

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37119
37120
37121
37122
37123
37124
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37119

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end