Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on an asset group.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroup
An asset group.
-
#remove ⇒ String
Remove operation: A resource name for the removed asset group is expected, in this format:
customers/customer_id/assetGroups/asset_group_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroup
An asset group.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetGroupOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAssetGroupOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetGroupOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAssetGroupOperation.
36979 36980 36981 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36979 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroup
An asset group. AssetGroupAsset is used to link an asset to the asset group.
AssetGroupSignal is used to associate a signal to an asset group.
Corresponds to the JSON property create
36960 36961 36962 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36960 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed asset group is expected, in
this format: customers/customer_id/assetGroups/asset_group_id`
Corresponds to the JSON propertyremove`
36966 36967 36968 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36966 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroup
An asset group. AssetGroupAsset is used to link an asset to the asset group.
AssetGroupSignal is used to associate a signal to an asset group.
Corresponds to the JSON property update
36972 36973 36974 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36972 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
36977 36978 36979 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36977 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36984 36985 36986 36987 36988 36989 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 36984 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |