Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupSignalOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on an asset group signal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetGroupSignalOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAssetGroupSignalOperation.



37156
37157
37158
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupSignal

AssetGroupSignal represents a signal in an asset group. The existence of a signal tells the performance max campaign who's most likely to convert. Performance Max uses the signal to look for new people with similar or stronger intent to find conversions across Search, Display, Video, and more. Corresponds to the JSON property create



37137
37138
37139
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37137

def create
  @create
end

#exempt_policy_violation_keysArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonPolicyViolationKey>

Optional. The list of policy violation keys that should not cause a PolicyViolationError to be reported. Not all policy violations are exemptable, refer to the is_exemptible field in the returned PolicyViolationError. Resources violating these polices will be saved, but will not be eligible to serve. They may begin serving at a later time due to a change in policies, re- review of the resource, or a change in advertiser certificates. Corresponds to the JSON property exemptPolicyViolationKeys



37147
37148
37149
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37147

def exempt_policy_violation_keys
  @exempt_policy_violation_keys
end

#removeString

Remove operation: A resource name for the removed asset group signal is expected, in this format: customers/customer_id/assetGroupSignals/ asset_group_id~criterion_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


37154
37155
37156
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37154

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37161
37162
37163
37164
37165
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37161

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @exempt_policy_violation_keys = args[:exempt_policy_violation_keys] if args.key?(:exempt_policy_violation_keys)
  @remove = args[:remove] if args.key?(:remove)
end