Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation to create an asset. Supported asset types are YoutubeVideoAsset, MediaBundleAsset, ImageAsset, LeadFormAsset, LocationAsset, and ImageAsset. TextAsset can be created with an Ad inline, but it can also be created apart from an Ad like other assets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAssetOperation.



37196
37197
37198
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37196

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAsset

Asset is a part of an ad which can be shared across multiple ads. It can be an image (ImageAsset), a video (YoutubeVideoAsset), etc. Assets are immutable and cannot be removed. To stop an asset from serving, remove the asset from the entity that is using it. Corresponds to the JSON property create



37181
37182
37183
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37181

def create
  @create
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAsset

Asset is a part of an ad which can be shared across multiple ads. It can be an image (ImageAsset), a video (YoutubeVideoAsset), etc. Assets are immutable and cannot be removed. To stop an asset from serving, remove the asset from the entity that is using it. Corresponds to the JSON property update



37189
37190
37191
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37189

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


37194
37195
37196
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37194

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37201
37202
37203
37204
37205
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37201

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end