Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetAssetOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetAssetOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on an asset set asset.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset
AssetSetAsset is the link between an asset and an asset set.
-
#remove ⇒ String
Remove operation: A resource name for the removed asset set asset is expected, in this format:
customers/customer_id/assetSetAssets/asset_set_id~asset_id`Corresponds to the JSON propertyremove`.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetSetAssetOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAssetSetAssetOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetSetAssetOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAssetSetAssetOperation.
37297 37298 37299 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37297 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset
AssetSetAsset is the link between an asset and an asset set. Adding an
AssetSetAsset links an asset with an asset set.
Corresponds to the JSON property create
37288 37289 37290 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37288 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed asset set asset is expected,
in this format: customers/customer_id/assetSetAssets/asset_set_id~
asset_id`
Corresponds to the JSON propertyremove`
37295 37296 37297 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37295 def remove @remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37302 37303 37304 37305 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37302 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) end |