Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetAssetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on an asset set asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetSetAssetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAssetSetAssetOperation.



37225
37226
37227
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset

AssetSetAsset is the link between an asset and an asset set. Adding an AssetSetAsset links an asset with an asset set. Corresponds to the JSON property create



37216
37217
37218
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37216

def create
  @create
end

#removeString

Remove operation: A resource name for the removed asset set asset is expected, in this format: customers/customer_id/assetSetAssets/asset_set_id~ asset_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


37223
37224
37225
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37223

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37230
37231
37232
37233
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37230

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end