Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on an asset set.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSet
An asset set representing a collection of assets.
-
#remove ⇒ String
Remove operation: A resource name for the removed asset set is expected, in this format:
customers/customer_id/assetSets/asset_set_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSet
An asset set representing a collection of assets.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetSetOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAssetSetOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetSetOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAssetSetOperation.
37335 37336 37337 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37335 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSet
An asset set representing a collection of assets. Use AssetSetAsset to link an
asset to the asset set.
Corresponds to the JSON property create
37316 37317 37318 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37316 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed asset set is expected, in
this format: customers/customer_id/assetSets/asset_set_id`
Corresponds to the JSON propertyremove`
37322 37323 37324 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37322 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSet
An asset set representing a collection of assets. Use AssetSetAsset to link an
asset to the asset set.
Corresponds to the JSON property update
37328 37329 37330 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37328 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
37333 37334 37335 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37333 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37340 37341 37342 37343 37344 37345 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37340 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |