Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on an asset set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetSetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAssetSetOperation.



37263
37264
37265
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37263

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSet

An asset set representing a collection of assets. Use AssetSetAsset to link an asset to the asset set. Corresponds to the JSON property create



37244
37245
37246
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37244

def create
  @create
end

#removeString

Remove operation: A resource name for the removed asset set is expected, in this format: customers/customer_id/assetSets/asset_set_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


37250
37251
37252
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37250

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSet

An asset set representing a collection of assets. Use AssetSetAsset to link an asset to the asset set. Corresponds to the JSON property update



37256
37257
37258
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37256

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


37261
37262
37263
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37261

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37268
37269
37270
37271
37272
37273
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37268

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end