Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on an asset set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetSetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAssetSetOperation.



37128
37129
37130
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSet

An asset set representing a collection of assets. Use AssetSetAsset to link an asset to the asset set. Corresponds to the JSON property create



37109
37110
37111
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37109

def create
  @create
end

#removeString

Remove operation: A resource name for the removed asset set is expected, in this format: customers/customer_id/assetSets/asset_set_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


37115
37116
37117
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37115

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSet

An asset set representing a collection of assets. Use AssetSetAsset to link an asset to the asset set. Corresponds to the JSON property update



37121
37122
37123
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37121

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


37126
37127
37128
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37126

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37133
37134
37135
37136
37137
37138
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37133

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end