Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetsWithFieldType
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetsWithFieldType
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The combination of system asset and field type to remove.
Instance Attribute Summary collapse
-
#asset ⇒ String
Required.
-
#asset_field_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetsWithFieldType
constructor
A new instance of GoogleAdsSearchads360V23ServicesAssetsWithFieldType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAssetsWithFieldType
Returns a new instance of GoogleAdsSearchads360V23ServicesAssetsWithFieldType.
37155 37156 37157 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37155 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset ⇒ String
Required. The resource name of the asset to be removed.
Corresponds to the JSON property asset
37148 37149 37150 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37148 def asset @asset end |
#asset_field_type ⇒ String
Required. The asset field type.
Corresponds to the JSON property assetFieldType
37153 37154 37155 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37153 def asset_field_type @asset_field_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37160 37161 37162 37163 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37160 def update!(**args) @asset = args[:asset] if args.key?(:asset) @asset_field_type = args[:asset_field_type] if args.key?(:asset_field_type) end |