Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceCompositionAttribute
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceCompositionAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An audience attribute with metadata and metrics.
Instance Attribute Summary collapse
-
#attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata
An audience attribute, with metadata about it, returned in response to a search.
-
#metrics ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics
The share and index metrics associated with an attribute in an audience composition insights report.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceCompositionAttribute
constructor
A new instance of GoogleAdsSearchads360V23ServicesAudienceCompositionAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceCompositionAttribute
Returns a new instance of GoogleAdsSearchads360V23ServicesAudienceCompositionAttribute.
37182 37183 37184 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37182 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata
An audience attribute, with metadata about it, returned in response to a
search.
Corresponds to the JSON property attributeMetadata
37174 37175 37176 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37174 def @attribute_metadata end |
#metrics ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics
The share and index metrics associated with an attribute in an audience
composition insights report.
Corresponds to the JSON property metrics
37180 37181 37182 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37180 def metrics @metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37187 37188 37189 37190 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37187 def update!(**args) @attribute_metadata = args[:attribute_metadata] if args.key?(:attribute_metadata) @metrics = args[:metrics] if args.key?(:metrics) end |