Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceCompositionAttributeCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A collection of related attributes, with metadata and metrics, in an audience composition insights report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceCompositionAttributeCluster

Returns a new instance of GoogleAdsSearchads360V23ServicesAudienceCompositionAttributeCluster.



37214
37215
37216
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37214

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceCompositionAttribute>

The individual attributes that make up this cluster, with metadata and metrics. Corresponds to the JSON property attributes



37201
37202
37203
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37201

def attributes
  @attributes
end

#cluster_display_nameString

The name of this cluster of attributes Corresponds to the JSON property clusterDisplayName

Returns:

  • (String)


37206
37207
37208
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37206

def cluster_display_name
  @cluster_display_name
end

#cluster_metricsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics

The share and index metrics associated with an attribute in an audience composition insights report. Corresponds to the JSON property clusterMetrics



37212
37213
37214
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37212

def cluster_metrics
  @cluster_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37219
37220
37221
37222
37223
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37219

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @cluster_display_name = args[:cluster_display_name] if args.key?(:cluster_display_name)
  @cluster_metrics = args[:cluster_metrics] if args.key?(:cluster_metrics)
end