Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The share and index metrics associated with an attribute in an audience composition insights report.
Instance Attribute Summary collapse
-
#audience_share ⇒ Float
The fraction (from 0 to 1 inclusive) of the specific audience that match the attribute.
-
#baseline_audience_share ⇒ Float
The fraction (from 0 to 1 inclusive) of the baseline audience that match the attribute.
-
#index ⇒ Float
The ratio of audience_share to baseline_audience_share, or zero if this ratio is undefined or is not meaningful.
-
#score ⇒ Float
A relevance score from 0 to 1 inclusive.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics
constructor
A new instance of GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics
Returns a new instance of GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics.
37461 37462 37463 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience_share ⇒ Float
The fraction (from 0 to 1 inclusive) of the specific audience that match the
attribute.
Corresponds to the JSON property audienceShare
37442 37443 37444 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37442 def audience_share @audience_share end |
#baseline_audience_share ⇒ Float
The fraction (from 0 to 1 inclusive) of the baseline audience that match the
attribute.
Corresponds to the JSON property baselineAudienceShare
37448 37449 37450 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37448 def baseline_audience_share @baseline_audience_share end |
#index ⇒ Float
The ratio of audience_share to baseline_audience_share, or zero if this ratio
is undefined or is not meaningful.
Corresponds to the JSON property index
37454 37455 37456 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37454 def index @index end |
#score ⇒ Float
A relevance score from 0 to 1 inclusive.
Corresponds to the JSON property score
37459 37460 37461 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37459 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37466 37467 37468 37469 37470 37471 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37466 def update!(**args) @audience_share = args[:audience_share] if args.key?(:audience_share) @baseline_audience_share = args[:baseline_audience_share] if args.key?(:baseline_audience_share) @index = args[:index] if args.key?(:index) @score = args[:score] if args.key?(:score) end |