Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The share and index metrics associated with an attribute in an audience composition insights report.
Instance Attribute Summary collapse
-
#audience_share ⇒ Float
The fraction (from 0 to 1 inclusive) of the specific audience that match the attribute.
-
#baseline_audience_share ⇒ Float
The fraction (from 0 to 1 inclusive) of the baseline audience that match the attribute.
-
#index ⇒ Float
The ratio of audience_share to baseline_audience_share, or zero if this ratio is undefined or is not meaningful.
-
#score ⇒ Float
A relevance score from 0 to 1 inclusive.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics
constructor
A new instance of GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics
Returns a new instance of GoogleAdsSearchads360V23ServicesAudienceCompositionMetrics.
37389 37390 37391 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience_share ⇒ Float
The fraction (from 0 to 1 inclusive) of the specific audience that match the
attribute.
Corresponds to the JSON property audienceShare
37370 37371 37372 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37370 def audience_share @audience_share end |
#baseline_audience_share ⇒ Float
The fraction (from 0 to 1 inclusive) of the baseline audience that match the
attribute.
Corresponds to the JSON property baselineAudienceShare
37376 37377 37378 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37376 def baseline_audience_share @baseline_audience_share end |
#index ⇒ Float
The ratio of audience_share to baseline_audience_share, or zero if this ratio
is undefined or is not meaningful.
Corresponds to the JSON property index
37382 37383 37384 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37382 def index @index end |
#score ⇒ Float
A relevance score from 0 to 1 inclusive.
Corresponds to the JSON property score
37387 37388 37389 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37387 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37394 37395 37396 37397 37398 37399 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37394 def update!(**args) @audience_share = args[:audience_share] if args.key?(:audience_share) @baseline_audience_share = args[:baseline_audience_share] if args.key?(:baseline_audience_share) @index = args[:index] if args.key?(:index) @score = args[:score] if args.key?(:score) end |