Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update) on an audience.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAudience
Audience is an effective targeting option that lets you intersect different segment attributes, such as detailed demographics and affinities, to create audiences that represent sections of your target segments.
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAudience
Audience is an effective targeting option that lets you intersect different segment attributes, such as detailed demographics and affinities, to create audiences that represent sections of your target segments.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesAudienceOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesAudienceOperation.
37550 37551 37552 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37550 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAudience
Audience is an effective targeting option that lets you intersect different
segment attributes, such as detailed demographics and affinities, to create
audiences that represent sections of your target segments.
Corresponds to the JSON property create
37536 37537 37538 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37536 def create @create end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAudience
Audience is an effective targeting option that lets you intersect different
segment attributes, such as detailed demographics and affinities, to create
audiences that represent sections of your target segments.
Corresponds to the JSON property update
37543 37544 37545 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37543 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
37548 37549 37550 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37548 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37555 37556 37557 37558 37559 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37555 def update!(**args) @create = args[:create] if args.key?(:create) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |