Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update) on an audience.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesAudienceOperation.



37478
37479
37480
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAudience

Audience is an effective targeting option that lets you intersect different segment attributes, such as detailed demographics and affinities, to create audiences that represent sections of your target segments. Corresponds to the JSON property create



37464
37465
37466
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37464

def create
  @create
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAudience

Audience is an effective targeting option that lets you intersect different segment attributes, such as detailed demographics and affinities, to create audiences that represent sections of your target segments. Corresponds to the JSON property update



37471
37472
37473
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37471

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


37476
37477
37478
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37476

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37483
37484
37485
37486
37487
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37483

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end