Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOverlapItem
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOverlapItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An audience attribute, with metadata including the overlap between this attribute's potential YouTube reach and that of a primary attribute.
Instance Attribute Summary collapse
-
#attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata
An audience attribute, with metadata about it, returned in response to a search.
-
#potential_youtube_reach_intersection ⇒ Fixnum
The estimated size of the intersection of this audience attribute with the primary attribute, that is, the number of reachable YouTube users who match BOTH the primary attribute and this one.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceOverlapItem
constructor
A new instance of GoogleAdsSearchads360V23ServicesAudienceOverlapItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceOverlapItem
Returns a new instance of GoogleAdsSearchads360V23ServicesAudienceOverlapItem.
37508 37509 37510 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37508 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata
An audience attribute, with metadata about it, returned in response to a
search.
Corresponds to the JSON property attributeMetadata
37499 37500 37501 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37499 def @attribute_metadata end |
#potential_youtube_reach_intersection ⇒ Fixnum
The estimated size of the intersection of this audience attribute with the
primary attribute, that is, the number of reachable YouTube users who match
BOTH the primary attribute and this one.
Corresponds to the JSON property potentialYoutubeReachIntersection
37506 37507 37508 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37506 def potential_youtube_reach_intersection @potential_youtube_reach_intersection end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37513 37514 37515 37516 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37513 def update!(**args) @attribute_metadata = args[:attribute_metadata] if args.key?(:attribute_metadata) @potential_youtube_reach_intersection = args[:potential_youtube_reach_intersection] if args.key?(:potential_youtube_reach_intersection) end |