Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOverlapItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An audience attribute, with metadata including the overlap between this attribute's potential YouTube reach and that of a primary attribute.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceOverlapItem

Returns a new instance of GoogleAdsSearchads360V23ServicesAudienceOverlapItem.



37373
37374
37375
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_metadataGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata

An audience attribute, with metadata about it, returned in response to a search. Corresponds to the JSON property attributeMetadata



37364
37365
37366
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37364

def 
  @attribute_metadata
end

#potential_youtube_reach_intersectionFixnum

The estimated size of the intersection of this audience attribute with the primary attribute, that is, the number of reachable YouTube users who match BOTH the primary attribute and this one. Corresponds to the JSON property potentialYoutubeReachIntersection

Returns:

  • (Fixnum)


37371
37372
37373
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37371

def potential_youtube_reach_intersection
  @potential_youtube_reach_intersection
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37378
37379
37380
37381
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37378

def update!(**args)
  @attribute_metadata = args[:attribute_metadata] if args.key?(:attribute_metadata)
  @potential_youtube_reach_intersection = args[:potential_youtube_reach_intersection] if args.key?(:potential_youtube_reach_intersection)
end