Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceTargeting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Audience targeting for reach forecast.
Instance Attribute Summary collapse
-
#user_interest ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserInterestInfo>
List of audiences based on user interests to be targeted.
-
#user_lists ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListInfo>
List of audiences based on user lists to be targeted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceTargeting
constructor
A new instance of GoogleAdsSearchads360V23ServicesAudienceTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesAudienceTargeting
Returns a new instance of GoogleAdsSearchads360V23ServicesAudienceTargeting.
37398 37399 37400 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#user_interest ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserInterestInfo>
List of audiences based on user interests to be targeted.
Corresponds to the JSON property userInterest
37391 37392 37393 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37391 def user_interest @user_interest end |
#user_lists ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListInfo>
List of audiences based on user lists to be targeted.
Corresponds to the JSON property userLists
37396 37397 37398 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37396 def user_lists @user_lists end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37403 37404 37405 37406 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37403 def update!(**args) @user_interest = args[:user_interest] if args.key?(:user_interest) @user_lists = args[:user_lists] if args.key?(:user_lists) end |