Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBatchJobOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation on a batch job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBatchJobOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesBatchJobOperation.



37562
37563
37564
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBatchJob

A list of mutates being processed asynchronously. The mutates are uploaded by the user. The mutates themselves aren't readable and the results of the job can only be read using BatchJobService.ListBatchJobResults. Corresponds to the JSON property create



37553
37554
37555
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37553

def create
  @create
end

#removeString

Remove operation: The batch job must not have been run. A resource name for the removed batch job is expected, in this format: customers/customer_id/ batchJobs/batch_job_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


37560
37561
37562
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37560

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37567
37568
37569
37570
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37567

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end