Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBatchJobResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBatchJobResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An individual batch job result.
Instance Attribute Summary collapse
-
#mutate_operation_response ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperationResponse
Response message for the resource mutate.
-
#operation_index ⇒ Fixnum
Index of the mutate operation.
-
#status ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBatchJobResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesBatchJobResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBatchJobResult
Returns a new instance of GoogleAdsSearchads360V23ServicesBatchJobResult.
37597 37598 37599 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37597 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mutate_operation_response ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperationResponse
Response message for the resource mutate.
Corresponds to the JSON property mutateOperationResponse
37580 37581 37582 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37580 def mutate_operation_response @mutate_operation_response end |
#operation_index ⇒ Fixnum
Index of the mutate operation.
Corresponds to the JSON property operationIndex
37585 37586 37587 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37585 def operation_index @operation_index end |
#status ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
37595 37596 37597 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37595 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37602 37603 37604 37605 37606 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37602 def update!(**args) @mutate_operation_response = args[:mutate_operation_response] if args.key?(:mutate_operation_response) @operation_index = args[:operation_index] if args.key?(:operation_index) @status = args[:status] if args.key?(:status) end |