Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBatchJobResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An individual batch job result.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBatchJobResult

Returns a new instance of GoogleAdsSearchads360V23ServicesBatchJobResult.



37462
37463
37464
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mutate_operation_responseGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperationResponse

Response message for the resource mutate. Corresponds to the JSON property mutateOperationResponse



37445
37446
37447
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37445

def mutate_operation_response
  @mutate_operation_response
end

#operation_indexFixnum

Index of the mutate operation. Corresponds to the JSON property operationIndex

Returns:

  • (Fixnum)


37450
37451
37452
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37450

def operation_index
  @operation_index
end

#statusGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



37460
37461
37462
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37460

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37467
37468
37469
37470
37471
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37467

def update!(**args)
  @mutate_operation_response = args[:mutate_operation_response] if args.key?(:mutate_operation_response)
  @operation_index = args[:operation_index] if args.key?(:operation_index)
  @status = args[:status] if args.key?(:status)
end