Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBenchmarksProductMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The metadata associated with a product supported for benchmarks data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBenchmarksProductMetadata

Returns a new instance of GoogleAdsSearchads360V23ServicesBenchmarksProductMetadata.



37662
37663
37664
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37662

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#marketing_objectiveString

The marketing objective associated with the product. A marketing objective is a broader classification of products. Corresponds to the JSON property marketingObjective

Returns:

  • (String)


37649
37650
37651
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37649

def marketing_objective
  @marketing_objective
end

#product_codeString

The identifier of the product. The identifier can be used as inputs for BenchmarksService.GenerateBenchmarksMetrics. Corresponds to the JSON property productCode

Returns:

  • (String)


37655
37656
37657
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37655

def product_code
  @product_code
end

#product_nameString

The name of the product. Corresponds to the JSON property productName

Returns:

  • (String)


37660
37661
37662
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37660

def product_name
  @product_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37667
37668
37669
37670
37671
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37667

def update!(**args)
  @marketing_objective = args[:marketing_objective] if args.key?(:marketing_objective)
  @product_code = args[:product_code] if args.key?(:product_code)
  @product_name = args[:product_name] if args.key?(:product_name)
end