Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBenchmarksProductMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The metadata associated with a product supported for benchmarks data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBenchmarksProductMetadata

Returns a new instance of GoogleAdsSearchads360V23ServicesBenchmarksProductMetadata.



37527
37528
37529
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37527

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#marketing_objectiveString

The marketing objective associated with the product. A marketing objective is a broader classification of products. Corresponds to the JSON property marketingObjective

Returns:

  • (String)


37514
37515
37516
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37514

def marketing_objective
  @marketing_objective
end

#product_codeString

The identifier of the product. The identifier can be used as inputs for BenchmarksService.GenerateBenchmarksMetrics. Corresponds to the JSON property productCode

Returns:

  • (String)


37520
37521
37522
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37520

def product_code
  @product_code
end

#product_nameString

The name of the product. Corresponds to the JSON property productName

Returns:

  • (String)


37525
37526
37527
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37525

def product_name
  @product_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37532
37533
37534
37535
37536
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37532

def update!(**args)
  @marketing_objective = args[:marketing_objective] if args.key?(:marketing_objective)
  @product_code = args[:product_code] if args.key?(:product_code)
  @product_name = args[:product_name] if args.key?(:product_name)
end