Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddableKeyword
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddableKeyword
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A biddable keyword part of an ad group.
Instance Attribute Summary collapse
-
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo
A keyword criterion.
-
#max_cpc_bid_micros ⇒ Fixnum
A max cpc bid in micros that overrides the ad group level max cpc bid in forecast simulation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBiddableKeyword
constructor
A new instance of GoogleAdsSearchads360V23ServicesBiddableKeyword.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBiddableKeyword
Returns a new instance of GoogleAdsSearchads360V23ServicesBiddableKeyword.
37808 37809 37810 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37808 def initialize(**args) update!(**args) end |
Instance Attribute Details
#keyword ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo
A keyword criterion.
Corresponds to the JSON property keyword
37798 37799 37800 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37798 def keyword @keyword end |
#max_cpc_bid_micros ⇒ Fixnum
A max cpc bid in micros that overrides the ad group level max cpc bid in
forecast simulation. This value will override the max cpc value set in the
bidding strategy and ad group. Only specify this field for bidding strategies
that support max cpc values.
Corresponds to the JSON property maxCpcBidMicros
37806 37807 37808 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37806 def max_cpc_bid_micros @max_cpc_bid_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37813 37814 37815 37816 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37813 def update!(**args) @keyword = args[:keyword] if args.key?(:keyword) @max_cpc_bid_micros = args[:max_cpc_bid_micros] if args.key?(:max_cpc_bid_micros) end |