Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove, update) on a data exclusion.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingDataExclusion
Represents a bidding data exclusion.
-
#remove ⇒ String
Remove operation: A resource name for the removed data exclusion is expected, in this format:
customers/customer_id/biddingDataExclusions/data_exclusion_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingDataExclusion
Represents a bidding data exclusion.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation.
37851 37852 37853 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37851 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingDataExclusion
Represents a bidding data exclusion. Bidding data exclusions can be set in
client accounts only, and cannot be used in manager accounts. See "About data
exclusions" at https://support.google.com/google-ads/answer/10370710. Note: A
customer account can have a maximum of 500 active bidding data exclusions.
Corresponds to the JSON property create
37829 37830 37831 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37829 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed data exclusion is expected,
in this format: customers/customer_id/biddingDataExclusions/
data_exclusion_id`
Corresponds to the JSON propertyremove`
37836 37837 37838 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37836 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingDataExclusion
Represents a bidding data exclusion. Bidding data exclusions can be set in
client accounts only, and cannot be used in manager accounts. See "About data
exclusions" at https://support.google.com/google-ads/answer/10370710. Note: A
customer account can have a maximum of 500 active bidding data exclusions.
Corresponds to the JSON property update
37844 37845 37846 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37844 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
37849 37850 37851 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37849 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37856 37857 37858 37859 37860 37861 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37856 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |