Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove, update) on a data exclusion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation.



37779
37780
37781
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37779

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingDataExclusion

Represents a bidding data exclusion. Bidding data exclusions can be set in client accounts only, and cannot be used in manager accounts. See "About data exclusions" at https://support.google.com/google-ads/answer/10370710. Note: A customer account can have a maximum of 500 active bidding data exclusions. Corresponds to the JSON property create



37757
37758
37759
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37757

def create
  @create
end

#removeString

Remove operation: A resource name for the removed data exclusion is expected, in this format: customers/customer_id/biddingDataExclusions/ data_exclusion_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


37764
37765
37766
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37764

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingDataExclusion

Represents a bidding data exclusion. Bidding data exclusions can be set in client accounts only, and cannot be used in manager accounts. See "About data exclusions" at https://support.google.com/google-ads/answer/10370710. Note: A customer account can have a maximum of 500 active bidding data exclusions. Corresponds to the JSON property update



37772
37773
37774
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37772

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


37777
37778
37779
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37777

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37784
37785
37786
37787
37788
37789
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37784

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end