Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove, update) on a seasonality adjustment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation.



37687
37688
37689
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37687

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment

Represents a bidding seasonality adjustment. Cannot be used in manager accounts. See "About seasonality adjustments" at https://support.google.com/ google-ads/answer/10369906. Corresponds to the JSON property create



37666
37667
37668
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37666

def create
  @create
end

#removeString

Remove operation: A resource name for the removed seasonality adjustment is expected, in this format: customers/customer_id/ biddingSeasonalityAdjustments/seasonality_adjustment_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


37673
37674
37675
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37673

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment

Represents a bidding seasonality adjustment. Cannot be used in manager accounts. See "About seasonality adjustments" at https://support.google.com/ google-ads/answer/10369906. Corresponds to the JSON property update



37680
37681
37682
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37680

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


37685
37686
37687
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37685

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37692
37693
37694
37695
37696
37697
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37692

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end