Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove, update) on a seasonality adjustment.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment
Represents a bidding seasonality adjustment.
-
#remove ⇒ String
Remove operation: A resource name for the removed seasonality adjustment is expected, in this format:
customers/customer_id/ biddingSeasonalityAdjustments/seasonality_adjustment_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment
Represents a bidding seasonality adjustment.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation.
37687 37688 37689 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37687 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment
Represents a bidding seasonality adjustment. Cannot be used in manager
accounts. See "About seasonality adjustments" at https://support.google.com/
google-ads/answer/10369906.
Corresponds to the JSON property create
37666 37667 37668 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37666 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed seasonality adjustment is
expected, in this format: customers/customer_id/
biddingSeasonalityAdjustments/seasonality_adjustment_id`
Corresponds to the JSON propertyremove`
37673 37674 37675 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37673 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingSeasonalityAdjustment
Represents a bidding seasonality adjustment. Cannot be used in manager
accounts. See "About seasonality adjustments" at https://support.google.com/
google-ads/answer/10369906.
Corresponds to the JSON property update
37680 37681 37682 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37680 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
37685 37686 37687 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37685 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37692 37693 37694 37695 37696 37697 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37692 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |