Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingStrategyOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingStrategyOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a bidding strategy.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingStrategy
A bidding strategy.
-
#remove ⇒ String
Remove operation: A resource name for the removed bidding strategy is expected, in this format:
customers/customer_id/biddingStrategies/bidding_strategy_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingStrategy
A bidding strategy.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBiddingStrategyOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesBiddingStrategyOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBiddingStrategyOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesBiddingStrategyOperation.
37861 37862 37863 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37861 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingStrategy
A bidding strategy.
Corresponds to the JSON property create
37842 37843 37844 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37842 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed bidding strategy is expected,
in this format: customers/customer_id/biddingStrategies/
bidding_strategy_id`
Corresponds to the JSON propertyremove`
37849 37850 37851 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37849 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingStrategy
A bidding strategy.
Corresponds to the JSON property update
37854 37855 37856 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37854 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
37859 37860 37861 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37859 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37866 37867 37868 37869 37870 37871 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37866 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |