Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingStrategyOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingStrategyOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a bidding strategy.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingStrategy
A bidding strategy.
-
#remove ⇒ String
Remove operation: A resource name for the removed bidding strategy is expected, in this format:
customers/customer_id/biddingStrategies/bidding_strategy_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingStrategy
A bidding strategy.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBiddingStrategyOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesBiddingStrategyOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBiddingStrategyOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesBiddingStrategyOperation.
37726 37727 37728 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37726 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingStrategy
A bidding strategy.
Corresponds to the JSON property create
37707 37708 37709 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37707 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed bidding strategy is expected,
in this format: customers/customer_id/biddingStrategies/
bidding_strategy_id`
Corresponds to the JSON propertyremove`
37714 37715 37716 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37714 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBiddingStrategy
A bidding strategy.
Corresponds to the JSON property update
37719 37720 37721 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37719 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
37724 37725 37726 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37724 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37731 37732 37733 37734 37735 37736 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37731 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |