Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBillingSetupOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBillingSetupOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation on a billing setup, which describes the cancellation of an existing billing setup.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBillingSetup
A billing setup, which associates a payments account and an advertiser.
-
#remove ⇒ String
Resource name of the billing setup to remove.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBillingSetupOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesBillingSetupOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesBillingSetupOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesBillingSetupOperation.
37757 37758 37759 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesBillingSetup
A billing setup, which associates a payments account and an advertiser. A
billing setup is specific to one advertiser.
Corresponds to the JSON property create
37748 37749 37750 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37748 def create @create end |
#remove ⇒ String
Resource name of the billing setup to remove. A setup cannot be removed unless
it is in a pending state or its scheduled start time is in the future. The
resource name looks like customers/customer_id/billingSetups/billing_id`.
Corresponds to the JSON propertyremove`
37755 37756 37757 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37755 def remove @remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37762 37763 37764 37765 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37762 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) end |