Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCallConversion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCallConversion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A call conversion.
Instance Attribute Summary collapse
-
#call_start_date_time ⇒ String
The date time at which the call occurred.
-
#caller_id ⇒ String
The caller id from which this call was placed.
-
#consent ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonConsent
Consent Corresponds to the JSON property
consent. -
#conversion_action ⇒ String
Resource name of the conversion action associated with this conversion.
-
#conversion_date_time ⇒ String
The date time at which the conversion occurred.
-
#conversion_value ⇒ Float
The value of the conversion for the advertiser.
-
#currency_code ⇒ String
Currency associated with the conversion value.
-
#custom_variables ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomVariable>
The custom variables associated with this conversion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCallConversion
constructor
A new instance of GoogleAdsSearchads360V23ServicesCallConversion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCallConversion
Returns a new instance of GoogleAdsSearchads360V23ServicesCallConversion.
37988 37989 37990 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37988 def initialize(**args) update!(**args) end |
Instance Attribute Details
#call_start_date_time ⇒ String
The date time at which the call occurred. The timezone must be specified. The
format is "yyyy-mm-dd hh:mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08:
00".
Corresponds to the JSON property callStartDateTime
37944 37945 37946 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37944 def call_start_date_time @call_start_date_time end |
#caller_id ⇒ String
The caller id from which this call was placed. Caller id is expected to be in
E.164 format with preceding '+' sign, for example, "+16502531234".
Corresponds to the JSON property callerId
37950 37951 37952 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37950 def caller_id @caller_id end |
#consent ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonConsent
Consent
Corresponds to the JSON property consent
37955 37956 37957 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37955 def @consent end |
#conversion_action ⇒ String
Resource name of the conversion action associated with this conversion. Note:
Although this resource name consists of a customer id and a conversion action
id, validation will ignore the customer id and use the conversion action id as
the sole identifier of the conversion action.
Corresponds to the JSON property conversionAction
37963 37964 37965 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37963 def conversion_action @conversion_action end |
#conversion_date_time ⇒ String
The date time at which the conversion occurred. Must be after the call time.
The timezone must be specified. The format is "yyyy-mm-dd hh:mm:ss+|-hh:mm",
for example, "2019-01-01 12:32:45-08:00".
Corresponds to the JSON property conversionDateTime
37970 37971 37972 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37970 def conversion_date_time @conversion_date_time end |
#conversion_value ⇒ Float
The value of the conversion for the advertiser.
Corresponds to the JSON property conversionValue
37975 37976 37977 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37975 def conversion_value @conversion_value end |
#currency_code ⇒ String
Currency associated with the conversion value. This is the ISO 4217 3-
character currency code. For example: USD, EUR.
Corresponds to the JSON property currencyCode
37981 37982 37983 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37981 def currency_code @currency_code end |
#custom_variables ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomVariable>
The custom variables associated with this conversion.
Corresponds to the JSON property customVariables
37986 37987 37988 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37986 def custom_variables @custom_variables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37993 37994 37995 37996 37997 37998 37999 38000 38001 38002 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37993 def update!(**args) @call_start_date_time = args[:call_start_date_time] if args.key?(:call_start_date_time) @caller_id = args[:caller_id] if args.key?(:caller_id) @consent = args[:consent] if args.key?(:consent) @conversion_action = args[:conversion_action] if args.key?(:conversion_action) @conversion_date_time = args[:conversion_date_time] if args.key?(:conversion_date_time) @conversion_value = args[:conversion_value] if args.key?(:conversion_value) @currency_code = args[:currency_code] if args.key?(:currency_code) @custom_variables = args[:custom_variables] if args.key?(:custom_variables) end |