Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCallConversionResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCallConversionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Identifying information for a successfully processed CallConversionUpload.
Instance Attribute Summary collapse
-
#call_start_date_time ⇒ String
The date time at which the call occurred.
-
#caller_id ⇒ String
The caller id from which this call was placed.
-
#conversion_action ⇒ String
Resource name of the conversion action associated with this conversion.
-
#conversion_date_time ⇒ String
The date time at which the conversion occurred.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCallConversionResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesCallConversionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCallConversionResult
Returns a new instance of GoogleAdsSearchads360V23ServicesCallConversionResult.
38032 38033 38034 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38032 def initialize(**args) update!(**args) end |
Instance Attribute Details
#call_start_date_time ⇒ String
The date time at which the call occurred. The format is "yyyy-mm-dd hh:mm:ss+|-
hh:mm", for example, "2019-01-01 12:32:45-08:00".
Corresponds to the JSON property callStartDateTime
38013 38014 38015 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38013 def call_start_date_time @call_start_date_time end |
#caller_id ⇒ String
The caller id from which this call was placed. Caller id is expected to be in
E.164 format with preceding '+' sign.
Corresponds to the JSON property callerId
38019 38020 38021 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38019 def caller_id @caller_id end |
#conversion_action ⇒ String
Resource name of the conversion action associated with this conversion.
Corresponds to the JSON property conversionAction
38024 38025 38026 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38024 def conversion_action @conversion_action end |
#conversion_date_time ⇒ String
The date time at which the conversion occurred. The format is "yyyy-mm-dd hh:
mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08:00".
Corresponds to the JSON property conversionDateTime
38030 38031 38032 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38030 def conversion_date_time @conversion_date_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38037 38038 38039 38040 38041 38042 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38037 def update!(**args) @call_start_date_time = args[:call_start_date_time] if args.key?(:call_start_date_time) @caller_id = args[:caller_id] if args.key?(:caller_id) @conversion_action = args[:conversion_action] if args.key?(:conversion_action) @conversion_date_time = args[:conversion_date_time] if args.key?(:conversion_date_time) end |