Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on a campaign asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignAssetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignAssetOperation.



37826
37827
37828
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37826

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAsset

A link between a Campaign and an Asset. Corresponds to the JSON property create



37807
37808
37809
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37807

def create
  @create
end

#removeString

Remove operation: A resource name for the removed campaign asset is expected, in this format: customers/customer_id/campaignAssets/campaign_id~ asset_id~field_type` Corresponds to the JSON propertyremove`

Returns:

  • (String)


37814
37815
37816
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37814

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAsset

A link between a Campaign and an Asset. Corresponds to the JSON property update



37819
37820
37821
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37819

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


37824
37825
37826
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37824

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37831
37832
37833
37834
37835
37836
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37831

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end