Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetSetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on a campaign asset set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignAssetSetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignAssetSetOperation.



37856
37857
37858
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37856

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAssetSet

CampaignAssetSet is the linkage between a campaign and an asset set. Adding a CampaignAssetSet links an asset set with a campaign. Corresponds to the JSON property create



37847
37848
37849
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37847

def create
  @create
end

#removeString

Remove operation: A resource name for the removed campaign asset set is expected, in this format: customers/customer_id/campaignAssetSets/ campaign_id~asset_set_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


37854
37855
37856
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37854

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37861
37862
37863
37864
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37861

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end