Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove, update) on a campaign bid modifier.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation.



38138
38139
38140
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38138

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBidModifier

Represents a bid-modifiable only criterion at the campaign level. Corresponds to the JSON property create



38119
38120
38121
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38119

def create
  @create
end

#removeString

Remove operation: A resource name for the removed campaign bid modifier is expected, in this format: customers/customer_id/CampaignBidModifiers/ campaign_id~criterion_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


38126
38127
38128
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38126

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBidModifier

Represents a bid-modifiable only criterion at the campaign level. Corresponds to the JSON property update



38131
38132
38133
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38131

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


38136
38137
38138
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38136

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38143
38144
38145
38146
38147
38148
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38143

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end