Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove, update) on a campaign bid modifier.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBidModifier
Represents a bid-modifiable only criterion at the campaign level.
-
#remove ⇒ String
Remove operation: A resource name for the removed campaign bid modifier is expected, in this format:
customers/customer_id/CampaignBidModifiers/campaign_id~criterion_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBidModifier
Represents a bid-modifiable only criterion at the campaign level.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation.
37893 37894 37895 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37893 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBidModifier
Represents a bid-modifiable only criterion at the campaign level.
Corresponds to the JSON property create
37874 37875 37876 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37874 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed campaign bid modifier is
expected, in this format: customers/customer_id/CampaignBidModifiers/
campaign_id~criterion_id`
Corresponds to the JSON propertyremove`
37881 37882 37883 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37881 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBidModifier
Represents a bid-modifiable only criterion at the campaign level.
Corresponds to the JSON property update
37886 37887 37888 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37886 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
37891 37892 37893 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37891 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37898 37899 37900 37901 37902 37903 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37898 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |