Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetMapping
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetMapping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The mapping of experiment campaign and budget to be graduated.
Instance Attribute Summary collapse
-
#campaign_budget ⇒ String
Required.
-
#experiment_campaign ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignBudgetMapping
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignBudgetMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignBudgetMapping
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignBudgetMapping.
38166 38167 38168 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38166 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign_budget ⇒ String
Required. The budget that should be attached to the graduating experiment
campaign.
Corresponds to the JSON property campaignBudget
38159 38160 38161 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38159 def campaign_budget @campaign_budget end |
#experiment_campaign ⇒ String
Required. The experiment campaign to graduate.
Corresponds to the JSON property experimentCampaign
38164 38165 38166 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38164 def experiment_campaign @experiment_campaign end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38171 38172 38173 38174 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38171 def update!(**args) @campaign_budget = args[:campaign_budget] if args.key?(:campaign_budget) @experiment_campaign = args[:experiment_campaign] if args.key?(:experiment_campaign) end |