Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetMapping
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetMapping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The mapping of experiment campaign and budget to be graduated.
Instance Attribute Summary collapse
-
#campaign_budget ⇒ String
Required.
-
#experiment_campaign ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignBudgetMapping
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignBudgetMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignBudgetMapping
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignBudgetMapping.
37921 37922 37923 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign_budget ⇒ String
Required. The budget that should be attached to the graduating experiment
campaign.
Corresponds to the JSON property campaignBudget
37914 37915 37916 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37914 def campaign_budget @campaign_budget end |
#experiment_campaign ⇒ String
Required. The experiment campaign to graduate.
Corresponds to the JSON property experimentCampaign
37919 37920 37921 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37919 def experiment_campaign @experiment_campaign end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37926 37927 37928 37929 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37926 def update!(**args) @campaign_budget = args[:campaign_budget] if args.key?(:campaign_budget) @experiment_campaign = args[:experiment_campaign] if args.key?(:experiment_campaign) end |