Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a campaign budget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignBudgetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignBudgetOperation.



38202
38203
38204
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38202

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBudget

A campaign budget. Corresponds to the JSON property create



38184
38185
38186
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38184

def create
  @create
end

#removeString

Remove operation: A resource name for the removed budget is expected, in this format: customers/customer_id/campaignBudgets/budget_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


38190
38191
38192
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38190

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBudget

A campaign budget. Corresponds to the JSON property update



38195
38196
38197
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38195

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


38200
38201
38202
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38200

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38207
38208
38209
38210
38211
38212
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38207

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end