Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a campaign budget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignBudgetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignBudgetOperation.



37957
37958
37959
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBudget

A campaign budget. Corresponds to the JSON property create



37939
37940
37941
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37939

def create
  @create
end

#removeString

Remove operation: A resource name for the removed budget is expected, in this format: customers/customer_id/campaignBudgets/budget_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


37945
37946
37947
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37945

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignBudget

A campaign budget. Corresponds to the JSON property update



37950
37951
37952
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37950

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


37955
37956
37957
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37955

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37962
37963
37964
37965
37966
37967
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37962

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end