Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (update) on a campaign conversion goal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation.



37985
37986
37987
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37985

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignConversionGoal

The biddability setting for the specified campaign only for all conversion actions with a matching category and origin. Corresponds to the JSON property update



37978
37979
37980
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37978

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


37983
37984
37985
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37983

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37990
37991
37992
37993
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37990

def update!(**args)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end