Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (update) on a campaign conversion goal.
Instance Attribute Summary collapse
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignConversionGoal
The biddability setting for the specified campaign only for all conversion actions with a matching category and origin.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation.
37985 37986 37987 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignConversionGoal
The biddability setting for the specified campaign only for all conversion
actions with a matching category and origin.
Corresponds to the JSON property update
37978 37979 37980 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37978 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
37983 37984 37985 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37983 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37990 37991 37992 37993 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 37990 def update!(**args) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |