Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCriterionOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCriterionOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a campaign criterion.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion
A campaign criterion.
-
#remove ⇒ String
Remove operation: A resource name for the removed criterion is expected, in this format:
customers/customer_id/campaignCriteria/campaign_id~criterion_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion
A campaign criterion.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignCriterionOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignCriterionOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignCriterionOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignCriterionOperation.
38267 38268 38269 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion
A campaign criterion.
Corresponds to the JSON property create
38248 38249 38250 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38248 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed criterion is expected, in
this format: customers/customer_id/campaignCriteria/campaign_id~
criterion_id`
Corresponds to the JSON propertyremove`
38255 38256 38257 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38255 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion
A campaign criterion.
Corresponds to the JSON property update
38260 38261 38262 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38260 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
38265 38266 38267 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38265 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38272 38273 38274 38275 38276 38277 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38272 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |