Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCriterionOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a campaign criterion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignCriterionOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignCriterionOperation.



38022
38023
38024
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38022

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion

A campaign criterion. Corresponds to the JSON property create



38003
38004
38005
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38003

def create
  @create
end

#removeString

Remove operation: A resource name for the removed criterion is expected, in this format: customers/customer_id/campaignCriteria/campaign_id~ criterion_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


38010
38011
38012
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38010

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignCriterion

A campaign criterion. Corresponds to the JSON property update



38015
38016
38017
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38015

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


38020
38021
38022
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38020

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38027
38028
38029
38030
38031
38032
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38027

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end