Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignDraftOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignDraftOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a campaign draft.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDraft
A campaign draft.
-
#remove ⇒ String
Remove operation: The campaign draft is expected to have a valid resource name, in this format:
customers/customer_id/campaignDrafts/base_campaign_id~draft_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDraft
A campaign draft.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignDraftOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignDraftOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignDraftOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignDraftOperation.
38089 38090 38091 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38089 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDraft
A campaign draft.
Corresponds to the JSON property create
38070 38071 38072 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38070 def create @create end |
#remove ⇒ String
Remove operation: The campaign draft is expected to have a valid resource name,
in this format: customers/customer_id/campaignDrafts/base_campaign_id~
draft_id`
Corresponds to the JSON propertyremove`
38077 38078 38079 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38077 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignDraft
A campaign draft.
Corresponds to the JSON property update
38082 38083 38084 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38082 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
38087 38088 38089 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38087 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38094 38095 38096 38097 38098 38099 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38094 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |