Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGoalConfigOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGoalConfigOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single mutate operation on the campaign goal config.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGoalConfig
A link between a campaign and a goal enabling campaign-specific optimization.
-
#remove ⇒ String
Remove an existing campaign goal config.
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGoalConfig
A link between a campaign and a goal enabling campaign-specific optimization.
-
#update_mask ⇒ String
FieldMask that determines which fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignGoalConfigOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignGoalConfigOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignGoalConfigOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignGoalConfigOperation.
38397 38398 38399 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38397 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGoalConfig
A link between a campaign and a goal enabling campaign-specific optimization.
Corresponds to the JSON property create
38380 38381 38382 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38380 def create @create end |
#remove ⇒ String
Remove an existing campaign goal config.
Corresponds to the JSON property remove
38385 38386 38387 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38385 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGoalConfig
A link between a campaign and a goal enabling campaign-specific optimization.
Corresponds to the JSON property update
38390 38391 38392 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38390 def update @update end |
#update_mask ⇒ String
FieldMask that determines which fields are modified in an update.
Corresponds to the JSON property updateMask
38395 38396 38397 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38395 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38402 38403 38404 38405 38406 38407 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38402 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |