Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGoalConfigOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single mutate operation on the campaign goal config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignGoalConfigOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignGoalConfigOperation.



38152
38153
38154
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38152

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGoalConfig

A link between a campaign and a goal enabling campaign-specific optimization. Corresponds to the JSON property create



38135
38136
38137
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38135

def create
  @create
end

#removeString

Remove an existing campaign goal config. Corresponds to the JSON property remove

Returns:

  • (String)


38140
38141
38142
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38140

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGoalConfig

A link between a campaign and a goal enabling campaign-specific optimization. Corresponds to the JSON property update



38145
38146
38147
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38145

def update
  @update
end

#update_maskString

FieldMask that determines which fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


38150
38151
38152
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38150

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38157
38158
38159
38160
38161
38162
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38157

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end