Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGroupOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGroupOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a campaign group.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGroup
A campaign group.
-
#remove ⇒ String
Remove operation: A resource name for the removed campaign group is expected, in this format:
customers/customer_id/campaignGroups/campaign_group_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGroup
A campaign group.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignGroupOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignGroupOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignGroupOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignGroupOperation.
38507 38508 38509 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38507 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGroup
A campaign group.
Corresponds to the JSON property create
38489 38490 38491 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38489 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed campaign group is expected,
in this format: customers/customer_id/campaignGroups/campaign_group_id`
Corresponds to the JSON propertyremove`
38495 38496 38497 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38495 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGroup
A campaign group.
Corresponds to the JSON property update
38500 38501 38502 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38500 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
38505 38506 38507 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38505 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38512 38513 38514 38515 38516 38517 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38512 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |