Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGroupOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a campaign group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignGroupOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignGroupOperation.



38190
38191
38192
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGroup

A campaign group. Corresponds to the JSON property create



38172
38173
38174
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38172

def create
  @create
end

#removeString

Remove operation: A resource name for the removed campaign group is expected, in this format: customers/customer_id/campaignGroups/campaign_group_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


38178
38179
38180
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38178

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGroup

A campaign group. Corresponds to the JSON property update



38183
38184
38185
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38183

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


38188
38189
38190
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38188

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38195
38196
38197
38198
38199
38200
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38195

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end