Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGroupOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGroupOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a campaign group.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGroup
A campaign group.
-
#remove ⇒ String
Remove operation: A resource name for the removed campaign group is expected, in this format:
customers/customer_id/campaignGroups/campaign_group_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGroup
A campaign group.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignGroupOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignGroupOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignGroupOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignGroupOperation.
38190 38191 38192 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38190 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGroup
A campaign group.
Corresponds to the JSON property create
38172 38173 38174 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38172 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed campaign group is expected,
in this format: customers/customer_id/campaignGroups/campaign_group_id`
Corresponds to the JSON propertyremove`
38178 38179 38180 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38178 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignGroup
A campaign group.
Corresponds to the JSON property update
38183 38184 38185 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38183 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
38188 38189 38190 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38188 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38195 38196 38197 38198 38199 38200 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38195 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |