Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignOperation.



38532
38533
38534
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaign

A campaign. Corresponds to the JSON property create



38514
38515
38516
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38514

def create
  @create
end

#removeString

Remove operation: A resource name for the removed campaign is expected, in this format: customers/customer_id/campaigns/campaign_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


38520
38521
38522
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38520

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaign

A campaign. Corresponds to the JSON property update



38525
38526
38527
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38525

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


38530
38531
38532
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38530

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38537
38538
38539
38540
38541
38542
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38537

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end