Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a campaign.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaign
A campaign.
-
#remove ⇒ String
Remove operation: A resource name for the removed campaign is expected, in this format:
customers/customer_id/campaigns/campaign_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaign
A campaign.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignOperation.
38287 38288 38289 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38287 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaign
A campaign.
Corresponds to the JSON property create
38269 38270 38271 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38269 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed campaign is expected, in
this format: customers/customer_id/campaigns/campaign_id`
Corresponds to the JSON propertyremove`
38275 38276 38277 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38275 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaign
A campaign.
Corresponds to the JSON property update
38280 38281 38282 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38280 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
38285 38286 38287 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38285 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38292 38293 38294 38295 38296 38297 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38292 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |