Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignSharedSetOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignSharedSetOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on a campaign shared set.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSharedSet
CampaignSharedSets are used for managing the shared sets associated with a campaign.
-
#remove ⇒ String
Remove operation: A resource name for the removed campaign shared set is expected, in this format:
customers/customer_id/campaignSharedSets/campaign_id~shared_set_id`Corresponds to the JSON propertyremove`.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignSharedSetOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignSharedSetOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignSharedSetOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignSharedSetOperation.
38317 38318 38319 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignSharedSet
CampaignSharedSets are used for managing the shared sets associated with a
campaign.
Corresponds to the JSON property create
38308 38309 38310 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38308 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed campaign shared set is
expected, in this format: customers/customer_id/campaignSharedSets/
campaign_id~shared_set_id`
Corresponds to the JSON propertyremove`
38315 38316 38317 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38315 def remove @remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38322 38323 38324 38325 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38322 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) end |