Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignToForecast
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignToForecast
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A campaign to do a keyword campaign forecast.
Instance Attribute Summary collapse
-
#ad_groups ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecastAdGroup>
The ad groups in the new campaign to forecast.
-
#bidding_strategy ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignToForecastCampaignBiddingStrategy
Supported bidding strategies for new campaign forecasts.
-
#conversion_rate ⇒ Float
The expected conversion rate (number of conversions divided by number of total clicks) as defined by the user.
-
#geo_modifiers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCriterionBidModifier>
Locations to be targeted.
-
#keyword_plan_network ⇒ String
Required.
-
#language_constants ⇒ Array<String>
The list of resource names of languages to be targeted.
-
#negative_keywords ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo>
The list of negative keywords to be used in the campaign when doing the forecast.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignToForecast
constructor
A new instance of GoogleAdsSearchads360V23ServicesCampaignToForecast.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCampaignToForecast
Returns a new instance of GoogleAdsSearchads360V23ServicesCampaignToForecast.
38374 38375 38376 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38374 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_groups ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecastAdGroup>
The ad groups in the new campaign to forecast.
Corresponds to the JSON property adGroups
38335 38336 38337 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38335 def ad_groups @ad_groups end |
#bidding_strategy ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignToForecastCampaignBiddingStrategy
Supported bidding strategies for new campaign forecasts.
Corresponds to the JSON property biddingStrategy
38340 38341 38342 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38340 def bidding_strategy @bidding_strategy end |
#conversion_rate ⇒ Float
The expected conversion rate (number of conversions divided by number of total
clicks) as defined by the user. This value is expressed as a decimal value, so
an expected conversion rate of 2% should be entered as 0.02. If left empty, an
estimated conversion rate will be used.
Corresponds to the JSON property conversionRate
38348 38349 38350 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38348 def conversion_rate @conversion_rate end |
#geo_modifiers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCriterionBidModifier>
Locations to be targeted. Locations must be unique.
Corresponds to the JSON property geoModifiers
38353 38354 38355 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38353 def geo_modifiers @geo_modifiers end |
#keyword_plan_network ⇒ String
Required. The network used for targeting.
Corresponds to the JSON property keywordPlanNetwork
38358 38359 38360 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38358 def keyword_plan_network @keyword_plan_network end |
#language_constants ⇒ Array<String>
The list of resource names of languages to be targeted. The resource name is
of the format "languageConstants/criterion_id". See https://developers.
google.com/google-ads/api/data/codes-formats#languages for the list of
language criterion codes.
Corresponds to the JSON property languageConstants
38366 38367 38368 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38366 def language_constants @language_constants end |
#negative_keywords ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo>
The list of negative keywords to be used in the campaign when doing the
forecast.
Corresponds to the JSON property negativeKeywords
38372 38373 38374 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38372 def negative_keywords @negative_keywords end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38379 38380 38381 38382 38383 38384 38385 38386 38387 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38379 def update!(**args) @ad_groups = args[:ad_groups] if args.key?(:ad_groups) @bidding_strategy = args[:bidding_strategy] if args.key?(:bidding_strategy) @conversion_rate = args[:conversion_rate] if args.key?(:conversion_rate) @geo_modifiers = args[:geo_modifiers] if args.key?(:geo_modifiers) @keyword_plan_network = args[:keyword_plan_network] if args.key?(:keyword_plan_network) @language_constants = args[:language_constants] if args.key?(:language_constants) @negative_keywords = args[:negative_keywords] if args.key?(:negative_keywords) end |