Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCartData
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCartData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Contains additional information about cart data.
Instance Attribute Summary collapse
-
#feed_country_code ⇒ String
The country code associated with the feed where the items are uploaded.
-
#feed_language_code ⇒ String
The language code associated with the feed where the items are uploaded.
-
#items ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCartDataItem>
Data of the items purchased.
-
#local_transaction_cost ⇒ Float
Sum of all transaction level discounts, such as free shipping and coupon discounts for the whole cart.
-
#merchant_id ⇒ Fixnum
The Merchant Center ID where the items are uploaded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCartData
constructor
A new instance of GoogleAdsSearchads360V23ServicesCartData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCartData
Returns a new instance of GoogleAdsSearchads360V23ServicesCartData.
38666 38667 38668 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38666 def initialize(**args) update!(**args) end |
Instance Attribute Details
#feed_country_code ⇒ String
The country code associated with the feed where the items are uploaded.
Corresponds to the JSON property feedCountryCode
38642 38643 38644 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38642 def feed_country_code @feed_country_code end |
#feed_language_code ⇒ String
The language code associated with the feed where the items are uploaded.
Corresponds to the JSON property feedLanguageCode
38647 38648 38649 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38647 def feed_language_code @feed_language_code end |
#items ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCartDataItem>
Data of the items purchased.
Corresponds to the JSON property items
38652 38653 38654 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38652 def items @items end |
#local_transaction_cost ⇒ Float
Sum of all transaction level discounts, such as free shipping and coupon
discounts for the whole cart. The currency code is the same as that in the
ClickConversion message.
Corresponds to the JSON property localTransactionCost
38659 38660 38661 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38659 def local_transaction_cost @local_transaction_cost end |
#merchant_id ⇒ Fixnum
The Merchant Center ID where the items are uploaded.
Corresponds to the JSON property merchantId
38664 38665 38666 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38664 def merchant_id @merchant_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38671 38672 38673 38674 38675 38676 38677 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38671 def update!(**args) @feed_country_code = args[:feed_country_code] if args.key?(:feed_country_code) @feed_language_code = args[:feed_language_code] if args.key?(:feed_language_code) @items = args[:items] if args.key?(:items) @local_transaction_cost = args[:local_transaction_cost] if args.key?(:local_transaction_cost) @merchant_id = args[:merchant_id] if args.key?(:merchant_id) end |