Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCartDataItem
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCartDataItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Contains data of the items purchased.
Instance Attribute Summary collapse
-
#product_id ⇒ String
The shopping id of the item.
-
#quantity ⇒ Fixnum
Number of items sold.
-
#unit_price ⇒ Float
Unit price excluding tax, shipping, and any transaction level discounts.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCartDataItem
constructor
A new instance of GoogleAdsSearchads360V23ServicesCartDataItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCartDataItem
Returns a new instance of GoogleAdsSearchads360V23ServicesCartDataItem.
35423 35424 35425 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35423 def initialize(**args) update!(**args) end |
Instance Attribute Details
#product_id ⇒ String
The shopping id of the item. Must be equal to the Merchant Center product
identifier.
Corresponds to the JSON property productId
35410 35411 35412 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35410 def product_id @product_id end |
#quantity ⇒ Fixnum
Number of items sold.
Corresponds to the JSON property quantity
35415 35416 35417 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35415 def quantity @quantity end |
#unit_price ⇒ Float
Unit price excluding tax, shipping, and any transaction level discounts. The
currency code is the same as that in the ClickConversion message.
Corresponds to the JSON property unitPrice
35421 35422 35423 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35421 def unit_price @unit_price end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35428 35429 35430 35431 35432 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35428 def update!(**args) @product_id = args[:product_id] if args.key?(:product_id) @quantity = args[:quantity] if args.key?(:quantity) @unit_price = args[:unit_price] if args.key?(:unit_price) end |