Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesClickConversion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesClickConversion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A click conversion.
Instance Attribute Summary collapse
-
#cart_data ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCartData
Contains additional information about cart data.
-
#consent ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonConsent
Consent Corresponds to the JSON property
consent. -
#conversion_action ⇒ String
Resource name of the conversion action associated with this conversion.
-
#conversion_date_time ⇒ String
The date time at which the conversion occurred.
-
#conversion_environment ⇒ String
The environment this conversion was recorded on, for example, App or Web.
-
#conversion_value ⇒ Float
The value of the conversion for the advertiser.
-
#currency_code ⇒ String
Currency associated with the conversion value.
-
#custom_variables ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomVariable>
The custom variables associated with this conversion.
-
#customer_type ⇒ String
Type of the customer associated with the conversion (new or returning).
-
#external_attribution_data ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExternalAttributionData
Contains additional information about externally attributed conversions.
-
#gbraid ⇒ String
The URL parameter for clicks associated with app conversions.
-
#gclid ⇒ String
The Google click ID (gclid) associated with this conversion.
-
#order_id ⇒ String
The order ID associated with the conversion.
-
#session_attributes_encoded ⇒ String
The session attributes for the event, represented as a base64-encoded JSON string.
-
#session_attributes_key_value_pairs ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSessionAttributesKeyValuePairs
Contains session attributes of the conversion, represented as key-value pairs.
-
#user_identifiers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserIdentifier>
The user identifiers associated with this conversion.
-
#user_ip_address ⇒ String
The IP address of the customer when they arrived on the landing page after an ad click but before a conversion event.
-
#wbraid ⇒ String
The URL parameter for clicks associated with web conversions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesClickConversion
constructor
A new instance of GoogleAdsSearchads360V23ServicesClickConversion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesClickConversion
Returns a new instance of GoogleAdsSearchads360V23ServicesClickConversion.
38799 38800 38801 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cart_data ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCartData
Contains additional information about cart data.
Corresponds to the JSON property cartData
38687 38688 38689 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38687 def cart_data @cart_data end |
#consent ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonConsent
Consent
Corresponds to the JSON property consent
38692 38693 38694 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38692 def @consent end |
#conversion_action ⇒ String
Resource name of the conversion action associated with this conversion. Note:
Although this resource name consists of a customer id and a conversion action
id, validation will ignore the customer id and use the conversion action id as
the sole identifier of the conversion action.
Corresponds to the JSON property conversionAction
38700 38701 38702 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38700 def conversion_action @conversion_action end |
#conversion_date_time ⇒ String
The date time at which the conversion occurred. Must be after the click time.
The timezone must be specified. The format is "yyyy-mm-dd hh:mm:ss+|-hh:mm",
for example, "2019-01-01 12:32:45-08:00".
Corresponds to the JSON property conversionDateTime
38707 38708 38709 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38707 def conversion_date_time @conversion_date_time end |
#conversion_environment ⇒ String
The environment this conversion was recorded on, for example, App or Web.
Corresponds to the JSON property conversionEnvironment
38712 38713 38714 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38712 def conversion_environment @conversion_environment end |
#conversion_value ⇒ Float
The value of the conversion for the advertiser.
Corresponds to the JSON property conversionValue
38717 38718 38719 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38717 def conversion_value @conversion_value end |
#currency_code ⇒ String
Currency associated with the conversion value. This is the ISO 4217 3-
character currency code. For example: USD, EUR.
Corresponds to the JSON property currencyCode
38723 38724 38725 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38723 def currency_code @currency_code end |
#custom_variables ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomVariable>
The custom variables associated with this conversion.
Corresponds to the JSON property customVariables
38728 38729 38730 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38728 def custom_variables @custom_variables end |
#customer_type ⇒ String
Type of the customer associated with the conversion (new or returning).
Corresponds to the JSON property customerType
38733 38734 38735 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38733 def customer_type @customer_type end |
#external_attribution_data ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExternalAttributionData
Contains additional information about externally attributed conversions.
Corresponds to the JSON property externalAttributionData
38738 38739 38740 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38738 def external_attribution_data @external_attribution_data end |
#gbraid ⇒ String
The URL parameter for clicks associated with app conversions.
Corresponds to the JSON property gbraid
38743 38744 38745 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38743 def gbraid @gbraid end |
#gclid ⇒ String
The Google click ID (gclid) associated with this conversion.
Corresponds to the JSON property gclid
38748 38749 38750 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38748 def gclid @gclid end |
#order_id ⇒ String
The order ID associated with the conversion. An order id can only be used for
one conversion per conversion action.
Corresponds to the JSON property orderId
38754 38755 38756 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38754 def order_id @order_id end |
#session_attributes_encoded ⇒ String
The session attributes for the event, represented as a base64-encoded JSON
string. The content should be generated by Google-provided library. To set
session attributes individually, use session_attributes_key_value_pairs
instead. This field is only available to allowlisted users. To include this
field in conversion imports, upgrade to the Data Manager API.
Corresponds to the JSON property sessionAttributesEncoded
NOTE: Values are automatically base64 encoded/decoded in the client library.
38764 38765 38766 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38764 def session_attributes_encoded @session_attributes_encoded end |
#session_attributes_key_value_pairs ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSessionAttributesKeyValuePairs
Contains session attributes of the conversion, represented as key-value pairs.
Corresponds to the JSON property sessionAttributesKeyValuePairs
38769 38770 38771 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38769 def session_attributes_key_value_pairs @session_attributes_key_value_pairs end |
#user_identifiers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserIdentifier>
The user identifiers associated with this conversion. Only hashed_email and
hashed_phone_number are supported for conversion uploads. The maximum number
of user identifiers for each conversion is 5.
Corresponds to the JSON property userIdentifiers
38776 38777 38778 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38776 def user_identifiers @user_identifiers end |
#user_ip_address ⇒ String
The IP address of the customer when they arrived on the landing page after an
ad click but before a conversion event. This is the IP address of the customer'
s device, not the advertiser's server. Google Ads does not support IP address
matching for end users in the European Economic Area (EEA), United Kingdom (UK)
, or Switzerland (CH). Add logic to conditionally exclude sharing IP addresses
from users from these regions and ensure that you provide users with clear and
comprehensive information about the data you collect on your sites, apps, and
other properties and get consent where required by law or any applicable
Google policies. See About offline conversion imports page for more details. This field is only available
to allowlisted users. To include this field in conversion imports, upgrade to
the Data Manager API.
Corresponds to the JSON property userIpAddress
38792 38793 38794 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38792 def user_ip_address @user_ip_address end |
#wbraid ⇒ String
The URL parameter for clicks associated with web conversions.
Corresponds to the JSON property wbraid
38797 38798 38799 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38797 def wbraid @wbraid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38804 38805 38806 38807 38808 38809 38810 38811 38812 38813 38814 38815 38816 38817 38818 38819 38820 38821 38822 38823 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38804 def update!(**args) @cart_data = args[:cart_data] if args.key?(:cart_data) @consent = args[:consent] if args.key?(:consent) @conversion_action = args[:conversion_action] if args.key?(:conversion_action) @conversion_date_time = args[:conversion_date_time] if args.key?(:conversion_date_time) @conversion_environment = args[:conversion_environment] if args.key?(:conversion_environment) @conversion_value = args[:conversion_value] if args.key?(:conversion_value) @currency_code = args[:currency_code] if args.key?(:currency_code) @custom_variables = args[:custom_variables] if args.key?(:custom_variables) @customer_type = args[:customer_type] if args.key?(:customer_type) @external_attribution_data = args[:external_attribution_data] if args.key?(:external_attribution_data) @gbraid = args[:gbraid] if args.key?(:gbraid) @gclid = args[:gclid] if args.key?(:gclid) @order_id = args[:order_id] if args.key?(:order_id) @session_attributes_encoded = args[:session_attributes_encoded] if args.key?(:session_attributes_encoded) @session_attributes_key_value_pairs = args[:session_attributes_key_value_pairs] if args.key?(:session_attributes_key_value_pairs) @user_identifiers = args[:user_identifiers] if args.key?(:user_identifiers) @user_ip_address = args[:user_ip_address] if args.key?(:user_ip_address) @wbraid = args[:wbraid] if args.key?(:wbraid) end |