Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesClickConversionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Identifying information for a successfully processed ClickConversion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesClickConversionResult

Returns a new instance of GoogleAdsSearchads360V23ServicesClickConversionResult.



38863
38864
38865
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversion_actionString

Resource name of the conversion action associated with this conversion. Corresponds to the JSON property conversionAction

Returns:

  • (String)


38833
38834
38835
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38833

def conversion_action
  @conversion_action
end

#conversion_date_timeString

The date time at which the conversion occurred. The format is "yyyy-mm-dd hh: mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08:00". Corresponds to the JSON property conversionDateTime

Returns:

  • (String)


38839
38840
38841
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38839

def conversion_date_time
  @conversion_date_time
end

#gbraidString

The URL parameter for clicks associated with app conversions. Corresponds to the JSON property gbraid

Returns:

  • (String)


38844
38845
38846
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38844

def gbraid
  @gbraid
end

#gclidString

The Google Click ID (gclid) associated with this conversion. Corresponds to the JSON property gclid

Returns:

  • (String)


38849
38850
38851
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38849

def gclid
  @gclid
end

#user_identifiersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserIdentifier>

The user identifiers associated with this conversion. Only hashed_email and hashed_phone_number are supported for conversion uploads. The maximum number of user identifiers for each conversion is 5. Corresponds to the JSON property userIdentifiers



38856
38857
38858
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38856

def user_identifiers
  @user_identifiers
end

#wbraidString

The URL parameter for clicks associated with web conversions. Corresponds to the JSON property wbraid

Returns:

  • (String)


38861
38862
38863
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38861

def wbraid
  @wbraid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38868
38869
38870
38871
38872
38873
38874
38875
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38868

def update!(**args)
  @conversion_action = args[:conversion_action] if args.key?(:conversion_action)
  @conversion_date_time = args[:conversion_date_time] if args.key?(:conversion_date_time)
  @gbraid = args[:gbraid] if args.key?(:gbraid)
  @gclid = args[:gclid] if args.key?(:gclid)
  @user_identifiers = args[:user_identifiers] if args.key?(:user_identifiers)
  @wbraid = args[:wbraid] if args.key?(:wbraid)
end