Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Details of the conversation that needs to be appended.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversation

Returns a new instance of GoogleAdsSearchads360V23ServicesConversation.



39027
39028
39029
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#local_services_leadString

Required. The resource name of the local services lead that the conversation should be applied to. Corresponds to the JSON property localServicesLead

Returns:

  • (String)


39020
39021
39022
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39020

def local_services_lead
  @local_services_lead
end

#textString

Required. Text message that user wanted to append to lead. Corresponds to the JSON property text

Returns:

  • (String)


39025
39026
39027
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39025

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39032
39033
39034
39035
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39032

def update!(**args)
  @local_services_lead = args[:local_services_lead] if args.key?(:local_services_lead)
  @text = args[:text] if args.key?(:text)
end