Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Details of the conversation that needs to be appended.
Instance Attribute Summary collapse
-
#local_services_lead ⇒ String
Required.
-
#text ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversation
constructor
A new instance of GoogleAdsSearchads360V23ServicesConversation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversation
Returns a new instance of GoogleAdsSearchads360V23ServicesConversation.
38539 38540 38541 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38539 def initialize(**args) update!(**args) end |
Instance Attribute Details
#local_services_lead ⇒ String
Required. The resource name of the local services lead that the conversation
should be applied to.
Corresponds to the JSON property localServicesLead
38532 38533 38534 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38532 def local_services_lead @local_services_lead end |
#text ⇒ String
Required. Text message that user wanted to append to lead.
Corresponds to the JSON property text
38537 38538 38539 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38537 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38544 38545 38546 38547 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38544 def update!(**args) @local_services_lead = args[:local_services_lead] if args.key?(:local_services_lead) @text = args[:text] if args.key?(:text) end |