Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversationOrError
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversationOrError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Result of the append conversation operation.
Instance Attribute Summary collapse
-
#local_services_lead_conversation ⇒ String
The resource name of the appended local services lead conversation.
-
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversationOrError
constructor
A new instance of GoogleAdsSearchads360V23ServicesConversationOrError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversationOrError
Returns a new instance of GoogleAdsSearchads360V23ServicesConversationOrError.
39129 39130 39131 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39129 def initialize(**args) update!(**args) end |
Instance Attribute Details
#local_services_lead_conversation ⇒ String
The resource name of the appended local services lead conversation.
Corresponds to the JSON property localServicesLeadConversation
39117 39118 39119 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39117 def local_services_lead_conversation @local_services_lead_conversation end |
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property partialFailureError
39127 39128 39129 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39127 def partial_failure_error @partial_failure_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39134 39135 39136 39137 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39134 def update!(**args) @local_services_lead_conversation = args[:local_services_lead_conversation] if args.key?(:local_services_lead_conversation) @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error) end |