Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversationOrError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Result of the append conversation operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversationOrError

Returns a new instance of GoogleAdsSearchads360V23ServicesConversationOrError.



38569
38570
38571
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38569

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#local_services_lead_conversationString

The resource name of the appended local services lead conversation. Corresponds to the JSON property localServicesLeadConversation

Returns:

  • (String)


38557
38558
38559
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38557

def local_services_lead_conversation
  @local_services_lead_conversation
end

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



38567
38568
38569
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38567

def partial_failure_error
  @partial_failure_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38574
38575
38576
38577
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38574

def update!(**args)
  @local_services_lead_conversation = args[:local_services_lead_conversation] if args.key?(:local_services_lead_conversation)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
end