Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionActionOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionActionOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a conversion action.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionAction
A conversion action.
-
#remove ⇒ String
Remove operation: A resource name for the removed conversion action is expected, in this format:
customers/customer_id/conversionActions/conversion_action_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionAction
A conversion action.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionActionOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesConversionActionOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionActionOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesConversionActionOperation.
39094 39095 39096 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39094 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionAction
A conversion action.
Corresponds to the JSON property create
39075 39076 39077 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39075 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed conversion action is
expected, in this format: customers/customer_id/conversionActions/
conversion_action_id`
Corresponds to the JSON propertyremove`
39082 39083 39084 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39082 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionAction
A conversion action.
Corresponds to the JSON property update
39087 39088 39089 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39087 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
39092 39093 39094 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39092 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39099 39100 39101 39102 39103 39104 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39099 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |