Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionAdjustment
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionAdjustment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A conversion adjustment.
Instance Attribute Summary collapse
-
#adjustment_date_time ⇒ String
The date time at which the adjustment occurred.
-
#adjustment_type ⇒ String
The adjustment type.
-
#conversion_action ⇒ String
Resource name of the conversion action associated with this conversion adjustment.
-
#gclid_date_time_pair ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGclidDateTimePair
Uniquely identifies a conversion that was reported without an order ID specified.
-
#order_id ⇒ String
The order ID of the conversion to be adjusted.
-
#restatement_value ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRestatementValue
Contains information needed to restate a conversion's value.
-
#user_agent ⇒ String
The user agent to enhance the original conversion.
-
#user_identifiers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserIdentifier>
The user identifiers to enhance the original conversion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionAdjustment
constructor
A new instance of GoogleAdsSearchads360V23ServicesConversionAdjustment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionAdjustment
Returns a new instance of GoogleAdsSearchads360V23ServicesConversionAdjustment.
39164 39165 39166 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adjustment_date_time ⇒ String
The date time at which the adjustment occurred. Must be after the
conversion_date_time. The timezone must be specified. The format is "yyyy-mm-
dd hh:mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08:00".
Corresponds to the JSON property adjustmentDateTime
39116 39117 39118 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39116 def adjustment_date_time @adjustment_date_time end |
#adjustment_type ⇒ String
The adjustment type.
Corresponds to the JSON property adjustmentType
39121 39122 39123 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39121 def adjustment_type @adjustment_type end |
#conversion_action ⇒ String
Resource name of the conversion action associated with this conversion
adjustment. Note: Although this resource name consists of a customer id and a
conversion action id, validation will ignore the customer id and use the
conversion action id as the sole identifier of the conversion action.
Corresponds to the JSON property conversionAction
39129 39130 39131 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39129 def conversion_action @conversion_action end |
#gclid_date_time_pair ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGclidDateTimePair
Uniquely identifies a conversion that was reported without an order ID
specified.
Corresponds to the JSON property gclidDateTimePair
39135 39136 39137 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39135 def gclid_date_time_pair @gclid_date_time_pair end |
#order_id ⇒ String
The order ID of the conversion to be adjusted. If the conversion was reported
with an order ID specified, that order ID must be used as the identifier here.
The order ID is required for enhancements.
Corresponds to the JSON property orderId
39142 39143 39144 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39142 def order_id @order_id end |
#restatement_value ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRestatementValue
Contains information needed to restate a conversion's value.
Corresponds to the JSON property restatementValue
39147 39148 39149 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39147 def restatement_value @restatement_value end |
#user_agent ⇒ String
The user agent to enhance the original conversion. This can be found in your
user's HTTP request header when they convert on your web page. Example, "
Mozilla/5.0 (iPhone; CPU iPhone OS 12_2 like Mac OS X)". User agent can only
be specified in enhancements with user identifiers.
Corresponds to the JSON property userAgent
39155 39156 39157 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39155 def user_agent @user_agent end |
#user_identifiers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserIdentifier>
The user identifiers to enhance the original conversion.
ConversionAdjustmentUploadService only accepts user identifiers in
enhancements. The maximum number of user identifiers for each enhancement is 5.
Corresponds to the JSON property userIdentifiers
39162 39163 39164 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39162 def user_identifiers @user_identifiers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39169 39170 39171 39172 39173 39174 39175 39176 39177 39178 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39169 def update!(**args) @adjustment_date_time = args[:adjustment_date_time] if args.key?(:adjustment_date_time) @adjustment_type = args[:adjustment_type] if args.key?(:adjustment_type) @conversion_action = args[:conversion_action] if args.key?(:conversion_action) @gclid_date_time_pair = args[:gclid_date_time_pair] if args.key?(:gclid_date_time_pair) @order_id = args[:order_id] if args.key?(:order_id) @restatement_value = args[:restatement_value] if args.key?(:restatement_value) @user_agent = args[:user_agent] if args.key?(:user_agent) @user_identifiers = args[:user_identifiers] if args.key?(:user_identifiers) end |