Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionAdjustmentResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Information identifying a successfully processed ConversionAdjustment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionAdjustmentResult

Returns a new instance of GoogleAdsSearchads360V23ServicesConversionAdjustmentResult.



39213
39214
39215
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adjustment_date_timeString

The date time at which the adjustment occurred. The format is "yyyy-mm-dd hh: mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08:00". Corresponds to the JSON property adjustmentDateTime

Returns:

  • (String)


39189
39190
39191
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39189

def adjustment_date_time
  @adjustment_date_time
end

#adjustment_typeString

The adjustment type. Corresponds to the JSON property adjustmentType

Returns:

  • (String)


39194
39195
39196
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39194

def adjustment_type
  @adjustment_type
end

#conversion_actionString

Resource name of the conversion action associated with this conversion adjustment. Corresponds to the JSON property conversionAction

Returns:

  • (String)


39200
39201
39202
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39200

def conversion_action
  @conversion_action
end

#gclid_date_time_pairGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGclidDateTimePair

Uniquely identifies a conversion that was reported without an order ID specified. Corresponds to the JSON property gclidDateTimePair



39206
39207
39208
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39206

def gclid_date_time_pair
  @gclid_date_time_pair
end

#order_idString

The order ID of the conversion to be adjusted. Corresponds to the JSON property orderId

Returns:

  • (String)


39211
39212
39213
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39211

def order_id
  @order_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39218
39219
39220
39221
39222
39223
39224
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39218

def update!(**args)
  @adjustment_date_time = args[:adjustment_date_time] if args.key?(:adjustment_date_time)
  @adjustment_type = args[:adjustment_type] if args.key?(:adjustment_type)
  @conversion_action = args[:conversion_action] if args.key?(:conversion_action)
  @gclid_date_time_pair = args[:gclid_date_time_pair] if args.key?(:gclid_date_time_pair)
  @order_id = args[:order_id] if args.key?(:order_id)
end