Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomMetricHeader
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomMetricHeader
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Message for conversion custom metric header.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
The conversion custom metric ID.
-
#name ⇒ String
The user defined name of the conversion custom metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionCustomMetricHeader
constructor
A new instance of GoogleAdsSearchads360V23ServicesConversionCustomMetricHeader.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionCustomMetricHeader
Returns a new instance of GoogleAdsSearchads360V23ServicesConversionCustomMetricHeader.
38658 38659 38660 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38658 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
The conversion custom metric ID.
Corresponds to the JSON property id
38651 38652 38653 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38651 def id @id end |
#name ⇒ String
The user defined name of the conversion custom metric.
Corresponds to the JSON property name
38656 38657 38658 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38656 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38663 38664 38665 38666 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38663 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) end |