Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update) on a conversion custom variable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation.



39300
39301
39302
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39300

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionCustomVariable

A conversion custom variable. See "About custom Floodlight metrics and dimensions in the new Search Ads 360" at https://support.google.com/sa360/ answer/13567857 Corresponds to the JSON property create



39286
39287
39288
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39286

def create
  @create
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionCustomVariable

A conversion custom variable. See "About custom Floodlight metrics and dimensions in the new Search Ads 360" at https://support.google.com/sa360/ answer/13567857 Corresponds to the JSON property update



39293
39294
39295
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39293

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


39298
39299
39300
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39298

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39305
39306
39307
39308
39309
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39305

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end