Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update) on a conversion custom variable.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionCustomVariable
A conversion custom variable.
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionCustomVariable
A conversion custom variable.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation.
38692 38693 38694 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38692 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionCustomVariable
A conversion custom variable. See "About custom Floodlight metrics and
dimensions in the new Search Ads 360" at https://support.google.com/sa360/
answer/13567857
Corresponds to the JSON property create
38678 38679 38680 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38678 def create @create end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionCustomVariable
A conversion custom variable. See "About custom Floodlight metrics and
dimensions in the new Search Ads 360" at https://support.google.com/sa360/
answer/13567857
Corresponds to the JSON property update
38685 38686 38687 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38685 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
38690 38691 38692 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38690 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38697 38698 38699 38700 38701 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38697 def update!(**args) @create = args[:create] if args.key?(:create) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |