Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionRateSuggestion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionRateSuggestion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A conversion rate suggestion.
Instance Attribute Summary collapse
-
#conversion_rate ⇒ Float
The suggested conversion rate.
-
#conversion_rate_model ⇒ String
Model type used to calculate the suggested conversion rate.
-
#plannable_product_code ⇒ String
The code associated with the plannable product (for example: DEMAND_GEN).
-
#surface_targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargeting
Container for surfaces for a product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionRateSuggestion
constructor
A new instance of GoogleAdsSearchads360V23ServicesConversionRateSuggestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionRateSuggestion
Returns a new instance of GoogleAdsSearchads360V23ServicesConversionRateSuggestion.
39435 39436 39437 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39435 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_rate ⇒ Float
The suggested conversion rate. The value is between 0 and 1 (exclusive).
Corresponds to the JSON property conversionRate
39416 39417 39418 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39416 def conversion_rate @conversion_rate end |
#conversion_rate_model ⇒ String
Model type used to calculate the suggested conversion rate.
Corresponds to the JSON property conversionRateModel
39421 39422 39423 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39421 def conversion_rate_model @conversion_rate_model end |
#plannable_product_code ⇒ String
The code associated with the plannable product (for example: DEMAND_GEN). To
list all plannable product codes, use ReachPlanService.ListPlannableProducts.
Corresponds to the JSON property plannableProductCode
39427 39428 39429 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39427 def plannable_product_code @plannable_product_code end |
#surface_targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargeting
Container for surfaces for a product. Surfaces refer to the available types of
ad inventories such as In-Feed, In-Stream, and Shorts.
Corresponds to the JSON property surfaceTargeting
39433 39434 39435 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39433 def surface_targeting @surface_targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39440 39441 39442 39443 39444 39445 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39440 def update!(**args) @conversion_rate = args[:conversion_rate] if args.key?(:conversion_rate) @conversion_rate_model = args[:conversion_rate_model] if args.key?(:conversion_rate_model) @plannable_product_code = args[:plannable_product_code] if args.key?(:plannable_product_code) @surface_targeting = args[:surface_targeting] if args.key?(:surface_targeting) end |