Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionRateSuggestion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A conversion rate suggestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionRateSuggestion

Returns a new instance of GoogleAdsSearchads360V23ServicesConversionRateSuggestion.



39363
39364
39365
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversion_rateFloat

The suggested conversion rate. The value is between 0 and 1 (exclusive). Corresponds to the JSON property conversionRate

Returns:

  • (Float)


39344
39345
39346
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39344

def conversion_rate
  @conversion_rate
end

#conversion_rate_modelString

Model type used to calculate the suggested conversion rate. Corresponds to the JSON property conversionRateModel

Returns:

  • (String)


39349
39350
39351
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39349

def conversion_rate_model
  @conversion_rate_model
end

#plannable_product_codeString

The code associated with the plannable product (for example: DEMAND_GEN). To list all plannable product codes, use ReachPlanService.ListPlannableProducts. Corresponds to the JSON property plannableProductCode

Returns:

  • (String)


39355
39356
39357
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39355

def plannable_product_code
  @plannable_product_code
end

#surface_targetingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargeting

Container for surfaces for a product. Surfaces refer to the available types of ad inventories such as In-Feed, In-Stream, and Shorts. Corresponds to the JSON property surfaceTargeting



39361
39362
39363
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39361

def surface_targeting
  @surface_targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39368
39369
39370
39371
39372
39373
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39368

def update!(**args)
  @conversion_rate = args[:conversion_rate] if args.key?(:conversion_rate)
  @conversion_rate_model = args[:conversion_rate_model] if args.key?(:conversion_rate_model)
  @plannable_product_code = args[:plannable_product_code] if args.key?(:plannable_product_code)
  @surface_targeting = args[:surface_targeting] if args.key?(:surface_targeting)
end