Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionRateSuggestion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionRateSuggestion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A conversion rate suggestion.
Instance Attribute Summary collapse
-
#conversion_rate ⇒ Float
The suggested conversion rate.
-
#conversion_rate_model ⇒ String
Model type used to calculate the suggested conversion rate.
-
#plannable_product_code ⇒ String
The code associated with the plannable product (for example: DEMAND_GEN).
-
#surface_targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargeting
Container for surfaces for a product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionRateSuggestion
constructor
A new instance of GoogleAdsSearchads360V23ServicesConversionRateSuggestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionRateSuggestion
Returns a new instance of GoogleAdsSearchads360V23ServicesConversionRateSuggestion.
38755 38756 38757 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38755 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_rate ⇒ Float
The suggested conversion rate. The value is between 0 and 1 (exclusive).
Corresponds to the JSON property conversionRate
38736 38737 38738 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38736 def conversion_rate @conversion_rate end |
#conversion_rate_model ⇒ String
Model type used to calculate the suggested conversion rate.
Corresponds to the JSON property conversionRateModel
38741 38742 38743 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38741 def conversion_rate_model @conversion_rate_model end |
#plannable_product_code ⇒ String
The code associated with the plannable product (for example: DEMAND_GEN). To
list all plannable product codes, use ReachPlanService.ListPlannableProducts.
Corresponds to the JSON property plannableProductCode
38747 38748 38749 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38747 def plannable_product_code @plannable_product_code end |
#surface_targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargeting
Container for surfaces for a product. Surfaces refer to the available types of
ad inventories such as In-Feed, In-Stream, and Shorts.
Corresponds to the JSON property surfaceTargeting
38753 38754 38755 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38753 def surface_targeting @surface_targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38760 38761 38762 38763 38764 38765 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38760 def update!(**args) @conversion_rate = args[:conversion_rate] if args.key?(:conversion_rate) @conversion_rate_model = args[:conversion_rate_model] if args.key?(:conversion_rate_model) @plannable_product_code = args[:plannable_product_code] if args.key?(:plannable_product_code) @surface_targeting = args[:surface_targeting] if args.key?(:surface_targeting) end |