Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a conversion value rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionValueRuleOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesConversionValueRuleOperation.



39402
39403
39404
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRule

A conversion value rule Corresponds to the JSON property create



39383
39384
39385
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39383

def create
  @create
end

#removeString

Remove operation: A resource name for the removed conversion value rule is expected, in this format: customers/customer_id/conversionValueRules/ conversion_value_rule_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


39390
39391
39392
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39390

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRule

A conversion value rule Corresponds to the JSON property update



39395
39396
39397
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39395

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


39400
39401
39402
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39400

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39407
39408
39409
39410
39411
39412
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39407

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end