Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a conversion value rule.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRule
A conversion value rule Corresponds to the JSON property
create. -
#remove ⇒ String
Remove operation: A resource name for the removed conversion value rule is expected, in this format:
customers/customer_id/conversionValueRules/conversion_value_rule_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRule
A conversion value rule Corresponds to the JSON property
update. -
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionValueRuleOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesConversionValueRuleOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionValueRuleOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesConversionValueRuleOperation.
38794 38795 38796 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38794 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRule
A conversion value rule
Corresponds to the JSON property create
38775 38776 38777 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38775 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed conversion value rule is
expected, in this format: customers/customer_id/conversionValueRules/
conversion_value_rule_id`
Corresponds to the JSON propertyremove`
38782 38783 38784 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38782 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRule
A conversion value rule
Corresponds to the JSON property update
38787 38788 38789 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38787 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
38792 38793 38794 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38792 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38799 38800 38801 38802 38803 38804 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38799 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |