Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a conversion value rule set.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleSet
A conversion value rule set is a collection of conversion value rules that lets you adjust conversion values based on the dimensions specified in the
dimensionsfield. -
#remove ⇒ String
Remove operation: A resource name for the removed conversion value rule set is expected, in this format:
customers/customer_id/conversionValueRuleSets/conversion_value_rule_set_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleSet
A conversion value rule set is a collection of conversion value rules that lets you adjust conversion values based on the dimensions specified in the
dimensionsfield. -
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation.
39445 39446 39447 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39445 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleSet
A conversion value rule set is a collection of conversion value rules that
lets you adjust conversion values based on the dimensions specified in the
dimensions field.
Corresponds to the JSON property create
39424 39425 39426 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39424 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed conversion value rule set is
expected, in this format: customers/customer_id/conversionValueRuleSets/
conversion_value_rule_set_id`
Corresponds to the JSON propertyremove`
39431 39432 39433 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39431 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleSet
A conversion value rule set is a collection of conversion value rules that
lets you adjust conversion values based on the dimensions specified in the
dimensions field.
Corresponds to the JSON property update
39438 39439 39440 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39438 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
39443 39444 39445 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39443 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39450 39451 39452 39453 39454 39455 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39450 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |