Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCreateAccountLinkRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCreateAccountLinkRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AccountLinkService.CreateAccountLink.
Instance Attribute Summary collapse
-
#account_link ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccountLink
Represents the data sharing connection between a Google Ads account and another account Corresponds to the JSON property
accountLink.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCreateAccountLinkRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesCreateAccountLinkRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCreateAccountLinkRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesCreateAccountLinkRequest.
38860 38861 38862 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38860 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_link ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAccountLink
Represents the data sharing connection between a Google Ads account and
another account
Corresponds to the JSON property accountLink
38858 38859 38860 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38858 def account_link @account_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38865 38866 38867 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38865 def update!(**args) @account_link = args[:account_link] if args.key?(:account_link) end |