Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCreateCustomerClientResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCreateCustomerClientResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for CreateCustomerClient mutate.
Instance Attribute Summary collapse
-
#invitation_link ⇒ String
Link for inviting user to access the created customer.
-
#resource_name ⇒ String
The resource name of the newly created customer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCreateCustomerClientResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesCreateCustomerClientResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCreateCustomerClientResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesCreateCustomerClientResponse.
38946 38947 38948 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38946 def initialize(**args) update!(**args) end |
Instance Attribute Details
#invitation_link ⇒ String
Link for inviting user to access the created customer. Accessible to
allowlisted customers only.
Corresponds to the JSON property invitationLink
38938 38939 38940 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38938 def invitation_link @invitation_link end |
#resource_name ⇒ String
The resource name of the newly created customer. Customer resource names have
the form: customers/customer_id`.
Corresponds to the JSON propertyresourceName`
38944 38945 38946 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38944 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38951 38952 38953 38954 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 38951 def update!(**args) @invitation_link = args[:invitation_link] if args.key?(:invitation_link) @resource_name = args[:resource_name] if args.key?(:resource_name) end |