Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCreateOfflineUserDataJobRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCreateOfflineUserDataJobRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for OfflineUserDataJobService.CreateOfflineUserDataJob.
Instance Attribute Summary collapse
-
#enable_match_rate_range_preview ⇒ Boolean
(also: #enable_match_rate_range_preview?)
If true, match rate range for the offline user data job is calculated and made available in the resource.
-
#job ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineUserDataJob
A job containing offline user data of store visitors, or user list members that will be processed asynchronously.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCreateOfflineUserDataJobRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesCreateOfflineUserDataJobRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCreateOfflineUserDataJobRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesCreateOfflineUserDataJobRequest.
39628 39629 39630 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39628 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_match_rate_range_preview ⇒ Boolean Also known as: enable_match_rate_range_preview?
If true, match rate range for the offline user data job is calculated and made
available in the resource.
Corresponds to the JSON property enableMatchRateRangePreview
39611 39612 39613 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39611 def enable_match_rate_range_preview @enable_match_rate_range_preview end |
#job ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineUserDataJob
A job containing offline user data of store visitors, or user list members
that will be processed asynchronously. The uploaded data isn't readable and
the processing results of the job can only be read using
Corresponds to the JSON property job
39619 39620 39621 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39619 def job @job end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
39625 39626 39627 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39625 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39633 39634 39635 39636 39637 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39633 def update!(**args) @enable_match_rate_range_preview = args[:enable_match_rate_range_preview] if args.key?(:enable_match_rate_range_preview) @job = args[:job] if args.key?(:job) @validate_only = args[:validate_only] if args.key?(:validate_only) end |