Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCreateOfflineUserDataJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for OfflineUserDataJobService.CreateOfflineUserDataJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCreateOfflineUserDataJobRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesCreateOfflineUserDataJobRequest.



39020
39021
39022
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_match_rate_range_previewBoolean Also known as: enable_match_rate_range_preview?

If true, match rate range for the offline user data job is calculated and made available in the resource. Corresponds to the JSON property enableMatchRateRangePreview

Returns:

  • (Boolean)


39003
39004
39005
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39003

def enable_match_rate_range_preview
  @enable_match_rate_range_preview
end

#jobGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesOfflineUserDataJob

A job containing offline user data of store visitors, or user list members that will be processed asynchronously. The uploaded data isn't readable and the processing results of the job can only be read using Corresponds to the JSON property job



39011
39012
39013
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39011

def job
  @job
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


39017
39018
39019
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39017

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39025
39026
39027
39028
39029
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39025

def update!(**args)
  @enable_match_rate_range_preview = args[:enable_match_rate_range_preview] if args.key?(:enable_match_rate_range_preview)
  @job = args[:job] if args.key?(:job)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end