Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomAudienceOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomAudienceOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update) on a custom audience.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudience
A custom audience.
-
#remove ⇒ String
Remove operation: A resource name for the removed custom audience is expected, in this format:
customers/customer_id/customAudiences/custom_audience_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudience
A custom audience.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomAudienceOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCustomAudienceOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomAudienceOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCustomAudienceOperation.
39183 39184 39185 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudience
A custom audience. This is a list of users by interest. The unique key of a
custom audience consists of the following fields: name. Violating the unique
key constraint produces error: CustomAudienceError.NAME_ALREADY_USED
Corresponds to the JSON property create
39163 39164 39165 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39163 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed custom audience is expected,
in this format: customers/customer_id/customAudiences/custom_audience_id`
Corresponds to the JSON propertyremove`
39169 39170 39171 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39169 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomAudience
A custom audience. This is a list of users by interest. The unique key of a
custom audience consists of the following fields: name. Violating the unique
key constraint produces error: CustomAudienceError.NAME_ALREADY_USED
Corresponds to the JSON property update
39176 39177 39178 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39176 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
39181 39182 39183 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39181 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39188 39189 39190 39191 39192 39193 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39188 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |