Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomConversionGoalOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on a custom conversion goal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomConversionGoalOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCustomConversionGoalOperation.



39862
39863
39864
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomConversionGoal

Custom conversion goal that can make arbitrary conversion actions biddable. Corresponds to the JSON property create



39843
39844
39845
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39843

def create
  @create
end

#removeString

Remove operation: A resource name for the removed custom conversion goal is expected, in this format: 'customers/customer_id/customConversionGoals/ goal_id' Corresponds to the JSON property remove

Returns:

  • (String)


39850
39851
39852
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39850

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomConversionGoal

Custom conversion goal that can make arbitrary conversion actions biddable. Corresponds to the JSON property update



39855
39856
39857
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39855

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


39860
39861
39862
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39860

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39867
39868
39869
39870
39871
39872
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39867

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end