Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomVariable
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomVariable
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A custom variable.
Instance Attribute Summary collapse
-
#conversion_custom_variable ⇒ String
Resource name of the custom variable associated with this conversion.
-
#value ⇒ String
The value string of this custom variable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomVariable
constructor
A new instance of GoogleAdsSearchads360V23ServicesCustomVariable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomVariable
Returns a new instance of GoogleAdsSearchads360V23ServicesCustomVariable.
39925 39926 39927 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39925 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_custom_variable ⇒ String
Resource name of the custom variable associated with this conversion. Note:
Although this resource name consists of a customer id and a conversion custom
variable id, validation will ignore the customer id and use the conversion
custom variable id as the sole identifier of the conversion custom variable.
Corresponds to the JSON property conversionCustomVariable
39916 39917 39918 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39916 def conversion_custom_variable @conversion_custom_variable end |
#value ⇒ String
The value string of this custom variable. The value of the custom variable
should not contain private customer data, such as email addresses or phone
numbers.
Corresponds to the JSON property value
39923 39924 39925 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39923 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39930 39931 39932 39933 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39930 def update!(**args) @conversion_custom_variable = args[:conversion_custom_variable] if args.key?(:conversion_custom_variable) @value = args[:value] if args.key?(:value) end |