Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a customer asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerAssetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerAssetOperation.



39962
39963
39964
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAsset

A link between a customer and an asset. Corresponds to the JSON property create



39943
39944
39945
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39943

def create
  @create
end

#removeString

Remove operation: A resource name for the removed customer asset is expected, in this format: customers/customer_id/customerAssets/asset_id~field_type Corresponds to the JSON property remove

Returns:

  • (String)


39950
39951
39952
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39950

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAsset

A link between a customer and an asset. Corresponds to the JSON property update



39955
39956
39957
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39955

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


39960
39961
39962
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39960

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39967
39968
39969
39970
39971
39972
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39967

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end