Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a customer asset.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAsset
A link between a customer and an asset.
-
#remove ⇒ String
Remove operation: A resource name for the removed customer asset is expected, in this format:
customers/customer_id/customerAssets/asset_id~field_typeCorresponds to the JSON propertyremove. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAsset
A link between a customer and an asset.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerAssetOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCustomerAssetOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerAssetOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerAssetOperation.
39324 39325 39326 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39324 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAsset
A link between a customer and an asset.
Corresponds to the JSON property create
39305 39306 39307 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39305 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed customer asset is expected,
in this format: customers/customer_id/customerAssets/asset_id~field_type
Corresponds to the JSON property remove
39312 39313 39314 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39312 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAsset
A link between a customer and an asset.
Corresponds to the JSON property update
39317 39318 39319 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39317 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
39322 39323 39324 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39322 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39329 39330 39331 39332 39333 39334 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39329 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |