Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetSetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on a customer asset set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerAssetSetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerAssetSetOperation.



39992
39993
39994
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAssetSet

CustomerAssetSet is the linkage between a customer and an asset set. Adding a CustomerAssetSet links an asset set with a customer. Corresponds to the JSON property create



39983
39984
39985
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39983

def create
  @create
end

#removeString

Remove operation: A resource name for the removed customer asset set is expected, in this format: customers/customer_id/customerAssetSets/ asset_set_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


39990
39991
39992
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39990

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39997
39998
39999
40000
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39997

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end