Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetSetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on a customer asset set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerAssetSetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerAssetSetOperation.



39354
39355
39356
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerAssetSet

CustomerAssetSet is the linkage between a customer and an asset set. Adding a CustomerAssetSet links an asset set with a customer. Corresponds to the JSON property create



39345
39346
39347
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39345

def create
  @create
end

#removeString

Remove operation: A resource name for the removed customer asset set is expected, in this format: customers/customer_id/customerAssetSets/ asset_set_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


39352
39353
39354
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39352

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39359
39360
39361
39362
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39359

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end