Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update) on a CustomerClientLink.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClientLink
Represents customer client link relationship.
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClientLink
Represents customer client link relationship.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation.
40022 40023 40024 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClientLink
Represents customer client link relationship.
Corresponds to the JSON property create
40010 40011 40012 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40010 def create @create end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerClientLink
Represents customer client link relationship.
Corresponds to the JSON property update
40015 40016 40017 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40015 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
40020 40021 40022 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40020 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40027 40028 40029 40030 40031 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40027 def update!(**args) @create = args[:create] if args.key?(:create) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |