Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (update) on a customer conversion goal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation.



39410
39411
39412
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerConversionGoal

Biddability control for conversion actions with a matching category and origin. Corresponds to the JSON property update



39403
39404
39405
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39403

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


39408
39409
39410
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39408

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39415
39416
39417
39418
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39415

def update!(**args)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end