Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove) on a customizer attribute.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerCustomizer
A customizer value for the associated CustomizerAttribute at the Customer level.
-
#remove ⇒ String
Remove operation: A resource name for the removed customer customizer is expected, in this format:
customers/customer_id/customerCustomizers/customizer_attribute_id`Corresponds to the JSON propertyremove`.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation.
39438 39439 39440 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39438 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerCustomizer
A customizer value for the associated CustomizerAttribute at the Customer
level.
Corresponds to the JSON property create
39429 39430 39431 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39429 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed customer customizer is
expected, in this format: customers/customer_id/customerCustomizers/
customizer_attribute_id`
Corresponds to the JSON propertyremove`
39436 39437 39438 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39436 def remove @remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39443 39444 39445 39446 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39443 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) end |