Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerLabelOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove) on a customer-label relationship.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerLabelOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerLabelOperation.



39466
39467
39468
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerLabel

Represents a relationship between a customer and a label. This customer may not have access to all the labels attached to it. Additional CustomerLabels may be returned by increasing permissions with login-customer-id. Corresponds to the JSON property create



39458
39459
39460
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39458

def create
  @create
end

#removeString

Remove operation: A resource name for the customer-label relationship being removed, in this format: customers/customer_id/customerLabels/label_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


39464
39465
39466
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39464

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39471
39472
39473
39474
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39471

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end