Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerNegativeCriterionOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create or remove) on a customer level negative criterion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerNegativeCriterionOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerNegativeCriterionOperation.



39552
39553
39554
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39552

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerNegativeCriterion

A negative criterion for exclusions at the customer level. Corresponds to the JSON property create



39544
39545
39546
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39544

def create
  @create
end

#removeString

Remove operation: A resource name for the removed criterion is expected, in this format: customers/customer_id/customerNegativeCriteria/criterion_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


39550
39551
39552
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39550

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39557
39558
39559
39560
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39557

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end