Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerUserAccessInvitationOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create or remove) on customer user access invitation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerUserAccessInvitationOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerUserAccessInvitationOperation.



40261
40262
40263
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40261

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation

Represent an invitation to a new user on this customer account. Corresponds to the JSON property create



40252
40253
40254
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40252

def create
  @create
end

#removeString

Remove operation: A resource name for the revoke invitation is expected, in this format: customers/customer_id/customerUserAccessInvitations/ invitation_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


40259
40260
40261
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40259

def remove
  @remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40266
40267
40268
40269
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40266

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
end