Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerUserAccessInvitationOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerUserAccessInvitationOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create or remove) on customer user access invitation.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation
Represent an invitation to a new user on this customer account.
-
#remove ⇒ String
Remove operation: A resource name for the revoke invitation is expected, in this format:
customers/customer_id/customerUserAccessInvitations/invitation_id`Corresponds to the JSON propertyremove`.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerUserAccessInvitationOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCustomerUserAccessInvitationOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerUserAccessInvitationOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerUserAccessInvitationOperation.
39623 39624 39625 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39623 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccessInvitation
Represent an invitation to a new user on this customer account.
Corresponds to the JSON property create
39614 39615 39616 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39614 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the revoke invitation is expected, in
this format: customers/customer_id/customerUserAccessInvitations/
invitation_id`
Corresponds to the JSON propertyremove`
39621 39622 39623 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39621 def remove @remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39628 39629 39630 39631 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39628 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) end |