Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerUserAccessOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerUserAccessOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (update, remove) on customer user access.
Instance Attribute Summary collapse
-
#remove ⇒ String
Remove operation: A resource name for the removed access is expected, in this format:
customers/customer_id/customerUserAccesses/CustomerUserAccess. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccess
Represents the permission of a single user onto a single customer.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerUserAccessOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesCustomerUserAccessOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerUserAccessOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerUserAccessOperation.
40293 40294 40295 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40293 def initialize(**args) update!(**args) end |
Instance Attribute Details
#remove ⇒ String
Remove operation: A resource name for the removed access is expected, in this
format: customers/customer_id/customerUserAccesses/CustomerUserAccess.
user_id`
Corresponds to the JSON propertyremove`
40281 40282 40283 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40281 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccess
Represents the permission of a single user onto a single customer.
Corresponds to the JSON property update
40286 40287 40288 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40286 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
40291 40292 40293 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40291 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40298 40299 40300 40301 40302 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40298 def update!(**args) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |