Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerUserAccessOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (update, remove) on customer user access.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCustomerUserAccessOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesCustomerUserAccessOperation.



39655
39656
39657
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39655

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#removeString

Remove operation: A resource name for the removed access is expected, in this format: customers/customer_id/customerUserAccesses/CustomerUserAccess. user_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


39643
39644
39645
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39643

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomerUserAccess

Represents the permission of a single user onto a single customer. Corresponds to the JSON property update



39648
39649
39650
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39648

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


39653
39654
39655
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39653

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39660
39661
39662
39663
39664
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39660

def update!(**args)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end