Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCyoIncentives
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCyoIncentives
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An incentive offer in the Choose-Your-Own Incentive feature where a user can select from a set of incentives with different money amounts.
Instance Attribute Summary collapse
-
#high_offer ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive
An incentive that a user can claim for their account.
-
#low_offer ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive
An incentive that a user can claim for their account.
-
#medium_offer ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive
An incentive that a user can claim for their account.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCyoIncentives
constructor
A new instance of GoogleAdsSearchads360V23ServicesCyoIncentives.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesCyoIncentives
Returns a new instance of GoogleAdsSearchads360V23ServicesCyoIncentives.
39723 39724 39725 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39723 def initialize(**args) update!(**args) end |
Instance Attribute Details
#high_offer ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive
An incentive that a user can claim for their account.
Corresponds to the JSON property highOffer
39711 39712 39713 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39711 def high_offer @high_offer end |
#low_offer ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive
An incentive that a user can claim for their account.
Corresponds to the JSON property lowOffer
39716 39717 39718 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39716 def low_offer @low_offer end |
#medium_offer ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive
An incentive that a user can claim for their account.
Corresponds to the JSON property mediumOffer
39721 39722 39723 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39721 def medium_offer @medium_offer end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39728 39729 39730 39731 39732 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39728 def update!(**args) @high_offer = args[:high_offer] if args.key?(:high_offer) @low_offer = args[:low_offer] if args.key?(:low_offer) @medium_offer = args[:medium_offer] if args.key?(:medium_offer) end |