Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDimensionOverlapResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDimensionOverlapResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A list of audience attributes of a single dimension, including their overlap with a primary attribute, returned as part of a GenerateAudienceOverlapInsightsResponse.
Instance Attribute Summary collapse
-
#dimension ⇒ String
The dimension of all the attributes in this section.
-
#items ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOverlapItem>
The attributes and their overlap with the primary attribute.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesDimensionOverlapResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesDimensionOverlapResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesDimensionOverlapResult
Returns a new instance of GoogleAdsSearchads360V23ServicesDimensionOverlapResult.
40461 40462 40463 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimension ⇒ String
The dimension of all the attributes in this section.
Corresponds to the JSON property dimension
40454 40455 40456 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40454 def dimension @dimension end |
#items ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOverlapItem>
The attributes and their overlap with the primary attribute.
Corresponds to the JSON property items
40459 40460 40461 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40459 def items @items end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40466 40467 40468 40469 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40466 def update!(**args) @dimension = args[:dimension] if args.key?(:dimension) @items = args[:items] if args.key?(:items) end |