Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDimensionOverlapResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A list of audience attributes of a single dimension, including their overlap with a primary attribute, returned as part of a GenerateAudienceOverlapInsightsResponse.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesDimensionOverlapResult

Returns a new instance of GoogleAdsSearchads360V23ServicesDimensionOverlapResult.



39751
39752
39753
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionString

The dimension of all the attributes in this section. Corresponds to the JSON property dimension

Returns:

  • (String)


39744
39745
39746
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39744

def dimension
  @dimension
end

#itemsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOverlapItem>

The attributes and their overlap with the primary attribute. Corresponds to the JSON property items



39749
39750
39751
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39749

def items
  @items
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39756
39757
39758
39759
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39756

def update!(**args)
  @dimension = args[:dimension] if args.key?(:dimension)
  @items = args[:items] if args.key?(:items)
end