Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDismissRecommendationRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDismissRecommendationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for RecommendationService.DismissRecommendation.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDismissRecommendationRequestDismissRecommendationOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesDismissRecommendationRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesDismissRecommendationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesDismissRecommendationRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesDismissRecommendationRequest.
39781 39782 39783 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39781 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDismissRecommendationRequestDismissRecommendationOperation>
Required. The list of operations to dismiss recommendations. If
partial_failure=false all recommendations should be of the same type There is
a limit of 100 operations per request.
Corresponds to the JSON property operations
39771 39772 39773 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39771 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, operations will be carried in a single transaction if
and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
39778 39779 39780 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39778 def partial_failure @partial_failure end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39786 39787 39788 39789 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39786 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) end |