Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDismissRecommendationResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDismissRecommendationResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for RecommendationService.DismissRecommendation.
Instance Attribute Summary collapse
-
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDismissRecommendationResponseDismissRecommendationResult>
Results of operations to dismiss recommendations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesDismissRecommendationResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesDismissRecommendationResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesDismissRecommendationResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesDismissRecommendationResponse.
39811 39812 39813 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39811 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property partialFailureError
39804 39805 39806 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39804 def partial_failure_error @partial_failure_error end |
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDismissRecommendationResponseDismissRecommendationResult>
Results of operations to dismiss recommendations.
Corresponds to the JSON property results
39809 39810 39811 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39809 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39816 39817 39818 39819 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 39816 def update!(**args) @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error) @results = args[:results] if args.key?(:results) end |