Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesEffectiveFrequencyBreakdown
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesEffectiveFrequencyBreakdown
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A breakdown of the number of unique people reached at a given effective frequency.
Instance Attribute Summary collapse
-
#effective_coview_reach ⇒ Fixnum
The number of users (including co-viewing users) reached for the associated effective_frequency value.
-
#effective_frequency ⇒ Fixnum
The effective frequency [1-10].
-
#on_target_effective_coview_reach ⇒ Fixnum
The number of users (including co-viewing users) reached for the associated effective_frequency value within the specified plan demographic.
-
#on_target_reach ⇒ Fixnum
The number of unique people reached at least effective_frequency times that exactly matches the Targeting.
-
#total_reach ⇒ Fixnum
Total number of unique people reached at least effective_frequency times.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesEffectiveFrequencyBreakdown
constructor
A new instance of GoogleAdsSearchads360V23ServicesEffectiveFrequencyBreakdown.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesEffectiveFrequencyBreakdown
Returns a new instance of GoogleAdsSearchads360V23ServicesEffectiveFrequencyBreakdown.
40499 40500 40501 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40499 def initialize(**args) update!(**args) end |
Instance Attribute Details
#effective_coview_reach ⇒ Fixnum
The number of users (including co-viewing users) reached for the associated
effective_frequency value.
Corresponds to the JSON property effectiveCoviewReach
40469 40470 40471 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40469 def effective_coview_reach @effective_coview_reach end |
#effective_frequency ⇒ Fixnum
The effective frequency [1-10].
Corresponds to the JSON property effectiveFrequency
40474 40475 40476 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40474 def effective_frequency @effective_frequency end |
#on_target_effective_coview_reach ⇒ Fixnum
The number of users (including co-viewing users) reached for the associated
effective_frequency value within the specified plan demographic.
Corresponds to the JSON property onTargetEffectiveCoviewReach
40480 40481 40482 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40480 def on_target_effective_coview_reach @on_target_effective_coview_reach end |
#on_target_reach ⇒ Fixnum
The number of unique people reached at least effective_frequency times that
exactly matches the Targeting. Note that a minimum number of unique people
must be reached in order for data to be reported. If the minimum number is not
met, the on_target_reach value will be rounded to 0.
Corresponds to the JSON property onTargetReach
40488 40489 40490 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40488 def on_target_reach @on_target_reach end |
#total_reach ⇒ Fixnum
Total number of unique people reached at least effective_frequency times. This
includes people that may fall outside the specified Targeting. Note that a
minimum number of unique people must be reached in order for data to be
reported. If the minimum number is not met, the total_reach value will be
rounded to 0.
Corresponds to the JSON property totalReach
40497 40498 40499 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40497 def total_reach @total_reach end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40504 40505 40506 40507 40508 40509 40510 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40504 def update!(**args) @effective_coview_reach = args[:effective_coview_reach] if args.key?(:effective_coview_reach) @effective_frequency = args[:effective_frequency] if args.key?(:effective_frequency) @on_target_effective_coview_reach = args[:on_target_effective_coview_reach] if args.key?(:on_target_effective_coview_reach) @on_target_reach = args[:on_target_reach] if args.key?(:on_target_reach) @total_reach = args[:total_reach] if args.key?(:total_reach) end |