Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesEnableOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single enable operation of a campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesEnableOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesEnableOperation.



40581
40582
40583
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accent_colorString

Optional. Hex code representation of the accent brand color, for example # 00ff00. accent_color is required when main_color is specified. Corresponds to the JSON property accentColor

Returns:

  • (String)


40542
40543
40544
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40542

def accent_color
  @accent_color
end

#auto_populate_brand_assetsBoolean Also known as: auto_populate_brand_assets?

Required. The switch to automatically populate top-performing brand assets. This field is required. If true, top-performing brand assets will be automatically populated. If false, the brand_assets field is required. Corresponds to the JSON property autoPopulateBrandAssets

Returns:

  • (Boolean)


40549
40550
40551
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40549

def auto_populate_brand_assets
  @auto_populate_brand_assets
end

#brand_assetsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBrandCampaignAssets

Assets linked at the campaign level. A business_name and at least one logo_asset are required. Corresponds to the JSON property brandAssets



40556
40557
40558
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40556

def brand_assets
  @brand_assets
end

#campaignString

Required. The resource name of the campaign to enable. Corresponds to the JSON property campaign

Returns:

  • (String)


40561
40562
40563
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40561

def campaign
  @campaign
end

#final_uri_domainString

Optional. The domain of the final uri. Corresponds to the JSON property finalUriDomain

Returns:

  • (String)


40566
40567
40568
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40566

def final_uri_domain
  @final_uri_domain
end

#font_familyString

Optional. The font family is specified as a string, and must be one of the following: "Open Sans", "Roboto", "Roboto Slab", "Montserrat", "Poppins", " Lato", "Oswald", or "Playfair Display". Corresponds to the JSON property fontFamily

Returns:

  • (String)


40573
40574
40575
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40573

def font_family
  @font_family
end

#main_colorString

Optional. Hex code representation of the main brand color, for example #00ff00. main_color is required when accent color is specified. Corresponds to the JSON property mainColor

Returns:

  • (String)


40579
40580
40581
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40579

def main_color
  @main_color
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40586
40587
40588
40589
40590
40591
40592
40593
40594
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40586

def update!(**args)
  @accent_color = args[:accent_color] if args.key?(:accent_color)
  @auto_populate_brand_assets = args[:auto_populate_brand_assets] if args.key?(:auto_populate_brand_assets)
  @brand_assets = args[:brand_assets] if args.key?(:brand_assets)
  @campaign = args[:campaign] if args.key?(:campaign)
  @final_uri_domain = args[:final_uri_domain] if args.key?(:final_uri_domain)
  @font_family = args[:font_family] if args.key?(:font_family)
  @main_color = args[:main_color] if args.key?(:main_color)
end