Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesEnablementResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesEnablementResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single enablement result of a campaign.
Instance Attribute Summary collapse
-
#campaign ⇒ String
This indicates the campaign for which enablement was tried, regardless of the outcome.
-
#enablement_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesEnablementResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesEnablementResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesEnablementResult
Returns a new instance of GoogleAdsSearchads360V23ServicesEnablementResult.
40018 40019 40020 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40018 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign ⇒ String
This indicates the campaign for which enablement was tried, regardless of the
outcome.
Corresponds to the JSON property campaign
40006 40007 40008 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40006 def campaign @campaign end |
#enablement_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property enablementError
40016 40017 40018 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40016 def enablement_error @enablement_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40023 40024 40025 40026 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40023 def update!(**args) @campaign = args[:campaign] if args.key?(:campaign) @enablement_error = args[:enablement_error] if args.key?(:enablement_error) end |