Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentArmOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentArmOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation on an experiment arm.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArm
A Google ads experiment for users to experiment changes on multiple campaigns, compare the performance, and apply the effective changes.
-
#remove ⇒ String
Remove operation: The experiment arm is expected to have a valid resource name, in this format:
customers/customer_id/experiments/campaign_experiment_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArm
A Google ads experiment for users to experiment changes on multiple campaigns, compare the performance, and apply the effective changes.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesExperimentArmOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesExperimentArmOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesExperimentArmOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesExperimentArmOperation.
40077 40078 40079 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArm
A Google ads experiment for users to experiment changes on multiple campaigns,
compare the performance, and apply the effective changes.
Corresponds to the JSON property create
40058 40059 40060 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40058 def create @create end |
#remove ⇒ String
Remove operation: The experiment arm is expected to have a valid resource name,
in this format: customers/customer_id/experiments/campaign_experiment_id`
Corresponds to the JSON propertyremove`
40064 40065 40066 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40064 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArm
A Google ads experiment for users to experiment changes on multiple campaigns,
compare the performance, and apply the effective changes.
Corresponds to the JSON property update
40070 40071 40072 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40070 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
40075 40076 40077 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40075 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40082 40083 40084 40085 40086 40087 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40082 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |