Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation on an experiment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesExperimentOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesExperimentOperation.



40117
40118
40119
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40117

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperiment

A Google ads experiment for users to experiment changes on multiple campaigns, compare the performance, and apply the effective changes. Corresponds to the JSON property create



40098
40099
40100
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40098

def create
  @create
end

#removeString

Remove operation: The experiment is expected to have a valid resource name, in this format: customers/customer_id/experiments/campaign_experiment_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


40104
40105
40106
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40104

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperiment

A Google ads experiment for users to experiment changes on multiple campaigns, compare the performance, and apply the effective changes. Corresponds to the JSON property update



40110
40111
40112
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40110

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


40115
40116
40117
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40115

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40122
40123
40124
40125
40126
40127
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40122

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end