Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecast
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecast
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Forecasted traffic metrics for the planned products and targeting.
Instance Attribute Summary collapse
-
#conversions ⇒ Float
The number of conversions.
-
#effective_frequency_breakdowns ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesEffectiveFrequencyBreakdown>
A list of effective frequency forecasts.
-
#on_target_coview_impressions ⇒ Fixnum
Number of ad impressions that exactly matches the Targeting including co- viewers.
-
#on_target_coview_reach ⇒ Fixnum
Number of unique people reached that exactly matches the Targeting including co-viewers.
-
#on_target_impressions ⇒ Fixnum
Number of ad impressions that exactly matches the Targeting.
-
#on_target_reach ⇒ Fixnum
Number of unique people reached at least GenerateReachForecastRequest.
-
#total_coview_impressions ⇒ Fixnum
Total number of ad impressions including co-viewers.
-
#total_coview_reach ⇒ Fixnum
Number of unique people reached including co-viewers.
-
#total_impressions ⇒ Fixnum
Total number of ad impressions.
-
#total_reach ⇒ Fixnum
Total number of unique people reached at least GenerateReachForecastRequest.
-
#trueview_views ⇒ Fixnum
Number of ad views forecasted for the specified product and targeting.
-
#viewable_impressions ⇒ Fixnum
Number of times the ad's impressions were considered viewable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesForecast
constructor
A new instance of GoogleAdsSearchads360V23ServicesForecast.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesForecast
Returns a new instance of GoogleAdsSearchads360V23ServicesForecast.
40906 40907 40908 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversions ⇒ Float
The number of conversions. This metric is only available for DEMAND_GEN
plannable products. See https://support.google.com/google-ads/answer/2375431
for more information on conversions.
Corresponds to the JSON property conversions
40824 40825 40826 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40824 def conversions @conversions end |
#effective_frequency_breakdowns ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesEffectiveFrequencyBreakdown>
A list of effective frequency forecasts. The list is ordered starting with 1+
and ending with the value set in GenerateReachForecastRequest.
effective_frequency_limit. If no effective_frequency_limit was set, this list
will be empty.
Corresponds to the JSON property effectiveFrequencyBreakdowns
40832 40833 40834 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40832 def effective_frequency_breakdowns @effective_frequency_breakdowns end |
#on_target_coview_impressions ⇒ Fixnum
Number of ad impressions that exactly matches the Targeting including co-
viewers.
Corresponds to the JSON property onTargetCoviewImpressions
40838 40839 40840 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40838 def on_target_coview_impressions @on_target_coview_impressions end |
#on_target_coview_reach ⇒ Fixnum
Number of unique people reached that exactly matches the Targeting including
co-viewers.
Corresponds to the JSON property onTargetCoviewReach
40844 40845 40846 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40844 def on_target_coview_reach @on_target_coview_reach end |
#on_target_impressions ⇒ Fixnum
Number of ad impressions that exactly matches the Targeting.
Corresponds to the JSON property onTargetImpressions
40849 40850 40851 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40849 def on_target_impressions @on_target_impressions end |
#on_target_reach ⇒ Fixnum
Number of unique people reached at least GenerateReachForecastRequest.
min_effective_frequency or GenerateReachForecastRequest.
effective_frequency_limit times that exactly matches the Targeting. Note that
a minimum number of unique people must be reached in order for data to be
reported. If the minimum number is not met, the on_target_reach value will be
rounded to 0.
Corresponds to the JSON property onTargetReach
40859 40860 40861 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40859 def on_target_reach @on_target_reach end |
#total_coview_impressions ⇒ Fixnum
Total number of ad impressions including co-viewers. This includes impressions
that may fall outside the specified Targeting, due to insufficient information
on signed-in users.
Corresponds to the JSON property totalCoviewImpressions
40866 40867 40868 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40866 def total_coview_impressions @total_coview_impressions end |
#total_coview_reach ⇒ Fixnum
Number of unique people reached including co-viewers. This includes people
that may fall outside the specified Targeting.
Corresponds to the JSON property totalCoviewReach
40872 40873 40874 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40872 def total_coview_reach @total_coview_reach end |
#total_impressions ⇒ Fixnum
Total number of ad impressions. This includes impressions that may fall
outside the specified Targeting, due to insufficient information on signed-in
users.
Corresponds to the JSON property totalImpressions
40879 40880 40881 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40879 def total_impressions @total_impressions end |
#total_reach ⇒ Fixnum
Total number of unique people reached at least GenerateReachForecastRequest.
min_effective_frequency or GenerateReachForecastRequest.
effective_frequency_limit times. This includes people that may fall outside
the specified Targeting. Note that a minimum number of unique people must be
reached in order for data to be reported. If the minimum number is not met,
the total_reach value will be rounded to 0.
Corresponds to the JSON property totalReach
40889 40890 40891 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40889 def total_reach @total_reach end |
#trueview_views ⇒ Fixnum
Number of ad views forecasted for the specified product and targeting. A
TrueView View is counted when a viewer views a larger portion or the entirety
of an ad beyond an impression. See https://support.google.com/google-ads/
answer/2375431 for more information on TrueView Views.
Corresponds to the JSON property trueviewViews
40897 40898 40899 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40897 def trueview_views @trueview_views end |
#viewable_impressions ⇒ Fixnum
Number of times the ad's impressions were considered viewable. See https://
support.google.com/google-ads/answer/7029393 for more information about what
makes an ad viewable and how viewability is measured.
Corresponds to the JSON property viewableImpressions
40904 40905 40906 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40904 def viewable_impressions @viewable_impressions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40911 40912 40913 40914 40915 40916 40917 40918 40919 40920 40921 40922 40923 40924 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40911 def update!(**args) @conversions = args[:conversions] if args.key?(:conversions) @effective_frequency_breakdowns = args[:effective_frequency_breakdowns] if args.key?(:effective_frequency_breakdowns) @on_target_coview_impressions = args[:on_target_coview_impressions] if args.key?(:on_target_coview_impressions) @on_target_coview_reach = args[:on_target_coview_reach] if args.key?(:on_target_coview_reach) @on_target_impressions = args[:on_target_impressions] if args.key?(:on_target_impressions) @on_target_reach = args[:on_target_reach] if args.key?(:on_target_reach) @total_coview_impressions = args[:total_coview_impressions] if args.key?(:total_coview_impressions) @total_coview_reach = args[:total_coview_reach] if args.key?(:total_coview_reach) @total_impressions = args[:total_impressions] if args.key?(:total_impressions) @total_reach = args[:total_reach] if args.key?(:total_reach) @trueview_views = args[:trueview_views] if args.key?(:trueview_views) @viewable_impressions = args[:viewable_impressions] if args.key?(:viewable_impressions) end |