Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecastAdGroup
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecastAdGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An ad group that is part of a campaign to be forecasted.
Instance Attribute Summary collapse
-
#biddable_keywords ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddableKeyword>
Required.
-
#max_cpc_bid_micros ⇒ Fixnum
The max cpc to use for the ad group when generating forecasted traffic.
-
#negative_keywords ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo>
The details of the keyword.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesForecastAdGroup
constructor
A new instance of GoogleAdsSearchads360V23ServicesForecastAdGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesForecastAdGroup
Returns a new instance of GoogleAdsSearchads360V23ServicesForecastAdGroup.
41022 41023 41024 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#biddable_keywords ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddableKeyword>
Required. The list of biddable keywords to be used in the ad group when doing
the forecast. Requires at least one keyword.
Corresponds to the JSON property biddableKeywords
41007 41008 41009 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41007 def biddable_keywords @biddable_keywords end |
#max_cpc_bid_micros ⇒ Fixnum
The max cpc to use for the ad group when generating forecasted traffic. This
value will override the max cpc value set in the bidding strategy. Only
specify this field for bidding strategies that max cpc values.
Corresponds to the JSON property maxCpcBidMicros
41014 41015 41016 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41014 def max_cpc_bid_micros @max_cpc_bid_micros end |
#negative_keywords ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo>
The details of the keyword. You should specify both the keyword text and match
type.
Corresponds to the JSON property negativeKeywords
41020 41021 41022 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41020 def negative_keywords @negative_keywords end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41027 41028 41029 41030 41031 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41027 def update!(**args) @biddable_keywords = args[:biddable_keywords] if args.key?(:biddable_keywords) @max_cpc_bid_micros = args[:max_cpc_bid_micros] if args.key?(:max_cpc_bid_micros) @negative_keywords = args[:negative_keywords] if args.key?(:negative_keywords) end |