Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecastAdGroup
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecastAdGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An ad group that is part of a campaign to be forecasted.
Instance Attribute Summary collapse
-
#biddable_keywords ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddableKeyword>
Required.
-
#max_cpc_bid_micros ⇒ Fixnum
The max cpc to use for the ad group when generating forecasted traffic.
-
#negative_keywords ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo>
The details of the keyword.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesForecastAdGroup
constructor
A new instance of GoogleAdsSearchads360V23ServicesForecastAdGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesForecastAdGroup
Returns a new instance of GoogleAdsSearchads360V23ServicesForecastAdGroup.
40286 40287 40288 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40286 def initialize(**args) update!(**args) end |
Instance Attribute Details
#biddable_keywords ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddableKeyword>
Required. The list of biddable keywords to be used in the ad group when doing
the forecast. Requires at least one keyword.
Corresponds to the JSON property biddableKeywords
40271 40272 40273 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40271 def biddable_keywords @biddable_keywords end |
#max_cpc_bid_micros ⇒ Fixnum
The max cpc to use for the ad group when generating forecasted traffic. This
value will override the max cpc value set in the bidding strategy. Only
specify this field for bidding strategies that max cpc values.
Corresponds to the JSON property maxCpcBidMicros
40278 40279 40280 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40278 def max_cpc_bid_micros @max_cpc_bid_micros end |
#negative_keywords ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordInfo>
The details of the keyword. You should specify both the keyword text and match
type.
Corresponds to the JSON property negativeKeywords
40284 40285 40286 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40284 def negative_keywords @negative_keywords end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40291 40292 40293 40294 40295 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40291 def update!(**args) @biddable_keywords = args[:biddable_keywords] if args.key?(:biddable_keywords) @max_cpc_bid_micros = args[:max_cpc_bid_micros] if args.key?(:max_cpc_bid_micros) @negative_keywords = args[:negative_keywords] if args.key?(:negative_keywords) end |