Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesFrequencyCap
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesFrequencyCap
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A rule specifying the maximum number of times an ad can be shown to a user over a particular time period.
Instance Attribute Summary collapse
-
#impressions ⇒ Fixnum
Required.
-
#time_unit ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesFrequencyCap
constructor
A new instance of GoogleAdsSearchads360V23ServicesFrequencyCap.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesFrequencyCap
Returns a new instance of GoogleAdsSearchads360V23ServicesFrequencyCap.
41069 41070 41071 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41069 def initialize(**args) update!(**args) end |
Instance Attribute Details
#impressions ⇒ Fixnum
Required. The number of impressions, inclusive.
Corresponds to the JSON property impressions
41062 41063 41064 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41062 def impressions @impressions end |
#time_unit ⇒ String
Required. The type of time unit.
Corresponds to the JSON property timeUnit
41067 41068 41069 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41067 def time_unit @time_unit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41074 41075 41076 41077 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41074 def update!(**args) @impressions = args[:impressions] if args.key?(:impressions) @time_unit = args[:time_unit] if args.key?(:time_unit) end |