Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesFrequencyCap

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A rule specifying the maximum number of times an ad can be shown to a user over a particular time period.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesFrequencyCap

Returns a new instance of GoogleAdsSearchads360V23ServicesFrequencyCap.



40997
40998
40999
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40997

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#impressionsFixnum

Required. The number of impressions, inclusive. Corresponds to the JSON property impressions

Returns:

  • (Fixnum)


40990
40991
40992
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40990

def impressions
  @impressions
end

#time_unitString

Required. The type of time unit. Corresponds to the JSON property timeUnit

Returns:

  • (String)


40995
40996
40997
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40995

def time_unit
  @time_unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41002
41003
41004
41005
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41002

def update!(**args)
  @impressions = args[:impressions] if args.key?(:impressions)
  @time_unit = args[:time_unit] if args.key?(:time_unit)
end