Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesFrequencyCap
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesFrequencyCap
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A rule specifying the maximum number of times an ad can be shown to a user over a particular time period.
Instance Attribute Summary collapse
-
#impressions ⇒ Fixnum
Required.
-
#time_unit ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesFrequencyCap
constructor
A new instance of GoogleAdsSearchads360V23ServicesFrequencyCap.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesFrequencyCap
Returns a new instance of GoogleAdsSearchads360V23ServicesFrequencyCap.
40333 40334 40335 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40333 def initialize(**args) update!(**args) end |
Instance Attribute Details
#impressions ⇒ Fixnum
Required. The number of impressions, inclusive.
Corresponds to the JSON property impressions
40326 40327 40328 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40326 def impressions @impressions end |
#time_unit ⇒ String
Required. The type of time unit.
Corresponds to the JSON property timeUnit
40331 40332 40333 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40331 def time_unit @time_unit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40338 40339 40340 40341 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40338 def update!(**args) @impressions = args[:impressions] if args.key?(:impressions) @time_unit = args[:time_unit] if args.key?(:time_unit) end |