Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGclidDateTimePair
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGclidDateTimePair
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Uniquely identifies a conversion that was reported without an order ID specified.
Instance Attribute Summary collapse
-
#conversion_date_time ⇒ String
The date time at which the original conversion for this adjustment occurred.
-
#gclid ⇒ String
Google click ID (gclid) associated with the original conversion for this adjustment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGclidDateTimePair
constructor
A new instance of GoogleAdsSearchads360V23ServicesGclidDateTimePair.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGclidDateTimePair
Returns a new instance of GoogleAdsSearchads360V23ServicesGclidDateTimePair.
41026 41027 41028 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_date_time ⇒ String
The date time at which the original conversion for this adjustment occurred.
The timezone must be specified. The format is "yyyy-mm-dd hh:mm:ss+|-hh:mm",
for example, "2019-01-01 12:32:45-08:00".
Corresponds to the JSON property conversionDateTime
41018 41019 41020 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41018 def conversion_date_time @conversion_date_time end |
#gclid ⇒ String
Google click ID (gclid) associated with the original conversion for this
adjustment.
Corresponds to the JSON property gclid
41024 41025 41026 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41024 def gclid @gclid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41031 41032 41033 41034 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41031 def update!(**args) @conversion_date_time = args[:conversion_date_time] if args.key?(:conversion_date_time) @gclid = args[:gclid] if args.key?(:gclid) end |