Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AudienceInsightsService. GenerateAudienceCompositionInsights.
Instance Attribute Summary collapse
-
#audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService.
-
#baseline_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService.
-
#customer_insights_group ⇒ String
The name of the customer being planned for.
-
#data_month ⇒ String
The one-month range of historical data to use for insights, in the format " yyyy-mm".
-
#dimensions ⇒ Array<String>
Required.
-
#insights_application_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo
Additional information about the application/tool issuing the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsRequest.
41203 41204 41205 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41203 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be
requested in AudienceInsightsService.
Corresponds to the JSON property audience
41169 41170 41171 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41169 def audience @audience end |
#baseline_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be
requested in AudienceInsightsService.
Corresponds to the JSON property baselineAudience
41175 41176 41177 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41175 def baseline_audience @baseline_audience end |
#customer_insights_group ⇒ String
The name of the customer being planned for. This is a user-defined value.
Corresponds to the JSON property customerInsightsGroup
41180 41181 41182 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41180 def customer_insights_group @customer_insights_group end |
#data_month ⇒ String
The one-month range of historical data to use for insights, in the format "
yyyy-mm". If unset, insights will be returned for the last thirty days of data.
Corresponds to the JSON property dataMonth
41186 41187 41188 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41186 def data_month @data_month end |
#dimensions ⇒ Array<String>
Required. The audience dimensions for which composition insights should be
returned. Supported dimensions are KNOWLEDGE_GRAPH, GEO_TARGET_COUNTRY,
SUB_COUNTRY_LOCATION, YOUTUBE_CHANNEL, YOUTUBE_LINEUP, AFFINITY_USER_INTEREST,
IN_MARKET_USER_INTEREST, .
Corresponds to the JSON property dimensions
41194 41195 41196 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41194 def dimensions @dimensions end |
#insights_application_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo
Additional information about the application/tool issuing the request. This
field is only used by ContentCreatorInsightsService, AudienceInsightsService,
and ReachPlanService APIs.
Corresponds to the JSON property insightsApplicationInfo
41201 41202 41203 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41201 def insights_application_info @insights_application_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41208 41209 41210 41211 41212 41213 41214 41215 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41208 def update!(**args) @audience = args[:audience] if args.key?(:audience) @baseline_audience = args[:baseline_audience] if args.key?(:baseline_audience) @customer_insights_group = args[:customer_insights_group] if args.key?(:customer_insights_group) @data_month = args[:data_month] if args.key?(:data_month) @dimensions = args[:dimensions] if args.key?(:dimensions) @insights_application_info = args[:insights_application_info] if args.key?(:insights_application_info) end |