Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AudienceInsightsService. GenerateAudienceCompositionInsights.
Instance Attribute Summary collapse
-
#audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService.
-
#baseline_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService.
-
#customer_insights_group ⇒ String
The name of the customer being planned for.
-
#data_month ⇒ String
The one-month range of historical data to use for insights, in the format " yyyy-mm".
-
#dimensions ⇒ Array<String>
Required.
-
#insights_application_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo
Additional information about the application/tool issuing the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsRequest.
41131 41132 41133 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41131 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be
requested in AudienceInsightsService.
Corresponds to the JSON property audience
41097 41098 41099 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41097 def audience @audience end |
#baseline_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be
requested in AudienceInsightsService.
Corresponds to the JSON property baselineAudience
41103 41104 41105 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41103 def baseline_audience @baseline_audience end |
#customer_insights_group ⇒ String
The name of the customer being planned for. This is a user-defined value.
Corresponds to the JSON property customerInsightsGroup
41108 41109 41110 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41108 def customer_insights_group @customer_insights_group end |
#data_month ⇒ String
The one-month range of historical data to use for insights, in the format "
yyyy-mm". If unset, insights will be returned for the last thirty days of data.
Corresponds to the JSON property dataMonth
41114 41115 41116 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41114 def data_month @data_month end |
#dimensions ⇒ Array<String>
Required. The audience dimensions for which composition insights should be
returned. Supported dimensions are KNOWLEDGE_GRAPH, GEO_TARGET_COUNTRY,
SUB_COUNTRY_LOCATION, YOUTUBE_CHANNEL, YOUTUBE_LINEUP, AFFINITY_USER_INTEREST,
IN_MARKET_USER_INTEREST, .
Corresponds to the JSON property dimensions
41122 41123 41124 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41122 def dimensions @dimensions end |
#insights_application_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo
Additional information about the application/tool issuing the request. This
field is only used by ContentCreatorInsightsService, AudienceInsightsService,
and ReachPlanService APIs.
Corresponds to the JSON property insightsApplicationInfo
41129 41130 41131 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41129 def insights_application_info @insights_application_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41136 41137 41138 41139 41140 41141 41142 41143 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41136 def update!(**args) @audience = args[:audience] if args.key?(:audience) @baseline_audience = args[:baseline_audience] if args.key?(:baseline_audience) @customer_insights_group = args[:customer_insights_group] if args.key?(:customer_insights_group) @data_month = args[:data_month] if args.key?(:data_month) @dimensions = args[:dimensions] if args.key?(:dimensions) @insights_application_info = args[:insights_application_info] if args.key?(:insights_application_info) end |