Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for AudienceInsightsService. GenerateAudienceCompositionInsights.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsResponse.



40465
40466
40467
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40465

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sectionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceCompositionSection>

The contents of the insights report, organized into sections. Each section is associated with one of the AudienceInsightsDimension values in the request. There may be more than one section per dimension. Corresponds to the JSON property sections



40463
40464
40465
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40463

def sections
  @sections
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40470
40471
40472
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40470

def update!(**args)
  @sections = args[:sections] if args.key?(:sections)
end