Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AudienceInsightsService.GenerateAudienceDefinition.
Instance Attribute Summary collapse
-
#audience_description ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceDescription
A text description of the audience of interest for which insights are being requested in AudienceInsightsService.
-
#customer_insights_group ⇒ String
Optional.
-
#insights_application_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo
Additional information about the application/tool issuing the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionRequest.
40498 40499 40500 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40498 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience_description ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceDescription
A text description of the audience of interest for which insights are being
requested in AudienceInsightsService.
Corresponds to the JSON property audienceDescription
40483 40484 40485 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40483 def audience_description @audience_description end |
#customer_insights_group ⇒ String
Optional. The name of the customer being planned for. This is a user-defined
value.
Corresponds to the JSON property customerInsightsGroup
40489 40490 40491 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40489 def customer_insights_group @customer_insights_group end |
#insights_application_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo
Additional information about the application/tool issuing the request. This
field is only used by ContentCreatorInsightsService, AudienceInsightsService,
and ReachPlanService APIs.
Corresponds to the JSON property insightsApplicationInfo
40496 40497 40498 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40496 def insights_application_info @insights_application_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40503 40504 40505 40506 40507 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40503 def update!(**args) @audience_description = args[:audience_description] if args.key?(:audience_description) @customer_insights_group = args[:customer_insights_group] if args.key?(:customer_insights_group) @insights_application_info = args[:insights_application_info] if args.key?(:insights_application_info) end |