Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for AudienceInsightsService.GenerateAudienceDefinition.
Instance Attribute Summary collapse
-
#high_relevance_attributes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata>
The attributes that make up the audience definition.
-
#medium_relevance_attributes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata>
Additional attributes that are less relevant but still related to the audience description.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionResponse.
41219 41220 41221 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41219 def initialize(**args) update!(**args) end |
Instance Attribute Details
#high_relevance_attributes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata>
The attributes that make up the audience definition.
Corresponds to the JSON property highRelevanceAttributes
41210 41211 41212 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41210 def high_relevance_attributes @high_relevance_attributes end |
#medium_relevance_attributes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata>
Additional attributes that are less relevant but still related to the audience
description. Use these attributes to broaden the audience definition to reach
more users.
Corresponds to the JSON property mediumRelevanceAttributes
41217 41218 41219 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41217 def medium_relevance_attributes @medium_relevance_attributes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41224 41225 41226 41227 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41224 def update!(**args) @high_relevance_attributes = args[:high_relevance_attributes] if args.key?(:high_relevance_attributes) @medium_relevance_attributes = args[:medium_relevance_attributes] if args.key?(:medium_relevance_attributes) end |