Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceOverlapInsightsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AudienceInsightsService.GenerateAudienceOverlapInsights.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceOverlapInsightsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceOverlapInsightsRequest.



40570
40571
40572
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_locationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo

A location criterion. Corresponds to the JSON property countryLocation



40544
40545
40546
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40544

def country_location
  @country_location
end

#customer_insights_groupString

The name of the customer being planned for. This is a user-defined value. Corresponds to the JSON property customerInsightsGroup

Returns:

  • (String)


40549
40550
40551
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40549

def customer_insights_group
  @customer_insights_group
end

#dimensionsArray<String>

Required. The types of attributes of which to calculate the overlap with the primary_attribute. The values must be a subset of AFFINITY_USER_INTEREST, IN_MARKET_USER_INTEREST, AGE_RANGE and GENDER. Corresponds to the JSON property dimensions

Returns:

  • (Array<String>)


40556
40557
40558
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40556

def dimensions
  @dimensions
end

#insights_application_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo

Additional information about the application/tool issuing the request. This field is only used by ContentCreatorInsightsService, AudienceInsightsService, and ReachPlanService APIs. Corresponds to the JSON property insightsApplicationInfo



40563
40564
40565
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40563

def insights_application_info
  @insights_application_info
end

#primary_attributeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttribute

An audience attribute that can be used to request insights about the audience. Corresponds to the JSON property primaryAttribute



40568
40569
40570
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40568

def primary_attribute
  @primary_attribute
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40575
40576
40577
40578
40579
40580
40581
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40575

def update!(**args)
  @country_location = args[:country_location] if args.key?(:country_location)
  @customer_insights_group = args[:customer_insights_group] if args.key?(:customer_insights_group)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @insights_application_info = args[:insights_application_info] if args.key?(:insights_application_info)
  @primary_attribute = args[:primary_attribute] if args.key?(:primary_attribute)
end