Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceOverlapInsightsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for AudienceInsightsService.GenerateAudienceOverlapInsights.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceOverlapInsightsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceOverlapInsightsResponse.



41293
41294
41295
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41293

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimension_resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDimensionOverlapResult>

Lists of attributes and their overlap with the primary attribute, one list per requested dimension. Corresponds to the JSON property dimensionResults



41285
41286
41287
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41285

def dimension_results
  @dimension_results
end

#primary_attribute_metadataGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata

An audience attribute, with metadata about it, returned in response to a search. Corresponds to the JSON property primaryAttributeMetadata



41291
41292
41293
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41291

def 
  @primary_attribute_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41298
41299
41300
41301
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41298

def update!(**args)
  @dimension_results = args[:dimension_results] if args.key?(:dimension_results)
  @primary_attribute_metadata = args[:primary_attribute_metadata] if args.key?(:primary_attribute_metadata)
end