Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceOverlapInsightsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateAudienceOverlapInsightsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for AudienceInsightsService.GenerateAudienceOverlapInsights.
Instance Attribute Summary collapse
-
#dimension_results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDimensionOverlapResult>
Lists of attributes and their overlap with the primary attribute, one list per requested dimension.
-
#primary_attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata
An audience attribute, with metadata about it, returned in response to a search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceOverlapInsightsResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceOverlapInsightsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateAudienceOverlapInsightsResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateAudienceOverlapInsightsResponse.
40600 40601 40602 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40600 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimension_results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesDimensionOverlapResult>
Lists of attributes and their overlap with the primary attribute, one list per
requested dimension.
Corresponds to the JSON property dimensionResults
40592 40593 40594 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40592 def dimension_results @dimension_results end |
#primary_attribute_metadata ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata
An audience attribute, with metadata about it, returned in response to a
search.
Corresponds to the JSON property primaryAttributeMetadata
40598 40599 40600 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40598 def @primary_attribute_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40605 40606 40607 40608 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40605 def update!(**args) @dimension_results = args[:dimension_results] if args.key?(:dimension_results) @primary_attribute_metadata = args[:primary_attribute_metadata] if args.key?(:primary_attribute_metadata) end |