Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateBenchmarksMetricsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for BenchmarksService.GenerateBenchmarksMetrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateBenchmarksMetricsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateBenchmarksMetricsRequest.



41347
41348
41349
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41347

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#application_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo

Additional information about the application/tool issuing the request. This field is only used by ContentCreatorInsightsService, AudienceInsightsService, and ReachPlanService APIs. Corresponds to the JSON property applicationInfo



41313
41314
41315
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41313

def application_info
  @application_info
end

#benchmarks_sourceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBenchmarksSource

The source used to generate benchmarks metrics for. The ID of the source can be obtained from BenchmarksService.ListBenchmarksSources. Corresponds to the JSON property benchmarksSource



41319
41320
41321
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41319

def benchmarks_source
  @benchmarks_source
end

#currency_codeString

Optional. The three-character ISO 4217 currency code. If unspecified, the default currency for monetary values is USD. Corresponds to the JSON property currencyCode

Returns:

  • (String)


41325
41326
41327
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41325

def currency_code
  @currency_code
end

#customer_benchmarks_groupString

The name of the customer being planned for. This is a user-defined value. Corresponds to the JSON property customerBenchmarksGroup

Returns:

  • (String)


41330
41331
41332
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41330

def customer_benchmarks_group
  @customer_benchmarks_group
end

#date_rangeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDateRange

A date range. Corresponds to the JSON property dateRange



41335
41336
41337
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41335

def date_range
  @date_range
end

#locationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo

A location criterion. Corresponds to the JSON property location



41340
41341
41342
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41340

def location
  @location
end

#product_filterGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesProductFilter

The type and list of products to aggregate benchmarks metrics over. Corresponds to the JSON property productFilter



41345
41346
41347
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41345

def product_filter
  @product_filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41352
41353
41354
41355
41356
41357
41358
41359
41360
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41352

def update!(**args)
  @application_info = args[:application_info] if args.key?(:application_info)
  @benchmarks_source = args[:benchmarks_source] if args.key?(:benchmarks_source)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @customer_benchmarks_group = args[:customer_benchmarks_group] if args.key?(:customer_benchmarks_group)
  @date_range = args[:date_range] if args.key?(:date_range)
  @location = args[:location] if args.key?(:location)
  @product_filter = args[:product_filter] if args.key?(:product_filter)
end