Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AudienceInsightsService.GenerateInsightsFinderReport.
Instance Attribute Summary collapse
-
#baseline_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService.
-
#customer_insights_group ⇒ String
The name of the customer being planned for.
-
#insights_application_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo
Additional information about the application/tool issuing the request.
-
#specific_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportRequest.
40779 40780 40781 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40779 def initialize(**args) update!(**args) end |
Instance Attribute Details
#baseline_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be
requested in AudienceInsightsService.
Corresponds to the JSON property baselineAudience
40759 40760 40761 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40759 def baseline_audience @baseline_audience end |
#customer_insights_group ⇒ String
The name of the customer being planned for. This is a user-defined value.
Corresponds to the JSON property customerInsightsGroup
40764 40765 40766 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40764 def customer_insights_group @customer_insights_group end |
#insights_application_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo
Additional information about the application/tool issuing the request. This
field is only used by ContentCreatorInsightsService, AudienceInsightsService,
and ReachPlanService APIs.
Corresponds to the JSON property insightsApplicationInfo
40771 40772 40773 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40771 def insights_application_info @insights_application_info end |
#specific_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be
requested in AudienceInsightsService.
Corresponds to the JSON property specificAudience
40777 40778 40779 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40777 def specific_audience @specific_audience end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40784 40785 40786 40787 40788 40789 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40784 def update!(**args) @baseline_audience = args[:baseline_audience] if args.key?(:baseline_audience) @customer_insights_group = args[:customer_insights_group] if args.key?(:customer_insights_group) @insights_application_info = args[:insights_application_info] if args.key?(:insights_application_info) @specific_audience = args[:specific_audience] if args.key?(:specific_audience) end |