Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The response message for AudienceInsightsService.GenerateInsightsFinderReport, containing the shareable URL for the report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportResponse.



41496
41497
41498
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#saved_report_urlString

An HTTPS URL providing a deep link into the Insights Finder UI with the report inputs filled in according to the request. Corresponds to the JSON property savedReportUrl

Returns:

  • (String)


41494
41495
41496
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41494

def saved_report_url
  @saved_report_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41501
41502
41503
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41501

def update!(**args)
  @saved_report_url = args[:saved_report_url] if args.key?(:saved_report_url)
end