Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The response message for AudienceInsightsService.GenerateInsightsFinderReport, containing the shareable URL for the report.
Instance Attribute Summary collapse
-
#saved_report_url ⇒ String
An HTTPS URL providing a deep link into the Insights Finder UI with the report inputs filled in according to the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportResponse.
40803 40804 40805 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#saved_report_url ⇒ String
An HTTPS URL providing a deep link into the Insights Finder UI with the report
inputs filled in according to the request.
Corresponds to the JSON property savedReportUrl
40801 40802 40803 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40801 def saved_report_url @saved_report_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40808 40809 40810 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40808 def update!(**args) @saved_report_url = args[:saved_report_url] if args.key?(:saved_report_url) end |