Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordForecastMetricsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for KeywordPlanIdeaService.GenerateKeywordForecastMetrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateKeywordForecastMetricsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateKeywordForecastMetricsRequest.



41529
41530
41531
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41529

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaignGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignToForecast

A campaign to do a keyword campaign forecast. Corresponds to the JSON property campaign



41513
41514
41515
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41513

def campaign
  @campaign
end

#currency_codeString

The currency used for exchange rate conversion. By default, the account currency of the customer is used. Set this field only if the currency is different from the account currency. The list of valid currency codes can be found at https://developers.google.com/google-ads/api/data/codes-formats# currency-codes. Corresponds to the JSON property currencyCode

Returns:

  • (String)


41522
41523
41524
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41522

def currency_code
  @currency_code
end

#forecast_periodGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDateRange

A date range. Corresponds to the JSON property forecastPeriod



41527
41528
41529
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41527

def forecast_period
  @forecast_period
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41534
41535
41536
41537
41538
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41534

def update!(**args)
  @campaign = args[:campaign] if args.key?(:campaign)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @forecast_period = args[:forecast_period] if args.key?(:forecast_period)
end