Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordHistoricalMetricsResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordHistoricalMetricsResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result of generating keyword historical metrics.
Instance Attribute Summary collapse
-
#close_variants ⇒ Array<String>
The list of close variants from the requested keywords whose stats are combined into this GenerateKeywordHistoricalMetricsResult.
-
#keyword_metrics ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics
Historical metrics specific to the targeting options selected.
-
#text ⇒ String
The text of the query associated with one or more keywords.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateKeywordHistoricalMetricsResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesGenerateKeywordHistoricalMetricsResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateKeywordHistoricalMetricsResult
Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateKeywordHistoricalMetricsResult.
41746 41747 41748 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41746 def initialize(**args) update!(**args) end |
Instance Attribute Details
#close_variants ⇒ Array<String>
The list of close variants from the requested keywords whose stats are
combined into this GenerateKeywordHistoricalMetricsResult.
Corresponds to the JSON property closeVariants
41728 41729 41730 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41728 def close_variants @close_variants end |
#keyword_metrics ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics
Historical metrics specific to the targeting options selected. Targeting
options include geographies, network, and so on. Refer to https://support.
google.com/google-ads/answer/3022575 for more details.
Corresponds to the JSON property keywordMetrics
41735 41736 41737 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41735 def keyword_metrics @keyword_metrics end |
#text ⇒ String
The text of the query associated with one or more keywords. Note that we de-
dupe your keywords list, eliminating close variants before returning the
keywords as text. For example, if your request originally contained the
keywords "car" and "cars", the returned search query will only contain "cars".
The list of de-duped queries will be included in close_variants field.
Corresponds to the JSON property text
41744 41745 41746 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41744 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41751 41752 41753 41754 41755 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41751 def update!(**args) @close_variants = args[:close_variants] if args.key?(:close_variants) @keyword_metrics = args[:keyword_metrics] if args.key?(:keyword_metrics) @text = args[:text] if args.key?(:text) end |