Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordHistoricalMetricsResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The result of generating keyword historical metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateKeywordHistoricalMetricsResult

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateKeywordHistoricalMetricsResult.



40981
40982
40983
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40981

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#close_variantsArray<String>

The list of close variants from the requested keywords whose stats are combined into this GenerateKeywordHistoricalMetricsResult. Corresponds to the JSON property closeVariants

Returns:

  • (Array<String>)


40963
40964
40965
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40963

def close_variants
  @close_variants
end

#keyword_metricsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics

Historical metrics specific to the targeting options selected. Targeting options include geographies, network, and so on. Refer to https://support. google.com/google-ads/answer/3022575 for more details. Corresponds to the JSON property keywordMetrics



40970
40971
40972
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40970

def keyword_metrics
  @keyword_metrics
end

#textString

The text of the query associated with one or more keywords. Note that we de- dupe your keywords list, eliminating close variants before returning the keywords as text. For example, if your request originally contained the keywords "car" and "cars", the returned search query will only contain "cars". The list of de-duped queries will be included in close_variants field. Corresponds to the JSON property text

Returns:

  • (String)


40979
40980
40981
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40979

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40986
40987
40988
40989
40990
# File 'lib/google/apis/searchads360_v23/classes.rb', line 40986

def update!(**args)
  @close_variants = args[:close_variants] if args.key?(:close_variants)
  @keyword_metrics = args[:keyword_metrics] if args.key?(:keyword_metrics)
  @text = args[:text] if args.key?(:text)
end