Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for KeywordPlanIdeaService.GenerateKeywordIdeas.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResponse.



41019
41020
41021
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregate_metric_resultsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanAggregateMetricResults

The aggregated historical metrics for keyword plan keywords. Corresponds to the JSON property aggregateMetricResults



41000
41001
41002
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41000

def aggregate_metric_results
  @aggregate_metric_results
end

#next_page_tokenString

Pagination token used to retrieve the next page of results. Pass the content of this string as the page_token attribute of the next request. next_page_token is not returned for the last page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41007
41008
41009
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41007

def next_page_token
  @next_page_token
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResult>

Results of generating keyword ideas. Corresponds to the JSON property results



41012
41013
41014
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41012

def results
  @results
end

#total_sizeFixnum

Total number of results available. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


41017
41018
41019
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41017

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41024
41025
41026
41027
41028
41029
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41024

def update!(**args)
  @aggregate_metric_results = args[:aggregate_metric_results] if args.key?(:aggregate_metric_results)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @results = args[:results] if args.key?(:results)
  @total_size = args[:total_size] if args.key?(:total_size)
end