Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result of generating keyword ideas.
Instance Attribute Summary collapse
-
#close_variants ⇒ Array<String>
The list of close variants from the requested keywords that are combined into this GenerateKeywordIdeaResult.
-
#keyword_annotations ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordAnnotations
The annotations for the keyword plan keywords.
-
#keyword_idea_metrics ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics
Historical metrics specific to the targeting options selected.
-
#text ⇒ String
Text of the keyword idea.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResult
Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResult.
41755 41756 41757 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41755 def initialize(**args) update!(**args) end |
Instance Attribute Details
#close_variants ⇒ Array<String>
The list of close variants from the requested keywords that are combined into
this GenerateKeywordIdeaResult. See https://support.google.com/google-ads/
answer/9342105 for the definition of "close variants".
Corresponds to the JSON property closeVariants
41734 41735 41736 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41734 def close_variants @close_variants end |
#keyword_annotations ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordAnnotations
The annotations for the keyword plan keywords.
Corresponds to the JSON property keywordAnnotations
41739 41740 41741 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41739 def keyword_annotations @keyword_annotations end |
#keyword_idea_metrics ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanHistoricalMetrics
Historical metrics specific to the targeting options selected. Targeting
options include geographies, network, and so on. Refer to https://support.
google.com/google-ads/answer/3022575 for more details.
Corresponds to the JSON property keywordIdeaMetrics
41746 41747 41748 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41746 def keyword_idea_metrics @keyword_idea_metrics end |
#text ⇒ String
Text of the keyword idea. As in Keyword Plan historical metrics, this text may
not be an actual keyword, but the canonical form of multiple keywords. See
KeywordPlanKeywordHistoricalMetrics message in KeywordPlanService.
Corresponds to the JSON property text
41753 41754 41755 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41753 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41760 41761 41762 41763 41764 41765 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41760 def update!(**args) @close_variants = args[:close_variants] if args.key?(:close_variants) @keyword_annotations = args[:keyword_annotations] if args.key?(:keyword_annotations) @keyword_idea_metrics = args[:keyword_idea_metrics] if args.key?(:keyword_idea_metrics) @text = args[:text] if args.key?(:text) end |