Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordIdeasRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordIdeasRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for KeywordPlanIdeaService.GenerateKeywordIdeas.
Instance Attribute Summary collapse
-
#aggregate_metrics ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanAggregateMetrics
The aggregate metrics specification of the request.
-
#geo_target_constants ⇒ Array<String>
The resource names of the location to target.
-
#historical_metrics_options ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHistoricalMetricsOptions
Historical metrics options.
-
#include_adult_keywords ⇒ Boolean
(also: #include_adult_keywords?)
If true, adult keywords will be included in response.
-
#keyword_and_url_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordAndUrlSeed
Keyword And Url Seed Corresponds to the JSON property
keywordAndUrlSeed. -
#keyword_annotation ⇒ Array<String>
The keyword annotations to include in response.
-
#keyword_plan_network ⇒ String
Targeting network.
-
#keyword_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordSeed
Keyword Seed Corresponds to the JSON property
keywordSeed. -
#language ⇒ String
The resource name of the language to target.
-
#page_size ⇒ Fixnum
Number of results to retrieve in a single page.
-
#page_token ⇒ String
Token of the page to retrieve.
-
#site_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSiteSeed
Site Seed Corresponds to the JSON property
siteSeed. -
#url_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUrlSeed
Url Seed Corresponds to the JSON property
urlSeed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateKeywordIdeasRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesGenerateKeywordIdeasRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateKeywordIdeasRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateKeywordIdeasRequest.
41921 41922 41923 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregate_metrics ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanAggregateMetrics
The aggregate metrics specification of the request.
Corresponds to the JSON property aggregateMetrics
41847 41848 41849 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41847 def aggregate_metrics @aggregate_metrics end |
#geo_target_constants ⇒ Array<String>
The resource names of the location to target. Maximum is 10. An empty list MAY
be used to specify all targeting geos.
Corresponds to the JSON property geoTargetConstants
41853 41854 41855 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41853 def geo_target_constants @geo_target_constants end |
#historical_metrics_options ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHistoricalMetricsOptions
Historical metrics options.
Corresponds to the JSON property historicalMetricsOptions
41858 41859 41860 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41858 def @historical_metrics_options end |
#include_adult_keywords ⇒ Boolean Also known as: include_adult_keywords?
If true, adult keywords will be included in response. The default value is
false.
Corresponds to the JSON property includeAdultKeywords
41864 41865 41866 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41864 def include_adult_keywords @include_adult_keywords end |
#keyword_and_url_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordAndUrlSeed
Keyword And Url Seed
Corresponds to the JSON property keywordAndUrlSeed
41870 41871 41872 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41870 def keyword_and_url_seed @keyword_and_url_seed end |
#keyword_annotation ⇒ Array<String>
The keyword annotations to include in response.
Corresponds to the JSON property keywordAnnotation
41875 41876 41877 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41875 def keyword_annotation @keyword_annotation end |
#keyword_plan_network ⇒ String
Targeting network. If not set, Google Search And Partners Network will be used.
Corresponds to the JSON property keywordPlanNetwork
41880 41881 41882 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41880 def keyword_plan_network @keyword_plan_network end |
#keyword_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordSeed
Keyword Seed
Corresponds to the JSON property keywordSeed
41885 41886 41887 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41885 def keyword_seed @keyword_seed end |
#language ⇒ String
The resource name of the language to target. Each keyword belongs to some set
of languages; a keyword is included if language is one of its languages. If
not set, all keywords will be included.
Corresponds to the JSON property language
41892 41893 41894 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41892 def language @language end |
#page_size ⇒ Fixnum
Number of results to retrieve in a single page. A maximum of 10,000 results
may be returned, if the page_size exceeds this, it is ignored. If unspecified,
at most 10,000 results will be returned. The server may decide to further
limit the number of returned resources. If the response contains fewer than 10,
000 results it may not be assumed as last page of results.
Corresponds to the JSON property pageSize
41901 41902 41903 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41901 def page_size @page_size end |
#page_token ⇒ String
Token of the page to retrieve. If not specified, the first page of results
will be returned. To request next page of results use the value obtained from
next_page_token in the previous response. The request fields must match
across pages.
Corresponds to the JSON property pageToken
41909 41910 41911 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41909 def page_token @page_token end |
#site_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSiteSeed
Site Seed
Corresponds to the JSON property siteSeed
41914 41915 41916 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41914 def site_seed @site_seed end |
#url_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUrlSeed
Url Seed
Corresponds to the JSON property urlSeed
41919 41920 41921 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41919 def url_seed @url_seed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41926 41927 41928 41929 41930 41931 41932 41933 41934 41935 41936 41937 41938 41939 41940 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41926 def update!(**args) @aggregate_metrics = args[:aggregate_metrics] if args.key?(:aggregate_metrics) @geo_target_constants = args[:geo_target_constants] if args.key?(:geo_target_constants) @historical_metrics_options = args[:historical_metrics_options] if args.key?(:historical_metrics_options) @include_adult_keywords = args[:include_adult_keywords] if args.key?(:include_adult_keywords) @keyword_and_url_seed = args[:keyword_and_url_seed] if args.key?(:keyword_and_url_seed) @keyword_annotation = args[:keyword_annotation] if args.key?(:keyword_annotation) @keyword_plan_network = args[:keyword_plan_network] if args.key?(:keyword_plan_network) @keyword_seed = args[:keyword_seed] if args.key?(:keyword_seed) @language = args[:language] if args.key?(:language) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @site_seed = args[:site_seed] if args.key?(:site_seed) @url_seed = args[:url_seed] if args.key?(:url_seed) end |