Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordIdeasRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateKeywordIdeasRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for KeywordPlanIdeaService.GenerateKeywordIdeas.
Instance Attribute Summary collapse
-
#aggregate_metrics ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanAggregateMetrics
The aggregate metrics specification of the request.
-
#geo_target_constants ⇒ Array<String>
The resource names of the location to target.
-
#historical_metrics_options ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHistoricalMetricsOptions
Historical metrics options.
-
#include_adult_keywords ⇒ Boolean
(also: #include_adult_keywords?)
If true, adult keywords will be included in response.
-
#keyword_and_url_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordAndUrlSeed
Keyword And Url Seed Corresponds to the JSON property
keywordAndUrlSeed. -
#keyword_annotation ⇒ Array<String>
The keyword annotations to include in response.
-
#keyword_plan_network ⇒ String
Targeting network.
-
#keyword_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordSeed
Keyword Seed Corresponds to the JSON property
keywordSeed. -
#language ⇒ String
The resource name of the language to target.
-
#page_size ⇒ Fixnum
Number of results to retrieve in a single page.
-
#page_token ⇒ String
Token of the page to retrieve.
-
#site_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSiteSeed
Site Seed Corresponds to the JSON property
siteSeed. -
#url_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUrlSeed
Url Seed Corresponds to the JSON property
urlSeed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateKeywordIdeasRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesGenerateKeywordIdeasRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateKeywordIdeasRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateKeywordIdeasRequest.
41156 41157 41158 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41156 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregate_metrics ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordPlanAggregateMetrics
The aggregate metrics specification of the request.
Corresponds to the JSON property aggregateMetrics
41082 41083 41084 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41082 def aggregate_metrics @aggregate_metrics end |
#geo_target_constants ⇒ Array<String>
The resource names of the location to target. Maximum is 10. An empty list MAY
be used to specify all targeting geos.
Corresponds to the JSON property geoTargetConstants
41088 41089 41090 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41088 def geo_target_constants @geo_target_constants end |
#historical_metrics_options ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonHistoricalMetricsOptions
Historical metrics options.
Corresponds to the JSON property historicalMetricsOptions
41093 41094 41095 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41093 def @historical_metrics_options end |
#include_adult_keywords ⇒ Boolean Also known as: include_adult_keywords?
If true, adult keywords will be included in response. The default value is
false.
Corresponds to the JSON property includeAdultKeywords
41099 41100 41101 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41099 def include_adult_keywords @include_adult_keywords end |
#keyword_and_url_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordAndUrlSeed
Keyword And Url Seed
Corresponds to the JSON property keywordAndUrlSeed
41105 41106 41107 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41105 def keyword_and_url_seed @keyword_and_url_seed end |
#keyword_annotation ⇒ Array<String>
The keyword annotations to include in response.
Corresponds to the JSON property keywordAnnotation
41110 41111 41112 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41110 def keyword_annotation @keyword_annotation end |
#keyword_plan_network ⇒ String
Targeting network. If not set, Google Search And Partners Network will be used.
Corresponds to the JSON property keywordPlanNetwork
41115 41116 41117 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41115 def keyword_plan_network @keyword_plan_network end |
#keyword_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordSeed
Keyword Seed
Corresponds to the JSON property keywordSeed
41120 41121 41122 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41120 def keyword_seed @keyword_seed end |
#language ⇒ String
The resource name of the language to target. Each keyword belongs to some set
of languages; a keyword is included if language is one of its languages. If
not set, all keywords will be included.
Corresponds to the JSON property language
41127 41128 41129 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41127 def language @language end |
#page_size ⇒ Fixnum
Number of results to retrieve in a single page. A maximum of 10,000 results
may be returned, if the page_size exceeds this, it is ignored. If unspecified,
at most 10,000 results will be returned. The server may decide to further
limit the number of returned resources. If the response contains fewer than 10,
000 results it may not be assumed as last page of results.
Corresponds to the JSON property pageSize
41136 41137 41138 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41136 def page_size @page_size end |
#page_token ⇒ String
Token of the page to retrieve. If not specified, the first page of results
will be returned. To request next page of results use the value obtained from
next_page_token in the previous response. The request fields must match
across pages.
Corresponds to the JSON property pageToken
41144 41145 41146 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41144 def page_token @page_token end |
#site_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSiteSeed
Site Seed
Corresponds to the JSON property siteSeed
41149 41150 41151 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41149 def site_seed @site_seed end |
#url_seed ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUrlSeed
Url Seed
Corresponds to the JSON property urlSeed
41154 41155 41156 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41154 def url_seed @url_seed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41161 41162 41163 41164 41165 41166 41167 41168 41169 41170 41171 41172 41173 41174 41175 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41161 def update!(**args) @aggregate_metrics = args[:aggregate_metrics] if args.key?(:aggregate_metrics) @geo_target_constants = args[:geo_target_constants] if args.key?(:geo_target_constants) @historical_metrics_options = args[:historical_metrics_options] if args.key?(:historical_metrics_options) @include_adult_keywords = args[:include_adult_keywords] if args.key?(:include_adult_keywords) @keyword_and_url_seed = args[:keyword_and_url_seed] if args.key?(:keyword_and_url_seed) @keyword_annotation = args[:keyword_annotation] if args.key?(:keyword_annotation) @keyword_plan_network = args[:keyword_plan_network] if args.key?(:keyword_plan_network) @keyword_seed = args[:keyword_seed] if args.key?(:keyword_seed) @language = args[:language] if args.key?(:language) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @site_seed = args[:site_seed] if args.key?(:site_seed) @url_seed = args[:url_seed] if args.key?(:url_seed) end |