Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateReachForecastRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateReachForecastRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for ReachPlanService.GenerateReachForecast.
Instance Attribute Summary collapse
-
#campaign_duration ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignDuration
The duration of a planned campaign.
-
#cookie_frequency_cap ⇒ Fixnum
Chosen cookie frequency cap to be applied to each planned product.
-
#cookie_frequency_cap_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesFrequencyCap
A rule specifying the maximum number of times an ad can be shown to a user over a particular time period.
-
#currency_code ⇒ String
The currency code.
-
#customer_reach_group ⇒ String
The name of the customer being planned for.
-
#effective_frequency_limit ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesEffectiveFrequencyLimit
Effective frequency limit.
-
#forecast_metric_options ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecastMetricOptions
Controls forecast metrics to return.
-
#min_effective_frequency ⇒ Fixnum
Chosen minimum effective frequency (the number of times a person was exposed to the ad) for the reported reach metrics [1-10].
-
#planned_products ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProduct>
Required.
-
#reach_application_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo
Additional information about the application/tool issuing the request.
-
#targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesTargeting
The targeting for which traffic metrics will be reported.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateReachForecastRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesGenerateReachForecastRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateReachForecastRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateReachForecastRequest.
42013 42014 42015 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42013 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign_duration ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignDuration
The duration of a planned campaign.
Corresponds to the JSON property campaignDuration
41950 41951 41952 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41950 def campaign_duration @campaign_duration end |
#cookie_frequency_cap ⇒ Fixnum
Chosen cookie frequency cap to be applied to each planned product. This is
equivalent to the frequency cap exposed in Google Ads when creating a campaign,
it represents the maximum number of times an ad can be shown to the same user.
If not specified, no cap is applied. This field is deprecated in v4 and will
eventually be removed. Use cookie_frequency_cap_setting instead.
Corresponds to the JSON property cookieFrequencyCap
41959 41960 41961 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41959 def @cookie_frequency_cap end |
#cookie_frequency_cap_setting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesFrequencyCap
A rule specifying the maximum number of times an ad can be shown to a user
over a particular time period.
Corresponds to the JSON property cookieFrequencyCapSetting
41965 41966 41967 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41965 def @cookie_frequency_cap_setting end |
#currency_code ⇒ String
The currency code. Three-character ISO 4217 currency code.
Corresponds to the JSON property currencyCode
41970 41971 41972 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41970 def currency_code @currency_code end |
#customer_reach_group ⇒ String
The name of the customer being planned for. This is a user-defined value.
Corresponds to the JSON property customerReachGroup
41975 41976 41977 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41975 def customer_reach_group @customer_reach_group end |
#effective_frequency_limit ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesEffectiveFrequencyLimit
Effective frequency limit.
Corresponds to the JSON property effectiveFrequencyLimit
41980 41981 41982 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41980 def effective_frequency_limit @effective_frequency_limit end |
#forecast_metric_options ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecastMetricOptions
Controls forecast metrics to return.
Corresponds to the JSON property forecastMetricOptions
41985 41986 41987 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41985 def @forecast_metric_options end |
#min_effective_frequency ⇒ Fixnum
Chosen minimum effective frequency (the number of times a person was exposed
to the ad) for the reported reach metrics [1-10]. This won't affect the
targeting, but just the reporting. If not specified, a default of 1 is applied.
This field cannot be combined with the effective_frequency_limit field.
Corresponds to the JSON property minEffectiveFrequency
41993 41994 41995 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41993 def min_effective_frequency @min_effective_frequency end |
#planned_products ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProduct>
Required. The products to be forecast. The max number of allowed planned
products is 15.
Corresponds to the JSON property plannedProducts
41999 42000 42001 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41999 def planned_products @planned_products end |
#reach_application_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo
Additional information about the application/tool issuing the request. This
field is only used by ContentCreatorInsightsService, AudienceInsightsService,
and ReachPlanService APIs.
Corresponds to the JSON property reachApplicationInfo
42006 42007 42008 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42006 def reach_application_info @reach_application_info end |
#targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesTargeting
The targeting for which traffic metrics will be reported.
Corresponds to the JSON property targeting
42011 42012 42013 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42011 def targeting @targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42018 42019 42020 42021 42022 42023 42024 42025 42026 42027 42028 42029 42030 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42018 def update!(**args) @campaign_duration = args[:campaign_duration] if args.key?(:campaign_duration) @cookie_frequency_cap = args[:cookie_frequency_cap] if args.key?(:cookie_frequency_cap) @cookie_frequency_cap_setting = args[:cookie_frequency_cap_setting] if args.key?(:cookie_frequency_cap_setting) @currency_code = args[:currency_code] if args.key?(:currency_code) @customer_reach_group = args[:customer_reach_group] if args.key?(:customer_reach_group) @effective_frequency_limit = args[:effective_frequency_limit] if args.key?(:effective_frequency_limit) @forecast_metric_options = args[:forecast_metric_options] if args.key?(:forecast_metric_options) @min_effective_frequency = args[:min_effective_frequency] if args.key?(:min_effective_frequency) @planned_products = args[:planned_products] if args.key?(:planned_products) @reach_application_info = args[:reach_application_info] if args.key?(:reach_application_info) @targeting = args[:targeting] if args.key?(:targeting) end |