Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateReachForecastRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ReachPlanService.GenerateReachForecast.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateReachForecastRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateReachForecastRequest.



41941
41942
41943
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41941

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaign_durationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignDuration

The duration of a planned campaign. Corresponds to the JSON property campaignDuration



41878
41879
41880
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41878

def campaign_duration
  @campaign_duration
end

Chosen cookie frequency cap to be applied to each planned product. This is equivalent to the frequency cap exposed in Google Ads when creating a campaign, it represents the maximum number of times an ad can be shown to the same user. If not specified, no cap is applied. This field is deprecated in v4 and will eventually be removed. Use cookie_frequency_cap_setting instead. Corresponds to the JSON property cookieFrequencyCap

Returns:

  • (Fixnum)


41887
41888
41889
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41887

def cookie_frequency_cap
  @cookie_frequency_cap
end

A rule specifying the maximum number of times an ad can be shown to a user over a particular time period. Corresponds to the JSON property cookieFrequencyCapSetting



41893
41894
41895
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41893

def cookie_frequency_cap_setting
  @cookie_frequency_cap_setting
end

#currency_codeString

The currency code. Three-character ISO 4217 currency code. Corresponds to the JSON property currencyCode

Returns:

  • (String)


41898
41899
41900
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41898

def currency_code
  @currency_code
end

#customer_reach_groupString

The name of the customer being planned for. This is a user-defined value. Corresponds to the JSON property customerReachGroup

Returns:

  • (String)


41903
41904
41905
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41903

def customer_reach_group
  @customer_reach_group
end

#effective_frequency_limitGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesEffectiveFrequencyLimit

Effective frequency limit. Corresponds to the JSON property effectiveFrequencyLimit



41908
41909
41910
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41908

def effective_frequency_limit
  @effective_frequency_limit
end

#forecast_metric_optionsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecastMetricOptions

Controls forecast metrics to return. Corresponds to the JSON property forecastMetricOptions



41913
41914
41915
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41913

def forecast_metric_options
  @forecast_metric_options
end

#min_effective_frequencyFixnum

Chosen minimum effective frequency (the number of times a person was exposed to the ad) for the reported reach metrics [1-10]. This won't affect the targeting, but just the reporting. If not specified, a default of 1 is applied. This field cannot be combined with the effective_frequency_limit field. Corresponds to the JSON property minEffectiveFrequency

Returns:

  • (Fixnum)


41921
41922
41923
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41921

def min_effective_frequency
  @min_effective_frequency
end

#planned_productsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProduct>

Required. The products to be forecast. The max number of allowed planned products is 15. Corresponds to the JSON property plannedProducts



41927
41928
41929
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41927

def planned_products
  @planned_products
end

#reach_application_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo

Additional information about the application/tool issuing the request. This field is only used by ContentCreatorInsightsService, AudienceInsightsService, and ReachPlanService APIs. Corresponds to the JSON property reachApplicationInfo



41934
41935
41936
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41934

def reach_application_info
  @reach_application_info
end

#targetingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesTargeting

The targeting for which traffic metrics will be reported. Corresponds to the JSON property targeting



41939
41940
41941
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41939

def targeting
  @targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41946
41947
41948
41949
41950
41951
41952
41953
41954
41955
41956
41957
41958
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41946

def update!(**args)
  @campaign_duration = args[:campaign_duration] if args.key?(:campaign_duration)
  @cookie_frequency_cap = args[:cookie_frequency_cap] if args.key?(:cookie_frequency_cap)
  @cookie_frequency_cap_setting = args[:cookie_frequency_cap_setting] if args.key?(:cookie_frequency_cap_setting)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @customer_reach_group = args[:customer_reach_group] if args.key?(:customer_reach_group)
  @effective_frequency_limit = args[:effective_frequency_limit] if args.key?(:effective_frequency_limit)
  @forecast_metric_options = args[:forecast_metric_options] if args.key?(:forecast_metric_options)
  @min_effective_frequency = args[:min_effective_frequency] if args.key?(:min_effective_frequency)
  @planned_products = args[:planned_products] if args.key?(:planned_products)
  @reach_application_info = args[:reach_application_info] if args.key?(:reach_application_info)
  @targeting = args[:targeting] if args.key?(:targeting)
end