Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for RecommendationService.GenerateRecommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequest.



41439
41440
41441
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41439

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_infoArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestAdGroupInfo>

Optional. Current AdGroup Information. Supports information from a single AdGroup. This field is optional for the following recommendation_types: KEYWORD Corresponds to the JSON property adGroupInfo



41304
41305
41306
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41304

def ad_group_info
  @ad_group_info
end

#advertising_channel_typeString

Required. Advertising channel type of the campaign. The following advertising_channel_types are supported for recommendation generation: PERFORMANCE_MAX and SEARCH Corresponds to the JSON property advertisingChannelType

Returns:

  • (String)


41311
41312
41313
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41311

def advertising_channel_type
  @advertising_channel_type
end

#asset_group_infoArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestAssetGroupInfo>

Optional. Current AssetGroup Information. This field is required for the following recommendation_types: CAMPAIGN_BUDGET Corresponds to the JSON property assetGroupInfo



41317
41318
41319
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41317

def asset_group_info
  @asset_group_info
end

#bidding_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestBiddingInfo

Current bidding information of the campaign. Provides a wrapper for bidding- related signals that inform recommendations. Corresponds to the JSON property biddingInfo



41323
41324
41325
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41323

def bidding_info
  @bidding_info
end

#budget_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestBudgetInfo

Current budget information of the campaign. Corresponds to the JSON property budgetInfo



41328
41329
41330
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41328

def budget_info
  @budget_info
end

#campaign_call_asset_countFixnum

Optional. Current campaign call asset count. This field is optional for the following recommendation_types: CAMPAIGN_BUDGET Corresponds to the JSON property campaignCallAssetCount

Returns:

  • (Fixnum)


41334
41335
41336
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41334

def campaign_call_asset_count
  @campaign_call_asset_count
end

#campaign_image_asset_countFixnum

Optional. Current campaign image asset count. This field is optional for the following recommendation_types: CAMPAIGN_BUDGET Corresponds to the JSON property campaignImageAssetCount

Returns:

  • (Fixnum)


41340
41341
41342
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41340

def campaign_image_asset_count
  @campaign_image_asset_count
end

Optional. Number of sitelinks on the campaign. This field is necessary for the following recommendation_types: SITELINK_ASSET Corresponds to the JSON property campaignSitelinkCount

Returns:

  • (Fixnum)


41346
41347
41348
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41346

def campaign_sitelink_count
  @campaign_sitelink_count
end

#conversion_tracking_statusString

Optional. Current conversion tracking status. This field is necessary for the following recommendation_types: MAXIMIZE_CLICKS_OPT_IN, MAXIMIZE_CONVERSIONS_OPT_IN, MAXIMIZE_CONVERSION_VALUE_OPT_IN, SET_TARGET_CPA, SET_TARGET_ROAS, TARGET_CPA_OPT_IN, TARGET_ROAS_OPT_IN Corresponds to the JSON property conversionTrackingStatus

Returns:

  • (String)


41354
41355
41356
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41354

def conversion_tracking_status
  @conversion_tracking_status
end

#country_codesArray<String>

Optional. Current campaign country codes. This field is required for the following recommendation_types: CAMPAIGN_BUDGET if AdvertisingChannelType is SEARCH Corresponds to the JSON property countryCodes

Returns:

  • (Array<String>)


41361
41362
41363
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41361

def country_codes
  @country_codes
end

#is_new_customerBoolean Also known as: is_new_customer?

Optional. Whether or not this customer should be treated as a "new" customer ( that is, a customer who has not yet created a campaign). Setting this to true will cause the backend to generate recommendations using a dedicated recommendation model for onboarding new customers, as opposed to the default model for existing customers. This is only recommended for customers with 0 campaigns. This field is optional for the following recommendation_types: CAMPAIGN_BUDGET Corresponds to the JSON property isNewCustomer

Returns:

  • (Boolean)


41372
41373
41374
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41372

def is_new_customer
  @is_new_customer
end

#language_codesArray<String>

Optional. Current campaign language codes. This field is required for the following recommendation_types: CAMPAIGN_BUDGET if AdvertisingChannelType is SEARCH Corresponds to the JSON property languageCodes

Returns:

  • (Array<String>)


41380
41381
41382
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41380

def language_codes
  @language_codes
end

#merchant_center_account_idFixnum

Optional. Merchant Center account ID. This field should only be set when advertising_channel_type is PERFORMANCE_MAX. Setting this field causes RecommendationService to generate recommendations for Performance Max for retail instead of standard Performance Max. This field is optional for the following recommendation_types: CAMPAIGN_BUDGET Corresponds to the JSON property merchantCenterAccountId

Returns:

  • (Fixnum)


41389
41390
41391
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41389

def 
  @merchant_center_account_id
end

#negative_locations_idsArray<Fixnum>

Optional. Current campaign negative location ids. One of this field OR positive_location_ids is required for the following recommendation_types: CAMPAIGN_BUDGET if AdvertisingChannelType is SEARCH Corresponds to the JSON property negativeLocationsIds

Returns:

  • (Array<Fixnum>)


41396
41397
41398
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41396

def negative_locations_ids
  @negative_locations_ids
end

#positive_locations_idsArray<Fixnum>

Optional. Current campaign positive location ids. One of this field OR negative_location_ids is required for the following recommendation_types: CAMPAIGN_BUDGET if AdvertisingChannelType is SEARCH Corresponds to the JSON property positiveLocationsIds

Returns:

  • (Array<Fixnum>)


41403
41404
41405
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41403

def positive_locations_ids
  @positive_locations_ids
end

#recommendation_typesArray<String>

Required. List of eligible recommendation_types to generate. If the uploaded criteria isn't sufficient to make a recommendation, or the campaign is already in the recommended state, no recommendation will be returned for that type. Generally, a recommendation is returned if all required fields for that recommendation_type are uploaded, but there are cases where this is still not sufficient. The following recommendation_types are supported for recommendation generation: KEYWORD, MAXIMIZE_CLICKS_OPT_IN, MAXIMIZE_CONVERSIONS_OPT_IN, MAXIMIZE_CONVERSION_VALUE_OPT_IN, SET_TARGET_CPA, SET_TARGET_ROAS, SITELINK_ASSET, TARGET_CPA_OPT_IN, TARGET_ROAS_OPT_IN Corresponds to the JSON property recommendationTypes

Returns:

  • (Array<String>)


41416
41417
41418
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41416

def recommendation_types
  @recommendation_types
end

#seed_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsRequestSeedInfo

A keyword seed and a specific url to generate keywords from. Corresponds to the JSON property seedInfo



41421
41422
41423
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41421

def seed_info
  @seed_info
end

#target_content_networkBoolean Also known as: target_content_network?

Optional. If true, the campaign is opted into serving ads on specified placements in the Google Display Network. This field is optional for the following recommendation_types: CAMPAIGN_BUDGET Corresponds to the JSON property targetContentNetwork

Returns:

  • (Boolean)


41428
41429
41430
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41428

def target_content_network
  @target_content_network
end

#target_partner_search_networkBoolean Also known as: target_partner_search_network?

Optional. If true, the campaign is opted into serving ads on the Google Partner Network. This field is optional for the following recommendation_types: CAMPAIGN_BUDGET Corresponds to the JSON property targetPartnerSearchNetwork

Returns:

  • (Boolean)


41436
41437
41438
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41436

def target_partner_search_network
  @target_partner_search_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41444
41445
41446
41447
41448
41449
41450
41451
41452
41453
41454
41455
41456
41457
41458
41459
41460
41461
41462
41463
41464
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41444

def update!(**args)
  @ad_group_info = args[:ad_group_info] if args.key?(:ad_group_info)
  @advertising_channel_type = args[:advertising_channel_type] if args.key?(:advertising_channel_type)
  @asset_group_info = args[:asset_group_info] if args.key?(:asset_group_info)
  @bidding_info = args[:bidding_info] if args.key?(:bidding_info)
  @budget_info = args[:budget_info] if args.key?(:budget_info)
  @campaign_call_asset_count = args[:campaign_call_asset_count] if args.key?(:campaign_call_asset_count)
  @campaign_image_asset_count = args[:campaign_image_asset_count] if args.key?(:campaign_image_asset_count)
  @campaign_sitelink_count = args[:campaign_sitelink_count] if args.key?(:campaign_sitelink_count)
  @conversion_tracking_status = args[:conversion_tracking_status] if args.key?(:conversion_tracking_status)
  @country_codes = args[:country_codes] if args.key?(:country_codes)
  @is_new_customer = args[:is_new_customer] if args.key?(:is_new_customer)
  @language_codes = args[:language_codes] if args.key?(:language_codes)
  @merchant_center_account_id = args[:merchant_center_account_id] if args.key?(:merchant_center_account_id)
  @negative_locations_ids = args[:negative_locations_ids] if args.key?(:negative_locations_ids)
  @positive_locations_ids = args[:positive_locations_ids] if args.key?(:positive_locations_ids)
  @recommendation_types = args[:recommendation_types] if args.key?(:recommendation_types)
  @seed_info = args[:seed_info] if args.key?(:seed_info)
  @target_content_network = args[:target_content_network] if args.key?(:target_content_network)
  @target_partner_search_network = args[:target_partner_search_network] if args.key?(:target_partner_search_network)
end