Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGenerateRecommendationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for RecommendationService.GenerateRecommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGenerateRecommendationsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesGenerateRecommendationsResponse.



41479
41480
41481
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41479

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#recommendationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRecommendation>

List of generated recommendations from the passed in set of requested recommendation_types. If there isn't sufficient data to generate a recommendation for the requested recommendation_types, the result set won't contain a recommendation for that type. Corresponds to the JSON property recommendations



41477
41478
41479
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41477

def recommendations
  @recommendations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41484
41485
41486
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41484

def update!(**args)
  @recommendations = args[:recommendations] if args.key?(:recommendations)
end