Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGeoTargetConstantSuggestion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGeoTargetConstantSuggestion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A geo target constant suggestion.
Instance Attribute Summary collapse
-
#geo_target_constant ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGeoTargetConstant
A geo target constant.
-
#geo_target_constant_parents ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGeoTargetConstant>
The list of parents of the geo target constant.
-
#locale ⇒ String
The language this GeoTargetConstantSuggestion is currently translated to.
-
#reach ⇒ Fixnum
Approximate user population that will be targeted, rounded to the nearest 100.
-
#search_term ⇒ String
If the request searched by location name, this is the location name that matched the geo target.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGeoTargetConstantSuggestion
constructor
A new instance of GoogleAdsSearchads360V23ServicesGeoTargetConstantSuggestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGeoTargetConstantSuggestion
Returns a new instance of GoogleAdsSearchads360V23ServicesGeoTargetConstantSuggestion.
42333 42334 42335 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42333 def initialize(**args) update!(**args) end |
Instance Attribute Details
#geo_target_constant ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGeoTargetConstant
A geo target constant.
Corresponds to the JSON property geoTargetConstant
42307 42308 42309 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42307 def geo_target_constant @geo_target_constant end |
#geo_target_constant_parents ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGeoTargetConstant>
The list of parents of the geo target constant.
Corresponds to the JSON property geoTargetConstantParents
42312 42313 42314 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42312 def geo_target_constant_parents @geo_target_constant_parents end |
#locale ⇒ String
The language this GeoTargetConstantSuggestion is currently translated to. It
affects the name of geo target fields. For example, if locale=en, then name=
Spain. If locale=es, then name=EspaƱa. The default locale will be returned if
no translation exists for the locale in the request.
Corresponds to the JSON property locale
42320 42321 42322 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42320 def locale @locale end |
#reach ⇒ Fixnum
Approximate user population that will be targeted, rounded to the nearest 100.
Corresponds to the JSON property reach
42325 42326 42327 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42325 def reach @reach end |
#search_term ⇒ String
If the request searched by location name, this is the location name that
matched the geo target.
Corresponds to the JSON property searchTerm
42331 42332 42333 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42331 def search_term @search_term end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42338 42339 42340 42341 42342 42343 42344 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42338 def update!(**args) @geo_target_constant = args[:geo_target_constant] if args.key?(:geo_target_constant) @geo_target_constant_parents = args[:geo_target_constant_parents] if args.key?(:geo_target_constant_parents) @locale = args[:locale] if args.key?(:locale) @reach = args[:reach] if args.key?(:reach) @search_term = args[:search_term] if args.key?(:search_term) end |