Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGeoTargetConstantSuggestion
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGeoTargetConstantSuggestion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A geo target constant suggestion.
Instance Attribute Summary collapse
-
#geo_target_constant ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGeoTargetConstant
A geo target constant.
-
#geo_target_constant_parents ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGeoTargetConstant>
The list of parents of the geo target constant.
-
#locale ⇒ String
The language this GeoTargetConstantSuggestion is currently translated to.
-
#reach ⇒ Fixnum
Approximate user population that will be targeted, rounded to the nearest 100.
-
#search_term ⇒ String
If the request searched by location name, this is the location name that matched the geo target.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGeoTargetConstantSuggestion
constructor
A new instance of GoogleAdsSearchads360V23ServicesGeoTargetConstantSuggestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGeoTargetConstantSuggestion
Returns a new instance of GoogleAdsSearchads360V23ServicesGeoTargetConstantSuggestion.
41640 41641 41642 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41640 def initialize(**args) update!(**args) end |
Instance Attribute Details
#geo_target_constant ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGeoTargetConstant
A geo target constant.
Corresponds to the JSON property geoTargetConstant
41614 41615 41616 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41614 def geo_target_constant @geo_target_constant end |
#geo_target_constant_parents ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGeoTargetConstant>
The list of parents of the geo target constant.
Corresponds to the JSON property geoTargetConstantParents
41619 41620 41621 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41619 def geo_target_constant_parents @geo_target_constant_parents end |
#locale ⇒ String
The language this GeoTargetConstantSuggestion is currently translated to. It
affects the name of geo target fields. For example, if locale=en, then name=
Spain. If locale=es, then name=EspaƱa. The default locale will be returned if
no translation exists for the locale in the request.
Corresponds to the JSON property locale
41627 41628 41629 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41627 def locale @locale end |
#reach ⇒ Fixnum
Approximate user population that will be targeted, rounded to the nearest 100.
Corresponds to the JSON property reach
41632 41633 41634 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41632 def reach @reach end |
#search_term ⇒ String
If the request searched by location name, this is the location name that
matched the geo target.
Corresponds to the JSON property searchTerm
41638 41639 41640 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41638 def search_term @search_term end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41645 41646 41647 41648 41649 41650 41651 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41645 def update!(**args) @geo_target_constant = args[:geo_target_constant] if args.key?(:geo_target_constant) @geo_target_constant_parents = args[:geo_target_constant_parents] if args.key?(:geo_target_constant_parents) @locale = args[:locale] if args.key?(:locale) @reach = args[:reach] if args.key?(:reach) @search_term = args[:search_term] if args.key?(:search_term) end |