Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGetSmartCampaignStatusResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGetSmartCampaignStatusResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for SmartCampaignSettingService.GetSmartCampaignStatus.
Instance Attribute Summary collapse
-
#eligible_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails
Details related to Smart campaigns that are eligible to serve.
-
#ended_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignEndedDetails
Details related to Smart campaigns that have ended.
-
#not_eligible_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails
Details related to Smart campaigns that are not eligible to serve.
-
#paused_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignPausedDetails
Details related to paused Smart campaigns.
-
#removed_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignRemovedDetails
Details related to removed Smart campaigns.
-
#smart_campaign_status ⇒ String
The status of this Smart campaign.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGetSmartCampaignStatusResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesGetSmartCampaignStatusResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGetSmartCampaignStatusResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesGetSmartCampaignStatusResponse.
41707 41708 41709 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41707 def initialize(**args) update!(**args) end |
Instance Attribute Details
#eligible_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails
Details related to Smart campaigns that are eligible to serve.
Corresponds to the JSON property eligibleDetails
41680 41681 41682 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41680 def eligible_details @eligible_details end |
#ended_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignEndedDetails
Details related to Smart campaigns that have ended.
Corresponds to the JSON property endedDetails
41685 41686 41687 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41685 def ended_details @ended_details end |
#not_eligible_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails
Details related to Smart campaigns that are not eligible to serve.
Corresponds to the JSON property notEligibleDetails
41690 41691 41692 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41690 def not_eligible_details @not_eligible_details end |
#paused_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignPausedDetails
Details related to paused Smart campaigns.
Corresponds to the JSON property pausedDetails
41695 41696 41697 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41695 def paused_details @paused_details end |
#removed_details ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignRemovedDetails
Details related to removed Smart campaigns.
Corresponds to the JSON property removedDetails
41700 41701 41702 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41700 def removed_details @removed_details end |
#smart_campaign_status ⇒ String
The status of this Smart campaign.
Corresponds to the JSON property smartCampaignStatus
41705 41706 41707 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41705 def smart_campaign_status @smart_campaign_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41712 41713 41714 41715 41716 41717 41718 41719 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41712 def update!(**args) @eligible_details = args[:eligible_details] if args.key?(:eligible_details) @ended_details = args[:ended_details] if args.key?(:ended_details) @not_eligible_details = args[:not_eligible_details] if args.key?(:not_eligible_details) @paused_details = args[:paused_details] if args.key?(:paused_details) @removed_details = args[:removed_details] if args.key?(:removed_details) @smart_campaign_status = args[:smart_campaign_status] if args.key?(:smart_campaign_status) end |