Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGoalOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesGoalOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single mutate operation on the goal.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGoal
Representation of goals.
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGoal
Representation of goals.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGoalOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesGoalOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesGoalOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesGoalOperation.
41741 41742 41743 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41741 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGoal
Representation of goals.
Corresponds to the JSON property create
41729 41730 41731 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41729 def create @create end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesGoal
Representation of goals.
Corresponds to the JSON property update
41734 41735 41736 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41734 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
41739 41740 41741 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41739 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41746 41747 41748 41749 41750 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41746 def update!(**args) @create = args[:create] if args.key?(:create) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |