Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIdentityVerification
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIdentityVerification
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An identity verification for a customer.
Instance Attribute Summary collapse
-
#identity_verification_requirement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIdentityVerificationRequirement
Information regarding the verification requirement for a verification program type.
-
#verification_program ⇒ String
The verification program type.
-
#verification_progress ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIdentityVerificationProgress
Information regarding the verification progress for a verification program type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIdentityVerification
constructor
A new instance of GoogleAdsSearchads360V23ServicesIdentityVerification.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIdentityVerification
Returns a new instance of GoogleAdsSearchads360V23ServicesIdentityVerification.
42602 42603 42604 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#identity_verification_requirement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIdentityVerificationRequirement
Information regarding the verification requirement for a verification program
type.
Corresponds to the JSON property identityVerificationRequirement
42589 42590 42591 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42589 def identity_verification_requirement @identity_verification_requirement end |
#verification_program ⇒ String
The verification program type.
Corresponds to the JSON property verificationProgram
42594 42595 42596 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42594 def verification_program @verification_program end |
#verification_progress ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIdentityVerificationProgress
Information regarding the verification progress for a verification program
type.
Corresponds to the JSON property verificationProgress
42600 42601 42602 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42600 def verification_progress @verification_progress end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42607 42608 42609 42610 42611 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42607 def update!(**args) @identity_verification_requirement = args[:identity_verification_requirement] if args.key?(:identity_verification_requirement) @verification_program = args[:verification_program] if args.key?(:verification_program) @verification_progress = args[:verification_progress] if args.key?(:verification_progress) end |