Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIdentityVerificationProgress
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIdentityVerificationProgress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Information regarding the verification progress for a verification program type.
Instance Attribute Summary collapse
-
#action_url ⇒ String
Action URL for user to complete verification for the given verification program type.
-
#invitation_link_expiration_time ⇒ String
The timestamp when the action url will expire in "yyyy-MM-dd HH:mm:ss" format.
-
#program_status ⇒ String
Current Status (PENDING_USER_ACTION, SUCCESS, FAILURE etc) Corresponds to the JSON property
programStatus.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIdentityVerificationProgress
constructor
A new instance of GoogleAdsSearchads360V23ServicesIdentityVerificationProgress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIdentityVerificationProgress
Returns a new instance of GoogleAdsSearchads360V23ServicesIdentityVerificationProgress.
42635 42636 42637 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42635 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_url ⇒ String
Action URL for user to complete verification for the given verification
program type.
Corresponds to the JSON property actionUrl
42623 42624 42625 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42623 def action_url @action_url end |
#invitation_link_expiration_time ⇒ String
The timestamp when the action url will expire in "yyyy-MM-dd HH:mm:ss" format.
Corresponds to the JSON property invitationLinkExpirationTime
42628 42629 42630 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42628 def invitation_link_expiration_time @invitation_link_expiration_time end |
#program_status ⇒ String
Current Status (PENDING_USER_ACTION, SUCCESS, FAILURE etc)
Corresponds to the JSON property programStatus
42633 42634 42635 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42633 def program_status @program_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42640 42641 42642 42643 42644 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42640 def update!(**args) @action_url = args[:action_url] if args.key?(:action_url) @invitation_link_expiration_time = args[:invitation_link_expiration_time] if args.key?(:invitation_link_expiration_time) @program_status = args[:program_status] if args.key?(:program_status) end |