Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIdentityVerificationProgress
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIdentityVerificationProgress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Information regarding the verification progress for a verification program type.
Instance Attribute Summary collapse
-
#action_url ⇒ String
Action URL for user to complete verification for the given verification program type.
-
#invitation_link_expiration_time ⇒ String
The timestamp when the action url will expire in "yyyy-MM-dd HH:mm:ss" format.
-
#program_status ⇒ String
Current Status (PENDING_USER_ACTION, SUCCESS, FAILURE etc) Corresponds to the JSON property
programStatus.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIdentityVerificationProgress
constructor
A new instance of GoogleAdsSearchads360V23ServicesIdentityVerificationProgress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIdentityVerificationProgress
Returns a new instance of GoogleAdsSearchads360V23ServicesIdentityVerificationProgress.
41942 41943 41944 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41942 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_url ⇒ String
Action URL for user to complete verification for the given verification
program type.
Corresponds to the JSON property actionUrl
41930 41931 41932 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41930 def action_url @action_url end |
#invitation_link_expiration_time ⇒ String
The timestamp when the action url will expire in "yyyy-MM-dd HH:mm:ss" format.
Corresponds to the JSON property invitationLinkExpirationTime
41935 41936 41937 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41935 def invitation_link_expiration_time @invitation_link_expiration_time end |
#program_status ⇒ String
Current Status (PENDING_USER_ACTION, SUCCESS, FAILURE etc)
Corresponds to the JSON property programStatus
41940 41941 41942 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41940 def program_status @program_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41947 41948 41949 41950 41951 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41947 def update!(**args) @action_url = args[:action_url] if args.key?(:action_url) @invitation_link_expiration_time = args[:invitation_link_expiration_time] if args.key?(:invitation_link_expiration_time) @program_status = args[:program_status] if args.key?(:program_status) end |