Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An incentive that a user can claim for their account.
Instance Attribute Summary collapse
-
#incentive_id ⇒ Fixnum
The incentive ID of this incentive.
-
#incentive_terms_and_conditions_url ⇒ String
The URL of the terms and conditions for THIS incentive offer ONLY.
-
#requirement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentiveRequirement
Requirement for an incentive.
-
#type ⇒ String
The type of the incentive.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIncentive
constructor
A new instance of GoogleAdsSearchads360V23ServicesIncentive.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIncentive
Returns a new instance of GoogleAdsSearchads360V23ServicesIncentive.
42772 42773 42774 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#incentive_id ⇒ Fixnum
The incentive ID of this incentive. This is used to identify which incentive
is selected by the user in the CYO flow.
Corresponds to the JSON property incentiveId
42753 42754 42755 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42753 def incentive_id @incentive_id end |
#incentive_terms_and_conditions_url ⇒ String
The URL of the terms and conditions for THIS incentive offer ONLY. This is
different from the terms_and_conditions_url field in AcquisitionIncentiveOffer
which is a combination of all the Incentive offers in a CYO offer.
Corresponds to the JSON property incentiveTermsAndConditionsUrl
42760 42761 42762 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42760 def incentive_terms_and_conditions_url @incentive_terms_and_conditions_url end |
#requirement ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentiveRequirement
Requirement for an incentive.
Corresponds to the JSON property requirement
42765 42766 42767 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42765 def requirement @requirement end |
#type ⇒ String
The type of the incentive.
Corresponds to the JSON property type
42770 42771 42772 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42770 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42777 42778 42779 42780 42781 42782 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42777 def update!(**args) @incentive_id = args[:incentive_id] if args.key?(:incentive_id) @incentive_terms_and_conditions_url = args[:incentive_terms_and_conditions_url] if args.key?(:incentive_terms_and_conditions_url) @requirement = args[:requirement] if args.key?(:requirement) @type = args[:type] if args.key?(:type) end |