Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentive

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

An incentive that a user can claim for their account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIncentive

Returns a new instance of GoogleAdsSearchads360V23ServicesIncentive.



42007
42008
42009
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42007

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#incentive_idFixnum

The incentive ID of this incentive. This is used to identify which incentive is selected by the user in the CYO flow. Corresponds to the JSON property incentiveId

Returns:

  • (Fixnum)


41988
41989
41990
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41988

def incentive_id
  @incentive_id
end

#incentive_terms_and_conditions_urlString

The URL of the terms and conditions for THIS incentive offer ONLY. This is different from the terms_and_conditions_url field in AcquisitionIncentiveOffer which is a combination of all the Incentive offers in a CYO offer. Corresponds to the JSON property incentiveTermsAndConditionsUrl

Returns:

  • (String)


41995
41996
41997
# File 'lib/google/apis/searchads360_v23/classes.rb', line 41995

def incentive_terms_and_conditions_url
  @incentive_terms_and_conditions_url
end

#requirementGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentiveRequirement

Requirement for an incentive. Corresponds to the JSON property requirement



42000
42001
42002
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42000

def requirement
  @requirement
end

#typeString

The type of the incentive. Corresponds to the JSON property type

Returns:

  • (String)


42005
42006
42007
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42005

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42012
42013
42014
42015
42016
42017
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42012

def update!(**args)
  @incentive_id = args[:incentive_id] if args.key?(:incentive_id)
  @incentive_terms_and_conditions_url = args[:incentive_terms_and_conditions_url] if args.key?(:incentive_terms_and_conditions_url)
  @requirement = args[:requirement] if args.key?(:requirement)
  @type = args[:type] if args.key?(:type)
end