Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentiveOffer
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentiveOffer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
An acquisition incentive offer for a user. An offer means how the user is treated. An offer can have no incentive or multiple incentives.
Instance Attribute Summary collapse
-
#consolidated_terms_and_conditions_url ⇒ String
Optional.
-
#cyo_incentives ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCyoIncentives
An incentive offer in the Choose-Your-Own Incentive feature where a user can select from a set of incentives with different money amounts.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIncentiveOffer
constructor
A new instance of GoogleAdsSearchads360V23ServicesIncentiveOffer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIncentiveOffer
Returns a new instance of GoogleAdsSearchads360V23ServicesIncentiveOffer.
42734 42735 42736 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consolidated_terms_and_conditions_url ⇒ String
Optional. The URL of the terms and conditions for the incentive offer.
Corresponds to the JSON property consolidatedTermsAndConditionsUrl
42721 42722 42723 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42721 def consolidated_terms_and_conditions_url @consolidated_terms_and_conditions_url end |
#cyo_incentives ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCyoIncentives
An incentive offer in the Choose-Your-Own Incentive feature where a user can
select from a set of incentives with different money amounts.
Corresponds to the JSON property cyoIncentives
42727 42728 42729 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42727 def cyo_incentives @cyo_incentives end |
#type ⇒ String
Required. The type of this acquisition incentive offer.
Corresponds to the JSON property type
42732 42733 42734 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42732 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42739 42740 42741 42742 42743 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42739 def update!(**args) @consolidated_terms_and_conditions_url = args[:consolidated_terms_and_conditions_url] if args.key?(:consolidated_terms_and_conditions_url) @cyo_incentives = args[:cyo_incentives] if args.key?(:cyo_incentives) @type = args[:type] if args.key?(:type) end |