Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIncentiveRequirementSpend

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Spend requirements for an incentive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIncentiveRequirementSpend

Returns a new instance of GoogleAdsSearchads360V23ServicesIncentiveRequirementSpend.



35540
35541
35542
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35540

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#award_amountGoogle::Apis::Searchads360V23::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property awardAmount



35533
35534
35535
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35533

def award_amount
  @award_amount
end

#required_amountGoogle::Apis::Searchads360V23::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property requiredAmount



35538
35539
35540
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35538

def required_amount
  @required_amount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35545
35546
35547
35548
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35545

def update!(**args)
  @award_amount = args[:award_amount] if args.key?(:award_amount)
  @required_amount = args[:required_amount] if args.key?(:required_amount)
end