Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIndustryVerticalInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesIndustryVerticalInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The information associated with an Industry Vertical.
Instance Attribute Summary collapse
-
#industry_vertical_id ⇒ Fixnum
The unique identifier of the Industry Vertical.
-
#industry_vertical_name ⇒ String
The name of the Industry Vertical.
-
#parent_industry_vertical_id ⇒ Fixnum
The unique identifier of the parent Industry Vertical, if exists.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIndustryVerticalInfo
constructor
A new instance of GoogleAdsSearchads360V23ServicesIndustryVerticalInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesIndustryVerticalInfo
Returns a new instance of GoogleAdsSearchads360V23ServicesIndustryVerticalInfo.
42072 42073 42074 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42072 def initialize(**args) update!(**args) end |
Instance Attribute Details
#industry_vertical_id ⇒ Fixnum
The unique identifier of the Industry Vertical.
Corresponds to the JSON property industryVerticalId
42060 42061 42062 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42060 def industry_vertical_id @industry_vertical_id end |
#industry_vertical_name ⇒ String
The name of the Industry Vertical.
Corresponds to the JSON property industryVerticalName
42065 42066 42067 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42065 def industry_vertical_name @industry_vertical_name end |
#parent_industry_vertical_id ⇒ Fixnum
The unique identifier of the parent Industry Vertical, if exists.
Corresponds to the JSON property parentIndustryVerticalId
42070 42071 42072 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42070 def parent_industry_vertical_id @parent_industry_vertical_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42077 42078 42079 42080 42081 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42077 def update!(**args) @industry_vertical_id = args[:industry_vertical_id] if args.key?(:industry_vertical_id) @industry_vertical_name = args[:industry_vertical_name] if args.key?(:industry_vertical_name) @parent_industry_vertical_id = args[:parent_industry_vertical_id] if args.key?(:parent_industry_vertical_id) end |