Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService.
Instance Attribute Summary collapse
-
#age_ranges ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo>
Age ranges for the audience.
-
#country_locations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>
Required.
-
#gender ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo
A gender criterion.
-
#income_ranges ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIncomeRangeInfo>
Household income percentile ranges for the audience.
-
#lineups ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsLineup>
Lineups representing the YouTube content viewed by the audience.
-
#parental_status ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo
A parental status criterion.
-
#sub_country_locations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>
Sub-country geographic location attributes.
-
#topic_audience_combinations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceAttributeGroup>
A combination of entity, category and user interest attributes defining the audience.
-
#user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListInfo
A User List criterion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesInsightsAudience
constructor
A new instance of GoogleAdsSearchads360V23ServicesInsightsAudience.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesInsightsAudience
Returns a new instance of GoogleAdsSearchads360V23ServicesInsightsAudience.
42837 42838 42839 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42837 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age_ranges ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo>
Age ranges for the audience. If absent, the audience represents all people
over 18 that match the other attributes.
Corresponds to the JSON property ageRanges
42786 42787 42788 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42786 def age_ranges @age_ranges end |
#country_locations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>
Required. The countries for the audience.
Corresponds to the JSON property countryLocations
42791 42792 42793 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42791 def country_locations @country_locations end |
#gender ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo
A gender criterion.
Corresponds to the JSON property gender
42796 42797 42798 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42796 def gender @gender end |
#income_ranges ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIncomeRangeInfo>
Household income percentile ranges for the audience. If absent, the audience
does not restrict by household income range.
Corresponds to the JSON property incomeRanges
42802 42803 42804 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42802 def income_ranges @income_ranges end |
#lineups ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsLineup>
Lineups representing the YouTube content viewed by the audience.
Corresponds to the JSON property lineups
42807 42808 42809 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42807 def lineups @lineups end |
#parental_status ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo
A parental status criterion.
Corresponds to the JSON property parentalStatus
42812 42813 42814 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42812 def parental_status @parental_status end |
#sub_country_locations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>
Sub-country geographic location attributes. If present, each of these must be
contained in one of the countries in this audience. If absent, the audience is
geographically to the country_locations and no further.
Corresponds to the JSON property subCountryLocations
42819 42820 42821 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42819 def sub_country_locations @sub_country_locations end |
#topic_audience_combinations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceAttributeGroup>
A combination of entity, category and user interest attributes defining the
audience. The combination has a logical AND-of-ORs structure: Attributes
within each InsightsAudienceAttributeGroup are combined with OR, and the
combinations themselves are combined together with AND. For example, the
expression (Entity OR Affinity) AND (In-Market OR Category) can be formed
using two InsightsAudienceAttributeGroups with two Attributes each.
Corresponds to the JSON property topicAudienceCombinations
42829 42830 42831 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42829 def topic_audience_combinations @topic_audience_combinations end |
#user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListInfo
A User List criterion. Represents a user list that is defined by the
advertiser to be targeted.
Corresponds to the JSON property userList
42835 42836 42837 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42835 def user_list @user_list end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42842 42843 42844 42845 42846 42847 42848 42849 42850 42851 42852 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42842 def update!(**args) @age_ranges = args[:age_ranges] if args.key?(:age_ranges) @country_locations = args[:country_locations] if args.key?(:country_locations) @gender = args[:gender] if args.key?(:gender) @income_ranges = args[:income_ranges] if args.key?(:income_ranges) @lineups = args[:lineups] if args.key?(:lineups) @parental_status = args[:parental_status] if args.key?(:parental_status) @sub_country_locations = args[:sub_country_locations] if args.key?(:sub_country_locations) @topic_audience_combinations = args[:topic_audience_combinations] if args.key?(:topic_audience_combinations) @user_list = args[:user_list] if args.key?(:user_list) end |