Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService.
Instance Attribute Summary collapse
-
#age_ranges ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo>
Age ranges for the audience.
-
#country_locations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>
Required.
-
#gender ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo
A gender criterion.
-
#income_ranges ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIncomeRangeInfo>
Household income percentile ranges for the audience.
-
#lineups ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsLineup>
Lineups representing the YouTube content viewed by the audience.
-
#parental_status ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo
A parental status criterion.
-
#sub_country_locations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>
Sub-country geographic location attributes.
-
#topic_audience_combinations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceAttributeGroup>
A combination of entity, category and user interest attributes defining the audience.
-
#user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListInfo
A User List criterion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesInsightsAudience
constructor
A new instance of GoogleAdsSearchads360V23ServicesInsightsAudience.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesInsightsAudience
Returns a new instance of GoogleAdsSearchads360V23ServicesInsightsAudience.
42144 42145 42146 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age_ranges ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo>
Age ranges for the audience. If absent, the audience represents all people
over 18 that match the other attributes.
Corresponds to the JSON property ageRanges
42093 42094 42095 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42093 def age_ranges @age_ranges end |
#country_locations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>
Required. The countries for the audience.
Corresponds to the JSON property countryLocations
42098 42099 42100 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42098 def country_locations @country_locations end |
#gender ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo
A gender criterion.
Corresponds to the JSON property gender
42103 42104 42105 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42103 def gender @gender end |
#income_ranges ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonIncomeRangeInfo>
Household income percentile ranges for the audience. If absent, the audience
does not restrict by household income range.
Corresponds to the JSON property incomeRanges
42109 42110 42111 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42109 def income_ranges @income_ranges end |
#lineups ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsLineup>
Lineups representing the YouTube content viewed by the audience.
Corresponds to the JSON property lineups
42114 42115 42116 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42114 def lineups @lineups end |
#parental_status ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo
A parental status criterion.
Corresponds to the JSON property parentalStatus
42119 42120 42121 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42119 def parental_status @parental_status end |
#sub_country_locations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>
Sub-country geographic location attributes. If present, each of these must be
contained in one of the countries in this audience. If absent, the audience is
geographically to the country_locations and no further.
Corresponds to the JSON property subCountryLocations
42126 42127 42128 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42126 def sub_country_locations @sub_country_locations end |
#topic_audience_combinations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceAttributeGroup>
A combination of entity, category and user interest attributes defining the
audience. The combination has a logical AND-of-ORs structure: Attributes
within each InsightsAudienceAttributeGroup are combined with OR, and the
combinations themselves are combined together with AND. For example, the
expression (Entity OR Affinity) AND (In-Market OR Category) can be formed
using two InsightsAudienceAttributeGroups with two Attributes each.
Corresponds to the JSON property topicAudienceCombinations
42136 42137 42138 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42136 def topic_audience_combinations @topic_audience_combinations end |
#user_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonUserListInfo
A User List criterion. Represents a user list that is defined by the
advertiser to be targeted.
Corresponds to the JSON property userList
42142 42143 42144 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42142 def user_list @user_list end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42149 42150 42151 42152 42153 42154 42155 42156 42157 42158 42159 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42149 def update!(**args) @age_ranges = args[:age_ranges] if args.key?(:age_ranges) @country_locations = args[:country_locations] if args.key?(:country_locations) @gender = args[:gender] if args.key?(:gender) @income_ranges = args[:income_ranges] if args.key?(:income_ranges) @lineups = args[:lineups] if args.key?(:lineups) @parental_status = args[:parental_status] if args.key?(:parental_status) @sub_country_locations = args[:sub_country_locations] if args.key?(:sub_country_locations) @topic_audience_combinations = args[:topic_audience_combinations] if args.key?(:topic_audience_combinations) @user_list = args[:user_list] if args.key?(:user_list) end |