Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceDefinition
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceDefinition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A structured definition of the audience of interest for which insights are being requested in AudienceInsightsService.
Instance Attribute Summary collapse
-
#audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService.
-
#baseline_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService.
-
#data_month ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesInsightsAudienceDefinition
constructor
A new instance of GoogleAdsSearchads360V23ServicesInsightsAudienceDefinition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesInsightsAudienceDefinition
Returns a new instance of GoogleAdsSearchads360V23ServicesInsightsAudienceDefinition.
42901 42902 42903 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be
requested in AudienceInsightsService.
Corresponds to the JSON property audience
42886 42887 42888 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42886 def audience @audience end |
#baseline_audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience
A set of users, defined by various characteristics, for which insights can be
requested in AudienceInsightsService.
Corresponds to the JSON property baselineAudience
42892 42893 42894 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42892 def baseline_audience @baseline_audience end |
#data_month ⇒ String
Optional. The one-month range of historical data to use for insights, in the
format "yyyy-mm". If unset, insights will be returned for the last thirty days
of data.
Corresponds to the JSON property dataMonth
42899 42900 42901 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42899 def data_month @data_month end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42906 42907 42908 42909 42910 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42906 def update!(**args) @audience = args[:audience] if args.key?(:audience) @baseline_audience = args[:baseline_audience] if args.key?(:baseline_audience) @data_month = args[:data_month] if args.key?(:data_month) end |