Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceDefinition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A structured definition of the audience of interest for which insights are being requested in AudienceInsightsService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesInsightsAudienceDefinition

Returns a new instance of GoogleAdsSearchads360V23ServicesInsightsAudienceDefinition.



42208
42209
42210
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audienceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience

A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService. Corresponds to the JSON property audience



42193
42194
42195
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42193

def audience
  @audience
end

#baseline_audienceGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudience

A set of users, defined by various characteristics, for which insights can be requested in AudienceInsightsService. Corresponds to the JSON property baselineAudience



42199
42200
42201
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42199

def baseline_audience
  @baseline_audience
end

#data_monthString

Optional. The one-month range of historical data to use for insights, in the format "yyyy-mm". If unset, insights will be returned for the last thirty days of data. Corresponds to the JSON property dataMonth

Returns:

  • (String)


42206
42207
42208
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42206

def data_month
  @data_month
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42213
42214
42215
42216
42217
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42213

def update!(**args)
  @audience = args[:audience] if args.key?(:audience)
  @baseline_audience = args[:baseline_audience] if args.key?(:baseline_audience)
  @data_month = args[:data_month] if args.key?(:data_month)
end