Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceDescription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A text description of the audience of interest for which insights are being requested in AudienceInsightsService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesInsightsAudienceDescription

Returns a new instance of GoogleAdsSearchads360V23ServicesInsightsAudienceDescription.



42941
42942
42943
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42941

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audience_descriptionString

Required. An English language text description of an audience to get suggestions for. Maximum length is 2000 characters. For example, "Women in their 30s who love to travel". Corresponds to the JSON property audienceDescription

Returns:

  • (String)


42923
42924
42925
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42923

def audience_description
  @audience_description
end

#audience_dimensionsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceInsightsDimensions

A collection of dimensions to be used for generating insights. Corresponds to the JSON property audienceDimensions



42928
42929
42930
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42928

def audience_dimensions
  @audience_dimensions
end

#country_locationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>

Required. The countries for the audience. Corresponds to the JSON property countryLocations



42933
42934
42935
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42933

def country_locations
  @country_locations
end

#marketing_objectiveString

Optional. An optional marketing objective which will influence the type of suggestions produced. Corresponds to the JSON property marketingObjective

Returns:

  • (String)


42939
42940
42941
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42939

def marketing_objective
  @marketing_objective
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42946
42947
42948
42949
42950
42951
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42946

def update!(**args)
  @audience_description = args[:audience_description] if args.key?(:audience_description)
  @audience_dimensions = args[:audience_dimensions] if args.key?(:audience_dimensions)
  @country_locations = args[:country_locations] if args.key?(:country_locations)
  @marketing_objective = args[:marketing_objective] if args.key?(:marketing_objective)
end