Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesInsightsAudienceDescription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A text description of the audience of interest for which insights are being requested in AudienceInsightsService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesInsightsAudienceDescription

Returns a new instance of GoogleAdsSearchads360V23ServicesInsightsAudienceDescription.



42248
42249
42250
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42248

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audience_descriptionString

Required. An English language text description of an audience to get suggestions for. Maximum length is 2000 characters. For example, "Women in their 30s who love to travel". Corresponds to the JSON property audienceDescription

Returns:

  • (String)


42230
42231
42232
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42230

def audience_description
  @audience_description
end

#audience_dimensionsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceInsightsDimensions

A collection of dimensions to be used for generating insights. Corresponds to the JSON property audienceDimensions



42235
42236
42237
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42235

def audience_dimensions
  @audience_dimensions
end

#country_locationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>

Required. The countries for the audience. Corresponds to the JSON property countryLocations



42240
42241
42242
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42240

def country_locations
  @country_locations
end

#marketing_objectiveString

Optional. An optional marketing objective which will influence the type of suggestions produced. Corresponds to the JSON property marketingObjective

Returns:

  • (String)


42246
42247
42248
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42246

def marketing_objective
  @marketing_objective
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42253
42254
42255
42256
42257
42258
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42253

def update!(**args)
  @audience_description = args[:audience_description] if args.key?(:audience_description)
  @audience_dimensions = args[:audience_dimensions] if args.key?(:audience_dimensions)
  @country_locations = args[:country_locations] if args.key?(:country_locations)
  @marketing_objective = args[:marketing_objective] if args.key?(:marketing_objective)
end