Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordAndUrlSeed
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordAndUrlSeed
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Keyword And Url Seed
Instance Attribute Summary collapse
-
#keywords ⇒ Array<String>
Requires at least one keyword and no more than 20 keywords.
-
#url ⇒ String
The URL to crawl in order to generate keyword ideas.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordAndUrlSeed
constructor
A new instance of GoogleAdsSearchads360V23ServicesKeywordAndUrlSeed.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordAndUrlSeed
Returns a new instance of GoogleAdsSearchads360V23ServicesKeywordAndUrlSeed.
42275 42276 42277 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42275 def initialize(**args) update!(**args) end |
Instance Attribute Details
#keywords ⇒ Array<String>
Requires at least one keyword and no more than 20 keywords.
Corresponds to the JSON property keywords
42268 42269 42270 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42268 def keywords @keywords end |
#url ⇒ String
The URL to crawl in order to generate keyword ideas.
Corresponds to the JSON property url
42273 42274 42275 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42273 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42280 42281 42282 42283 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42280 def update!(**args) @keywords = args[:keywords] if args.key?(:keywords) @url = args[:url] if args.key?(:url) end |