Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a Keyword Plan ad group keyword.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation.



42375
42376
42377
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword

A Keyword Plan ad group keyword. Max number of keyword plan keywords per plan: 10000. Corresponds to the JSON property create



42355
42356
42357
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42355

def create
  @create
end

#removeString

Remove operation: A resource name for the removed Keyword Plan ad group keyword is expected, in this format: customers/customer_id/ keywordPlanAdGroupKeywords/kp_ad_group_keyword_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


42362
42363
42364
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42362

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroupKeyword

A Keyword Plan ad group keyword. Max number of keyword plan keywords per plan: 10000. Corresponds to the JSON property update



42368
42369
42370
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42368

def update
  @update
end

#update_maskString

The FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


42373
42374
42375
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42373

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42380
42381
42382
42383
42384
42385
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42380

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end