Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a Keyword Plan ad group.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
A Keyword Planner ad group.
-
#remove ⇒ String
Remove operation: A resource name for the removed Keyword Plan ad group is expected, in this format:
customers/customer_id/keywordPlanAdGroups/kp_ad_group_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
A Keyword Planner ad group.
-
#update_mask ⇒ String
The FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation.
43179 43180 43181 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43179 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
A Keyword Planner ad group. Max number of keyword plan ad groups per plan: 200.
Corresponds to the JSON property create
43160 43161 43162 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43160 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed Keyword Plan ad group is
expected, in this format: customers/customer_id/keywordPlanAdGroups/
kp_ad_group_id`
Corresponds to the JSON propertyremove`
43167 43168 43169 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43167 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
A Keyword Planner ad group. Max number of keyword plan ad groups per plan: 200.
Corresponds to the JSON property update
43172 43173 43174 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43172 def update @update end |
#update_mask ⇒ String
The FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
43177 43178 43179 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43177 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43184 43185 43186 43187 43188 43189 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43184 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |