Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a Keyword Plan ad group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation.



43107
43108
43109
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43107

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup

A Keyword Planner ad group. Max number of keyword plan ad groups per plan: 200. Corresponds to the JSON property create



43088
43089
43090
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43088

def create
  @create
end

#removeString

Remove operation: A resource name for the removed Keyword Plan ad group is expected, in this format: customers/customer_id/keywordPlanAdGroups/ kp_ad_group_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


43095
43096
43097
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43095

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup

A Keyword Planner ad group. Max number of keyword plan ad groups per plan: 200. Corresponds to the JSON property update



43100
43101
43102
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43100

def update
  @update
end

#update_maskString

The FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


43105
43106
43107
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43105

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43112
43113
43114
43115
43116
43117
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43112

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end