Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a Keyword Plan ad group.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
A Keyword Planner ad group.
-
#remove ⇒ String
Remove operation: A resource name for the removed Keyword Plan ad group is expected, in this format:
customers/customer_id/keywordPlanAdGroups/kp_ad_group_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
A Keyword Planner ad group.
-
#update_mask ⇒ String
The FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation.
42414 42415 42416 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42414 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
A Keyword Planner ad group. Max number of keyword plan ad groups per plan: 200.
Corresponds to the JSON property create
42395 42396 42397 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42395 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed Keyword Plan ad group is
expected, in this format: customers/customer_id/keywordPlanAdGroups/
kp_ad_group_id`
Corresponds to the JSON propertyremove`
42402 42403 42404 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42402 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanAdGroup
A Keyword Planner ad group. Max number of keyword plan ad groups per plan: 200.
Corresponds to the JSON property update
42407 42408 42409 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42407 def update @update end |
#update_mask ⇒ String
The FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
42412 42413 42414 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42412 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42419 42420 42421 42422 42423 42424 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42419 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |