Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a Keyword Plan campaign keyword.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaignKeyword
A Keyword Plan Campaign keyword.
-
#remove ⇒ String
Remove operation: A resource name for the removed Keyword Plan campaign keywords expected in this format:
customers/customer_id/ keywordPlanCampaignKeywords/kp_campaign_keyword_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaignKeyword
A Keyword Plan Campaign keyword.
-
#update_mask ⇒ String
The FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation.
42455 42456 42457 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaignKeyword
A Keyword Plan Campaign keyword. Only negative keywords are supported for
Campaign Keyword.
Corresponds to the JSON property create
42435 42436 42437 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42435 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed Keyword Plan campaign
keywords expected in this format: customers/customer_id/
keywordPlanCampaignKeywords/kp_campaign_keyword_id`
Corresponds to the JSON propertyremove`
42442 42443 42444 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42442 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaignKeyword
A Keyword Plan Campaign keyword. Only negative keywords are supported for
Campaign Keyword.
Corresponds to the JSON property update
42448 42449 42450 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42448 def update @update end |
#update_mask ⇒ String
The FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
42453 42454 42455 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42453 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42460 42461 42462 42463 42464 42465 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42460 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |