Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a Keyword Plan campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation.



43189
43190
43191
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43189

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaign

A Keyword Plan campaign. Max number of keyword plan campaigns per plan allowed: 1. Corresponds to the JSON property create



43169
43170
43171
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43169

def create
  @create
end

#removeString

Remove operation: A resource name for the removed Keyword Plan campaign is expected, in this format: customers/customer_id/keywordPlanCampaigns/ keywordPlan_campaign_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


43176
43177
43178
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43176

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaign

A Keyword Plan campaign. Max number of keyword plan campaigns per plan allowed: 1. Corresponds to the JSON property update



43182
43183
43184
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43182

def update
  @update
end

#update_maskString

The FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


43187
43188
43189
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43187

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43194
43195
43196
43197
43198
43199
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43194

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end