Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a Keyword Plan campaign.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaign
A Keyword Plan campaign.
-
#remove ⇒ String
Remove operation: A resource name for the removed Keyword Plan campaign is expected, in this format:
customers/customer_id/keywordPlanCampaigns/keywordPlan_campaign_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaign
A Keyword Plan campaign.
-
#update_mask ⇒ String
The FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation.
42496 42497 42498 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42496 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaign
A Keyword Plan campaign. Max number of keyword plan campaigns per plan allowed:
1.
Corresponds to the JSON property create
42476 42477 42478 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42476 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed Keyword Plan campaign is
expected, in this format: customers/customer_id/keywordPlanCampaigns/
keywordPlan_campaign_id`
Corresponds to the JSON propertyremove`
42483 42484 42485 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42483 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlanCampaign
A Keyword Plan campaign. Max number of keyword plan campaigns per plan allowed:
1.
Corresponds to the JSON property update
42489 42490 42491 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42489 def update @update end |
#update_mask ⇒ String
The FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
42494 42495 42496 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42494 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42501 42502 42503 42504 42505 42506 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42501 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |