Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a keyword plan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesKeywordPlanOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesKeywordPlanOperation.



42536
42537
42538
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlan

A Keyword Planner plan. Max number of saved keyword plans: 10000. It's possible to remove plans if limit is reached. Corresponds to the JSON property create



42517
42518
42519
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42517

def create
  @create
end

#removeString

Remove operation: A resource name for the removed keyword plan is expected in this format: customers/customer_id/keywordPlans/keyword_plan_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


42523
42524
42525
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42523

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesKeywordPlan

A Keyword Planner plan. Max number of saved keyword plans: 10000. It's possible to remove plans if limit is reached. Corresponds to the JSON property update



42529
42530
42531
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42529

def update
  @update
end

#update_maskString

The FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


42534
42535
42536
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42534

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42541
42542
42543
42544
42545
42546
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42541

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end