Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesLabelOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesLabelOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, remove, update) on a label.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLabel
A label.
-
#remove ⇒ String
Remove operation: A resource name for the label being removed, in this format:
customers/customer_id/labels/label_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLabel
A label.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesLabelOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesLabelOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesLabelOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesLabelOperation.
43286 43287 43288 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43286 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLabel
A label.
Corresponds to the JSON property create
43268 43269 43270 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43268 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the label being removed, in this format:
customers/customer_id/labels/label_id`
Corresponds to the JSON propertyremove`
43274 43275 43276 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43274 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLabel
A label.
Corresponds to the JSON property update
43279 43280 43281 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43279 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
43284 43285 43286 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43284 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43291 43292 43293 43294 43295 43296 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43291 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |