Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesLabelOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, remove, update) on a label.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesLabelOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesLabelOperation.



42593
42594
42595
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42593

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLabel

A label. Corresponds to the JSON property create



42575
42576
42577
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42575

def create
  @create
end

#removeString

Remove operation: A resource name for the label being removed, in this format: customers/customer_id/labels/label_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


42581
42582
42583
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42581

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesLabel

A label. Corresponds to the JSON property update



42586
42587
42588
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42586

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


42591
42592
42593
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42591

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42598
42599
42600
42601
42602
42603
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42598

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end