Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListAudienceInsightsAttributesRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListAudienceInsightsAttributesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AudienceInsightsService.ListAudienceInsightsAttributes.
Instance Attribute Summary collapse
-
#customer_insights_group ⇒ String
The name of the customer being planned for.
-
#dimensions ⇒ Array<String>
Required.
-
#insights_application_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo
Additional information about the application/tool issuing the request.
-
#location_country_filters ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>
If SUB_COUNTRY_LOCATION attributes are one of the requested dimensions and this field is present, then the SUB_COUNTRY_LOCATION attributes returned will be located in these countries.
-
#query_text ⇒ String
Required.
-
#youtube_reach_location ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo
A location criterion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListAudienceInsightsAttributesRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesListAudienceInsightsAttributesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListAudienceInsightsAttributesRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesListAudienceInsightsAttributesRequest.
43436 43437 43438 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer_insights_group ⇒ String
The name of the customer being planned for. This is a user-defined value.
Corresponds to the JSON property customerInsightsGroup
43398 43399 43400 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43398 def customer_insights_group @customer_insights_group end |
#dimensions ⇒ Array<String>
Required. The types of attributes to be returned. Supported dimensions are
CATEGORY, KNOWLEDGE_GRAPH, GEO_TARGET_COUNTRY, SUB_COUNTRY_LOCATION,
YOUTUBE_LINEUP, AFFINITY_USER_INTEREST, IN_MARKET_USER_INTEREST, .
Corresponds to the JSON property dimensions
43405 43406 43407 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43405 def dimensions @dimensions end |
#insights_application_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo
Additional information about the application/tool issuing the request. This
field is only used by ContentCreatorInsightsService, AudienceInsightsService,
and ReachPlanService APIs.
Corresponds to the JSON property insightsApplicationInfo
43412 43413 43414 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43412 def insights_application_info @insights_application_info end |
#location_country_filters ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>
If SUB_COUNTRY_LOCATION attributes are one of the requested dimensions and
this field is present, then the SUB_COUNTRY_LOCATION attributes returned will
be located in these countries. If this field is absent, then location
attributes are not filtered by country. Setting this field when
SUB_COUNTRY_LOCATION attributes are not requested will return an error.
Corresponds to the JSON property locationCountryFilters
43421 43422 43423 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43421 def location_country_filters @location_country_filters end |
#query_text ⇒ String
Required. A free text query. If the requested dimensions include Attributes
CATEGORY or KNOWLEDGE_GRAPH, then the attributes returned for those dimensions
will match or be related to this string. For other dimensions, this field is
ignored and all available attributes are returned.
Corresponds to the JSON property queryText
43429 43430 43431 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43429 def query_text @query_text end |
#youtube_reach_location ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo
A location criterion.
Corresponds to the JSON property youtubeReachLocation
43434 43435 43436 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43434 def youtube_reach_location @youtube_reach_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43441 43442 43443 43444 43445 43446 43447 43448 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43441 def update!(**args) @customer_insights_group = args[:customer_insights_group] if args.key?(:customer_insights_group) @dimensions = args[:dimensions] if args.key?(:dimensions) @insights_application_info = args[:insights_application_info] if args.key?(:insights_application_info) @location_country_filters = args[:location_country_filters] if args.key?(:location_country_filters) @query_text = args[:query_text] if args.key?(:query_text) @youtube_reach_location = args[:youtube_reach_location] if args.key?(:youtube_reach_location) end |