Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListAudienceInsightsAttributesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AudienceInsightsService.ListAudienceInsightsAttributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListAudienceInsightsAttributesRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesListAudienceInsightsAttributesRequest.



42671
42672
42673
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42671

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customer_insights_groupString

The name of the customer being planned for. This is a user-defined value. Corresponds to the JSON property customerInsightsGroup

Returns:

  • (String)


42633
42634
42635
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42633

def customer_insights_group
  @customer_insights_group
end

#dimensionsArray<String>

Required. The types of attributes to be returned. Supported dimensions are CATEGORY, KNOWLEDGE_GRAPH, GEO_TARGET_COUNTRY, SUB_COUNTRY_LOCATION, YOUTUBE_LINEUP, AFFINITY_USER_INTEREST, IN_MARKET_USER_INTEREST, . Corresponds to the JSON property dimensions

Returns:

  • (Array<String>)


42640
42641
42642
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42640

def dimensions
  @dimensions
end

#insights_application_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo

Additional information about the application/tool issuing the request. This field is only used by ContentCreatorInsightsService, AudienceInsightsService, and ReachPlanService APIs. Corresponds to the JSON property insightsApplicationInfo



42647
42648
42649
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42647

def insights_application_info
  @insights_application_info
end

#location_country_filtersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo>

If SUB_COUNTRY_LOCATION attributes are one of the requested dimensions and this field is present, then the SUB_COUNTRY_LOCATION attributes returned will be located in these countries. If this field is absent, then location attributes are not filtered by country. Setting this field when SUB_COUNTRY_LOCATION attributes are not requested will return an error. Corresponds to the JSON property locationCountryFilters



42656
42657
42658
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42656

def location_country_filters
  @location_country_filters
end

#query_textString

Required. A free text query. If the requested dimensions include Attributes CATEGORY or KNOWLEDGE_GRAPH, then the attributes returned for those dimensions will match or be related to this string. For other dimensions, this field is ignored and all available attributes are returned. Corresponds to the JSON property queryText

Returns:

  • (String)


42664
42665
42666
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42664

def query_text
  @query_text
end

#youtube_reach_locationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonLocationInfo

A location criterion. Corresponds to the JSON property youtubeReachLocation



42669
42670
42671
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42669

def youtube_reach_location
  @youtube_reach_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42676
42677
42678
42679
42680
42681
42682
42683
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42676

def update!(**args)
  @customer_insights_group = args[:customer_insights_group] if args.key?(:customer_insights_group)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @insights_application_info = args[:insights_application_info] if args.key?(:insights_application_info)
  @location_country_filters = args[:location_country_filters] if args.key?(:location_country_filters)
  @query_text = args[:query_text] if args.key?(:query_text)
  @youtube_reach_location = args[:youtube_reach_location] if args.key?(:youtube_reach_location)
end