Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListBatchJobResultsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for BatchJobService.ListBatchJobResults.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListBatchJobResultsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesListBatchJobResultsResponse.



42721
42722
42723
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Pagination token used to retrieve the next page of results. Pass the content of this string as the page_token attribute of the next request. next_page_token is not returned for the last page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42714
42715
42716
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42714

def next_page_token
  @next_page_token
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBatchJobResult>

The list of rows that matched the query. Corresponds to the JSON property results



42719
42720
42721
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42719

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42726
42727
42728
42729
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42726

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @results = args[:results] if args.key?(:results)
end