Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListBenchmarksSourcesResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListBenchmarksSourcesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for BenchmarksService.ListBenchmarksSources.
Instance Attribute Summary collapse
-
#benchmarks_sources ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBenchmarksSourceMetadata>
The list of available source used to generate benchmarks data for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListBenchmarksSourcesResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesListBenchmarksSourcesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListBenchmarksSourcesResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesListBenchmarksSourcesResponse.
42889 42890 42891 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#benchmarks_sources ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBenchmarksSourceMetadata>
The list of available source used to generate benchmarks data for.
Corresponds to the JSON property benchmarksSources
42887 42888 42889 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42887 def benchmarks_sources @benchmarks_sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42894 42895 42896 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42894 def update!(**args) @benchmarks_sources = args[:benchmarks_sources] if args.key?(:benchmarks_sources) end |