Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListCampaignDraftAsyncErrorsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListCampaignDraftAsyncErrorsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for CampaignDraftService.ListCampaignDraftAsyncErrors.
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::Searchads360V23::GoogleRpcStatus>
Details of the errors when performing the asynchronous operation.
-
#next_page_token ⇒ String
Pagination token used to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListCampaignDraftAsyncErrorsResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesListCampaignDraftAsyncErrorsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListCampaignDraftAsyncErrorsResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesListCampaignDraftAsyncErrorsResponse.
42915 42916 42917 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42915 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::Searchads360V23::GoogleRpcStatus>
Details of the errors when performing the asynchronous operation.
Corresponds to the JSON property errors
42906 42907 42908 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42906 def errors @errors end |
#next_page_token ⇒ String
Pagination token used to retrieve the next page of results. Pass the content
of this string as the page_token attribute of the next request.
next_page_token is not returned for the last page.
Corresponds to the JSON property nextPageToken
42913 42914 42915 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42913 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42920 42921 42922 42923 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 42920 def update!(**args) @errors = args[:errors] if args.key?(:errors) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |