Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListPlannableUserInterestsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ReachPlanService.ListPlannableUserInterests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListPlannableUserInterestsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesListPlannableUserInterestsRequest.



43183
43184
43185
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customer_idString

Required. The ID of the customer. Corresponds to the JSON property customerId

Returns:

  • (String)


43152
43153
43154
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43152

def customer_id
  @customer_id
end

#name_queryString

A filter by user interest name. If set, only user interests with a name containing the literal string (case insensitive) in the filter will be returned. Maximum length is 200 characters. Corresponds to the JSON property nameQuery

Returns:

  • (String)


43159
43160
43161
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43159

def name_query
  @name_query
end

#path_queryString

A filter by user interest path. If set, only user interests with a path containing the literal string (case insensitive) in the filter will be returned. Maximum length is 200 characters. Corresponds to the JSON property pathQuery

Returns:

  • (String)


43166
43167
43168
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43166

def path_query
  @path_query
end

#reach_application_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdditionalApplicationInfo

Additional information about the application/tool issuing the request. This field is only used by ContentCreatorInsightsService, AudienceInsightsService, and ReachPlanService APIs. Corresponds to the JSON property reachApplicationInfo



43173
43174
43175
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43173

def reach_application_info
  @reach_application_info
end

#user_interest_taxonomy_typesArray<String>

Optional. A filter by user interest type. If set, only user interests with a type listed in the filter will be returned. If not set, user interests of all supported types will be returned. Supported user interest types are AFFINITY and IN_MARKET. Each type must be specified at most once. Corresponds to the JSON property userInterestTaxonomyTypes

Returns:

  • (Array<String>)


43181
43182
43183
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43181

def user_interest_taxonomy_types
  @user_interest_taxonomy_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43188
43189
43190
43191
43192
43193
43194
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43188

def update!(**args)
  @customer_id = args[:customer_id] if args.key?(:customer_id)
  @name_query = args[:name_query] if args.key?(:name_query)
  @path_query = args[:path_query] if args.key?(:path_query)
  @reach_application_info = args[:reach_application_info] if args.key?(:reach_application_info)
  @user_interest_taxonomy_types = args[:user_interest_taxonomy_types] if args.key?(:user_interest_taxonomy_types)
end