Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListPlannableUserListsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesListPlannableUserListsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A response with all available user lists with their plannable status.
Instance Attribute Summary collapse
-
#plannable_user_lists ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannableUserList>
The list of user lists available for planning and related targeting metadata.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListPlannableUserListsResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesListPlannableUserListsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesListPlannableUserListsResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesListPlannableUserListsResponse.
44024 44025 44026 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44024 def initialize(**args) update!(**args) end |
Instance Attribute Details
#plannable_user_lists ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannableUserList>
The list of user lists available for planning and related targeting metadata.
Corresponds to the JSON property plannableUserLists
44022 44023 44024 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44022 def plannable_user_lists @plannable_user_lists end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44029 44030 44031 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44029 def update!(**args) @plannable_user_lists = args[:plannable_user_lists] if args.key?(:plannable_user_lists) end |