Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesManualCpcBiddingStrategy
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesManualCpcBiddingStrategy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Manual CPC Bidding Strategy.
Instance Attribute Summary collapse
-
#daily_budget_micros ⇒ Fixnum
Campaign level budget in micros.
-
#max_cpc_bid_micros ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesManualCpcBiddingStrategy
constructor
A new instance of GoogleAdsSearchads360V23ServicesManualCpcBiddingStrategy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesManualCpcBiddingStrategy
Returns a new instance of GoogleAdsSearchads360V23ServicesManualCpcBiddingStrategy.
43979 43980 43981 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43979 def initialize(**args) update!(**args) end |
Instance Attribute Details
#daily_budget_micros ⇒ Fixnum
Campaign level budget in micros. If set, a minimum value is enforced for the
local currency used in the campaign. An error will occur showing the minimum
value if this field is set too low.
Corresponds to the JSON property dailyBudgetMicros
43971 43972 43973 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43971 def daily_budget_micros @daily_budget_micros end |
#max_cpc_bid_micros ⇒ Fixnum
Required. A bid in micros to be applied to ad groups within the campaign for a
manual CPC bidding strategy.
Corresponds to the JSON property maxCpcBidMicros
43977 43978 43979 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43977 def max_cpc_bid_micros @max_cpc_bid_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43984 43985 43986 43987 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43984 def update!(**args) @daily_budget_micros = args[:daily_budget_micros] if args.key?(:daily_budget_micros) @max_cpc_bid_micros = args[:max_cpc_bid_micros] if args.key?(:max_cpc_bid_micros) end |