Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesManualCpcBiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Manual CPC Bidding Strategy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesManualCpcBiddingStrategy

Returns a new instance of GoogleAdsSearchads360V23ServicesManualCpcBiddingStrategy.



43286
43287
43288
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#daily_budget_microsFixnum

Campaign level budget in micros. If set, a minimum value is enforced for the local currency used in the campaign. An error will occur showing the minimum value if this field is set too low. Corresponds to the JSON property dailyBudgetMicros

Returns:

  • (Fixnum)


43278
43279
43280
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43278

def daily_budget_micros
  @daily_budget_micros
end

#max_cpc_bid_microsFixnum

Required. A bid in micros to be applied to ad groups within the campaign for a manual CPC bidding strategy. Corresponds to the JSON property maxCpcBidMicros

Returns:

  • (Fixnum)


43284
43285
43286
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43284

def max_cpc_bid_micros
  @max_cpc_bid_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43291
43292
43293
43294
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43291

def update!(**args)
  @daily_budget_micros = args[:daily_budget_micros] if args.key?(:daily_budget_micros)
  @max_cpc_bid_micros = args[:max_cpc_bid_micros] if args.key?(:max_cpc_bid_micros)
end