Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMaximizeClicksBiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Maximize Clicks Bidding Strategy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMaximizeClicksBiddingStrategy

Returns a new instance of GoogleAdsSearchads360V23ServicesMaximizeClicksBiddingStrategy.



43313
43314
43315
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43313

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#daily_target_spend_microsFixnum

Required. The daily target spend in micros to be used for estimation. A minimum value is enforced for the local currency used in the campaign. An error will occur showing the minimum value if this field is set too low. Corresponds to the JSON property dailyTargetSpendMicros

Returns:

  • (Fixnum)


43306
43307
43308
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43306

def daily_target_spend_micros
  @daily_target_spend_micros
end

#max_cpc_bid_ceiling_microsFixnum

Ceiling on max CPC bids in micros. Corresponds to the JSON property maxCpcBidCeilingMicros

Returns:

  • (Fixnum)


43311
43312
43313
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43311

def max_cpc_bid_ceiling_micros
  @max_cpc_bid_ceiling_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43318
43319
43320
43321
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43318

def update!(**args)
  @daily_target_spend_micros = args[:daily_target_spend_micros] if args.key?(:daily_target_spend_micros)
  @max_cpc_bid_ceiling_micros = args[:max_cpc_bid_ceiling_micros] if args.key?(:max_cpc_bid_ceiling_micros)
end