Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMoveManagerLinkRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomerManagerLinkService.MoveManagerLink.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMoveManagerLinkRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMoveManagerLinkRequest.



43413
43414
43415
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_managerString

Required. The resource name of the new manager customer that the client wants to move to. Customer resource names have the format: "customers/customer_id" Corresponds to the JSON property newManager

Returns:

  • (String)


43397
43398
43399
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43397

def new_manager
  @new_manager
end

Required. The resource name of the previous CustomerManagerLink. The resource name has the form: customers/customer_id/customerManagerLinks/ manager_customer_id~manager_link_id` Corresponds to the JSON propertypreviousCustomerManagerLink`

Returns:

  • (String)


43404
43405
43406
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43404

def previous_customer_manager_link
  @previous_customer_manager_link
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


43410
43411
43412
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43410

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43418
43419
43420
43421
43422
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43418

def update!(**args)
  @new_manager = args[:new_manager] if args.key?(:new_manager)
  @previous_customer_manager_link = args[:previous_customer_manager_link] if args.key?(:previous_customer_manager_link)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end