Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountBudgetProposalRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountBudgetProposalRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AccountBudgetProposalService.MutateAccountBudgetProposal.
Instance Attribute Summary collapse
-
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAccountBudgetProposalOperation
A single operation to propose the creation of a new account-level budget or edit/end/remove an existing one.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAccountBudgetProposalRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAccountBudgetProposalRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAccountBudgetProposalRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAccountBudgetProposalRequest.
43462 43463 43464 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43462 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAccountBudgetProposalOperation
A single operation to propose the creation of a new account-level budget or
edit/end/remove an existing one.
Corresponds to the JSON property operation
43453 43454 43455 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43453 def operation @operation end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
43459 43460 43461 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43459 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43467 43468 43469 43470 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43467 def update!(**args) @operation = args[:operation] if args.key?(:operation) @validate_only = args[:validate_only] if args.key?(:validate_only) end |