Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AccountLinkService.MutateAccountLink.
Instance Attribute Summary collapse
-
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAccountLinkOperation
A single update on an account link.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest.
44300 44301 44302 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44300 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAccountLinkOperation
A single update on an account link.
Corresponds to the JSON property operation
44283 44284 44285 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44283 def operation @operation end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
44290 44291 44292 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44290 def partial_failure @partial_failure end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
44297 44298 44299 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44297 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44305 44306 44307 44308 44309 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44305 def update!(**args) @operation = args[:operation] if args.key?(:operation) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @validate_only = args[:validate_only] if args.key?(:validate_only) end |