Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AccountLinkService.MutateAccountLink.
Instance Attribute Summary collapse
-
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAccountLinkOperation
A single update on an account link.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest.
44228 44229 44230 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAccountLinkOperation
A single update on an account link.
Corresponds to the JSON property operation
44211 44212 44213 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44211 def operation @operation end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
44218 44219 44220 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44218 def partial_failure @partial_failure end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
44225 44226 44227 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44225 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44233 44234 44235 44236 44237 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44233 def update!(**args) @operation = args[:operation] if args.key?(:operation) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @validate_only = args[:validate_only] if args.key?(:validate_only) end |