Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AccountLinkService.MutateAccountLink.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAccountLinkRequest.



43535
43536
43537
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43535

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAccountLinkOperation

A single update on an account link. Corresponds to the JSON property operation



43518
43519
43520
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43518

def operation
  @operation
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


43525
43526
43527
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43525

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


43532
43533
43534
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43532

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43540
43541
43542
43543
43544
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43540

def update!(**args)
  @operation = args[:operation] if args.key?(:operation)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end