Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountLinkResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountLinkResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for account link mutate.
Instance Attribute Summary collapse
-
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountLinkResult
The result for the account link mutate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAccountLinkResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAccountLinkResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAccountLinkResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAccountLinkResponse.
44259 44260 44261 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44259 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property partialFailureError
44252 44253 44254 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44252 def partial_failure_error @partial_failure_error end |
#result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountLinkResult
The result for the account link mutate.
Corresponds to the JSON property result
44257 44258 44259 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44257 def result @result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44264 44265 44266 44267 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44264 def update!(**args) @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error) @result = args[:result] if args.key?(:result) end |