Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountLinkResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for account link mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAccountLinkResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAccountLinkResponse.



43566
43567
43568
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43566

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



43559
43560
43561
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43559

def partial_failure_error
  @partial_failure_error
end

#resultGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAccountLinkResult

The result for the account link mutate. Corresponds to the JSON property result



43564
43565
43566
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43564

def result
  @result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43571
43572
43573
43574
# File 'lib/google/apis/searchads360_v23/classes.rb', line 43571

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @result = args[:result] if args.key?(:result)
end