Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AdGroupAdLabelService.MutateAdGroupAdLabels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupAdLabelsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupAdLabelsRequest.



44332
44333
44334
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44332

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation>

Required. The list of operations to perform on ad group ad labels. Corresponds to the JSON property operations



44315
44316
44317
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44315

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


44322
44323
44324
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44322

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


44329
44330
44331
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44329

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44337
44338
44339
44340
44341
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44337

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end