Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAssetSetResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The result for the ad group asset set mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupAssetSetResult

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupAssetSetResult.



44512
44513
44514
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44512

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_asset_setGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdGroupAssetSet

AdGroupAssetSet is the linkage between an ad group and an asset set. Creating an AdGroupAssetSet links an asset set with an ad group. Corresponds to the JSON property adGroupAssetSet



44505
44506
44507
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44505

def ad_group_asset_set
  @ad_group_asset_set
end

#resource_nameString

Returned for successful operations. Corresponds to the JSON property resourceName

Returns:

  • (String)


44510
44511
44512
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44510

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44517
44518
44519
44520
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44517

def update!(**args)
  @ad_group_asset_set = args[:ad_group_asset_set] if args.key?(:ad_group_asset_set)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end