Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupBidModifiersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AdGroupBidModifierService.MutateAdGroupBidModifiers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupBidModifiersRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupBidModifiersRequest.



44725
44726
44727
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44725

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation>

Required. The list of operations to perform on individual ad group bid modifiers. Corresponds to the JSON property operations



44702
44703
44704
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44702

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


44709
44710
44711
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44709

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


44716
44717
44718
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44716

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


44722
44723
44724
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44722

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44730
44731
44732
44733
44734
44735
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44730

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end