Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizersRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AdGroupCriterionCustomizerService. MutateAdGroupCriterionCustomizers.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionCustomizerOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizersRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizersRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizersRequest.
44899 44900 44901 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44899 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionCustomizerOperation>
Required. The list of operations to perform on individual ad group criterion
customizers.
Corresponds to the JSON property operations
44876 44877 44878 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44876 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
44883 44884 44885 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44883 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
44890 44891 44892 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44890 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
44896 44897 44898 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44896 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44904 44905 44906 44907 44908 44909 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44904 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |