Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AdGroupCriterionCustomizerService. MutateAdGroupCriterionCustomizers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizersRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizersRequest.



44206
44207
44208
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionCustomizerOperation>

Required. The list of operations to perform on individual ad group criterion customizers. Corresponds to the JSON property operations



44183
44184
44185
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44183

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


44190
44191
44192
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44190

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


44197
44198
44199
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44197

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


44203
44204
44205
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44203

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44211
44212
44213
44214
44215
44216
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44211

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end