Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AdGroupCriterionLabelService.MutateAdGroupCriterionLabels.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionLabelOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelsRequest.
45057 45058 45059 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45057 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionLabelOperation>
Required. The list of operations to perform on ad group criterion labels.
Corresponds to the JSON property operations
45040 45041 45042 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45040 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
45047 45048 45049 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45047 def partial_failure @partial_failure end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
45054 45055 45056 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45054 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45062 45063 45064 45065 45066 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45062 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @validate_only = args[:validate_only] if args.key?(:validate_only) end |