Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AdGroupCriterionLabelService.MutateAdGroupCriterionLabels.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionLabelOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelsRequest.
44292 44293 44294 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44292 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionLabelOperation>
Required. The list of operations to perform on ad group criterion labels.
Corresponds to the JSON property operations
44275 44276 44277 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44275 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
44282 44283 44284 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44282 def partial_failure @partial_failure end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
44289 44290 44291 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44289 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44297 44298 44299 44300 44301 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44297 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @validate_only = args[:validate_only] if args.key?(:validate_only) end |