Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AdGroupCustomizerService.MutateAdGroupCustomizers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizersRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizersRequest.



45108
45109
45110
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45108

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCustomizerOperation>

Required. The list of operations to perform on individual ad group customizers. Corresponds to the JSON property operations



45085
45086
45087
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45085

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


45092
45093
45094
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45092

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


45099
45100
45101
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45099

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


45105
45106
45107
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45105

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45113
45114
45115
45116
45117
45118
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45113

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end