Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizersResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for an ad group customizer mutate.
Instance Attribute Summary collapse
-
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizerResult>
All results for the mutate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizersResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizersResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizersResponse.
45140 45141 45142 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45140 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property partialFailureError
45133 45134 45135 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45133 def partial_failure_error @partial_failure_error end |
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizerResult>
All results for the mutate.
Corresponds to the JSON property results
45138 45139 45140 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45138 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45145 45146 45147 45148 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45145 def update!(**args) @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error) @results = args[:results] if args.key?(:results) end |