Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AdGroupLabelService.MutateAdGroupLabels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdGroupLabelsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdGroupLabelsRequest.



44501
44502
44503
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupLabelOperation>

Required. The list of operations to perform on ad group labels. Corresponds to the JSON property operations



44484
44485
44486
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44484

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


44491
44492
44493
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44491

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


44498
44499
44500
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44498

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44506
44507
44508
44509
44510
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44506

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end