Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdParameterResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The result for the ad parameter mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdParameterResult

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdParameterResult.



44659
44660
44661
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44659

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_parameterGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAdParameter

An ad parameter that is used to update numeric values (such as prices or inventory levels) in any text line of an ad (including URLs). There can be a maximum of two AdParameters per ad group criterion. (One with parameter_index = 1 and one with parameter_index = 2.) In the ad the parameters are referenced by a placeholder of the form "param#:value". For example, "param1:$17" Corresponds to the JSON property adParameter



44652
44653
44654
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44652

def ad_parameter
  @ad_parameter
end

#resource_nameString

The resource name returned for successful operations. Corresponds to the JSON property resourceName

Returns:

  • (String)


44657
44658
44659
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44657

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44664
44665
44666
44667
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44664

def update!(**args)
  @ad_parameter = args[:ad_parameter] if args.key?(:ad_parameter)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end