Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdParametersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AdParameterService.MutateAdParameters

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdParametersRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdParametersRequest.



45393
45394
45395
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdParameterOperation>

Required. The list of operations to perform on individual ad parameters. Corresponds to the JSON property operations



45370
45371
45372
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45370

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


45377
45378
45379
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45377

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


45384
45385
45386
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45384

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


45390
45391
45392
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45390

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45398
45399
45400
45401
45402
45403
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45398

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end