Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for an ad mutate.
Instance Attribute Summary collapse
-
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdResult>
All results for the mutate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdsResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAdsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAdsResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAdsResponse.
44830 44831 44832 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property partialFailureError
44823 44824 44825 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44823 def partial_failure_error @partial_failure_error end |
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdResult>
All results for the mutate.
Corresponds to the JSON property results
44828 44829 44830 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44828 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44835 44836 44837 44838 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 44835 def update!(**args) @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error) @results = args[:results] if args.key?(:results) end |