Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupAssetsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AssetGroupAssetService.MutateAssetGroupAssets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetGroupAssetsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAssetGroupAssetsRequest.



45577
45578
45579
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation>

Required. The list of operations to perform on individual asset group assets. Corresponds to the JSON property operations



45560
45561
45562
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45560

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


45567
45568
45569
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45567

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


45574
45575
45576
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45574

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45582
45583
45584
45585
45586
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45582

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end