Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupSignalResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The result for the asset group signal mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetGroupSignalResult

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAssetGroupSignalResult.



45044
45045
45046
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_group_signalGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetGroupSignal

AssetGroupSignal represents a signal in an asset group. The existence of a signal tells the performance max campaign who's most likely to convert. Performance Max uses the signal to look for new people with similar or stronger intent to find conversions across Search, Display, Video, and more. Corresponds to the JSON property assetGroupSignal



45037
45038
45039
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45037

def asset_group_signal
  @asset_group_signal
end

#resource_nameString

Returned for successful operations. Corresponds to the JSON property resourceName

Returns:

  • (String)


45042
45043
45044
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45042

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45049
45050
45051
45052
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45049

def update!(**args)
  @asset_group_signal = args[:asset_group_signal] if args.key?(:asset_group_signal)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end