Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AssetGroupService.MutateAssetGroups.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupOperation>
Required.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetGroupsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAssetGroupsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetGroupsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAssetGroupsRequest.
45144 45145 45146 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupOperation>
Required. The list of operations to perform on individual asset groups.
Corresponds to the JSON property operations
45135 45136 45137 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45135 def operations @operations end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
45141 45142 45143 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45141 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45149 45150 45151 45152 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45149 def update!(**args) @operations = args[:operations] if args.key?(:operations) @validate_only = args[:validate_only] if args.key?(:validate_only) end |