Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for an asset group mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetGroupsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAssetGroupsResponse.



45867
45868
45869
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



45860
45861
45862
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45860

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupResult>

All results for the mutate. Corresponds to the JSON property results



45865
45866
45867
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45865

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45872
45873
45874
45875
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45872

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end