Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the asset mutate.
Instance Attribute Summary collapse
-
#asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAsset
Asset is a part of an ad which can be shared across multiple ads.
-
#resource_name ⇒ String
The resource name returned for successful operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAssetResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAssetResult.
45202 45203 45204 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45202 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAsset
Asset is a part of an ad which can be shared across multiple ads. It can be an
image (ImageAsset), a video (YoutubeVideoAsset), etc. Assets are immutable and
cannot be removed. To stop an asset from serving, remove the asset from the
entity that is using it.
Corresponds to the JSON property asset
45195 45196 45197 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45195 def asset @asset end |
#resource_name ⇒ String
The resource name returned for successful operations.
Corresponds to the JSON property resourceName
45200 45201 45202 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45200 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45207 45208 45209 45210 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45207 def update!(**args) @asset = args[:asset] if args.key?(:asset) @resource_name = args[:resource_name] if args.key?(:resource_name) end |