Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the asset set asset mutate.
Instance Attribute Summary collapse
-
#asset_set_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset
AssetSetAsset is the link between an asset and an asset set.
-
#resource_name ⇒ String
Returned for successful operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult.
45228 45229 45230 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_set_asset ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAssetSetAsset
AssetSetAsset is the link between an asset and an asset set. Adding an
AssetSetAsset links an asset with an asset set.
Corresponds to the JSON property assetSetAsset
45221 45222 45223 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45221 def asset_set_asset @asset_set_asset end |
#resource_name ⇒ String
Returned for successful operations.
Corresponds to the JSON property resourceName
45226 45227 45228 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45226 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45233 45234 45235 45236 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45233 def update!(**args) @asset_set_asset = args[:asset_set_asset] if args.key?(:asset_set_asset) @resource_name = args[:resource_name] if args.key?(:resource_name) end |