Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAudienceResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAudienceResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the audience mutate.
Instance Attribute Summary collapse
-
#audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAudience
Audience is an effective targeting option that lets you intersect different segment attributes, such as detailed demographics and affinities, to create audiences that represent sections of your target segments.
-
#resource_name ⇒ String
Returned for successful operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAudienceResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAudienceResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAudienceResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAudienceResult.
46193 46194 46195 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46193 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAudience
Audience is an effective targeting option that lets you intersect different
segment attributes, such as detailed demographics and affinities, to create
audiences that represent sections of your target segments.
Corresponds to the JSON property audience
46186 46187 46188 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46186 def audience @audience end |
#resource_name ⇒ String
Returned for successful operations.
Corresponds to the JSON property resourceName
46191 46192 46193 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46191 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46198 46199 46200 46201 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46198 def update!(**args) @audience = args[:audience] if args.key?(:audience) @resource_name = args[:resource_name] if args.key?(:resource_name) end |