Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAudienceResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAudienceResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the audience mutate.
Instance Attribute Summary collapse
-
#audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAudience
Audience is an effective targeting option that lets you intersect different segment attributes, such as detailed demographics and affinities, to create audiences that represent sections of your target segments.
-
#resource_name ⇒ String
Returned for successful operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAudienceResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAudienceResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAudienceResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAudienceResult.
45500 45501 45502 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45500 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesAudience
Audience is an effective targeting option that lets you intersect different
segment attributes, such as detailed demographics and affinities, to create
audiences that represent sections of your target segments.
Corresponds to the JSON property audience
45493 45494 45495 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45493 def audience @audience end |
#resource_name ⇒ String
Returned for successful operations.
Corresponds to the JSON property resourceName
45498 45499 45500 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45498 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45505 45506 45507 45508 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45505 def update!(**args) @audience = args[:audience] if args.key?(:audience) @resource_name = args[:resource_name] if args.key?(:resource_name) end |