Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAudiencesRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAudiencesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AudienceService.MutateAudiences.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAudiencesRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateAudiencesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateAudiencesRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateAudiencesRequest.
46306 46307 46308 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46306 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOperation>
Required. The list of operations to perform on individual audiences.
Corresponds to the JSON property operations
46283 46284 46285 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46283 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
46290 46291 46292 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46290 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
46297 46298 46299 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46297 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
46303 46304 46305 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46303 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46311 46312 46313 46314 46315 46316 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46311 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |