Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingDataExclusionsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingDataExclusionsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for BiddingDataExclusionService.MutateBiddingDataExclusions.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateBiddingDataExclusionsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateBiddingDataExclusionsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateBiddingDataExclusionsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateBiddingDataExclusionsRequest.
46436 46437 46438 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation>
Required. The list of operations to perform on individual data exclusions.
Corresponds to the JSON property operations
46413 46414 46415 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46413 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
46420 46421 46422 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46420 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
46427 46428 46429 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46427 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
46433 46434 46435 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46433 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46441 46442 46443 46444 46445 46446 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46441 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |