Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingSeasonalityAdjustmentsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingSeasonalityAdjustmentsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for BiddingSeasonalityAdjustmentService. MutateBiddingSeasonalityAdjustments.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateBiddingSeasonalityAdjustmentsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateBiddingSeasonalityAdjustmentsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateBiddingSeasonalityAdjustmentsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateBiddingSeasonalityAdjustmentsRequest.
45774 45775 45776 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45774 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation>
Required. The list of operations to perform on individual seasonality
adjustments.
Corresponds to the JSON property operations
45751 45752 45753 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45751 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
45758 45759 45760 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45758 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
45765 45766 45767 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45765 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
45771 45772 45773 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45771 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45779 45780 45781 45782 45783 45784 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45779 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |