Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingStrategiesRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingStrategiesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for BiddingStrategyService.MutateBiddingStrategies.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingStrategyOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateBiddingStrategiesRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateBiddingStrategiesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateBiddingStrategiesRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateBiddingStrategiesRequest.
45874 45875 45876 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45874 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingStrategyOperation>
Required. The list of operations to perform on individual bidding strategies.
Corresponds to the JSON property operations
45851 45852 45853 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45851 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
45858 45859 45860 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45858 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
45865 45866 45867 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45865 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
45871 45872 45873 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45871 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45879 45880 45881 45882 45883 45884 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45879 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |