Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBillingSetupRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBillingSetupRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for billing setup mutate operations.
Instance Attribute Summary collapse
-
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBillingSetupOperation
A single operation on a billing setup, which describes the cancellation of an existing billing setup.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateBillingSetupRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateBillingSetupRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateBillingSetupRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateBillingSetupRequest.
45952 45953 45954 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45952 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBillingSetupOperation
A single operation on a billing setup, which describes the cancellation of an
existing billing setup.
Corresponds to the JSON property operation
45950 45951 45952 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45950 def operation @operation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45957 45958 45959 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 45957 def update!(**args) @operation = args[:operation] if args.key?(:operation) end |