Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the campaign asset set mutate.
Instance Attribute Summary collapse
-
#campaign_asset_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAssetSet
CampaignAssetSet is the linkage between a campaign and an asset set.
-
#resource_name ⇒ String
Returned for successful operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetResult.
46040 46041 46042 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46040 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign_asset_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCampaignAssetSet
CampaignAssetSet is the linkage between a campaign and an asset set. Adding a
CampaignAssetSet links an asset set with a campaign.
Corresponds to the JSON property campaignAssetSet
46033 46034 46035 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46033 def campaign_asset_set @campaign_asset_set end |
#resource_name ⇒ String
Returned for successful operations.
Corresponds to the JSON property resourceName
46038 46039 46040 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46038 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46045 46046 46047 46048 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46045 def update!(**args) @campaign_asset_set = args[:campaign_asset_set] if args.key?(:campaign_asset_set) @resource_name = args[:resource_name] if args.key?(:resource_name) end |