Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CampaignAssetSetService.MutateCampaignAssetSets.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetSetOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetsRequest.
46774 46775 46776 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46774 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetSetOperation>
Required. The list of operations to perform on individual campaign asset sets.
Corresponds to the JSON property operations
46751 46752 46753 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46751 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
46758 46759 46760 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46758 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
46765 46766 46767 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46765 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
46771 46772 46773 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46771 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46779 46780 46781 46782 46783 46784 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46779 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |