Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CampaignAssetSetService.MutateCampaignAssetSets.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetSetOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetsRequest.
46081 46082 46083 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46081 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetSetOperation>
Required. The list of operations to perform on individual campaign asset sets.
Corresponds to the JSON property operations
46058 46059 46060 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46058 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
46065 46066 46067 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46065 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
46072 46073 46074 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46072 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
46078 46079 46080 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46078 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46086 46087 46088 46089 46090 46091 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46086 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |