Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CampaignAssetService.MutateCampaignAssets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignAssetsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignAssetsRequest.



46154
46155
46156
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46154

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetOperation>

Required. The list of operations to perform on individual campaign assets. Corresponds to the JSON property operations



46131
46132
46133
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46131

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


46138
46139
46140
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46138

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


46145
46146
46147
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46145

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


46151
46152
46153
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46151

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46159
46160
46161
46162
46163
46164
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46159

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end