Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for a campaign asset mutate.
Instance Attribute Summary collapse
-
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetResult>
All results for the mutate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignAssetsResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCampaignAssetsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignAssetsResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignAssetsResponse.
46879 46880 46881 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46879 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property partialFailureError
46872 46873 46874 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46872 def partial_failure_error @partial_failure_error end |
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetResult>
All results for the mutate.
Corresponds to the JSON property results
46877 46878 46879 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46877 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46884 46885 46886 46887 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46884 def update!(**args) @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error) @results = args[:results] if args.key?(:results) end |