Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBudgetsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CampaignBudgetService.MutateCampaignBudgets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignBudgetsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignBudgetsRequest.



47044
47045
47046
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetOperation>

Required. The list of operations to perform on individual campaign budgets. Corresponds to the JSON property operations



47021
47022
47023
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47021

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


47028
47029
47030
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47028

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


47035
47036
47037
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47035

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


47041
47042
47043
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47041

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47049
47050
47051
47052
47053
47054
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47049

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end