Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBudgetsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBudgetsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CampaignBudgetService.MutateCampaignBudgets.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignBudgetsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCampaignBudgetsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignBudgetsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignBudgetsRequest.
46351 46352 46353 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46351 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetOperation>
Required. The list of operations to perform on individual campaign budgets.
Corresponds to the JSON property operations
46328 46329 46330 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46328 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
46335 46336 46337 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46335 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
46342 46343 46344 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46342 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
46348 46349 46350 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46348 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46356 46357 46358 46359 46360 46361 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46356 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |