Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CampaignConversionGoalService. MutateCampaignConversionGoals.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation>
Required.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalsRequest.
47196 47197 47198 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47196 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation>
Required. The list of operations to perform on individual campaign conversion
goal.
Corresponds to the JSON property operations
47187 47188 47189 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47187 def operations @operations end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
47193 47194 47195 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47193 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47201 47202 47203 47204 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47201 def update!(**args) @operations = args[:operations] if args.key?(:operations) @validate_only = args[:validate_only] if args.key?(:validate_only) end |