Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CampaignConversionGoalService. MutateCampaignConversionGoals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalsRequest.



46431
46432
46433
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation>

Required. The list of operations to perform on individual campaign conversion goal. Corresponds to the JSON property operations



46422
46423
46424
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46422

def operations
  @operations
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


46428
46429
46430
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46428

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46436
46437
46438
46439
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46436

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end