Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCriteriaRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCriteriaRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CampaignCriterionService.MutateCampaignCriteria.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCriterionOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignCriteriaRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCampaignCriteriaRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignCriteriaRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignCriteriaRequest.
47256 47257 47258 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47256 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCriterionOperation>
Required. The list of operations to perform on individual criteria.
Corresponds to the JSON property operations
47233 47234 47235 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47233 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
47240 47241 47242 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47240 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
47247 47248 47249 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47247 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
47253 47254 47255 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47253 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47261 47262 47263 47264 47265 47266 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47261 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |