Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCustomizersRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCustomizersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CampaignCustomizerService.MutateCampaignCustomizers.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCustomizerOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignCustomizersRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCampaignCustomizersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignCustomizersRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignCustomizersRequest.
47308 47309 47310 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47308 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCustomizerOperation>
Required. The list of operations to perform on individual campaign customizers.
Corresponds to the JSON property operations
47285 47286 47287 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47285 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
47292 47293 47294 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47292 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
47299 47300 47301 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47299 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
47305 47306 47307 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47305 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47313 47314 47315 47316 47317 47318 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47313 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |