Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCustomizersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for a campaign customizer mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignCustomizersResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignCustomizersResponse.



47340
47341
47342
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47340

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



47333
47334
47335
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47333

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCustomizerResult>

All results for the mutate. Corresponds to the JSON property results



47338
47339
47340
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47338

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47345
47346
47347
47348
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47345

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end