Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignDraftsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignDraftsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for campaign draft mutate.
Instance Attribute Summary collapse
-
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignDraftResult>
All results for the mutate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignDraftsResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCampaignDraftsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignDraftsResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignDraftsResponse.
46745 46746 46747 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46745 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property partialFailureError
46738 46739 46740 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46738 def partial_failure_error @partial_failure_error end |
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignDraftResult>
All results for the mutate.
Corresponds to the JSON property results
46743 46744 46745 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46743 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46750 46751 46752 46753 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46750 def update!(**args) @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error) @results = args[:results] if args.key?(:results) end |