Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignGoalConfigsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CampaignGoalConfigService.MutateCampaignGoalConfigs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignGoalConfigsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignGoalConfigsRequest.



47492
47493
47494
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47492

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGoalConfigOperation>

Required. The list of operations to perform on the campaign goal configs. Corresponds to the JSON property operations



47475
47476
47477
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47475

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

Optional. If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


47482
47483
47484
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47482

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


47489
47490
47491
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47489

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47497
47498
47499
47500
47501
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47497

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end