Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignGoalConfigsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for a campaign goal config mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignGoalConfigsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignGoalConfigsResponse.



46830
46831
46832
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46830

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



46823
46824
46825
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46823

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignGoalConfigResult>

All results for the mutate. Corresponds to the JSON property results



46828
46829
46830
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46828

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46835
46836
46837
46838
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46835

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end