Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CampaignLabelService.MutateCampaignLabels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCampaignLabelsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCampaignLabelsRequest.



46982
46983
46984
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46982

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignLabelOperation>

Required. The list of operations to perform on campaign-label relationships. Corresponds to the JSON property operations



46965
46966
46967
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46965

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


46972
46973
46974
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46972

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


46979
46980
46981
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46979

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46987
46988
46989
46990
46991
# File 'lib/google/apis/searchads360_v23/classes.rb', line 46987

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end