Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionActionsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionActionsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for ConversionActionService.MutateConversionActions.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionActionOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionActionsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateConversionActionsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionActionsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateConversionActionsRequest.
48041 48042 48043 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48041 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionActionOperation>
Required. The list of operations to perform on individual conversion actions.
Corresponds to the JSON property operations
48018 48019 48020 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48018 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
48025 48026 48027 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48025 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
48032 48033 48034 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48032 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
48038 48039 48040 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48038 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48046 48047 48048 48049 48050 48051 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48046 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |