Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionCustomVariablesRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionCustomVariablesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for ConversionCustomVariableService. MutateConversionCustomVariables.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionCustomVariablesRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateConversionCustomVariablesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionCustomVariablesRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateConversionCustomVariablesRequest.
48143 48144 48145 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48143 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation>
Required. The list of operations to perform on individual conversion custom
variables.
Corresponds to the JSON property operations
48120 48121 48122 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48120 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
48127 48128 48129 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48127 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
48134 48135 48136 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48134 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
48140 48141 48142 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48140 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48148 48149 48150 48151 48152 48153 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48148 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |