Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionCustomVariablesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ConversionCustomVariableService. MutateConversionCustomVariables.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionCustomVariablesRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateConversionCustomVariablesRequest.



47378
47379
47380
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation>

Required. The list of operations to perform on individual conversion custom variables. Corresponds to the JSON property operations



47355
47356
47357
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47355

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


47362
47363
47364
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47362

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


47369
47370
47371
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47369

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


47375
47376
47377
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47375

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47383
47384
47385
47386
47387
47388
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47383

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end