Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for ConversionGoalCampaignConfigService. MutateConversionGoalCampaignConfigs.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionGoalCampaignConfigOperation>
Required.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigsRequest.
48164 48165 48166 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionGoalCampaignConfigOperation>
Required. The list of operations to perform on individual conversion goal
campaign config.
Corresponds to the JSON property operations
48149 48150 48151 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48149 def operations @operations end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
48155 48156 48157 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48155 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
48161 48162 48163 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48161 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48169 48170 48171 48172 48173 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48169 def update!(**args) @operations = args[:operations] if args.key?(:operations) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |