Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ConversionGoalCampaignConfigService. MutateConversionGoalCampaignConfigs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigsRequest.



47471
47472
47473
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47471

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionGoalCampaignConfigOperation>

Required. The list of operations to perform on individual conversion goal campaign config. Corresponds to the JSON property operations



47456
47457
47458
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47456

def operations
  @operations
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


47462
47463
47464
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47462

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


47468
47469
47470
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47468

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47476
47477
47478
47479
47480
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47476

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end