Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the conversion value rule set mutate.
Instance Attribute Summary collapse
-
#conversion_value_rule_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleSet
A conversion value rule set is a collection of conversion value rules that lets you adjust conversion values based on the dimensions specified in the
dimensionsfield. -
#resource_name ⇒ String
Returned for successful operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult.
47543 47544 47545 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_value_rule_set ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesConversionValueRuleSet
A conversion value rule set is a collection of conversion value rules that
lets you adjust conversion values based on the dimensions specified in the
dimensions field.
Corresponds to the JSON property conversionValueRuleSet
47536 47537 47538 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47536 def conversion_value_rule_set @conversion_value_rule_set end |
#resource_name ⇒ String
Returned for successful operations.
Corresponds to the JSON property resourceName
47541 47542 47543 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47541 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47548 47549 47550 47551 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47548 def update!(**args) @conversion_value_rule_set = args[:conversion_value_rule_set] if args.key?(:conversion_value_rule_set) @resource_name = args[:resource_name] if args.key?(:resource_name) end |