Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ConversionValueRuleSetService. MutateConversionValueRuleSets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetsRequest.



47586
47587
47588
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation>

Required. The list of operations to perform on individual conversion value rule sets. Corresponds to the JSON property operations



47563
47564
47565
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47563

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


47570
47571
47572
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47570

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


47577
47578
47579
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47577

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


47583
47584
47585
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47583

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47591
47592
47593
47594
47595
47596
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47591

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end