Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRulesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for ConversionValueRuleService.MutateConversionValueRules.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateConversionValueRulesResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateConversionValueRulesResponse.



47693
47694
47695
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47693

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



47686
47687
47688
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47686

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleResult>

All results for the mutate. Corresponds to the JSON property results



47691
47692
47693
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47691

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47698
47699
47700
47701
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47698

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end