Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomAudiencesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomAudienceService.MutateCustomAudiences.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomAudiencesRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomAudiencesRequest.



47739
47740
47741
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomAudienceOperation>

Required. The list of operations to perform on individual custom audiences. Corresponds to the JSON property operations



47730
47731
47732
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47730

def operations
  @operations
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


47736
47737
47738
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47736

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47744
47745
47746
47747
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47744

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end