Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the custom conversion goal mutate.
Instance Attribute Summary collapse
-
#custom_conversion_goal ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomConversionGoal
Custom conversion goal that can make arbitrary conversion actions biddable.
-
#resource_name ⇒ String
Returned for successful operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult.
47783 47784 47785 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47783 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_conversion_goal ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomConversionGoal
Custom conversion goal that can make arbitrary conversion actions biddable.
Corresponds to the JSON property customConversionGoal
47776 47777 47778 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47776 def custom_conversion_goal @custom_conversion_goal end |
#resource_name ⇒ String
Returned for successful operations.
Corresponds to the JSON property resourceName
47781 47782 47783 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47781 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47788 47789 47790 47791 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47788 def update!(**args) @custom_conversion_goal = args[:custom_conversion_goal] if args.key?(:custom_conversion_goal) @resource_name = args[:resource_name] if args.key?(:resource_name) end |