Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomInterestsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomInterestsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CustomInterestService.MutateCustomInterests.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomInterestOperation>
Required.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomInterestsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomInterestsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomInterestsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomInterestsRequest.
47883 47884 47885 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomInterestOperation>
Required. The list of operations to perform on individual custom interests.
Corresponds to the JSON property operations
47874 47875 47876 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47874 def operations @operations end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
47880 47881 47882 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47880 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47888 47889 47890 47891 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 47888 def update!(**args) @operations = args[:operations] if args.key?(:operations) @validate_only = args[:validate_only] if args.key?(:validate_only) end |