Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomerAssetSetService.MutateCustomerAssetSets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetsRequest.



48687
48688
48689
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48687

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetSetOperation>

Required. The list of operations to perform on individual customer asset sets. Corresponds to the JSON property operations



48664
48665
48666
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48664

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


48671
48672
48673
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48671

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


48678
48679
48680
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48678

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


48684
48685
48686
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48684

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48692
48693
48694
48695
48696
48697
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48692

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end