Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for a customer asset set mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetsResponse.



48026
48027
48028
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



48019
48020
48021
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48019

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerAssetSetResult>

All results for the mutate. Corresponds to the JSON property results



48024
48025
48026
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48024

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48031
48032
48033
48034
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48031

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end