Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerAssetsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerAssetsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CustomerAssetService.MutateCustomerAssets.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerAssetsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomerAssetsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerAssetsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerAssetsRequest.
48760 48761 48762 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetOperation>
Required. The list of operations to perform on individual customer assets.
Corresponds to the JSON property operations
48737 48738 48739 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48737 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
48744 48745 48746 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48744 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
48751 48752 48753 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48751 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
48757 48758 48759 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48757 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48765 48766 48767 48768 48769 48770 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48765 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |