Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CustomerClientLinkService.MutateCustomerClientLink.
Instance Attribute Summary collapse
-
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation
A single operation (create, update) on a CustomerClientLink.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerClientLinkRequest.
48126 48127 48128 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48126 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerClientLinkOperation
A single operation (create, update) on a CustomerClientLink.
Corresponds to the JSON property operation
48117 48118 48119 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48117 def operation @operation end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
48123 48124 48125 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48123 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48131 48132 48133 48134 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48131 def update!(**args) @operation = args[:operation] if args.key?(:operation) @validate_only = args[:validate_only] if args.key?(:validate_only) end |