Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerConversionGoalsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomerConversionGoalService. MutateCustomerConversionGoals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerConversionGoalsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerConversionGoalsRequest.



48212
48213
48214
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48212

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation>

Required. The list of operations to perform on individual customer conversion goal. Corresponds to the JSON property operations



48203
48204
48205
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48203

def operations
  @operations
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


48209
48210
48211
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48209

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48217
48218
48219
48220
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48217

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end