Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomerCustomizerService.MutateCustomerCustomizers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest.



48991
48992
48993
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48991

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation>

Required. The list of operations to perform on individual customer customizers. Corresponds to the JSON property operations



48968
48969
48970
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48968

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


48975
48976
48977
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48975

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


48982
48983
48984
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48982

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


48988
48989
48990
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48988

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48996
48997
48998
48999
49000
49001
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48996

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end