Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CustomerCustomizerService.MutateCustomerCustomizers.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerCustomizersRequest.
48298 48299 48300 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation>
Required. The list of operations to perform on individual customer customizers.
Corresponds to the JSON property operations
48275 48276 48277 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48275 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
48282 48283 48284 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48282 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
48289 48290 48291 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48289 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
48295 48296 48297 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48295 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48303 48304 48305 48306 48307 48308 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48303 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |