Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomerLabelService.MutateCustomerLabels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerLabelsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerLabelsRequest.



48384
48385
48386
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48384

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerLabelOperation>

Required. The list of operations to perform on customer-label relationships. Corresponds to the JSON property operations



48367
48368
48369
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48367

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


48374
48375
48376
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48374

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


48381
48382
48383
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48381

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48389
48390
48391
48392
48393
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48389

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end