Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerManagerLinkRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomerManagerLinkService.MutateCustomerManagerLink.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerManagerLinkRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerManagerLinkRequest.



48443
48444
48445
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerManagerLinkOperation>

Required. The list of operations to perform on individual customer manager links. Corresponds to the JSON property operations



48434
48435
48436
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48434

def operations
  @operations
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


48440
48441
48442
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48440

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48448
48449
48450
48451
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48448

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end