Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CustomerService.MutateCustomer.
Instance Attribute Summary collapse
-
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerOperation
A single update on a customer.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomerRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerRequest.
48613 48614 48615 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48613 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerOperation
A single update on a customer.
Corresponds to the JSON property operation
48598 48599 48600 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48598 def operation @operation end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
48604 48605 48606 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48604 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
48610 48611 48612 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48610 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48618 48619 48620 48621 48622 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48618 def update!(**args) @operation = args[:operation] if args.key?(:operation) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |