Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomerSkAdNetworkConversionValueSchemaService. MutateCustomerSkAdNetworkConversionValueSchema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaRequest.



49389
49390
49391
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49389

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_warningsBoolean Also known as: enable_warnings?

Optional. If true, enables returning warnings. Warnings return error messages and error codes without blocking the execution of the mutate operation. Corresponds to the JSON property enableWarnings

Returns:

  • (Boolean)


49374
49375
49376
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49374

def enable_warnings
  @enable_warnings
end

#operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerSkAdNetworkConversionValueSchemaOperation

A single update operation for a CustomerSkAdNetworkConversionValueSchema. Corresponds to the JSON property operation



49380
49381
49382
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49380

def operation
  @operation
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


49386
49387
49388
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49386

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49394
49395
49396
49397
49398
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49394

def update!(**args)
  @enable_warnings = args[:enable_warnings] if args.key?(:enable_warnings)
  @operation = args[:operation] if args.key?(:operation)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end