Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for CustomerSkAdNetworkConversionValueSchemaService. MutateCustomerSkAdNetworkConversionValueSchema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaRequest.



48693
48694
48695
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48693

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_warningsBoolean Also known as: enable_warnings?

Optional. If true, enables returning warnings. Warnings return error messages and error codes without blocking the execution of the mutate operation. Corresponds to the JSON property enableWarnings

Returns:

  • (Boolean)


48678
48679
48680
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48678

def enable_warnings
  @enable_warnings
end

#operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerSkAdNetworkConversionValueSchemaOperation

A single update operation for a CustomerSkAdNetworkConversionValueSchema. Corresponds to the JSON property operation



48684
48685
48686
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48684

def operation
  @operation
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


48690
48691
48692
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48690

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48698
48699
48700
48701
48702
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48698

def update!(**args)
  @enable_warnings = args[:enable_warnings] if args.key?(:enable_warnings)
  @operation = args[:operation] if args.key?(:operation)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end