Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for MutateCustomerSkAdNetworkConversionValueSchema.
Instance Attribute Summary collapse
-
#result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResult
The result for the CustomerSkAdNetworkConversionValueSchema mutate.
-
#warning ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse.
49492 49493 49494 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResult
The result for the CustomerSkAdNetworkConversionValueSchema mutate.
Corresponds to the JSON property result
49480 49481 49482 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49480 def result @result end |
#warning ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property warning
49490 49491 49492 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49490 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49497 49498 49499 49500 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49497 def update!(**args) @result = args[:result] if args.key?(:result) @warning = args[:warning] if args.key?(:warning) end |