Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for MutateCustomerSkAdNetworkConversionValueSchema.
Instance Attribute Summary collapse
-
#result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResult
The result for the CustomerSkAdNetworkConversionValueSchema mutate.
-
#warning ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse.
49420 49421 49422 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49420 def initialize(**args) update!(**args) end |
Instance Attribute Details
#result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResult
The result for the CustomerSkAdNetworkConversionValueSchema mutate.
Corresponds to the JSON property result
49408 49409 49410 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49408 def result @result end |
#warning ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property warning
49418 49419 49420 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49418 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49425 49426 49427 49428 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49425 def update!(**args) @result = args[:result] if args.key?(:result) @warning = args[:warning] if args.key?(:warning) end |