Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for MutateCustomerSkAdNetworkConversionValueSchema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResponse.



48724
48725
48726
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48724

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resultGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerSkAdNetworkConversionValueSchemaResult

The result for the CustomerSkAdNetworkConversionValueSchema mutate. Corresponds to the JSON property result



48712
48713
48714
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48712

def result
  @result
end

#warningGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property warning



48722
48723
48724
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48722

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48729
48730
48731
48732
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48729

def update!(**args)
  @result = args[:result] if args.key?(:result)
  @warning = args[:warning] if args.key?(:warning)
end