Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomizerAttributeResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The result for the customizer attribute mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomizerAttributeResult

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomizerAttributeResult.



48892
48893
48894
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customizer_attributeGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesCustomizerAttribute

A customizer attribute. Use CustomerCustomizer, CampaignCustomizer, AdGroupCustomizer, or AdGroupCriterionCustomizer to associate a customizer attribute and set its value at the customer, campaign, ad group, or ad group criterion level, respectively. Corresponds to the JSON property customizerAttribute



48885
48886
48887
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48885

def customizer_attribute
  @customizer_attribute
end

#resource_nameString

Returned for successful operations. Corresponds to the JSON property resourceName

Returns:

  • (String)


48890
48891
48892
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48890

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48897
48898
48899
48900
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48897

def update!(**args)
  @customizer_attribute = args[:customizer_attribute] if args.key?(:customizer_attribute)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end