Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomizerAttributesRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomizerAttributesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CustomizerAttributeService.MutateCustomizerAttributes.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomizerAttributeOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomizerAttributesRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateCustomizerAttributesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateCustomizerAttributesRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateCustomizerAttributesRequest.
49630 49631 49632 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49630 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomizerAttributeOperation>
Required. The list of operations to perform on individual customizer
attributes.
Corresponds to the JSON property operations
49607 49608 49609 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49607 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
49614 49615 49616 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49614 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
49621 49622 49623 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49621 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
49627 49628 49629 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49627 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49635 49636 49637 49638 49639 49640 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49635 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |