Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentArmResult
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentArmResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The result for the experiment arm mutate.
Instance Attribute Summary collapse
-
#experiment_arm ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArm
A Google ads experiment for users to experiment changes on multiple campaigns, compare the performance, and apply the effective changes.
-
#resource_name ⇒ String
Returned for successful operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateExperimentArmResult
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateExperimentArmResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateExperimentArmResult
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateExperimentArmResult.
49688 49689 49690 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49688 def initialize(**args) update!(**args) end |
Instance Attribute Details
#experiment_arm ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArm
A Google ads experiment for users to experiment changes on multiple campaigns,
compare the performance, and apply the effective changes.
Corresponds to the JSON property experimentArm
49681 49682 49683 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49681 def experiment_arm @experiment_arm end |
#resource_name ⇒ String
Returned for successful operations.
Corresponds to the JSON property resourceName
49686 49687 49688 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49686 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49693 49694 49695 49696 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49693 def update!(**args) @experiment_arm = args[:experiment_arm] if args.key?(:experiment_arm) @resource_name = args[:resource_name] if args.key?(:resource_name) end |