Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentArmResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The result for the experiment arm mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateExperimentArmResult

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateExperimentArmResult.



48992
48993
48994
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#experiment_armGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesExperimentArm

A Google ads experiment for users to experiment changes on multiple campaigns, compare the performance, and apply the effective changes. Corresponds to the JSON property experimentArm



48985
48986
48987
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48985

def experiment_arm
  @experiment_arm
end

#resource_nameString

Returned for successful operations. Corresponds to the JSON property resourceName

Returns:

  • (String)


48990
48991
48992
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48990

def resource_name
  @resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48997
48998
48999
49000
# File 'lib/google/apis/searchads360_v23/classes.rb', line 48997

def update!(**args)
  @experiment_arm = args[:experiment_arm] if args.key?(:experiment_arm)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
end