Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentArmsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ExperimentArmService.MutateExperimentArms.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateExperimentArmsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateExperimentArmsRequest.



49729
49730
49731
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentArmOperation>

Required. The list of operations to perform on individual experiment arm. Corresponds to the JSON property operations



49706
49707
49708
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49706

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


49713
49714
49715
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49713

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


49720
49721
49722
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49720

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


49726
49727
49728
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49726

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49734
49735
49736
49737
49738
49739
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49734

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end