Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ExperimentService.MutateExperiments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateExperimentsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateExperimentsRequest.



49119
49120
49121
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49119

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentOperation>

Required. The list of operations to perform on individual experiments. Corresponds to the JSON property operations



49102
49103
49104
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49102

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


49109
49110
49111
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49109

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


49116
49117
49118
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49116

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49124
49125
49126
49127
49128
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49124

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end