Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for KeywordPlanAdGroupKeywordService. MutateKeywordPlanAdGroupKeywords.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordsRequest.
50059 50060 50061 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50059 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation>
Required. The list of operations to perform on individual Keyword Plan ad
group keywords.
Corresponds to the JSON property operations
50042 50043 50044 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50042 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
50049 50050 50051 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50049 def partial_failure @partial_failure end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
50056 50057 50058 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50056 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50064 50065 50066 50067 50068 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50064 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @validate_only = args[:validate_only] if args.key?(:validate_only) end |