Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for KeywordPlanAdGroupKeywordService. MutateKeywordPlanAdGroupKeywords.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordsRequest.



49987
49988
49989
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49987

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation>

Required. The list of operations to perform on individual Keyword Plan ad group keywords. Corresponds to the JSON property operations



49970
49971
49972
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49970

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


49977
49978
49979
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49977

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


49984
49985
49986
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49984

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49992
49993
49994
49995
49996
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49992

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end