Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for KeywordPlanAdGroupService.MutateKeywordPlanAdGroups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupsRequest.



50073
50074
50075
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50073

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation>

Required. The list of operations to perform on individual Keyword Plan ad groups. Corresponds to the JSON property operations



50056
50057
50058
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50056

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


50063
50064
50065
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50063

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


50070
50071
50072
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50070

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50078
50079
50080
50081
50082
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50078

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end