Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for KeywordPlanAdGroupService.MutateKeywordPlanAdGroups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupsRequest.



49377
49378
49379
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation>

Required. The list of operations to perform on individual Keyword Plan ad groups. Corresponds to the JSON property operations



49360
49361
49362
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49360

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


49367
49368
49369
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49367

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


49374
49375
49376
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49374

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49382
49383
49384
49385
49386
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49382

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end