Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for a Keyword Plan ad group mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupsResponse.



49409
49410
49411
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49409

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



49401
49402
49403
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49401

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupResult>

All results for the mutate. The order of the results is determined by the order of the keywords in the original request. Corresponds to the JSON property results



49407
49408
49409
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49407

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49414
49415
49416
49417
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49414

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end