Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignKeywordsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for KeywordPlanCampaignKeywordService. MutateKeywordPlanCampaignKeywords.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignKeywordsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignKeywordsRequest.



50161
50162
50163
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50161

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation>

Required. The list of operations to perform on individual Keyword Plan campaign keywords. Corresponds to the JSON property operations



50144
50145
50146
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50144

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


50151
50152
50153
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50151

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


50158
50159
50160
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50158

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50166
50167
50168
50169
50170
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50166

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end