Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for KeywordPlanCampaignService.MutateKeywordPlanCampaigns.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignsRequest.
50319 50320 50321 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50319 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation>
Required. The list of operations to perform on individual Keyword Plan
campaigns.
Corresponds to the JSON property operations
50302 50303 50304 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50302 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
50309 50310 50311 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50309 def partial_failure @partial_failure end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
50316 50317 50318 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50316 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50324 50325 50326 50327 50328 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50324 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @validate_only = args[:validate_only] if args.key?(:validate_only) end |