Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for KeywordPlanCampaignService.MutateKeywordPlanCampaigns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignsRequest.



49551
49552
49553
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation>

Required. The list of operations to perform on individual Keyword Plan campaigns. Corresponds to the JSON property operations



49534
49535
49536
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49534

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


49541
49542
49543
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49541

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


49548
49549
49550
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49548

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49556
49557
49558
49559
49560
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49556

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end