Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for KeywordPlanService.MutateKeywordPlans.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlansRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlansRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlansRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlansRequest.
50313 50314 50315 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50313 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanOperation>
Required. The list of operations to perform on individual keyword plans.
Corresponds to the JSON property operations
50296 50297 50298 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50296 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
50303 50304 50305 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50303 def partial_failure @partial_failure end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
50310 50311 50312 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50310 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50318 50319 50320 50321 50322 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50318 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @validate_only = args[:validate_only] if args.key?(:validate_only) end |