Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for a keyword plan mutate.
Instance Attribute Summary collapse
-
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansResult>
All results for the mutate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlansResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlansResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlansResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlansResponse.
50344 50345 50346 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50344 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property partialFailureError
50337 50338 50339 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50337 def partial_failure_error @partial_failure_error end |
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansResult>
All results for the mutate.
Corresponds to the JSON property results
50342 50343 50344 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50342 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50349 50350 50351 50352 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50349 def update!(**args) @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error) @results = args[:results] if args.key?(:results) end |