Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for a keyword plan mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateKeywordPlansResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateKeywordPlansResponse.



49648
49649
49650
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49648

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



49641
49642
49643
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49641

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansResult>

All results for the mutate. Corresponds to the JSON property results



49646
49647
49648
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49646

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49653
49654
49655
49656
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49653

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end