Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for LabelService.MutateLabels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateLabelsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateLabelsRequest.



50429
50430
50431
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesLabelOperation>

Required. The list of operations to perform on labels. Corresponds to the JSON property operations



50406
50407
50408
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50406

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


50413
50414
50415
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50413

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


50420
50421
50422
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50420

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


50426
50427
50428
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50426

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50434
50435
50436
50437
50438
50439
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50434

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end