Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a resource.
Instance Attribute Summary collapse
-
#ad_group_ad_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation
A single operation (create, remove) on an ad group ad label.
-
#ad_group_ad_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdOperation
A single operation (create, update, remove) on an ad group ad.
-
#ad_group_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAssetOperation
A single operation (create, update, remove) on an ad group asset.
-
#ad_group_bid_modifier_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation
A single operation (create, remove, update) on an ad group bid modifier.
-
#ad_group_criterion_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionCustomizerOperation
A single operation (create, remove) on a customizer attribute.
-
#ad_group_criterion_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionLabelOperation
A single operation (create, remove) on an ad group criterion label.
-
#ad_group_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionOperation
A single operation (create, remove, update) on an ad group criterion.
-
#ad_group_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCustomizerOperation
A single operation (create, remove) on a customizer attribute.
-
#ad_group_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupLabelOperation
A single operation (create, remove) on an ad group label.
-
#ad_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupOperation
A single operation (create, update, remove) on an ad group.
-
#ad_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdOperation
A single update operation on an ad.
-
#ad_parameter_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdParameterOperation
A single operation (create, update, remove) on ad parameter.
-
#asset_group_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation
A single operation (create, remove) on an asset group asset.
-
#asset_group_listing_group_filter_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupListingGroupFilterOperation
A single operation (create, remove) on an asset group listing group filter.
-
#asset_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupOperation
A single operation (create, remove) on an asset group.
-
#asset_group_signal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupSignalOperation
A single operation (create, remove) on an asset group signal.
-
#asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetOperation
A single operation to create an asset.
-
#asset_set_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetAssetOperation
A single operation (create, remove) on an asset set asset.
-
#asset_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetOperation
A single operation (create, remove) on an asset set.
-
#audience_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOperation
A single operation (create, update) on an audience.
-
#bidding_data_exclusion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation
A single operation (create, remove, update) on a data exclusion.
-
#bidding_seasonality_adjustment_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation
A single operation (create, remove, update) on a seasonality adjustment.
-
#bidding_strategy_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingStrategyOperation
A single operation (create, update, remove) on a bidding strategy.
-
#campaign_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetOperation
A single operation (create, remove) on a campaign asset.
-
#campaign_asset_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetSetOperation
A single operation (create, remove) on a campaign asset set.
-
#campaign_bid_modifier_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation
A single operation (create, remove, update) on a campaign bid modifier.
-
#campaign_budget_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetOperation
A single operation (create, update, remove) on a campaign budget.
-
#campaign_conversion_goal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation
A single operation (update) on a campaign conversion goal.
-
#campaign_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCriterionOperation
A single operation (create, update, remove) on a campaign criterion.
-
#campaign_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCustomizerOperation
A single operation (create, remove) on a customizer attribute.
-
#campaign_draft_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignDraftOperation
A single operation (create, update, remove) on a campaign draft.
-
#campaign_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGroupOperation
A single operation (create, update, remove) on a campaign group.
-
#campaign_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignLabelOperation
A single operation (create, remove) on a campaign-label relationship.
-
#campaign_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignOperation
A single operation (create, update, remove) on a campaign.
-
#campaign_shared_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignSharedSetOperation
A single operation (create, remove) on a campaign shared set.
-
#conversion_action_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionActionOperation
A single operation (create, update, remove) on a conversion action.
-
#conversion_custom_variable_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation
A single operation (create, update) on a conversion custom variable.
-
#conversion_goal_campaign_config_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionGoalCampaignConfigOperation
A single operation (update) on a conversion goal campaign config.
-
#conversion_value_rule_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleOperation
A single operation (create, update, remove) on a conversion value rule.
-
#conversion_value_rule_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation
A single operation (create, update, remove) on a conversion value rule set.
-
#custom_conversion_goal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomConversionGoalOperation
A single operation (create, remove) on a custom conversion goal.
-
#customer_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetOperation
A single operation (create, update, remove) on a customer asset.
-
#customer_conversion_goal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation
A single operation (update) on a customer conversion goal.
-
#customer_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation
A single operation (create, remove) on a customizer attribute.
-
#customer_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerLabelOperation
A single operation (create, remove) on a customer-label relationship.
-
#customer_negative_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerNegativeCriterionOperation
A single operation (create or remove) on a customer level negative criterion.
-
#customer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerOperation
A single update on a customer.
-
#customizer_attribute_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomizerAttributeOperation
A single operation (create, remove) on a customizer attribute.
-
#experiment_arm_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentArmOperation
A single operation on an experiment arm.
-
#experiment_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentOperation
A single operation on an experiment.
-
#keyword_plan_ad_group_keyword_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation
A single operation (create, update, remove) on a Keyword Plan ad group keyword.
-
#keyword_plan_ad_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation
A single operation (create, update, remove) on a Keyword Plan ad group.
-
#keyword_plan_campaign_keyword_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation
A single operation (create, update, remove) on a Keyword Plan campaign keyword.
-
#keyword_plan_campaign_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation
A single operation (create, update, remove) on a Keyword Plan campaign.
-
#keyword_plan_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanOperation
A single operation (create, update, remove) on a keyword plan.
-
#label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesLabelOperation
A single operation (create, remove, update) on a label.
-
#recommendation_subscription_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRecommendationSubscriptionOperation
A single operation (create, update) on a recommendation subscription.
-
#remarketing_action_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemarketingActionOperation
A single operation (create, update) on a remarketing action.
-
#search_ads360_campaign_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation
A single operation (update) on a Search Ads 360 campaign.
-
#shared_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedCriterionOperation
A single operation (create, remove) on an shared criterion.
-
#shared_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedSetOperation
A single operation (create, update, remove) on an shared set.
-
#smart_campaign_setting_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSettingOperation
A single operation to update Smart campaign settings for a campaign.
-
#user_list_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUserListOperation
A single operation (create, update) on a user list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateOperation.
50867 50868 50869 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_ad_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation
A single operation (create, remove) on an ad group ad label.
Corresponds to the JSON property adGroupAdLabelOperation
50551 50552 50553 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50551 def ad_group_ad_label_operation @ad_group_ad_label_operation end |
#ad_group_ad_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdOperation
A single operation (create, update, remove) on an ad group ad.
Corresponds to the JSON property adGroupAdOperation
50556 50557 50558 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50556 def ad_group_ad_operation @ad_group_ad_operation end |
#ad_group_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAssetOperation
A single operation (create, update, remove) on an ad group asset.
Corresponds to the JSON property adGroupAssetOperation
50561 50562 50563 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50561 def ad_group_asset_operation @ad_group_asset_operation end |
#ad_group_bid_modifier_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation
A single operation (create, remove, update) on an ad group bid modifier.
Corresponds to the JSON property adGroupBidModifierOperation
50566 50567 50568 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50566 def ad_group_bid_modifier_operation @ad_group_bid_modifier_operation end |
#ad_group_criterion_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionCustomizerOperation
A single operation (create, remove) on a customizer attribute.
Corresponds to the JSON property adGroupCriterionCustomizerOperation
50571 50572 50573 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50571 def ad_group_criterion_customizer_operation @ad_group_criterion_customizer_operation end |
#ad_group_criterion_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionLabelOperation
A single operation (create, remove) on an ad group criterion label.
Corresponds to the JSON property adGroupCriterionLabelOperation
50576 50577 50578 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50576 def ad_group_criterion_label_operation @ad_group_criterion_label_operation end |
#ad_group_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionOperation
A single operation (create, remove, update) on an ad group criterion.
Corresponds to the JSON property adGroupCriterionOperation
50581 50582 50583 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50581 def ad_group_criterion_operation @ad_group_criterion_operation end |
#ad_group_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCustomizerOperation
A single operation (create, remove) on a customizer attribute.
Corresponds to the JSON property adGroupCustomizerOperation
50586 50587 50588 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50586 def ad_group_customizer_operation @ad_group_customizer_operation end |
#ad_group_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupLabelOperation
A single operation (create, remove) on an ad group label.
Corresponds to the JSON property adGroupLabelOperation
50591 50592 50593 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50591 def ad_group_label_operation @ad_group_label_operation end |
#ad_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupOperation
A single operation (create, update, remove) on an ad group.
Corresponds to the JSON property adGroupOperation
50596 50597 50598 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50596 def ad_group_operation @ad_group_operation end |
#ad_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdOperation
A single update operation on an ad.
Corresponds to the JSON property adOperation
50601 50602 50603 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50601 def ad_operation @ad_operation end |
#ad_parameter_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdParameterOperation
A single operation (create, update, remove) on ad parameter.
Corresponds to the JSON property adParameterOperation
50606 50607 50608 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50606 def ad_parameter_operation @ad_parameter_operation end |
#asset_group_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation
A single operation (create, remove) on an asset group asset.
Corresponds to the JSON property assetGroupAssetOperation
50611 50612 50613 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50611 def asset_group_asset_operation @asset_group_asset_operation end |
#asset_group_listing_group_filter_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupListingGroupFilterOperation
A single operation (create, remove) on an asset group listing group filter.
Corresponds to the JSON property assetGroupListingGroupFilterOperation
50616 50617 50618 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50616 def asset_group_listing_group_filter_operation @asset_group_listing_group_filter_operation end |
#asset_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupOperation
A single operation (create, remove) on an asset group.
Corresponds to the JSON property assetGroupOperation
50621 50622 50623 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50621 def asset_group_operation @asset_group_operation end |
#asset_group_signal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupSignalOperation
A single operation (create, remove) on an asset group signal.
Corresponds to the JSON property assetGroupSignalOperation
50626 50627 50628 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50626 def asset_group_signal_operation @asset_group_signal_operation end |
#asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetOperation
A single operation to create an asset. Supported asset types are
YoutubeVideoAsset, MediaBundleAsset, ImageAsset, LeadFormAsset, LocationAsset,
and ImageAsset. TextAsset can be created with an Ad inline, but it can also be
created apart from an Ad like other assets.
Corresponds to the JSON property assetOperation
50634 50635 50636 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50634 def asset_operation @asset_operation end |
#asset_set_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetAssetOperation
A single operation (create, remove) on an asset set asset.
Corresponds to the JSON property assetSetAssetOperation
50639 50640 50641 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50639 def asset_set_asset_operation @asset_set_asset_operation end |
#asset_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetOperation
A single operation (create, remove) on an asset set.
Corresponds to the JSON property assetSetOperation
50644 50645 50646 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50644 def asset_set_operation @asset_set_operation end |
#audience_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOperation
A single operation (create, update) on an audience.
Corresponds to the JSON property audienceOperation
50649 50650 50651 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50649 def audience_operation @audience_operation end |
#bidding_data_exclusion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation
A single operation (create, remove, update) on a data exclusion.
Corresponds to the JSON property biddingDataExclusionOperation
50654 50655 50656 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50654 def bidding_data_exclusion_operation @bidding_data_exclusion_operation end |
#bidding_seasonality_adjustment_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation
A single operation (create, remove, update) on a seasonality adjustment.
Corresponds to the JSON property biddingSeasonalityAdjustmentOperation
50659 50660 50661 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50659 def bidding_seasonality_adjustment_operation @bidding_seasonality_adjustment_operation end |
#bidding_strategy_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingStrategyOperation
A single operation (create, update, remove) on a bidding strategy.
Corresponds to the JSON property biddingStrategyOperation
50664 50665 50666 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50664 def bidding_strategy_operation @bidding_strategy_operation end |
#campaign_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetOperation
A single operation (create, remove) on a campaign asset.
Corresponds to the JSON property campaignAssetOperation
50669 50670 50671 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50669 def campaign_asset_operation @campaign_asset_operation end |
#campaign_asset_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetSetOperation
A single operation (create, remove) on a campaign asset set.
Corresponds to the JSON property campaignAssetSetOperation
50674 50675 50676 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50674 def campaign_asset_set_operation @campaign_asset_set_operation end |
#campaign_bid_modifier_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation
A single operation (create, remove, update) on a campaign bid modifier.
Corresponds to the JSON property campaignBidModifierOperation
50679 50680 50681 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50679 def campaign_bid_modifier_operation @campaign_bid_modifier_operation end |
#campaign_budget_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetOperation
A single operation (create, update, remove) on a campaign budget.
Corresponds to the JSON property campaignBudgetOperation
50684 50685 50686 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50684 def campaign_budget_operation @campaign_budget_operation end |
#campaign_conversion_goal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation
A single operation (update) on a campaign conversion goal.
Corresponds to the JSON property campaignConversionGoalOperation
50689 50690 50691 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50689 def campaign_conversion_goal_operation @campaign_conversion_goal_operation end |
#campaign_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCriterionOperation
A single operation (create, update, remove) on a campaign criterion.
Corresponds to the JSON property campaignCriterionOperation
50694 50695 50696 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50694 def campaign_criterion_operation @campaign_criterion_operation end |
#campaign_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCustomizerOperation
A single operation (create, remove) on a customizer attribute.
Corresponds to the JSON property campaignCustomizerOperation
50699 50700 50701 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50699 def campaign_customizer_operation @campaign_customizer_operation end |
#campaign_draft_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignDraftOperation
A single operation (create, update, remove) on a campaign draft.
Corresponds to the JSON property campaignDraftOperation
50704 50705 50706 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50704 def campaign_draft_operation @campaign_draft_operation end |
#campaign_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGroupOperation
A single operation (create, update, remove) on a campaign group.
Corresponds to the JSON property campaignGroupOperation
50709 50710 50711 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50709 def campaign_group_operation @campaign_group_operation end |
#campaign_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignLabelOperation
A single operation (create, remove) on a campaign-label relationship.
Corresponds to the JSON property campaignLabelOperation
50714 50715 50716 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50714 def campaign_label_operation @campaign_label_operation end |
#campaign_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignOperation
A single operation (create, update, remove) on a campaign.
Corresponds to the JSON property campaignOperation
50719 50720 50721 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50719 def campaign_operation @campaign_operation end |
#campaign_shared_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignSharedSetOperation
A single operation (create, remove) on a campaign shared set.
Corresponds to the JSON property campaignSharedSetOperation
50724 50725 50726 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50724 def campaign_shared_set_operation @campaign_shared_set_operation end |
#conversion_action_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionActionOperation
A single operation (create, update, remove) on a conversion action.
Corresponds to the JSON property conversionActionOperation
50729 50730 50731 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50729 def conversion_action_operation @conversion_action_operation end |
#conversion_custom_variable_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation
A single operation (create, update) on a conversion custom variable.
Corresponds to the JSON property conversionCustomVariableOperation
50734 50735 50736 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50734 def conversion_custom_variable_operation @conversion_custom_variable_operation end |
#conversion_goal_campaign_config_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionGoalCampaignConfigOperation
A single operation (update) on a conversion goal campaign config.
Corresponds to the JSON property conversionGoalCampaignConfigOperation
50739 50740 50741 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50739 def conversion_goal_campaign_config_operation @conversion_goal_campaign_config_operation end |
#conversion_value_rule_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleOperation
A single operation (create, update, remove) on a conversion value rule.
Corresponds to the JSON property conversionValueRuleOperation
50744 50745 50746 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50744 def conversion_value_rule_operation @conversion_value_rule_operation end |
#conversion_value_rule_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation
A single operation (create, update, remove) on a conversion value rule set.
Corresponds to the JSON property conversionValueRuleSetOperation
50749 50750 50751 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50749 def conversion_value_rule_set_operation @conversion_value_rule_set_operation end |
#custom_conversion_goal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomConversionGoalOperation
A single operation (create, remove) on a custom conversion goal.
Corresponds to the JSON property customConversionGoalOperation
50754 50755 50756 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50754 def custom_conversion_goal_operation @custom_conversion_goal_operation end |
#customer_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetOperation
A single operation (create, update, remove) on a customer asset.
Corresponds to the JSON property customerAssetOperation
50759 50760 50761 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50759 def customer_asset_operation @customer_asset_operation end |
#customer_conversion_goal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation
A single operation (update) on a customer conversion goal.
Corresponds to the JSON property customerConversionGoalOperation
50764 50765 50766 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50764 def customer_conversion_goal_operation @customer_conversion_goal_operation end |
#customer_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation
A single operation (create, remove) on a customizer attribute.
Corresponds to the JSON property customerCustomizerOperation
50769 50770 50771 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50769 def customer_customizer_operation @customer_customizer_operation end |
#customer_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerLabelOperation
A single operation (create, remove) on a customer-label relationship.
Corresponds to the JSON property customerLabelOperation
50774 50775 50776 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50774 def customer_label_operation @customer_label_operation end |
#customer_negative_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerNegativeCriterionOperation
A single operation (create or remove) on a customer level negative criterion.
Corresponds to the JSON property customerNegativeCriterionOperation
50779 50780 50781 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50779 def customer_negative_criterion_operation @customer_negative_criterion_operation end |
#customer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerOperation
A single update on a customer.
Corresponds to the JSON property customerOperation
50784 50785 50786 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50784 def customer_operation @customer_operation end |
#customizer_attribute_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomizerAttributeOperation
A single operation (create, remove) on a customizer attribute.
Corresponds to the JSON property customizerAttributeOperation
50789 50790 50791 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50789 def customizer_attribute_operation @customizer_attribute_operation end |
#experiment_arm_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentArmOperation
A single operation on an experiment arm.
Corresponds to the JSON property experimentArmOperation
50794 50795 50796 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50794 def experiment_arm_operation @experiment_arm_operation end |
#experiment_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentOperation
A single operation on an experiment.
Corresponds to the JSON property experimentOperation
50799 50800 50801 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50799 def experiment_operation @experiment_operation end |
#keyword_plan_ad_group_keyword_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation
A single operation (create, update, remove) on a Keyword Plan ad group keyword.
Corresponds to the JSON property keywordPlanAdGroupKeywordOperation
50804 50805 50806 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50804 def keyword_plan_ad_group_keyword_operation @keyword_plan_ad_group_keyword_operation end |
#keyword_plan_ad_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation
A single operation (create, update, remove) on a Keyword Plan ad group.
Corresponds to the JSON property keywordPlanAdGroupOperation
50809 50810 50811 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50809 def keyword_plan_ad_group_operation @keyword_plan_ad_group_operation end |
#keyword_plan_campaign_keyword_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation
A single operation (create, update, remove) on a Keyword Plan campaign keyword.
Corresponds to the JSON property keywordPlanCampaignKeywordOperation
50814 50815 50816 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50814 def keyword_plan_campaign_keyword_operation @keyword_plan_campaign_keyword_operation end |
#keyword_plan_campaign_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation
A single operation (create, update, remove) on a Keyword Plan campaign.
Corresponds to the JSON property keywordPlanCampaignOperation
50819 50820 50821 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50819 def keyword_plan_campaign_operation @keyword_plan_campaign_operation end |
#keyword_plan_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanOperation
A single operation (create, update, remove) on a keyword plan.
Corresponds to the JSON property keywordPlanOperation
50824 50825 50826 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50824 def keyword_plan_operation @keyword_plan_operation end |
#label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesLabelOperation
A single operation (create, remove, update) on a label.
Corresponds to the JSON property labelOperation
50829 50830 50831 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50829 def label_operation @label_operation end |
#recommendation_subscription_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRecommendationSubscriptionOperation
A single operation (create, update) on a recommendation subscription.
RecommendationSubscriptionService.MutateRecommendationSubscription
Corresponds to the JSON property recommendationSubscriptionOperation
50835 50836 50837 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50835 def recommendation_subscription_operation @recommendation_subscription_operation end |
#remarketing_action_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemarketingActionOperation
A single operation (create, update) on a remarketing action.
Corresponds to the JSON property remarketingActionOperation
50840 50841 50842 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50840 def remarketing_action_operation @remarketing_action_operation end |
#search_ads360_campaign_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation
A single operation (update) on a Search Ads 360 campaign.
Corresponds to the JSON property searchAds360CampaignOperation
50845 50846 50847 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50845 def search_ads360_campaign_operation @search_ads360_campaign_operation end |
#shared_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedCriterionOperation
A single operation (create, remove) on an shared criterion.
Corresponds to the JSON property sharedCriterionOperation
50850 50851 50852 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50850 def shared_criterion_operation @shared_criterion_operation end |
#shared_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedSetOperation
A single operation (create, update, remove) on an shared set.
Corresponds to the JSON property sharedSetOperation
50855 50856 50857 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50855 def shared_set_operation @shared_set_operation end |
#smart_campaign_setting_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSettingOperation
A single operation to update Smart campaign settings for a campaign.
Corresponds to the JSON property smartCampaignSettingOperation
50860 50861 50862 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50860 def smart_campaign_setting_operation @smart_campaign_setting_operation end |
#user_list_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUserListOperation
A single operation (create, update) on a user list.
Corresponds to the JSON property userListOperation
50865 50866 50867 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50865 def user_list_operation @user_list_operation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50872 50873 50874 50875 50876 50877 50878 50879 50880 50881 50882 50883 50884 50885 50886 50887 50888 50889 50890 50891 50892 50893 50894 50895 50896 50897 50898 50899 50900 50901 50902 50903 50904 50905 50906 50907 50908 50909 50910 50911 50912 50913 50914 50915 50916 50917 50918 50919 50920 50921 50922 50923 50924 50925 50926 50927 50928 50929 50930 50931 50932 50933 50934 50935 50936 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50872 def update!(**args) @ad_group_ad_label_operation = args[:ad_group_ad_label_operation] if args.key?(:ad_group_ad_label_operation) @ad_group_ad_operation = args[:ad_group_ad_operation] if args.key?(:ad_group_ad_operation) @ad_group_asset_operation = args[:ad_group_asset_operation] if args.key?(:ad_group_asset_operation) @ad_group_bid_modifier_operation = args[:ad_group_bid_modifier_operation] if args.key?(:ad_group_bid_modifier_operation) @ad_group_criterion_customizer_operation = args[:ad_group_criterion_customizer_operation] if args.key?(:ad_group_criterion_customizer_operation) @ad_group_criterion_label_operation = args[:ad_group_criterion_label_operation] if args.key?(:ad_group_criterion_label_operation) @ad_group_criterion_operation = args[:ad_group_criterion_operation] if args.key?(:ad_group_criterion_operation) @ad_group_customizer_operation = args[:ad_group_customizer_operation] if args.key?(:ad_group_customizer_operation) @ad_group_label_operation = args[:ad_group_label_operation] if args.key?(:ad_group_label_operation) @ad_group_operation = args[:ad_group_operation] if args.key?(:ad_group_operation) @ad_operation = args[:ad_operation] if args.key?(:ad_operation) @ad_parameter_operation = args[:ad_parameter_operation] if args.key?(:ad_parameter_operation) @asset_group_asset_operation = args[:asset_group_asset_operation] if args.key?(:asset_group_asset_operation) @asset_group_listing_group_filter_operation = args[:asset_group_listing_group_filter_operation] if args.key?(:asset_group_listing_group_filter_operation) @asset_group_operation = args[:asset_group_operation] if args.key?(:asset_group_operation) @asset_group_signal_operation = args[:asset_group_signal_operation] if args.key?(:asset_group_signal_operation) @asset_operation = args[:asset_operation] if args.key?(:asset_operation) @asset_set_asset_operation = args[:asset_set_asset_operation] if args.key?(:asset_set_asset_operation) @asset_set_operation = args[:asset_set_operation] if args.key?(:asset_set_operation) @audience_operation = args[:audience_operation] if args.key?(:audience_operation) @bidding_data_exclusion_operation = args[:bidding_data_exclusion_operation] if args.key?(:bidding_data_exclusion_operation) @bidding_seasonality_adjustment_operation = args[:bidding_seasonality_adjustment_operation] if args.key?(:bidding_seasonality_adjustment_operation) @bidding_strategy_operation = args[:bidding_strategy_operation] if args.key?(:bidding_strategy_operation) @campaign_asset_operation = args[:campaign_asset_operation] if args.key?(:campaign_asset_operation) @campaign_asset_set_operation = args[:campaign_asset_set_operation] if args.key?(:campaign_asset_set_operation) @campaign_bid_modifier_operation = args[:campaign_bid_modifier_operation] if args.key?(:campaign_bid_modifier_operation) @campaign_budget_operation = args[:campaign_budget_operation] if args.key?(:campaign_budget_operation) @campaign_conversion_goal_operation = args[:campaign_conversion_goal_operation] if args.key?(:campaign_conversion_goal_operation) @campaign_criterion_operation = args[:campaign_criterion_operation] if args.key?(:campaign_criterion_operation) @campaign_customizer_operation = args[:campaign_customizer_operation] if args.key?(:campaign_customizer_operation) @campaign_draft_operation = args[:campaign_draft_operation] if args.key?(:campaign_draft_operation) @campaign_group_operation = args[:campaign_group_operation] if args.key?(:campaign_group_operation) @campaign_label_operation = args[:campaign_label_operation] if args.key?(:campaign_label_operation) @campaign_operation = args[:campaign_operation] if args.key?(:campaign_operation) @campaign_shared_set_operation = args[:campaign_shared_set_operation] if args.key?(:campaign_shared_set_operation) @conversion_action_operation = args[:conversion_action_operation] if args.key?(:conversion_action_operation) @conversion_custom_variable_operation = args[:conversion_custom_variable_operation] if args.key?(:conversion_custom_variable_operation) @conversion_goal_campaign_config_operation = args[:conversion_goal_campaign_config_operation] if args.key?(:conversion_goal_campaign_config_operation) @conversion_value_rule_operation = args[:conversion_value_rule_operation] if args.key?(:conversion_value_rule_operation) @conversion_value_rule_set_operation = args[:conversion_value_rule_set_operation] if args.key?(:conversion_value_rule_set_operation) @custom_conversion_goal_operation = args[:custom_conversion_goal_operation] if args.key?(:custom_conversion_goal_operation) @customer_asset_operation = args[:customer_asset_operation] if args.key?(:customer_asset_operation) @customer_conversion_goal_operation = args[:customer_conversion_goal_operation] if args.key?(:customer_conversion_goal_operation) @customer_customizer_operation = args[:customer_customizer_operation] if args.key?(:customer_customizer_operation) @customer_label_operation = args[:customer_label_operation] if args.key?(:customer_label_operation) @customer_negative_criterion_operation = args[:customer_negative_criterion_operation] if args.key?(:customer_negative_criterion_operation) @customer_operation = args[:customer_operation] if args.key?(:customer_operation) @customizer_attribute_operation = args[:customizer_attribute_operation] if args.key?(:customizer_attribute_operation) @experiment_arm_operation = args[:experiment_arm_operation] if args.key?(:experiment_arm_operation) @experiment_operation = args[:experiment_operation] if args.key?(:experiment_operation) @keyword_plan_ad_group_keyword_operation = args[:keyword_plan_ad_group_keyword_operation] if args.key?(:keyword_plan_ad_group_keyword_operation) @keyword_plan_ad_group_operation = args[:keyword_plan_ad_group_operation] if args.key?(:keyword_plan_ad_group_operation) @keyword_plan_campaign_keyword_operation = args[:keyword_plan_campaign_keyword_operation] if args.key?(:keyword_plan_campaign_keyword_operation) @keyword_plan_campaign_operation = args[:keyword_plan_campaign_operation] if args.key?(:keyword_plan_campaign_operation) @keyword_plan_operation = args[:keyword_plan_operation] if args.key?(:keyword_plan_operation) @label_operation = args[:label_operation] if args.key?(:label_operation) @recommendation_subscription_operation = args[:recommendation_subscription_operation] if args.key?(:recommendation_subscription_operation) @remarketing_action_operation = args[:remarketing_action_operation] if args.key?(:remarketing_action_operation) @search_ads360_campaign_operation = args[:search_ads360_campaign_operation] if args.key?(:search_ads360_campaign_operation) @shared_criterion_operation = args[:shared_criterion_operation] if args.key?(:shared_criterion_operation) @shared_set_operation = args[:shared_set_operation] if args.key?(:shared_set_operation) @smart_campaign_setting_operation = args[:smart_campaign_setting_operation] if args.key?(:smart_campaign_setting_operation) @user_list_operation = args[:user_list_operation] if args.key?(:user_list_operation) end |