Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateOperation.



50795
50796
50797
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_ad_label_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation

A single operation (create, remove) on an ad group ad label. Corresponds to the JSON property adGroupAdLabelOperation



50479
50480
50481
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50479

def ad_group_ad_label_operation
  @ad_group_ad_label_operation
end

#ad_group_ad_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdOperation

A single operation (create, update, remove) on an ad group ad. Corresponds to the JSON property adGroupAdOperation



50484
50485
50486
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50484

def ad_group_ad_operation
  @ad_group_ad_operation
end

#ad_group_asset_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAssetOperation

A single operation (create, update, remove) on an ad group asset. Corresponds to the JSON property adGroupAssetOperation



50489
50490
50491
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50489

def ad_group_asset_operation
  @ad_group_asset_operation
end

#ad_group_bid_modifier_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation

A single operation (create, remove, update) on an ad group bid modifier. Corresponds to the JSON property adGroupBidModifierOperation



50494
50495
50496
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50494

def ad_group_bid_modifier_operation
  @ad_group_bid_modifier_operation
end

#ad_group_criterion_customizer_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionCustomizerOperation

A single operation (create, remove) on a customizer attribute. Corresponds to the JSON property adGroupCriterionCustomizerOperation



50499
50500
50501
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50499

def ad_group_criterion_customizer_operation
  @ad_group_criterion_customizer_operation
end

#ad_group_criterion_label_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionLabelOperation

A single operation (create, remove) on an ad group criterion label. Corresponds to the JSON property adGroupCriterionLabelOperation



50504
50505
50506
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50504

def ad_group_criterion_label_operation
  @ad_group_criterion_label_operation
end

#ad_group_criterion_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionOperation

A single operation (create, remove, update) on an ad group criterion. Corresponds to the JSON property adGroupCriterionOperation



50509
50510
50511
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50509

def ad_group_criterion_operation
  @ad_group_criterion_operation
end

#ad_group_customizer_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCustomizerOperation

A single operation (create, remove) on a customizer attribute. Corresponds to the JSON property adGroupCustomizerOperation



50514
50515
50516
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50514

def ad_group_customizer_operation
  @ad_group_customizer_operation
end

#ad_group_label_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupLabelOperation

A single operation (create, remove) on an ad group label. Corresponds to the JSON property adGroupLabelOperation



50519
50520
50521
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50519

def ad_group_label_operation
  @ad_group_label_operation
end

#ad_group_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupOperation

A single operation (create, update, remove) on an ad group. Corresponds to the JSON property adGroupOperation



50524
50525
50526
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50524

def ad_group_operation
  @ad_group_operation
end

#ad_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdOperation

A single update operation on an ad. Corresponds to the JSON property adOperation



50529
50530
50531
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50529

def ad_operation
  @ad_operation
end

#ad_parameter_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdParameterOperation

A single operation (create, update, remove) on ad parameter. Corresponds to the JSON property adParameterOperation



50534
50535
50536
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50534

def ad_parameter_operation
  @ad_parameter_operation
end

#asset_group_asset_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation

A single operation (create, remove) on an asset group asset. Corresponds to the JSON property assetGroupAssetOperation



50539
50540
50541
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50539

def asset_group_asset_operation
  @asset_group_asset_operation
end

#asset_group_listing_group_filter_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupListingGroupFilterOperation

A single operation (create, remove) on an asset group listing group filter. Corresponds to the JSON property assetGroupListingGroupFilterOperation



50544
50545
50546
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50544

def asset_group_listing_group_filter_operation
  @asset_group_listing_group_filter_operation
end

#asset_group_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupOperation

A single operation (create, remove) on an asset group. Corresponds to the JSON property assetGroupOperation



50549
50550
50551
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50549

def asset_group_operation
  @asset_group_operation
end

#asset_group_signal_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupSignalOperation

A single operation (create, remove) on an asset group signal. Corresponds to the JSON property assetGroupSignalOperation



50554
50555
50556
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50554

def asset_group_signal_operation
  @asset_group_signal_operation
end

#asset_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetOperation

A single operation to create an asset. Supported asset types are YoutubeVideoAsset, MediaBundleAsset, ImageAsset, LeadFormAsset, LocationAsset, and ImageAsset. TextAsset can be created with an Ad inline, but it can also be created apart from an Ad like other assets. Corresponds to the JSON property assetOperation



50562
50563
50564
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50562

def asset_operation
  @asset_operation
end

#asset_set_asset_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetAssetOperation

A single operation (create, remove) on an asset set asset. Corresponds to the JSON property assetSetAssetOperation



50567
50568
50569
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50567

def asset_set_asset_operation
  @asset_set_asset_operation
end

#asset_set_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetOperation

A single operation (create, remove) on an asset set. Corresponds to the JSON property assetSetOperation



50572
50573
50574
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50572

def asset_set_operation
  @asset_set_operation
end

#audience_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOperation

A single operation (create, update) on an audience. Corresponds to the JSON property audienceOperation



50577
50578
50579
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50577

def audience_operation
  @audience_operation
end

#bidding_data_exclusion_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation

A single operation (create, remove, update) on a data exclusion. Corresponds to the JSON property biddingDataExclusionOperation



50582
50583
50584
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50582

def bidding_data_exclusion_operation
  @bidding_data_exclusion_operation
end

#bidding_seasonality_adjustment_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation

A single operation (create, remove, update) on a seasonality adjustment. Corresponds to the JSON property biddingSeasonalityAdjustmentOperation



50587
50588
50589
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50587

def bidding_seasonality_adjustment_operation
  @bidding_seasonality_adjustment_operation
end

#bidding_strategy_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingStrategyOperation

A single operation (create, update, remove) on a bidding strategy. Corresponds to the JSON property biddingStrategyOperation



50592
50593
50594
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50592

def bidding_strategy_operation
  @bidding_strategy_operation
end

#campaign_asset_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetOperation

A single operation (create, remove) on a campaign asset. Corresponds to the JSON property campaignAssetOperation



50597
50598
50599
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50597

def campaign_asset_operation
  @campaign_asset_operation
end

#campaign_asset_set_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetSetOperation

A single operation (create, remove) on a campaign asset set. Corresponds to the JSON property campaignAssetSetOperation



50602
50603
50604
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50602

def campaign_asset_set_operation
  @campaign_asset_set_operation
end

#campaign_bid_modifier_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation

A single operation (create, remove, update) on a campaign bid modifier. Corresponds to the JSON property campaignBidModifierOperation



50607
50608
50609
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50607

def campaign_bid_modifier_operation
  @campaign_bid_modifier_operation
end

#campaign_budget_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetOperation

A single operation (create, update, remove) on a campaign budget. Corresponds to the JSON property campaignBudgetOperation



50612
50613
50614
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50612

def campaign_budget_operation
  @campaign_budget_operation
end

#campaign_conversion_goal_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation

A single operation (update) on a campaign conversion goal. Corresponds to the JSON property campaignConversionGoalOperation



50617
50618
50619
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50617

def campaign_conversion_goal_operation
  @campaign_conversion_goal_operation
end

#campaign_criterion_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCriterionOperation

A single operation (create, update, remove) on a campaign criterion. Corresponds to the JSON property campaignCriterionOperation



50622
50623
50624
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50622

def campaign_criterion_operation
  @campaign_criterion_operation
end

#campaign_customizer_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCustomizerOperation

A single operation (create, remove) on a customizer attribute. Corresponds to the JSON property campaignCustomizerOperation



50627
50628
50629
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50627

def campaign_customizer_operation
  @campaign_customizer_operation
end

#campaign_draft_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignDraftOperation

A single operation (create, update, remove) on a campaign draft. Corresponds to the JSON property campaignDraftOperation



50632
50633
50634
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50632

def campaign_draft_operation
  @campaign_draft_operation
end

#campaign_group_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGroupOperation

A single operation (create, update, remove) on a campaign group. Corresponds to the JSON property campaignGroupOperation



50637
50638
50639
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50637

def campaign_group_operation
  @campaign_group_operation
end

#campaign_label_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignLabelOperation

A single operation (create, remove) on a campaign-label relationship. Corresponds to the JSON property campaignLabelOperation



50642
50643
50644
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50642

def campaign_label_operation
  @campaign_label_operation
end

#campaign_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignOperation

A single operation (create, update, remove) on a campaign. Corresponds to the JSON property campaignOperation



50647
50648
50649
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50647

def campaign_operation
  @campaign_operation
end

#campaign_shared_set_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignSharedSetOperation

A single operation (create, remove) on a campaign shared set. Corresponds to the JSON property campaignSharedSetOperation



50652
50653
50654
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50652

def campaign_shared_set_operation
  @campaign_shared_set_operation
end

#conversion_action_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionActionOperation

A single operation (create, update, remove) on a conversion action. Corresponds to the JSON property conversionActionOperation



50657
50658
50659
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50657

def conversion_action_operation
  @conversion_action_operation
end

#conversion_custom_variable_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation

A single operation (create, update) on a conversion custom variable. Corresponds to the JSON property conversionCustomVariableOperation



50662
50663
50664
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50662

def conversion_custom_variable_operation
  @conversion_custom_variable_operation
end

#conversion_goal_campaign_config_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionGoalCampaignConfigOperation

A single operation (update) on a conversion goal campaign config. Corresponds to the JSON property conversionGoalCampaignConfigOperation



50667
50668
50669
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50667

def conversion_goal_campaign_config_operation
  @conversion_goal_campaign_config_operation
end

#conversion_value_rule_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleOperation

A single operation (create, update, remove) on a conversion value rule. Corresponds to the JSON property conversionValueRuleOperation



50672
50673
50674
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50672

def conversion_value_rule_operation
  @conversion_value_rule_operation
end

#conversion_value_rule_set_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation

A single operation (create, update, remove) on a conversion value rule set. Corresponds to the JSON property conversionValueRuleSetOperation



50677
50678
50679
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50677

def conversion_value_rule_set_operation
  @conversion_value_rule_set_operation
end

#custom_conversion_goal_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomConversionGoalOperation

A single operation (create, remove) on a custom conversion goal. Corresponds to the JSON property customConversionGoalOperation



50682
50683
50684
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50682

def custom_conversion_goal_operation
  @custom_conversion_goal_operation
end

#customer_asset_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetOperation

A single operation (create, update, remove) on a customer asset. Corresponds to the JSON property customerAssetOperation



50687
50688
50689
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50687

def customer_asset_operation
  @customer_asset_operation
end

#customer_conversion_goal_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation

A single operation (update) on a customer conversion goal. Corresponds to the JSON property customerConversionGoalOperation



50692
50693
50694
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50692

def customer_conversion_goal_operation
  @customer_conversion_goal_operation
end

#customer_customizer_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation

A single operation (create, remove) on a customizer attribute. Corresponds to the JSON property customerCustomizerOperation



50697
50698
50699
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50697

def customer_customizer_operation
  @customer_customizer_operation
end

#customer_label_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerLabelOperation

A single operation (create, remove) on a customer-label relationship. Corresponds to the JSON property customerLabelOperation



50702
50703
50704
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50702

def customer_label_operation
  @customer_label_operation
end

#customer_negative_criterion_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerNegativeCriterionOperation

A single operation (create or remove) on a customer level negative criterion. Corresponds to the JSON property customerNegativeCriterionOperation



50707
50708
50709
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50707

def customer_negative_criterion_operation
  @customer_negative_criterion_operation
end

#customer_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerOperation

A single update on a customer. Corresponds to the JSON property customerOperation



50712
50713
50714
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50712

def customer_operation
  @customer_operation
end

#customizer_attribute_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomizerAttributeOperation

A single operation (create, remove) on a customizer attribute. Corresponds to the JSON property customizerAttributeOperation



50717
50718
50719
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50717

def customizer_attribute_operation
  @customizer_attribute_operation
end

#experiment_arm_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentArmOperation

A single operation on an experiment arm. Corresponds to the JSON property experimentArmOperation



50722
50723
50724
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50722

def experiment_arm_operation
  @experiment_arm_operation
end

#experiment_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentOperation

A single operation on an experiment. Corresponds to the JSON property experimentOperation



50727
50728
50729
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50727

def experiment_operation
  @experiment_operation
end

#keyword_plan_ad_group_keyword_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation

A single operation (create, update, remove) on a Keyword Plan ad group keyword. Corresponds to the JSON property keywordPlanAdGroupKeywordOperation



50732
50733
50734
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50732

def keyword_plan_ad_group_keyword_operation
  @keyword_plan_ad_group_keyword_operation
end

#keyword_plan_ad_group_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation

A single operation (create, update, remove) on a Keyword Plan ad group. Corresponds to the JSON property keywordPlanAdGroupOperation



50737
50738
50739
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50737

def keyword_plan_ad_group_operation
  @keyword_plan_ad_group_operation
end

#keyword_plan_campaign_keyword_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation

A single operation (create, update, remove) on a Keyword Plan campaign keyword. Corresponds to the JSON property keywordPlanCampaignKeywordOperation



50742
50743
50744
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50742

def keyword_plan_campaign_keyword_operation
  @keyword_plan_campaign_keyword_operation
end

#keyword_plan_campaign_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation

A single operation (create, update, remove) on a Keyword Plan campaign. Corresponds to the JSON property keywordPlanCampaignOperation



50747
50748
50749
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50747

def keyword_plan_campaign_operation
  @keyword_plan_campaign_operation
end

#keyword_plan_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanOperation

A single operation (create, update, remove) on a keyword plan. Corresponds to the JSON property keywordPlanOperation



50752
50753
50754
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50752

def keyword_plan_operation
  @keyword_plan_operation
end

#label_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesLabelOperation

A single operation (create, remove, update) on a label. Corresponds to the JSON property labelOperation



50757
50758
50759
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50757

def label_operation
  @label_operation
end

#recommendation_subscription_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRecommendationSubscriptionOperation

A single operation (create, update) on a recommendation subscription. RecommendationSubscriptionService.MutateRecommendationSubscription Corresponds to the JSON property recommendationSubscriptionOperation



50763
50764
50765
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50763

def recommendation_subscription_operation
  @recommendation_subscription_operation
end

#remarketing_action_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemarketingActionOperation

A single operation (create, update) on a remarketing action. Corresponds to the JSON property remarketingActionOperation



50768
50769
50770
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50768

def remarketing_action_operation
  @remarketing_action_operation
end

#search_ads360_campaign_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation

A single operation (update) on a Search Ads 360 campaign. Corresponds to the JSON property searchAds360CampaignOperation



50773
50774
50775
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50773

def search_ads360_campaign_operation
  @search_ads360_campaign_operation
end

#shared_criterion_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedCriterionOperation

A single operation (create, remove) on an shared criterion. Corresponds to the JSON property sharedCriterionOperation



50778
50779
50780
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50778

def shared_criterion_operation
  @shared_criterion_operation
end

#shared_set_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedSetOperation

A single operation (create, update, remove) on an shared set. Corresponds to the JSON property sharedSetOperation



50783
50784
50785
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50783

def shared_set_operation
  @shared_set_operation
end

#smart_campaign_setting_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSettingOperation

A single operation to update Smart campaign settings for a campaign. Corresponds to the JSON property smartCampaignSettingOperation



50788
50789
50790
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50788

def smart_campaign_setting_operation
  @smart_campaign_setting_operation
end

#user_list_operationGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUserListOperation

A single operation (create, update) on a user list. Corresponds to the JSON property userListOperation



50793
50794
50795
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50793

def user_list_operation
  @user_list_operation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50800
50801
50802
50803
50804
50805
50806
50807
50808
50809
50810
50811
50812
50813
50814
50815
50816
50817
50818
50819
50820
50821
50822
50823
50824
50825
50826
50827
50828
50829
50830
50831
50832
50833
50834
50835
50836
50837
50838
50839
50840
50841
50842
50843
50844
50845
50846
50847
50848
50849
50850
50851
50852
50853
50854
50855
50856
50857
50858
50859
50860
50861
50862
50863
50864
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50800

def update!(**args)
  @ad_group_ad_label_operation = args[:ad_group_ad_label_operation] if args.key?(:ad_group_ad_label_operation)
  @ad_group_ad_operation = args[:ad_group_ad_operation] if args.key?(:ad_group_ad_operation)
  @ad_group_asset_operation = args[:ad_group_asset_operation] if args.key?(:ad_group_asset_operation)
  @ad_group_bid_modifier_operation = args[:ad_group_bid_modifier_operation] if args.key?(:ad_group_bid_modifier_operation)
  @ad_group_criterion_customizer_operation = args[:ad_group_criterion_customizer_operation] if args.key?(:ad_group_criterion_customizer_operation)
  @ad_group_criterion_label_operation = args[:ad_group_criterion_label_operation] if args.key?(:ad_group_criterion_label_operation)
  @ad_group_criterion_operation = args[:ad_group_criterion_operation] if args.key?(:ad_group_criterion_operation)
  @ad_group_customizer_operation = args[:ad_group_customizer_operation] if args.key?(:ad_group_customizer_operation)
  @ad_group_label_operation = args[:ad_group_label_operation] if args.key?(:ad_group_label_operation)
  @ad_group_operation = args[:ad_group_operation] if args.key?(:ad_group_operation)
  @ad_operation = args[:ad_operation] if args.key?(:ad_operation)
  @ad_parameter_operation = args[:ad_parameter_operation] if args.key?(:ad_parameter_operation)
  @asset_group_asset_operation = args[:asset_group_asset_operation] if args.key?(:asset_group_asset_operation)
  @asset_group_listing_group_filter_operation = args[:asset_group_listing_group_filter_operation] if args.key?(:asset_group_listing_group_filter_operation)
  @asset_group_operation = args[:asset_group_operation] if args.key?(:asset_group_operation)
  @asset_group_signal_operation = args[:asset_group_signal_operation] if args.key?(:asset_group_signal_operation)
  @asset_operation = args[:asset_operation] if args.key?(:asset_operation)
  @asset_set_asset_operation = args[:asset_set_asset_operation] if args.key?(:asset_set_asset_operation)
  @asset_set_operation = args[:asset_set_operation] if args.key?(:asset_set_operation)
  @audience_operation = args[:audience_operation] if args.key?(:audience_operation)
  @bidding_data_exclusion_operation = args[:bidding_data_exclusion_operation] if args.key?(:bidding_data_exclusion_operation)
  @bidding_seasonality_adjustment_operation = args[:bidding_seasonality_adjustment_operation] if args.key?(:bidding_seasonality_adjustment_operation)
  @bidding_strategy_operation = args[:bidding_strategy_operation] if args.key?(:bidding_strategy_operation)
  @campaign_asset_operation = args[:campaign_asset_operation] if args.key?(:campaign_asset_operation)
  @campaign_asset_set_operation = args[:campaign_asset_set_operation] if args.key?(:campaign_asset_set_operation)
  @campaign_bid_modifier_operation = args[:campaign_bid_modifier_operation] if args.key?(:campaign_bid_modifier_operation)
  @campaign_budget_operation = args[:campaign_budget_operation] if args.key?(:campaign_budget_operation)
  @campaign_conversion_goal_operation = args[:campaign_conversion_goal_operation] if args.key?(:campaign_conversion_goal_operation)
  @campaign_criterion_operation = args[:campaign_criterion_operation] if args.key?(:campaign_criterion_operation)
  @campaign_customizer_operation = args[:campaign_customizer_operation] if args.key?(:campaign_customizer_operation)
  @campaign_draft_operation = args[:campaign_draft_operation] if args.key?(:campaign_draft_operation)
  @campaign_group_operation = args[:campaign_group_operation] if args.key?(:campaign_group_operation)
  @campaign_label_operation = args[:campaign_label_operation] if args.key?(:campaign_label_operation)
  @campaign_operation = args[:campaign_operation] if args.key?(:campaign_operation)
  @campaign_shared_set_operation = args[:campaign_shared_set_operation] if args.key?(:campaign_shared_set_operation)
  @conversion_action_operation = args[:conversion_action_operation] if args.key?(:conversion_action_operation)
  @conversion_custom_variable_operation = args[:conversion_custom_variable_operation] if args.key?(:conversion_custom_variable_operation)
  @conversion_goal_campaign_config_operation = args[:conversion_goal_campaign_config_operation] if args.key?(:conversion_goal_campaign_config_operation)
  @conversion_value_rule_operation = args[:conversion_value_rule_operation] if args.key?(:conversion_value_rule_operation)
  @conversion_value_rule_set_operation = args[:conversion_value_rule_set_operation] if args.key?(:conversion_value_rule_set_operation)
  @custom_conversion_goal_operation = args[:custom_conversion_goal_operation] if args.key?(:custom_conversion_goal_operation)
  @customer_asset_operation = args[:customer_asset_operation] if args.key?(:customer_asset_operation)
  @customer_conversion_goal_operation = args[:customer_conversion_goal_operation] if args.key?(:customer_conversion_goal_operation)
  @customer_customizer_operation = args[:customer_customizer_operation] if args.key?(:customer_customizer_operation)
  @customer_label_operation = args[:customer_label_operation] if args.key?(:customer_label_operation)
  @customer_negative_criterion_operation = args[:customer_negative_criterion_operation] if args.key?(:customer_negative_criterion_operation)
  @customer_operation = args[:customer_operation] if args.key?(:customer_operation)
  @customizer_attribute_operation = args[:customizer_attribute_operation] if args.key?(:customizer_attribute_operation)
  @experiment_arm_operation = args[:experiment_arm_operation] if args.key?(:experiment_arm_operation)
  @experiment_operation = args[:experiment_operation] if args.key?(:experiment_operation)
  @keyword_plan_ad_group_keyword_operation = args[:keyword_plan_ad_group_keyword_operation] if args.key?(:keyword_plan_ad_group_keyword_operation)
  @keyword_plan_ad_group_operation = args[:keyword_plan_ad_group_operation] if args.key?(:keyword_plan_ad_group_operation)
  @keyword_plan_campaign_keyword_operation = args[:keyword_plan_campaign_keyword_operation] if args.key?(:keyword_plan_campaign_keyword_operation)
  @keyword_plan_campaign_operation = args[:keyword_plan_campaign_operation] if args.key?(:keyword_plan_campaign_operation)
  @keyword_plan_operation = args[:keyword_plan_operation] if args.key?(:keyword_plan_operation)
  @label_operation = args[:label_operation] if args.key?(:label_operation)
  @recommendation_subscription_operation = args[:recommendation_subscription_operation] if args.key?(:recommendation_subscription_operation)
  @remarketing_action_operation = args[:remarketing_action_operation] if args.key?(:remarketing_action_operation)
  @search_ads360_campaign_operation = args[:search_ads360_campaign_operation] if args.key?(:search_ads360_campaign_operation)
  @shared_criterion_operation = args[:shared_criterion_operation] if args.key?(:shared_criterion_operation)
  @shared_set_operation = args[:shared_set_operation] if args.key?(:shared_set_operation)
  @smart_campaign_setting_operation = args[:smart_campaign_setting_operation] if args.key?(:smart_campaign_setting_operation)
  @user_list_operation = args[:user_list_operation] if args.key?(:user_list_operation)
end