Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update, remove) on a resource.
Instance Attribute Summary collapse
-
#ad_group_ad_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation
A single operation (create, remove) on an ad group ad label.
-
#ad_group_ad_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdOperation
A single operation (create, update, remove) on an ad group ad.
-
#ad_group_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAssetOperation
A single operation (create, update, remove) on an ad group asset.
-
#ad_group_bid_modifier_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation
A single operation (create, remove, update) on an ad group bid modifier.
-
#ad_group_criterion_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionCustomizerOperation
A single operation (create, remove) on a customizer attribute.
-
#ad_group_criterion_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionLabelOperation
A single operation (create, remove) on an ad group criterion label.
-
#ad_group_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionOperation
A single operation (create, remove, update) on an ad group criterion.
-
#ad_group_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCustomizerOperation
A single operation (create, remove) on a customizer attribute.
-
#ad_group_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupLabelOperation
A single operation (create, remove) on an ad group label.
-
#ad_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupOperation
A single operation (create, update, remove) on an ad group.
-
#ad_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdOperation
A single update operation on an ad.
-
#ad_parameter_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdParameterOperation
A single operation (create, update, remove) on ad parameter.
-
#asset_group_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation
A single operation (create, remove) on an asset group asset.
-
#asset_group_listing_group_filter_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupListingGroupFilterOperation
A single operation (create, remove) on an asset group listing group filter.
-
#asset_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupOperation
A single operation (create, remove) on an asset group.
-
#asset_group_signal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupSignalOperation
A single operation (create, remove) on an asset group signal.
-
#asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetOperation
A single operation to create an asset.
-
#asset_set_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetAssetOperation
A single operation (create, remove) on an asset set asset.
-
#asset_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetOperation
A single operation (create, remove) on an asset set.
-
#audience_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOperation
A single operation (create, update) on an audience.
-
#bidding_data_exclusion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation
A single operation (create, remove, update) on a data exclusion.
-
#bidding_seasonality_adjustment_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation
A single operation (create, remove, update) on a seasonality adjustment.
-
#bidding_strategy_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingStrategyOperation
A single operation (create, update, remove) on a bidding strategy.
-
#campaign_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetOperation
A single operation (create, remove) on a campaign asset.
-
#campaign_asset_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetSetOperation
A single operation (create, remove) on a campaign asset set.
-
#campaign_bid_modifier_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation
A single operation (create, remove, update) on a campaign bid modifier.
-
#campaign_budget_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetOperation
A single operation (create, update, remove) on a campaign budget.
-
#campaign_conversion_goal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation
A single operation (update) on a campaign conversion goal.
-
#campaign_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCriterionOperation
A single operation (create, update, remove) on a campaign criterion.
-
#campaign_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCustomizerOperation
A single operation (create, remove) on a customizer attribute.
-
#campaign_draft_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignDraftOperation
A single operation (create, update, remove) on a campaign draft.
-
#campaign_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGroupOperation
A single operation (create, update, remove) on a campaign group.
-
#campaign_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignLabelOperation
A single operation (create, remove) on a campaign-label relationship.
-
#campaign_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignOperation
A single operation (create, update, remove) on a campaign.
-
#campaign_shared_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignSharedSetOperation
A single operation (create, remove) on a campaign shared set.
-
#conversion_action_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionActionOperation
A single operation (create, update, remove) on a conversion action.
-
#conversion_custom_variable_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation
A single operation (create, update) on a conversion custom variable.
-
#conversion_goal_campaign_config_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionGoalCampaignConfigOperation
A single operation (update) on a conversion goal campaign config.
-
#conversion_value_rule_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleOperation
A single operation (create, update, remove) on a conversion value rule.
-
#conversion_value_rule_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation
A single operation (create, update, remove) on a conversion value rule set.
-
#custom_conversion_goal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomConversionGoalOperation
A single operation (create, remove) on a custom conversion goal.
-
#customer_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetOperation
A single operation (create, update, remove) on a customer asset.
-
#customer_conversion_goal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation
A single operation (update) on a customer conversion goal.
-
#customer_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation
A single operation (create, remove) on a customizer attribute.
-
#customer_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerLabelOperation
A single operation (create, remove) on a customer-label relationship.
-
#customer_negative_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerNegativeCriterionOperation
A single operation (create or remove) on a customer level negative criterion.
-
#customer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerOperation
A single update on a customer.
-
#customizer_attribute_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomizerAttributeOperation
A single operation (create, remove) on a customizer attribute.
-
#experiment_arm_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentArmOperation
A single operation on an experiment arm.
-
#experiment_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentOperation
A single operation on an experiment.
-
#keyword_plan_ad_group_keyword_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation
A single operation (create, update, remove) on a Keyword Plan ad group keyword.
-
#keyword_plan_ad_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation
A single operation (create, update, remove) on a Keyword Plan ad group.
-
#keyword_plan_campaign_keyword_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation
A single operation (create, update, remove) on a Keyword Plan campaign keyword.
-
#keyword_plan_campaign_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation
A single operation (create, update, remove) on a Keyword Plan campaign.
-
#keyword_plan_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanOperation
A single operation (create, update, remove) on a keyword plan.
-
#label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesLabelOperation
A single operation (create, remove, update) on a label.
-
#recommendation_subscription_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRecommendationSubscriptionOperation
A single operation (create, update) on a recommendation subscription.
-
#remarketing_action_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemarketingActionOperation
A single operation (create, update) on a remarketing action.
-
#search_ads360_campaign_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation
A single operation (update) on a Search Ads 360 campaign.
-
#shared_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedCriterionOperation
A single operation (create, remove) on an shared criterion.
-
#shared_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedSetOperation
A single operation (create, update, remove) on an shared set.
-
#smart_campaign_setting_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSettingOperation
A single operation to update Smart campaign settings for a campaign.
-
#user_list_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUserListOperation
A single operation (create, update) on a user list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateOperation.
50099 50100 50101 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50099 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_ad_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdLabelOperation
A single operation (create, remove) on an ad group ad label.
Corresponds to the JSON property adGroupAdLabelOperation
49783 49784 49785 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49783 def ad_group_ad_label_operation @ad_group_ad_label_operation end |
#ad_group_ad_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAdOperation
A single operation (create, update, remove) on an ad group ad.
Corresponds to the JSON property adGroupAdOperation
49788 49789 49790 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49788 def ad_group_ad_operation @ad_group_ad_operation end |
#ad_group_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupAssetOperation
A single operation (create, update, remove) on an ad group asset.
Corresponds to the JSON property adGroupAssetOperation
49793 49794 49795 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49793 def ad_group_asset_operation @ad_group_asset_operation end |
#ad_group_bid_modifier_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupBidModifierOperation
A single operation (create, remove, update) on an ad group bid modifier.
Corresponds to the JSON property adGroupBidModifierOperation
49798 49799 49800 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49798 def ad_group_bid_modifier_operation @ad_group_bid_modifier_operation end |
#ad_group_criterion_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionCustomizerOperation
A single operation (create, remove) on a customizer attribute.
Corresponds to the JSON property adGroupCriterionCustomizerOperation
49803 49804 49805 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49803 def ad_group_criterion_customizer_operation @ad_group_criterion_customizer_operation end |
#ad_group_criterion_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionLabelOperation
A single operation (create, remove) on an ad group criterion label.
Corresponds to the JSON property adGroupCriterionLabelOperation
49808 49809 49810 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49808 def ad_group_criterion_label_operation @ad_group_criterion_label_operation end |
#ad_group_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCriterionOperation
A single operation (create, remove, update) on an ad group criterion.
Corresponds to the JSON property adGroupCriterionOperation
49813 49814 49815 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49813 def ad_group_criterion_operation @ad_group_criterion_operation end |
#ad_group_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupCustomizerOperation
A single operation (create, remove) on a customizer attribute.
Corresponds to the JSON property adGroupCustomizerOperation
49818 49819 49820 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49818 def ad_group_customizer_operation @ad_group_customizer_operation end |
#ad_group_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupLabelOperation
A single operation (create, remove) on an ad group label.
Corresponds to the JSON property adGroupLabelOperation
49823 49824 49825 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49823 def ad_group_label_operation @ad_group_label_operation end |
#ad_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdGroupOperation
A single operation (create, update, remove) on an ad group.
Corresponds to the JSON property adGroupOperation
49828 49829 49830 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49828 def ad_group_operation @ad_group_operation end |
#ad_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdOperation
A single update operation on an ad.
Corresponds to the JSON property adOperation
49833 49834 49835 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49833 def ad_operation @ad_operation end |
#ad_parameter_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdParameterOperation
A single operation (create, update, remove) on ad parameter.
Corresponds to the JSON property adParameterOperation
49838 49839 49840 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49838 def ad_parameter_operation @ad_parameter_operation end |
#asset_group_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupAssetOperation
A single operation (create, remove) on an asset group asset.
Corresponds to the JSON property assetGroupAssetOperation
49843 49844 49845 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49843 def asset_group_asset_operation @asset_group_asset_operation end |
#asset_group_listing_group_filter_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupListingGroupFilterOperation
A single operation (create, remove) on an asset group listing group filter.
Corresponds to the JSON property assetGroupListingGroupFilterOperation
49848 49849 49850 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49848 def asset_group_listing_group_filter_operation @asset_group_listing_group_filter_operation end |
#asset_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupOperation
A single operation (create, remove) on an asset group.
Corresponds to the JSON property assetGroupOperation
49853 49854 49855 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49853 def asset_group_operation @asset_group_operation end |
#asset_group_signal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetGroupSignalOperation
A single operation (create, remove) on an asset group signal.
Corresponds to the JSON property assetGroupSignalOperation
49858 49859 49860 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49858 def asset_group_signal_operation @asset_group_signal_operation end |
#asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetOperation
A single operation to create an asset. Supported asset types are
YoutubeVideoAsset, MediaBundleAsset, ImageAsset, LeadFormAsset, LocationAsset,
and ImageAsset. TextAsset can be created with an Ad inline, but it can also be
created apart from an Ad like other assets.
Corresponds to the JSON property assetOperation
49866 49867 49868 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49866 def asset_operation @asset_operation end |
#asset_set_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetAssetOperation
A single operation (create, remove) on an asset set asset.
Corresponds to the JSON property assetSetAssetOperation
49871 49872 49873 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49871 def asset_set_asset_operation @asset_set_asset_operation end |
#asset_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAssetSetOperation
A single operation (create, remove) on an asset set.
Corresponds to the JSON property assetSetOperation
49876 49877 49878 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49876 def asset_set_operation @asset_set_operation end |
#audience_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceOperation
A single operation (create, update) on an audience.
Corresponds to the JSON property audienceOperation
49881 49882 49883 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49881 def audience_operation @audience_operation end |
#bidding_data_exclusion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingDataExclusionOperation
A single operation (create, remove, update) on a data exclusion.
Corresponds to the JSON property biddingDataExclusionOperation
49886 49887 49888 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49886 def bidding_data_exclusion_operation @bidding_data_exclusion_operation end |
#bidding_seasonality_adjustment_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingSeasonalityAdjustmentOperation
A single operation (create, remove, update) on a seasonality adjustment.
Corresponds to the JSON property biddingSeasonalityAdjustmentOperation
49891 49892 49893 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49891 def bidding_seasonality_adjustment_operation @bidding_seasonality_adjustment_operation end |
#bidding_strategy_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesBiddingStrategyOperation
A single operation (create, update, remove) on a bidding strategy.
Corresponds to the JSON property biddingStrategyOperation
49896 49897 49898 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49896 def bidding_strategy_operation @bidding_strategy_operation end |
#campaign_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetOperation
A single operation (create, remove) on a campaign asset.
Corresponds to the JSON property campaignAssetOperation
49901 49902 49903 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49901 def campaign_asset_operation @campaign_asset_operation end |
#campaign_asset_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignAssetSetOperation
A single operation (create, remove) on a campaign asset set.
Corresponds to the JSON property campaignAssetSetOperation
49906 49907 49908 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49906 def campaign_asset_set_operation @campaign_asset_set_operation end |
#campaign_bid_modifier_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBidModifierOperation
A single operation (create, remove, update) on a campaign bid modifier.
Corresponds to the JSON property campaignBidModifierOperation
49911 49912 49913 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49911 def campaign_bid_modifier_operation @campaign_bid_modifier_operation end |
#campaign_budget_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignBudgetOperation
A single operation (create, update, remove) on a campaign budget.
Corresponds to the JSON property campaignBudgetOperation
49916 49917 49918 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49916 def campaign_budget_operation @campaign_budget_operation end |
#campaign_conversion_goal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignConversionGoalOperation
A single operation (update) on a campaign conversion goal.
Corresponds to the JSON property campaignConversionGoalOperation
49921 49922 49923 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49921 def campaign_conversion_goal_operation @campaign_conversion_goal_operation end |
#campaign_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCriterionOperation
A single operation (create, update, remove) on a campaign criterion.
Corresponds to the JSON property campaignCriterionOperation
49926 49927 49928 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49926 def campaign_criterion_operation @campaign_criterion_operation end |
#campaign_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignCustomizerOperation
A single operation (create, remove) on a customizer attribute.
Corresponds to the JSON property campaignCustomizerOperation
49931 49932 49933 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49931 def campaign_customizer_operation @campaign_customizer_operation end |
#campaign_draft_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignDraftOperation
A single operation (create, update, remove) on a campaign draft.
Corresponds to the JSON property campaignDraftOperation
49936 49937 49938 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49936 def campaign_draft_operation @campaign_draft_operation end |
#campaign_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignGroupOperation
A single operation (create, update, remove) on a campaign group.
Corresponds to the JSON property campaignGroupOperation
49941 49942 49943 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49941 def campaign_group_operation @campaign_group_operation end |
#campaign_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignLabelOperation
A single operation (create, remove) on a campaign-label relationship.
Corresponds to the JSON property campaignLabelOperation
49946 49947 49948 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49946 def campaign_label_operation @campaign_label_operation end |
#campaign_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignOperation
A single operation (create, update, remove) on a campaign.
Corresponds to the JSON property campaignOperation
49951 49952 49953 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49951 def campaign_operation @campaign_operation end |
#campaign_shared_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCampaignSharedSetOperation
A single operation (create, remove) on a campaign shared set.
Corresponds to the JSON property campaignSharedSetOperation
49956 49957 49958 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49956 def campaign_shared_set_operation @campaign_shared_set_operation end |
#conversion_action_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionActionOperation
A single operation (create, update, remove) on a conversion action.
Corresponds to the JSON property conversionActionOperation
49961 49962 49963 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49961 def conversion_action_operation @conversion_action_operation end |
#conversion_custom_variable_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomVariableOperation
A single operation (create, update) on a conversion custom variable.
Corresponds to the JSON property conversionCustomVariableOperation
49966 49967 49968 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49966 def conversion_custom_variable_operation @conversion_custom_variable_operation end |
#conversion_goal_campaign_config_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionGoalCampaignConfigOperation
A single operation (update) on a conversion goal campaign config.
Corresponds to the JSON property conversionGoalCampaignConfigOperation
49971 49972 49973 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49971 def conversion_goal_campaign_config_operation @conversion_goal_campaign_config_operation end |
#conversion_value_rule_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleOperation
A single operation (create, update, remove) on a conversion value rule.
Corresponds to the JSON property conversionValueRuleOperation
49976 49977 49978 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49976 def conversion_value_rule_operation @conversion_value_rule_operation end |
#conversion_value_rule_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionValueRuleSetOperation
A single operation (create, update, remove) on a conversion value rule set.
Corresponds to the JSON property conversionValueRuleSetOperation
49981 49982 49983 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49981 def conversion_value_rule_set_operation @conversion_value_rule_set_operation end |
#custom_conversion_goal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomConversionGoalOperation
A single operation (create, remove) on a custom conversion goal.
Corresponds to the JSON property customConversionGoalOperation
49986 49987 49988 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49986 def custom_conversion_goal_operation @custom_conversion_goal_operation end |
#customer_asset_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerAssetOperation
A single operation (create, update, remove) on a customer asset.
Corresponds to the JSON property customerAssetOperation
49991 49992 49993 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49991 def customer_asset_operation @customer_asset_operation end |
#customer_conversion_goal_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerConversionGoalOperation
A single operation (update) on a customer conversion goal.
Corresponds to the JSON property customerConversionGoalOperation
49996 49997 49998 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 49996 def customer_conversion_goal_operation @customer_conversion_goal_operation end |
#customer_customizer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerCustomizerOperation
A single operation (create, remove) on a customizer attribute.
Corresponds to the JSON property customerCustomizerOperation
50001 50002 50003 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50001 def customer_customizer_operation @customer_customizer_operation end |
#customer_label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerLabelOperation
A single operation (create, remove) on a customer-label relationship.
Corresponds to the JSON property customerLabelOperation
50006 50007 50008 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50006 def customer_label_operation @customer_label_operation end |
#customer_negative_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerNegativeCriterionOperation
A single operation (create or remove) on a customer level negative criterion.
Corresponds to the JSON property customerNegativeCriterionOperation
50011 50012 50013 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50011 def customer_negative_criterion_operation @customer_negative_criterion_operation end |
#customer_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomerOperation
A single update on a customer.
Corresponds to the JSON property customerOperation
50016 50017 50018 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50016 def customer_operation @customer_operation end |
#customizer_attribute_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomizerAttributeOperation
A single operation (create, remove) on a customizer attribute.
Corresponds to the JSON property customizerAttributeOperation
50021 50022 50023 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50021 def customizer_attribute_operation @customizer_attribute_operation end |
#experiment_arm_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentArmOperation
A single operation on an experiment arm.
Corresponds to the JSON property experimentArmOperation
50026 50027 50028 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50026 def experiment_arm_operation @experiment_arm_operation end |
#experiment_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesExperimentOperation
A single operation on an experiment.
Corresponds to the JSON property experimentOperation
50031 50032 50033 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50031 def experiment_operation @experiment_operation end |
#keyword_plan_ad_group_keyword_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupKeywordOperation
A single operation (create, update, remove) on a Keyword Plan ad group keyword.
Corresponds to the JSON property keywordPlanAdGroupKeywordOperation
50036 50037 50038 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50036 def keyword_plan_ad_group_keyword_operation @keyword_plan_ad_group_keyword_operation end |
#keyword_plan_ad_group_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanAdGroupOperation
A single operation (create, update, remove) on a Keyword Plan ad group.
Corresponds to the JSON property keywordPlanAdGroupOperation
50041 50042 50043 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50041 def keyword_plan_ad_group_operation @keyword_plan_ad_group_operation end |
#keyword_plan_campaign_keyword_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignKeywordOperation
A single operation (create, update, remove) on a Keyword Plan campaign keyword.
Corresponds to the JSON property keywordPlanCampaignKeywordOperation
50046 50047 50048 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50046 def keyword_plan_campaign_keyword_operation @keyword_plan_campaign_keyword_operation end |
#keyword_plan_campaign_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanCampaignOperation
A single operation (create, update, remove) on a Keyword Plan campaign.
Corresponds to the JSON property keywordPlanCampaignOperation
50051 50052 50053 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50051 def keyword_plan_campaign_operation @keyword_plan_campaign_operation end |
#keyword_plan_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesKeywordPlanOperation
A single operation (create, update, remove) on a keyword plan.
Corresponds to the JSON property keywordPlanOperation
50056 50057 50058 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50056 def keyword_plan_operation @keyword_plan_operation end |
#label_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesLabelOperation
A single operation (create, remove, update) on a label.
Corresponds to the JSON property labelOperation
50061 50062 50063 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50061 def label_operation @label_operation end |
#recommendation_subscription_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRecommendationSubscriptionOperation
A single operation (create, update) on a recommendation subscription.
RecommendationSubscriptionService.MutateRecommendationSubscription
Corresponds to the JSON property recommendationSubscriptionOperation
50067 50068 50069 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50067 def recommendation_subscription_operation @recommendation_subscription_operation end |
#remarketing_action_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemarketingActionOperation
A single operation (create, update) on a remarketing action.
Corresponds to the JSON property remarketingActionOperation
50072 50073 50074 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50072 def remarketing_action_operation @remarketing_action_operation end |
#search_ads360_campaign_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation
A single operation (update) on a Search Ads 360 campaign.
Corresponds to the JSON property searchAds360CampaignOperation
50077 50078 50079 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50077 def search_ads360_campaign_operation @search_ads360_campaign_operation end |
#shared_criterion_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedCriterionOperation
A single operation (create, remove) on an shared criterion.
Corresponds to the JSON property sharedCriterionOperation
50082 50083 50084 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50082 def shared_criterion_operation @shared_criterion_operation end |
#shared_set_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedSetOperation
A single operation (create, update, remove) on an shared set.
Corresponds to the JSON property sharedSetOperation
50087 50088 50089 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50087 def shared_set_operation @shared_set_operation end |
#smart_campaign_setting_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSettingOperation
A single operation to update Smart campaign settings for a campaign.
Corresponds to the JSON property smartCampaignSettingOperation
50092 50093 50094 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50092 def smart_campaign_setting_operation @smart_campaign_setting_operation end |
#user_list_operation ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUserListOperation
A single operation (create, update) on a user list.
Corresponds to the JSON property userListOperation
50097 50098 50099 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50097 def user_list_operation @user_list_operation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50104 50105 50106 50107 50108 50109 50110 50111 50112 50113 50114 50115 50116 50117 50118 50119 50120 50121 50122 50123 50124 50125 50126 50127 50128 50129 50130 50131 50132 50133 50134 50135 50136 50137 50138 50139 50140 50141 50142 50143 50144 50145 50146 50147 50148 50149 50150 50151 50152 50153 50154 50155 50156 50157 50158 50159 50160 50161 50162 50163 50164 50165 50166 50167 50168 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50104 def update!(**args) @ad_group_ad_label_operation = args[:ad_group_ad_label_operation] if args.key?(:ad_group_ad_label_operation) @ad_group_ad_operation = args[:ad_group_ad_operation] if args.key?(:ad_group_ad_operation) @ad_group_asset_operation = args[:ad_group_asset_operation] if args.key?(:ad_group_asset_operation) @ad_group_bid_modifier_operation = args[:ad_group_bid_modifier_operation] if args.key?(:ad_group_bid_modifier_operation) @ad_group_criterion_customizer_operation = args[:ad_group_criterion_customizer_operation] if args.key?(:ad_group_criterion_customizer_operation) @ad_group_criterion_label_operation = args[:ad_group_criterion_label_operation] if args.key?(:ad_group_criterion_label_operation) @ad_group_criterion_operation = args[:ad_group_criterion_operation] if args.key?(:ad_group_criterion_operation) @ad_group_customizer_operation = args[:ad_group_customizer_operation] if args.key?(:ad_group_customizer_operation) @ad_group_label_operation = args[:ad_group_label_operation] if args.key?(:ad_group_label_operation) @ad_group_operation = args[:ad_group_operation] if args.key?(:ad_group_operation) @ad_operation = args[:ad_operation] if args.key?(:ad_operation) @ad_parameter_operation = args[:ad_parameter_operation] if args.key?(:ad_parameter_operation) @asset_group_asset_operation = args[:asset_group_asset_operation] if args.key?(:asset_group_asset_operation) @asset_group_listing_group_filter_operation = args[:asset_group_listing_group_filter_operation] if args.key?(:asset_group_listing_group_filter_operation) @asset_group_operation = args[:asset_group_operation] if args.key?(:asset_group_operation) @asset_group_signal_operation = args[:asset_group_signal_operation] if args.key?(:asset_group_signal_operation) @asset_operation = args[:asset_operation] if args.key?(:asset_operation) @asset_set_asset_operation = args[:asset_set_asset_operation] if args.key?(:asset_set_asset_operation) @asset_set_operation = args[:asset_set_operation] if args.key?(:asset_set_operation) @audience_operation = args[:audience_operation] if args.key?(:audience_operation) @bidding_data_exclusion_operation = args[:bidding_data_exclusion_operation] if args.key?(:bidding_data_exclusion_operation) @bidding_seasonality_adjustment_operation = args[:bidding_seasonality_adjustment_operation] if args.key?(:bidding_seasonality_adjustment_operation) @bidding_strategy_operation = args[:bidding_strategy_operation] if args.key?(:bidding_strategy_operation) @campaign_asset_operation = args[:campaign_asset_operation] if args.key?(:campaign_asset_operation) @campaign_asset_set_operation = args[:campaign_asset_set_operation] if args.key?(:campaign_asset_set_operation) @campaign_bid_modifier_operation = args[:campaign_bid_modifier_operation] if args.key?(:campaign_bid_modifier_operation) @campaign_budget_operation = args[:campaign_budget_operation] if args.key?(:campaign_budget_operation) @campaign_conversion_goal_operation = args[:campaign_conversion_goal_operation] if args.key?(:campaign_conversion_goal_operation) @campaign_criterion_operation = args[:campaign_criterion_operation] if args.key?(:campaign_criterion_operation) @campaign_customizer_operation = args[:campaign_customizer_operation] if args.key?(:campaign_customizer_operation) @campaign_draft_operation = args[:campaign_draft_operation] if args.key?(:campaign_draft_operation) @campaign_group_operation = args[:campaign_group_operation] if args.key?(:campaign_group_operation) @campaign_label_operation = args[:campaign_label_operation] if args.key?(:campaign_label_operation) @campaign_operation = args[:campaign_operation] if args.key?(:campaign_operation) @campaign_shared_set_operation = args[:campaign_shared_set_operation] if args.key?(:campaign_shared_set_operation) @conversion_action_operation = args[:conversion_action_operation] if args.key?(:conversion_action_operation) @conversion_custom_variable_operation = args[:conversion_custom_variable_operation] if args.key?(:conversion_custom_variable_operation) @conversion_goal_campaign_config_operation = args[:conversion_goal_campaign_config_operation] if args.key?(:conversion_goal_campaign_config_operation) @conversion_value_rule_operation = args[:conversion_value_rule_operation] if args.key?(:conversion_value_rule_operation) @conversion_value_rule_set_operation = args[:conversion_value_rule_set_operation] if args.key?(:conversion_value_rule_set_operation) @custom_conversion_goal_operation = args[:custom_conversion_goal_operation] if args.key?(:custom_conversion_goal_operation) @customer_asset_operation = args[:customer_asset_operation] if args.key?(:customer_asset_operation) @customer_conversion_goal_operation = args[:customer_conversion_goal_operation] if args.key?(:customer_conversion_goal_operation) @customer_customizer_operation = args[:customer_customizer_operation] if args.key?(:customer_customizer_operation) @customer_label_operation = args[:customer_label_operation] if args.key?(:customer_label_operation) @customer_negative_criterion_operation = args[:customer_negative_criterion_operation] if args.key?(:customer_negative_criterion_operation) @customer_operation = args[:customer_operation] if args.key?(:customer_operation) @customizer_attribute_operation = args[:customizer_attribute_operation] if args.key?(:customizer_attribute_operation) @experiment_arm_operation = args[:experiment_arm_operation] if args.key?(:experiment_arm_operation) @experiment_operation = args[:experiment_operation] if args.key?(:experiment_operation) @keyword_plan_ad_group_keyword_operation = args[:keyword_plan_ad_group_keyword_operation] if args.key?(:keyword_plan_ad_group_keyword_operation) @keyword_plan_ad_group_operation = args[:keyword_plan_ad_group_operation] if args.key?(:keyword_plan_ad_group_operation) @keyword_plan_campaign_keyword_operation = args[:keyword_plan_campaign_keyword_operation] if args.key?(:keyword_plan_campaign_keyword_operation) @keyword_plan_campaign_operation = args[:keyword_plan_campaign_operation] if args.key?(:keyword_plan_campaign_operation) @keyword_plan_operation = args[:keyword_plan_operation] if args.key?(:keyword_plan_operation) @label_operation = args[:label_operation] if args.key?(:label_operation) @recommendation_subscription_operation = args[:recommendation_subscription_operation] if args.key?(:recommendation_subscription_operation) @remarketing_action_operation = args[:remarketing_action_operation] if args.key?(:remarketing_action_operation) @search_ads360_campaign_operation = args[:search_ads360_campaign_operation] if args.key?(:search_ads360_campaign_operation) @shared_criterion_operation = args[:shared_criterion_operation] if args.key?(:shared_criterion_operation) @shared_set_operation = args[:shared_set_operation] if args.key?(:shared_set_operation) @smart_campaign_setting_operation = args[:smart_campaign_setting_operation] if args.key?(:smart_campaign_setting_operation) @user_list_operation = args[:user_list_operation] if args.key?(:user_list_operation) end |