Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperationResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperationResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for the resource mutate.
Instance Attribute Summary collapse
-
#ad_group_ad_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdLabelResult
The result for an ad group ad label mutate.
-
#ad_group_ad_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdResult
The result for the ad mutate.
-
#ad_group_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAssetResult
The result for the ad group asset mutate.
-
#ad_group_bid_modifier_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupBidModifierResult
The result for the criterion mutate.
-
#ad_group_criterion_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizerResult
The result for the ad group criterion customizer mutate.
-
#ad_group_criterion_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelResult
The result for an ad group criterion label mutate.
-
#ad_group_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionResult
The result for the criterion mutate.
-
#ad_group_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizerResult
The result for the ad group customizer mutate.
-
#ad_group_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupLabelResult
The result for an ad group label mutate.
-
#ad_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupResult
The result for the ad group mutate.
-
#ad_parameter_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdParameterResult
The result for the ad parameter mutate.
-
#ad_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdResult
The result for the ad mutate.
-
#asset_group_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupAssetResult
The result for the asset group asset mutate.
-
#asset_group_listing_group_filter_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupListingGroupFilterResult
The result for the asset group listing group filter mutate.
-
#asset_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupResult
The result for the asset group mutate.
-
#asset_group_signal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupSignalResult
The result for the asset group signal mutate.
-
#asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetResult
The result for the asset mutate.
-
#asset_set_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult
The result for the asset set asset mutate.
-
#asset_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetResult
The result for the asset set mutate.
-
#audience_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAudienceResult
The result for the audience mutate.
-
#bidding_data_exclusion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingDataExclusionsResult
The result for the data exclusion mutate.
-
#bidding_seasonality_adjustment_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingSeasonalityAdjustmentsResult
The result for the seasonality adjustment mutate.
-
#bidding_strategy_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingStrategyResult
The result for the bidding strategy mutate.
-
#campaign_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetResult
The result for the campaign asset mutate.
-
#campaign_asset_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetResult
The result for the campaign asset set mutate.
-
#campaign_bid_modifier_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBidModifierResult
The result for the criterion mutate.
-
#campaign_budget_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBudgetResult
The result for the campaign budget mutate.
-
#campaign_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalResult
The result for the campaign conversion goal mutate.
-
#campaign_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCriterionResult
The result for the criterion mutate.
-
#campaign_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCustomizerResult
The result for the campaign customizer mutate.
-
#campaign_draft_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignDraftResult
The result for the campaign draft mutate.
-
#campaign_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignGroupResult
The result for the campaign group mutate.
-
#campaign_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignLabelResult
The result for a campaign label mutate.
-
#campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignResult
The result for the campaign mutate.
-
#campaign_shared_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignSharedSetResult
The result for the campaign shared set mutate.
-
#conversion_action_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionActionResult
The result for the conversion action mutate.
-
#conversion_custom_variable_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionCustomVariableResult
The result for the conversion custom variable mutate.
-
#conversion_goal_campaign_config_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigResult
The result for the conversion goal campaign config mutate.
-
#conversion_value_rule_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleResult
The result for the conversion value rule mutate.
-
#conversion_value_rule_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult
The result for the conversion value rule set mutate.
-
#custom_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult
The result for the custom conversion goal mutate.
-
#customer_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerAssetResult
The result for the customer asset mutate.
-
#customer_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerConversionGoalResult
The result for the customer conversion goal mutate.
-
#customer_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerCustomizerResult
The result for the customizer attribute mutate.
-
#customer_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerLabelResult
The result for a customer label mutate.
-
#customer_negative_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerNegativeCriteriaResult
The result for the criterion mutate.
-
#customer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerResult
The result for the customer mutate.
-
#customizer_attribute_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomizerAttributeResult
The result for the customizer attribute mutate.
-
#experiment_arm_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentArmResult
The result for the experiment arm mutate.
-
#experiment_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentResult
The result for the campaign experiment mutate.
-
#keyword_plan_ad_group_keyword_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordResult
The result for the Keyword Plan ad group keyword mutate.
-
#keyword_plan_ad_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupResult
The result for the Keyword Plan ad group mutate.
-
#keyword_plan_campaign_keyword_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignKeywordResult
The result for the Keyword Plan campaign keyword mutate.
-
#keyword_plan_campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignResult
The result for the Keyword Plan campaign mutate.
-
#keyword_plan_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansResult
The result for the keyword plan mutate.
-
#label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateLabelResult
The result for a label mutate.
-
#recommendation_subscription_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResult
Result message for RecommendationSubscriptionService.
-
#remarketing_action_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRemarketingActionResult
The result for the remarketing action mutate.
-
#search_ads360_campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSearchAds360CampaignResult
The result for the Search Ads 360 campaign mutate.
-
#shared_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedCriterionResult
The result for the shared criterion mutate.
-
#shared_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedSetResult
The result for the shared set mutate.
-
#smart_campaign_setting_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSmartCampaignSettingResult
The result for the Smart campaign setting mutate.
-
#user_list_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateUserListResult
The result for the user list mutate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateOperationResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateOperationResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateOperationResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateOperationResponse.
51187 51188 51189 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51187 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_ad_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdLabelResult
The result for an ad group ad label mutate.
Corresponds to the JSON property adGroupAdLabelResult
50874 50875 50876 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50874 def ad_group_ad_label_result @ad_group_ad_label_result end |
#ad_group_ad_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdResult
The result for the ad mutate.
Corresponds to the JSON property adGroupAdResult
50879 50880 50881 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50879 def ad_group_ad_result @ad_group_ad_result end |
#ad_group_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAssetResult
The result for the ad group asset mutate.
Corresponds to the JSON property adGroupAssetResult
50884 50885 50886 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50884 def ad_group_asset_result @ad_group_asset_result end |
#ad_group_bid_modifier_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupBidModifierResult
The result for the criterion mutate.
Corresponds to the JSON property adGroupBidModifierResult
50889 50890 50891 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50889 def ad_group_bid_modifier_result @ad_group_bid_modifier_result end |
#ad_group_criterion_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizerResult
The result for the ad group criterion customizer mutate.
Corresponds to the JSON property adGroupCriterionCustomizerResult
50894 50895 50896 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50894 def ad_group_criterion_customizer_result @ad_group_criterion_customizer_result end |
#ad_group_criterion_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelResult
The result for an ad group criterion label mutate.
Corresponds to the JSON property adGroupCriterionLabelResult
50899 50900 50901 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50899 def ad_group_criterion_label_result @ad_group_criterion_label_result end |
#ad_group_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionResult
The result for the criterion mutate.
Corresponds to the JSON property adGroupCriterionResult
50904 50905 50906 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50904 def ad_group_criterion_result @ad_group_criterion_result end |
#ad_group_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizerResult
The result for the ad group customizer mutate.
Corresponds to the JSON property adGroupCustomizerResult
50909 50910 50911 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50909 def ad_group_customizer_result @ad_group_customizer_result end |
#ad_group_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupLabelResult
The result for an ad group label mutate.
Corresponds to the JSON property adGroupLabelResult
50914 50915 50916 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50914 def ad_group_label_result @ad_group_label_result end |
#ad_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupResult
The result for the ad group mutate.
Corresponds to the JSON property adGroupResult
50919 50920 50921 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50919 def ad_group_result @ad_group_result end |
#ad_parameter_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdParameterResult
The result for the ad parameter mutate.
Corresponds to the JSON property adParameterResult
50924 50925 50926 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50924 def ad_parameter_result @ad_parameter_result end |
#ad_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdResult
The result for the ad mutate.
Corresponds to the JSON property adResult
50929 50930 50931 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50929 def ad_result @ad_result end |
#asset_group_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupAssetResult
The result for the asset group asset mutate.
Corresponds to the JSON property assetGroupAssetResult
50934 50935 50936 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50934 def asset_group_asset_result @asset_group_asset_result end |
#asset_group_listing_group_filter_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupListingGroupFilterResult
The result for the asset group listing group filter mutate.
Corresponds to the JSON property assetGroupListingGroupFilterResult
50939 50940 50941 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50939 def asset_group_listing_group_filter_result @asset_group_listing_group_filter_result end |
#asset_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupResult
The result for the asset group mutate.
Corresponds to the JSON property assetGroupResult
50944 50945 50946 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50944 def asset_group_result @asset_group_result end |
#asset_group_signal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupSignalResult
The result for the asset group signal mutate.
Corresponds to the JSON property assetGroupSignalResult
50949 50950 50951 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50949 def asset_group_signal_result @asset_group_signal_result end |
#asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetResult
The result for the asset mutate.
Corresponds to the JSON property assetResult
50954 50955 50956 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50954 def asset_result @asset_result end |
#asset_set_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult
The result for the asset set asset mutate.
Corresponds to the JSON property assetSetAssetResult
50959 50960 50961 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50959 def asset_set_asset_result @asset_set_asset_result end |
#asset_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetResult
The result for the asset set mutate.
Corresponds to the JSON property assetSetResult
50964 50965 50966 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50964 def asset_set_result @asset_set_result end |
#audience_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAudienceResult
The result for the audience mutate.
Corresponds to the JSON property audienceResult
50969 50970 50971 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50969 def audience_result @audience_result end |
#bidding_data_exclusion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingDataExclusionsResult
The result for the data exclusion mutate.
Corresponds to the JSON property biddingDataExclusionResult
50974 50975 50976 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50974 def bidding_data_exclusion_result @bidding_data_exclusion_result end |
#bidding_seasonality_adjustment_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingSeasonalityAdjustmentsResult
The result for the seasonality adjustment mutate.
Corresponds to the JSON property biddingSeasonalityAdjustmentResult
50979 50980 50981 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50979 def bidding_seasonality_adjustment_result @bidding_seasonality_adjustment_result end |
#bidding_strategy_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingStrategyResult
The result for the bidding strategy mutate.
Corresponds to the JSON property biddingStrategyResult
50984 50985 50986 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50984 def bidding_strategy_result @bidding_strategy_result end |
#campaign_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetResult
The result for the campaign asset mutate.
Corresponds to the JSON property campaignAssetResult
50989 50990 50991 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50989 def campaign_asset_result @campaign_asset_result end |
#campaign_asset_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetResult
The result for the campaign asset set mutate.
Corresponds to the JSON property campaignAssetSetResult
50994 50995 50996 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50994 def campaign_asset_set_result @campaign_asset_set_result end |
#campaign_bid_modifier_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBidModifierResult
The result for the criterion mutate.
Corresponds to the JSON property campaignBidModifierResult
50999 51000 51001 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50999 def campaign_bid_modifier_result @campaign_bid_modifier_result end |
#campaign_budget_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBudgetResult
The result for the campaign budget mutate.
Corresponds to the JSON property campaignBudgetResult
51004 51005 51006 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51004 def campaign_budget_result @campaign_budget_result end |
#campaign_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalResult
The result for the campaign conversion goal mutate.
Corresponds to the JSON property campaignConversionGoalResult
51009 51010 51011 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51009 def campaign_conversion_goal_result @campaign_conversion_goal_result end |
#campaign_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCriterionResult
The result for the criterion mutate.
Corresponds to the JSON property campaignCriterionResult
51014 51015 51016 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51014 def campaign_criterion_result @campaign_criterion_result end |
#campaign_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCustomizerResult
The result for the campaign customizer mutate.
Corresponds to the JSON property campaignCustomizerResult
51019 51020 51021 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51019 def campaign_customizer_result @campaign_customizer_result end |
#campaign_draft_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignDraftResult
The result for the campaign draft mutate.
Corresponds to the JSON property campaignDraftResult
51024 51025 51026 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51024 def campaign_draft_result @campaign_draft_result end |
#campaign_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignGroupResult
The result for the campaign group mutate.
Corresponds to the JSON property campaignGroupResult
51029 51030 51031 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51029 def campaign_group_result @campaign_group_result end |
#campaign_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignLabelResult
The result for a campaign label mutate.
Corresponds to the JSON property campaignLabelResult
51034 51035 51036 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51034 def campaign_label_result @campaign_label_result end |
#campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignResult
The result for the campaign mutate.
Corresponds to the JSON property campaignResult
51039 51040 51041 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51039 def campaign_result @campaign_result end |
#campaign_shared_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignSharedSetResult
The result for the campaign shared set mutate.
Corresponds to the JSON property campaignSharedSetResult
51044 51045 51046 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51044 def campaign_shared_set_result @campaign_shared_set_result end |
#conversion_action_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionActionResult
The result for the conversion action mutate.
Corresponds to the JSON property conversionActionResult
51049 51050 51051 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51049 def conversion_action_result @conversion_action_result end |
#conversion_custom_variable_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionCustomVariableResult
The result for the conversion custom variable mutate.
Corresponds to the JSON property conversionCustomVariableResult
51054 51055 51056 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51054 def conversion_custom_variable_result @conversion_custom_variable_result end |
#conversion_goal_campaign_config_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigResult
The result for the conversion goal campaign config mutate.
Corresponds to the JSON property conversionGoalCampaignConfigResult
51059 51060 51061 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51059 def conversion_goal_campaign_config_result @conversion_goal_campaign_config_result end |
#conversion_value_rule_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleResult
The result for the conversion value rule mutate.
Corresponds to the JSON property conversionValueRuleResult
51064 51065 51066 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51064 def conversion_value_rule_result @conversion_value_rule_result end |
#conversion_value_rule_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult
The result for the conversion value rule set mutate.
Corresponds to the JSON property conversionValueRuleSetResult
51069 51070 51071 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51069 def conversion_value_rule_set_result @conversion_value_rule_set_result end |
#custom_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult
The result for the custom conversion goal mutate.
Corresponds to the JSON property customConversionGoalResult
51074 51075 51076 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51074 def custom_conversion_goal_result @custom_conversion_goal_result end |
#customer_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerAssetResult
The result for the customer asset mutate.
Corresponds to the JSON property customerAssetResult
51079 51080 51081 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51079 def customer_asset_result @customer_asset_result end |
#customer_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerConversionGoalResult
The result for the customer conversion goal mutate.
Corresponds to the JSON property customerConversionGoalResult
51084 51085 51086 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51084 def customer_conversion_goal_result @customer_conversion_goal_result end |
#customer_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerCustomizerResult
The result for the customizer attribute mutate.
Corresponds to the JSON property customerCustomizerResult
51089 51090 51091 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51089 def customer_customizer_result @customer_customizer_result end |
#customer_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerLabelResult
The result for a customer label mutate.
Corresponds to the JSON property customerLabelResult
51094 51095 51096 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51094 def customer_label_result @customer_label_result end |
#customer_negative_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerNegativeCriteriaResult
The result for the criterion mutate.
Corresponds to the JSON property customerNegativeCriterionResult
51099 51100 51101 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51099 def customer_negative_criterion_result @customer_negative_criterion_result end |
#customer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerResult
The result for the customer mutate.
Corresponds to the JSON property customerResult
51104 51105 51106 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51104 def customer_result @customer_result end |
#customizer_attribute_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomizerAttributeResult
The result for the customizer attribute mutate.
Corresponds to the JSON property customizerAttributeResult
51109 51110 51111 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51109 def customizer_attribute_result @customizer_attribute_result end |
#experiment_arm_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentArmResult
The result for the experiment arm mutate.
Corresponds to the JSON property experimentArmResult
51114 51115 51116 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51114 def experiment_arm_result @experiment_arm_result end |
#experiment_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentResult
The result for the campaign experiment mutate.
Corresponds to the JSON property experimentResult
51119 51120 51121 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51119 def experiment_result @experiment_result end |
#keyword_plan_ad_group_keyword_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordResult
The result for the Keyword Plan ad group keyword mutate.
Corresponds to the JSON property keywordPlanAdGroupKeywordResult
51124 51125 51126 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51124 def keyword_plan_ad_group_keyword_result @keyword_plan_ad_group_keyword_result end |
#keyword_plan_ad_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupResult
The result for the Keyword Plan ad group mutate.
Corresponds to the JSON property keywordPlanAdGroupResult
51129 51130 51131 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51129 def keyword_plan_ad_group_result @keyword_plan_ad_group_result end |
#keyword_plan_campaign_keyword_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignKeywordResult
The result for the Keyword Plan campaign keyword mutate.
Corresponds to the JSON property keywordPlanCampaignKeywordResult
51134 51135 51136 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51134 def keyword_plan_campaign_keyword_result @keyword_plan_campaign_keyword_result end |
#keyword_plan_campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignResult
The result for the Keyword Plan campaign mutate.
Corresponds to the JSON property keywordPlanCampaignResult
51139 51140 51141 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51139 def keyword_plan_campaign_result @keyword_plan_campaign_result end |
#keyword_plan_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansResult
The result for the keyword plan mutate.
Corresponds to the JSON property keywordPlanResult
51144 51145 51146 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51144 def keyword_plan_result @keyword_plan_result end |
#label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateLabelResult
The result for a label mutate.
Corresponds to the JSON property labelResult
51149 51150 51151 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51149 def label_result @label_result end |
#recommendation_subscription_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResult
Result message for RecommendationSubscriptionService.
MutateRecommendationSubscription
Corresponds to the JSON property recommendationSubscriptionResult
51155 51156 51157 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51155 def recommendation_subscription_result @recommendation_subscription_result end |
#remarketing_action_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRemarketingActionResult
The result for the remarketing action mutate.
Corresponds to the JSON property remarketingActionResult
51160 51161 51162 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51160 def remarketing_action_result @remarketing_action_result end |
#search_ads360_campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSearchAds360CampaignResult
The result for the Search Ads 360 campaign mutate.
Corresponds to the JSON property searchAds360CampaignResult
51165 51166 51167 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51165 def search_ads360_campaign_result @search_ads360_campaign_result end |
#shared_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedCriterionResult
The result for the shared criterion mutate.
Corresponds to the JSON property sharedCriterionResult
51170 51171 51172 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51170 def shared_criterion_result @shared_criterion_result end |
#shared_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedSetResult
The result for the shared set mutate.
Corresponds to the JSON property sharedSetResult
51175 51176 51177 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51175 def shared_set_result @shared_set_result end |
#smart_campaign_setting_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSmartCampaignSettingResult
The result for the Smart campaign setting mutate.
Corresponds to the JSON property smartCampaignSettingResult
51180 51181 51182 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51180 def smart_campaign_setting_result @smart_campaign_setting_result end |
#user_list_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateUserListResult
The result for the user list mutate.
Corresponds to the JSON property userListResult
51185 51186 51187 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51185 def user_list_result @user_list_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51192 51193 51194 51195 51196 51197 51198 51199 51200 51201 51202 51203 51204 51205 51206 51207 51208 51209 51210 51211 51212 51213 51214 51215 51216 51217 51218 51219 51220 51221 51222 51223 51224 51225 51226 51227 51228 51229 51230 51231 51232 51233 51234 51235 51236 51237 51238 51239 51240 51241 51242 51243 51244 51245 51246 51247 51248 51249 51250 51251 51252 51253 51254 51255 51256 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51192 def update!(**args) @ad_group_ad_label_result = args[:ad_group_ad_label_result] if args.key?(:ad_group_ad_label_result) @ad_group_ad_result = args[:ad_group_ad_result] if args.key?(:ad_group_ad_result) @ad_group_asset_result = args[:ad_group_asset_result] if args.key?(:ad_group_asset_result) @ad_group_bid_modifier_result = args[:ad_group_bid_modifier_result] if args.key?(:ad_group_bid_modifier_result) @ad_group_criterion_customizer_result = args[:ad_group_criterion_customizer_result] if args.key?(:ad_group_criterion_customizer_result) @ad_group_criterion_label_result = args[:ad_group_criterion_label_result] if args.key?(:ad_group_criterion_label_result) @ad_group_criterion_result = args[:ad_group_criterion_result] if args.key?(:ad_group_criterion_result) @ad_group_customizer_result = args[:ad_group_customizer_result] if args.key?(:ad_group_customizer_result) @ad_group_label_result = args[:ad_group_label_result] if args.key?(:ad_group_label_result) @ad_group_result = args[:ad_group_result] if args.key?(:ad_group_result) @ad_parameter_result = args[:ad_parameter_result] if args.key?(:ad_parameter_result) @ad_result = args[:ad_result] if args.key?(:ad_result) @asset_group_asset_result = args[:asset_group_asset_result] if args.key?(:asset_group_asset_result) @asset_group_listing_group_filter_result = args[:asset_group_listing_group_filter_result] if args.key?(:asset_group_listing_group_filter_result) @asset_group_result = args[:asset_group_result] if args.key?(:asset_group_result) @asset_group_signal_result = args[:asset_group_signal_result] if args.key?(:asset_group_signal_result) @asset_result = args[:asset_result] if args.key?(:asset_result) @asset_set_asset_result = args[:asset_set_asset_result] if args.key?(:asset_set_asset_result) @asset_set_result = args[:asset_set_result] if args.key?(:asset_set_result) @audience_result = args[:audience_result] if args.key?(:audience_result) @bidding_data_exclusion_result = args[:bidding_data_exclusion_result] if args.key?(:bidding_data_exclusion_result) @bidding_seasonality_adjustment_result = args[:bidding_seasonality_adjustment_result] if args.key?(:bidding_seasonality_adjustment_result) @bidding_strategy_result = args[:bidding_strategy_result] if args.key?(:bidding_strategy_result) @campaign_asset_result = args[:campaign_asset_result] if args.key?(:campaign_asset_result) @campaign_asset_set_result = args[:campaign_asset_set_result] if args.key?(:campaign_asset_set_result) @campaign_bid_modifier_result = args[:campaign_bid_modifier_result] if args.key?(:campaign_bid_modifier_result) @campaign_budget_result = args[:campaign_budget_result] if args.key?(:campaign_budget_result) @campaign_conversion_goal_result = args[:campaign_conversion_goal_result] if args.key?(:campaign_conversion_goal_result) @campaign_criterion_result = args[:campaign_criterion_result] if args.key?(:campaign_criterion_result) @campaign_customizer_result = args[:campaign_customizer_result] if args.key?(:campaign_customizer_result) @campaign_draft_result = args[:campaign_draft_result] if args.key?(:campaign_draft_result) @campaign_group_result = args[:campaign_group_result] if args.key?(:campaign_group_result) @campaign_label_result = args[:campaign_label_result] if args.key?(:campaign_label_result) @campaign_result = args[:campaign_result] if args.key?(:campaign_result) @campaign_shared_set_result = args[:campaign_shared_set_result] if args.key?(:campaign_shared_set_result) @conversion_action_result = args[:conversion_action_result] if args.key?(:conversion_action_result) @conversion_custom_variable_result = args[:conversion_custom_variable_result] if args.key?(:conversion_custom_variable_result) @conversion_goal_campaign_config_result = args[:conversion_goal_campaign_config_result] if args.key?(:conversion_goal_campaign_config_result) @conversion_value_rule_result = args[:conversion_value_rule_result] if args.key?(:conversion_value_rule_result) @conversion_value_rule_set_result = args[:conversion_value_rule_set_result] if args.key?(:conversion_value_rule_set_result) @custom_conversion_goal_result = args[:custom_conversion_goal_result] if args.key?(:custom_conversion_goal_result) @customer_asset_result = args[:customer_asset_result] if args.key?(:customer_asset_result) @customer_conversion_goal_result = args[:customer_conversion_goal_result] if args.key?(:customer_conversion_goal_result) @customer_customizer_result = args[:customer_customizer_result] if args.key?(:customer_customizer_result) @customer_label_result = args[:customer_label_result] if args.key?(:customer_label_result) @customer_negative_criterion_result = args[:customer_negative_criterion_result] if args.key?(:customer_negative_criterion_result) @customer_result = args[:customer_result] if args.key?(:customer_result) @customizer_attribute_result = args[:customizer_attribute_result] if args.key?(:customizer_attribute_result) @experiment_arm_result = args[:experiment_arm_result] if args.key?(:experiment_arm_result) @experiment_result = args[:experiment_result] if args.key?(:experiment_result) @keyword_plan_ad_group_keyword_result = args[:keyword_plan_ad_group_keyword_result] if args.key?(:keyword_plan_ad_group_keyword_result) @keyword_plan_ad_group_result = args[:keyword_plan_ad_group_result] if args.key?(:keyword_plan_ad_group_result) @keyword_plan_campaign_keyword_result = args[:keyword_plan_campaign_keyword_result] if args.key?(:keyword_plan_campaign_keyword_result) @keyword_plan_campaign_result = args[:keyword_plan_campaign_result] if args.key?(:keyword_plan_campaign_result) @keyword_plan_result = args[:keyword_plan_result] if args.key?(:keyword_plan_result) @label_result = args[:label_result] if args.key?(:label_result) @recommendation_subscription_result = args[:recommendation_subscription_result] if args.key?(:recommendation_subscription_result) @remarketing_action_result = args[:remarketing_action_result] if args.key?(:remarketing_action_result) @search_ads360_campaign_result = args[:search_ads360_campaign_result] if args.key?(:search_ads360_campaign_result) @shared_criterion_result = args[:shared_criterion_result] if args.key?(:shared_criterion_result) @shared_set_result = args[:shared_set_result] if args.key?(:shared_set_result) @smart_campaign_setting_result = args[:smart_campaign_setting_result] if args.key?(:smart_campaign_setting_result) @user_list_result = args[:user_list_result] if args.key?(:user_list_result) end |