Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperationResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperationResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for the resource mutate.
Instance Attribute Summary collapse
-
#ad_group_ad_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdLabelResult
The result for an ad group ad label mutate.
-
#ad_group_ad_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdResult
The result for the ad mutate.
-
#ad_group_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAssetResult
The result for the ad group asset mutate.
-
#ad_group_bid_modifier_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupBidModifierResult
The result for the criterion mutate.
-
#ad_group_criterion_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizerResult
The result for the ad group criterion customizer mutate.
-
#ad_group_criterion_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelResult
The result for an ad group criterion label mutate.
-
#ad_group_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionResult
The result for the criterion mutate.
-
#ad_group_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizerResult
The result for the ad group customizer mutate.
-
#ad_group_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupLabelResult
The result for an ad group label mutate.
-
#ad_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupResult
The result for the ad group mutate.
-
#ad_parameter_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdParameterResult
The result for the ad parameter mutate.
-
#ad_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdResult
The result for the ad mutate.
-
#asset_group_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupAssetResult
The result for the asset group asset mutate.
-
#asset_group_listing_group_filter_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupListingGroupFilterResult
The result for the asset group listing group filter mutate.
-
#asset_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupResult
The result for the asset group mutate.
-
#asset_group_signal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupSignalResult
The result for the asset group signal mutate.
-
#asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetResult
The result for the asset mutate.
-
#asset_set_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult
The result for the asset set asset mutate.
-
#asset_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetResult
The result for the asset set mutate.
-
#audience_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAudienceResult
The result for the audience mutate.
-
#bidding_data_exclusion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingDataExclusionsResult
The result for the data exclusion mutate.
-
#bidding_seasonality_adjustment_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingSeasonalityAdjustmentsResult
The result for the seasonality adjustment mutate.
-
#bidding_strategy_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingStrategyResult
The result for the bidding strategy mutate.
-
#campaign_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetResult
The result for the campaign asset mutate.
-
#campaign_asset_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetResult
The result for the campaign asset set mutate.
-
#campaign_bid_modifier_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBidModifierResult
The result for the criterion mutate.
-
#campaign_budget_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBudgetResult
The result for the campaign budget mutate.
-
#campaign_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalResult
The result for the campaign conversion goal mutate.
-
#campaign_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCriterionResult
The result for the criterion mutate.
-
#campaign_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCustomizerResult
The result for the campaign customizer mutate.
-
#campaign_draft_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignDraftResult
The result for the campaign draft mutate.
-
#campaign_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignGroupResult
The result for the campaign group mutate.
-
#campaign_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignLabelResult
The result for a campaign label mutate.
-
#campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignResult
The result for the campaign mutate.
-
#campaign_shared_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignSharedSetResult
The result for the campaign shared set mutate.
-
#conversion_action_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionActionResult
The result for the conversion action mutate.
-
#conversion_custom_variable_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionCustomVariableResult
The result for the conversion custom variable mutate.
-
#conversion_goal_campaign_config_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigResult
The result for the conversion goal campaign config mutate.
-
#conversion_value_rule_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleResult
The result for the conversion value rule mutate.
-
#conversion_value_rule_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult
The result for the conversion value rule set mutate.
-
#custom_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult
The result for the custom conversion goal mutate.
-
#customer_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerAssetResult
The result for the customer asset mutate.
-
#customer_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerConversionGoalResult
The result for the customer conversion goal mutate.
-
#customer_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerCustomizerResult
The result for the customizer attribute mutate.
-
#customer_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerLabelResult
The result for a customer label mutate.
-
#customer_negative_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerNegativeCriteriaResult
The result for the criterion mutate.
-
#customer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerResult
The result for the customer mutate.
-
#customizer_attribute_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomizerAttributeResult
The result for the customizer attribute mutate.
-
#experiment_arm_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentArmResult
The result for the experiment arm mutate.
-
#experiment_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentResult
The result for the campaign experiment mutate.
-
#keyword_plan_ad_group_keyword_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordResult
The result for the Keyword Plan ad group keyword mutate.
-
#keyword_plan_ad_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupResult
The result for the Keyword Plan ad group mutate.
-
#keyword_plan_campaign_keyword_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignKeywordResult
The result for the Keyword Plan campaign keyword mutate.
-
#keyword_plan_campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignResult
The result for the Keyword Plan campaign mutate.
-
#keyword_plan_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansResult
The result for the keyword plan mutate.
-
#label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateLabelResult
The result for a label mutate.
-
#recommendation_subscription_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResult
Result message for RecommendationSubscriptionService.
-
#remarketing_action_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRemarketingActionResult
The result for the remarketing action mutate.
-
#search_ads360_campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSearchAds360CampaignResult
The result for the Search Ads 360 campaign mutate.
-
#shared_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedCriterionResult
The result for the shared criterion mutate.
-
#shared_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedSetResult
The result for the shared set mutate.
-
#smart_campaign_setting_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSmartCampaignSettingResult
The result for the Smart campaign setting mutate.
-
#user_list_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateUserListResult
The result for the user list mutate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateOperationResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateOperationResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateOperationResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateOperationResponse.
50491 50492 50493 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50491 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_ad_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdLabelResult
The result for an ad group ad label mutate.
Corresponds to the JSON property adGroupAdLabelResult
50178 50179 50180 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50178 def ad_group_ad_label_result @ad_group_ad_label_result end |
#ad_group_ad_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAdResult
The result for the ad mutate.
Corresponds to the JSON property adGroupAdResult
50183 50184 50185 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50183 def ad_group_ad_result @ad_group_ad_result end |
#ad_group_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupAssetResult
The result for the ad group asset mutate.
Corresponds to the JSON property adGroupAssetResult
50188 50189 50190 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50188 def ad_group_asset_result @ad_group_asset_result end |
#ad_group_bid_modifier_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupBidModifierResult
The result for the criterion mutate.
Corresponds to the JSON property adGroupBidModifierResult
50193 50194 50195 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50193 def ad_group_bid_modifier_result @ad_group_bid_modifier_result end |
#ad_group_criterion_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionCustomizerResult
The result for the ad group criterion customizer mutate.
Corresponds to the JSON property adGroupCriterionCustomizerResult
50198 50199 50200 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50198 def ad_group_criterion_customizer_result @ad_group_criterion_customizer_result end |
#ad_group_criterion_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionLabelResult
The result for an ad group criterion label mutate.
Corresponds to the JSON property adGroupCriterionLabelResult
50203 50204 50205 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50203 def ad_group_criterion_label_result @ad_group_criterion_label_result end |
#ad_group_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCriterionResult
The result for the criterion mutate.
Corresponds to the JSON property adGroupCriterionResult
50208 50209 50210 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50208 def ad_group_criterion_result @ad_group_criterion_result end |
#ad_group_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupCustomizerResult
The result for the ad group customizer mutate.
Corresponds to the JSON property adGroupCustomizerResult
50213 50214 50215 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50213 def ad_group_customizer_result @ad_group_customizer_result end |
#ad_group_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupLabelResult
The result for an ad group label mutate.
Corresponds to the JSON property adGroupLabelResult
50218 50219 50220 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50218 def ad_group_label_result @ad_group_label_result end |
#ad_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdGroupResult
The result for the ad group mutate.
Corresponds to the JSON property adGroupResult
50223 50224 50225 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50223 def ad_group_result @ad_group_result end |
#ad_parameter_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdParameterResult
The result for the ad parameter mutate.
Corresponds to the JSON property adParameterResult
50228 50229 50230 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50228 def ad_parameter_result @ad_parameter_result end |
#ad_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAdResult
The result for the ad mutate.
Corresponds to the JSON property adResult
50233 50234 50235 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50233 def ad_result @ad_result end |
#asset_group_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupAssetResult
The result for the asset group asset mutate.
Corresponds to the JSON property assetGroupAssetResult
50238 50239 50240 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50238 def asset_group_asset_result @asset_group_asset_result end |
#asset_group_listing_group_filter_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupListingGroupFilterResult
The result for the asset group listing group filter mutate.
Corresponds to the JSON property assetGroupListingGroupFilterResult
50243 50244 50245 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50243 def asset_group_listing_group_filter_result @asset_group_listing_group_filter_result end |
#asset_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupResult
The result for the asset group mutate.
Corresponds to the JSON property assetGroupResult
50248 50249 50250 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50248 def asset_group_result @asset_group_result end |
#asset_group_signal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetGroupSignalResult
The result for the asset group signal mutate.
Corresponds to the JSON property assetGroupSignalResult
50253 50254 50255 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50253 def asset_group_signal_result @asset_group_signal_result end |
#asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetResult
The result for the asset mutate.
Corresponds to the JSON property assetResult
50258 50259 50260 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50258 def asset_result @asset_result end |
#asset_set_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetAssetResult
The result for the asset set asset mutate.
Corresponds to the JSON property assetSetAssetResult
50263 50264 50265 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50263 def asset_set_asset_result @asset_set_asset_result end |
#asset_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAssetSetResult
The result for the asset set mutate.
Corresponds to the JSON property assetSetResult
50268 50269 50270 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50268 def asset_set_result @asset_set_result end |
#audience_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateAudienceResult
The result for the audience mutate.
Corresponds to the JSON property audienceResult
50273 50274 50275 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50273 def audience_result @audience_result end |
#bidding_data_exclusion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingDataExclusionsResult
The result for the data exclusion mutate.
Corresponds to the JSON property biddingDataExclusionResult
50278 50279 50280 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50278 def bidding_data_exclusion_result @bidding_data_exclusion_result end |
#bidding_seasonality_adjustment_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingSeasonalityAdjustmentsResult
The result for the seasonality adjustment mutate.
Corresponds to the JSON property biddingSeasonalityAdjustmentResult
50283 50284 50285 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50283 def bidding_seasonality_adjustment_result @bidding_seasonality_adjustment_result end |
#bidding_strategy_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateBiddingStrategyResult
The result for the bidding strategy mutate.
Corresponds to the JSON property biddingStrategyResult
50288 50289 50290 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50288 def bidding_strategy_result @bidding_strategy_result end |
#campaign_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetResult
The result for the campaign asset mutate.
Corresponds to the JSON property campaignAssetResult
50293 50294 50295 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50293 def campaign_asset_result @campaign_asset_result end |
#campaign_asset_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignAssetSetResult
The result for the campaign asset set mutate.
Corresponds to the JSON property campaignAssetSetResult
50298 50299 50300 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50298 def campaign_asset_set_result @campaign_asset_set_result end |
#campaign_bid_modifier_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBidModifierResult
The result for the criterion mutate.
Corresponds to the JSON property campaignBidModifierResult
50303 50304 50305 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50303 def campaign_bid_modifier_result @campaign_bid_modifier_result end |
#campaign_budget_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignBudgetResult
The result for the campaign budget mutate.
Corresponds to the JSON property campaignBudgetResult
50308 50309 50310 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50308 def campaign_budget_result @campaign_budget_result end |
#campaign_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignConversionGoalResult
The result for the campaign conversion goal mutate.
Corresponds to the JSON property campaignConversionGoalResult
50313 50314 50315 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50313 def campaign_conversion_goal_result @campaign_conversion_goal_result end |
#campaign_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCriterionResult
The result for the criterion mutate.
Corresponds to the JSON property campaignCriterionResult
50318 50319 50320 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50318 def campaign_criterion_result @campaign_criterion_result end |
#campaign_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignCustomizerResult
The result for the campaign customizer mutate.
Corresponds to the JSON property campaignCustomizerResult
50323 50324 50325 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50323 def campaign_customizer_result @campaign_customizer_result end |
#campaign_draft_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignDraftResult
The result for the campaign draft mutate.
Corresponds to the JSON property campaignDraftResult
50328 50329 50330 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50328 def campaign_draft_result @campaign_draft_result end |
#campaign_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignGroupResult
The result for the campaign group mutate.
Corresponds to the JSON property campaignGroupResult
50333 50334 50335 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50333 def campaign_group_result @campaign_group_result end |
#campaign_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignLabelResult
The result for a campaign label mutate.
Corresponds to the JSON property campaignLabelResult
50338 50339 50340 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50338 def campaign_label_result @campaign_label_result end |
#campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignResult
The result for the campaign mutate.
Corresponds to the JSON property campaignResult
50343 50344 50345 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50343 def campaign_result @campaign_result end |
#campaign_shared_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCampaignSharedSetResult
The result for the campaign shared set mutate.
Corresponds to the JSON property campaignSharedSetResult
50348 50349 50350 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50348 def campaign_shared_set_result @campaign_shared_set_result end |
#conversion_action_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionActionResult
The result for the conversion action mutate.
Corresponds to the JSON property conversionActionResult
50353 50354 50355 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50353 def conversion_action_result @conversion_action_result end |
#conversion_custom_variable_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionCustomVariableResult
The result for the conversion custom variable mutate.
Corresponds to the JSON property conversionCustomVariableResult
50358 50359 50360 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50358 def conversion_custom_variable_result @conversion_custom_variable_result end |
#conversion_goal_campaign_config_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionGoalCampaignConfigResult
The result for the conversion goal campaign config mutate.
Corresponds to the JSON property conversionGoalCampaignConfigResult
50363 50364 50365 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50363 def conversion_goal_campaign_config_result @conversion_goal_campaign_config_result end |
#conversion_value_rule_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleResult
The result for the conversion value rule mutate.
Corresponds to the JSON property conversionValueRuleResult
50368 50369 50370 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50368 def conversion_value_rule_result @conversion_value_rule_result end |
#conversion_value_rule_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateConversionValueRuleSetResult
The result for the conversion value rule set mutate.
Corresponds to the JSON property conversionValueRuleSetResult
50373 50374 50375 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50373 def conversion_value_rule_set_result @conversion_value_rule_set_result end |
#custom_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomConversionGoalResult
The result for the custom conversion goal mutate.
Corresponds to the JSON property customConversionGoalResult
50378 50379 50380 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50378 def custom_conversion_goal_result @custom_conversion_goal_result end |
#customer_asset_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerAssetResult
The result for the customer asset mutate.
Corresponds to the JSON property customerAssetResult
50383 50384 50385 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50383 def customer_asset_result @customer_asset_result end |
#customer_conversion_goal_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerConversionGoalResult
The result for the customer conversion goal mutate.
Corresponds to the JSON property customerConversionGoalResult
50388 50389 50390 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50388 def customer_conversion_goal_result @customer_conversion_goal_result end |
#customer_customizer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerCustomizerResult
The result for the customizer attribute mutate.
Corresponds to the JSON property customerCustomizerResult
50393 50394 50395 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50393 def customer_customizer_result @customer_customizer_result end |
#customer_label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerLabelResult
The result for a customer label mutate.
Corresponds to the JSON property customerLabelResult
50398 50399 50400 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50398 def customer_label_result @customer_label_result end |
#customer_negative_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerNegativeCriteriaResult
The result for the criterion mutate.
Corresponds to the JSON property customerNegativeCriterionResult
50403 50404 50405 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50403 def customer_negative_criterion_result @customer_negative_criterion_result end |
#customer_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomerResult
The result for the customer mutate.
Corresponds to the JSON property customerResult
50408 50409 50410 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50408 def customer_result @customer_result end |
#customizer_attribute_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateCustomizerAttributeResult
The result for the customizer attribute mutate.
Corresponds to the JSON property customizerAttributeResult
50413 50414 50415 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50413 def customizer_attribute_result @customizer_attribute_result end |
#experiment_arm_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentArmResult
The result for the experiment arm mutate.
Corresponds to the JSON property experimentArmResult
50418 50419 50420 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50418 def experiment_arm_result @experiment_arm_result end |
#experiment_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateExperimentResult
The result for the campaign experiment mutate.
Corresponds to the JSON property experimentResult
50423 50424 50425 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50423 def experiment_result @experiment_result end |
#keyword_plan_ad_group_keyword_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupKeywordResult
The result for the Keyword Plan ad group keyword mutate.
Corresponds to the JSON property keywordPlanAdGroupKeywordResult
50428 50429 50430 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50428 def keyword_plan_ad_group_keyword_result @keyword_plan_ad_group_keyword_result end |
#keyword_plan_ad_group_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanAdGroupResult
The result for the Keyword Plan ad group mutate.
Corresponds to the JSON property keywordPlanAdGroupResult
50433 50434 50435 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50433 def keyword_plan_ad_group_result @keyword_plan_ad_group_result end |
#keyword_plan_campaign_keyword_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignKeywordResult
The result for the Keyword Plan campaign keyword mutate.
Corresponds to the JSON property keywordPlanCampaignKeywordResult
50438 50439 50440 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50438 def keyword_plan_campaign_keyword_result @keyword_plan_campaign_keyword_result end |
#keyword_plan_campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlanCampaignResult
The result for the Keyword Plan campaign mutate.
Corresponds to the JSON property keywordPlanCampaignResult
50443 50444 50445 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50443 def keyword_plan_campaign_result @keyword_plan_campaign_result end |
#keyword_plan_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateKeywordPlansResult
The result for the keyword plan mutate.
Corresponds to the JSON property keywordPlanResult
50448 50449 50450 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50448 def keyword_plan_result @keyword_plan_result end |
#label_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateLabelResult
The result for a label mutate.
Corresponds to the JSON property labelResult
50453 50454 50455 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50453 def label_result @label_result end |
#recommendation_subscription_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResult
Result message for RecommendationSubscriptionService.
MutateRecommendationSubscription
Corresponds to the JSON property recommendationSubscriptionResult
50459 50460 50461 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50459 def recommendation_subscription_result @recommendation_subscription_result end |
#remarketing_action_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRemarketingActionResult
The result for the remarketing action mutate.
Corresponds to the JSON property remarketingActionResult
50464 50465 50466 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50464 def remarketing_action_result @remarketing_action_result end |
#search_ads360_campaign_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSearchAds360CampaignResult
The result for the Search Ads 360 campaign mutate.
Corresponds to the JSON property searchAds360CampaignResult
50469 50470 50471 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50469 def search_ads360_campaign_result @search_ads360_campaign_result end |
#shared_criterion_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedCriterionResult
The result for the shared criterion mutate.
Corresponds to the JSON property sharedCriterionResult
50474 50475 50476 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50474 def shared_criterion_result @shared_criterion_result end |
#shared_set_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedSetResult
The result for the shared set mutate.
Corresponds to the JSON property sharedSetResult
50479 50480 50481 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50479 def shared_set_result @shared_set_result end |
#smart_campaign_setting_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSmartCampaignSettingResult
The result for the Smart campaign setting mutate.
Corresponds to the JSON property smartCampaignSettingResult
50484 50485 50486 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50484 def smart_campaign_setting_result @smart_campaign_setting_result end |
#user_list_result ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateUserListResult
The result for the user list mutate.
Corresponds to the JSON property userListResult
50489 50490 50491 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50489 def user_list_result @user_list_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50496 50497 50498 50499 50500 50501 50502 50503 50504 50505 50506 50507 50508 50509 50510 50511 50512 50513 50514 50515 50516 50517 50518 50519 50520 50521 50522 50523 50524 50525 50526 50527 50528 50529 50530 50531 50532 50533 50534 50535 50536 50537 50538 50539 50540 50541 50542 50543 50544 50545 50546 50547 50548 50549 50550 50551 50552 50553 50554 50555 50556 50557 50558 50559 50560 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50496 def update!(**args) @ad_group_ad_label_result = args[:ad_group_ad_label_result] if args.key?(:ad_group_ad_label_result) @ad_group_ad_result = args[:ad_group_ad_result] if args.key?(:ad_group_ad_result) @ad_group_asset_result = args[:ad_group_asset_result] if args.key?(:ad_group_asset_result) @ad_group_bid_modifier_result = args[:ad_group_bid_modifier_result] if args.key?(:ad_group_bid_modifier_result) @ad_group_criterion_customizer_result = args[:ad_group_criterion_customizer_result] if args.key?(:ad_group_criterion_customizer_result) @ad_group_criterion_label_result = args[:ad_group_criterion_label_result] if args.key?(:ad_group_criterion_label_result) @ad_group_criterion_result = args[:ad_group_criterion_result] if args.key?(:ad_group_criterion_result) @ad_group_customizer_result = args[:ad_group_customizer_result] if args.key?(:ad_group_customizer_result) @ad_group_label_result = args[:ad_group_label_result] if args.key?(:ad_group_label_result) @ad_group_result = args[:ad_group_result] if args.key?(:ad_group_result) @ad_parameter_result = args[:ad_parameter_result] if args.key?(:ad_parameter_result) @ad_result = args[:ad_result] if args.key?(:ad_result) @asset_group_asset_result = args[:asset_group_asset_result] if args.key?(:asset_group_asset_result) @asset_group_listing_group_filter_result = args[:asset_group_listing_group_filter_result] if args.key?(:asset_group_listing_group_filter_result) @asset_group_result = args[:asset_group_result] if args.key?(:asset_group_result) @asset_group_signal_result = args[:asset_group_signal_result] if args.key?(:asset_group_signal_result) @asset_result = args[:asset_result] if args.key?(:asset_result) @asset_set_asset_result = args[:asset_set_asset_result] if args.key?(:asset_set_asset_result) @asset_set_result = args[:asset_set_result] if args.key?(:asset_set_result) @audience_result = args[:audience_result] if args.key?(:audience_result) @bidding_data_exclusion_result = args[:bidding_data_exclusion_result] if args.key?(:bidding_data_exclusion_result) @bidding_seasonality_adjustment_result = args[:bidding_seasonality_adjustment_result] if args.key?(:bidding_seasonality_adjustment_result) @bidding_strategy_result = args[:bidding_strategy_result] if args.key?(:bidding_strategy_result) @campaign_asset_result = args[:campaign_asset_result] if args.key?(:campaign_asset_result) @campaign_asset_set_result = args[:campaign_asset_set_result] if args.key?(:campaign_asset_set_result) @campaign_bid_modifier_result = args[:campaign_bid_modifier_result] if args.key?(:campaign_bid_modifier_result) @campaign_budget_result = args[:campaign_budget_result] if args.key?(:campaign_budget_result) @campaign_conversion_goal_result = args[:campaign_conversion_goal_result] if args.key?(:campaign_conversion_goal_result) @campaign_criterion_result = args[:campaign_criterion_result] if args.key?(:campaign_criterion_result) @campaign_customizer_result = args[:campaign_customizer_result] if args.key?(:campaign_customizer_result) @campaign_draft_result = args[:campaign_draft_result] if args.key?(:campaign_draft_result) @campaign_group_result = args[:campaign_group_result] if args.key?(:campaign_group_result) @campaign_label_result = args[:campaign_label_result] if args.key?(:campaign_label_result) @campaign_result = args[:campaign_result] if args.key?(:campaign_result) @campaign_shared_set_result = args[:campaign_shared_set_result] if args.key?(:campaign_shared_set_result) @conversion_action_result = args[:conversion_action_result] if args.key?(:conversion_action_result) @conversion_custom_variable_result = args[:conversion_custom_variable_result] if args.key?(:conversion_custom_variable_result) @conversion_goal_campaign_config_result = args[:conversion_goal_campaign_config_result] if args.key?(:conversion_goal_campaign_config_result) @conversion_value_rule_result = args[:conversion_value_rule_result] if args.key?(:conversion_value_rule_result) @conversion_value_rule_set_result = args[:conversion_value_rule_set_result] if args.key?(:conversion_value_rule_set_result) @custom_conversion_goal_result = args[:custom_conversion_goal_result] if args.key?(:custom_conversion_goal_result) @customer_asset_result = args[:customer_asset_result] if args.key?(:customer_asset_result) @customer_conversion_goal_result = args[:customer_conversion_goal_result] if args.key?(:customer_conversion_goal_result) @customer_customizer_result = args[:customer_customizer_result] if args.key?(:customer_customizer_result) @customer_label_result = args[:customer_label_result] if args.key?(:customer_label_result) @customer_negative_criterion_result = args[:customer_negative_criterion_result] if args.key?(:customer_negative_criterion_result) @customer_result = args[:customer_result] if args.key?(:customer_result) @customizer_attribute_result = args[:customizer_attribute_result] if args.key?(:customizer_attribute_result) @experiment_arm_result = args[:experiment_arm_result] if args.key?(:experiment_arm_result) @experiment_result = args[:experiment_result] if args.key?(:experiment_result) @keyword_plan_ad_group_keyword_result = args[:keyword_plan_ad_group_keyword_result] if args.key?(:keyword_plan_ad_group_keyword_result) @keyword_plan_ad_group_result = args[:keyword_plan_ad_group_result] if args.key?(:keyword_plan_ad_group_result) @keyword_plan_campaign_keyword_result = args[:keyword_plan_campaign_keyword_result] if args.key?(:keyword_plan_campaign_keyword_result) @keyword_plan_campaign_result = args[:keyword_plan_campaign_result] if args.key?(:keyword_plan_campaign_result) @keyword_plan_result = args[:keyword_plan_result] if args.key?(:keyword_plan_result) @label_result = args[:label_result] if args.key?(:label_result) @recommendation_subscription_result = args[:recommendation_subscription_result] if args.key?(:recommendation_subscription_result) @remarketing_action_result = args[:remarketing_action_result] if args.key?(:remarketing_action_result) @search_ads360_campaign_result = args[:search_ads360_campaign_result] if args.key?(:search_ads360_campaign_result) @shared_criterion_result = args[:shared_criterion_result] if args.key?(:shared_criterion_result) @shared_set_result = args[:shared_set_result] if args.key?(:shared_set_result) @smart_campaign_setting_result = args[:smart_campaign_setting_result] if args.key?(:smart_campaign_setting_result) @user_list_result = args[:user_list_result] if args.key?(:user_list_result) end |