Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for RecommendationSubscriptionService. MutateRecommendationSubscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionRequest.



51364
51365
51366
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51364

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRecommendationSubscriptionOperation>

Required. The list of create or update operations. Corresponds to the JSON property operations



51339
51340
51341
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51339

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


51346
51347
51348
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51346

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. The mutable resource will only be returned if the resource has the appropriate response field. For example, MutateCampaignResult.campaign. Corresponds to the JSON property responseContentType

Returns:

  • (String)


51355
51356
51357
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51355

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


51361
51362
51363
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51361

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51369
51370
51371
51372
51373
51374
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51369

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end