Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for RecommendationSubscriptionService. MutateRecommendationSubscription
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRecommendationSubscriptionOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionRequest.
51292 51293 51294 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51292 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRecommendationSubscriptionOperation>
Required. The list of create or update operations.
Corresponds to the JSON property operations
51267 51268 51269 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51267 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
51274 51275 51276 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51274 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation. The mutable resource
will only be returned if the resource has the appropriate response field. For
example, MutateCampaignResult.campaign.
Corresponds to the JSON property responseContentType
51283 51284 51285 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51283 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
51289 51290 51291 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51289 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51297 51298 51299 51300 51301 51302 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51297 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |