Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for RecommendationSubscriptionService. MutateRecommendationSubscription
Instance Attribute Summary collapse
-
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResult>
Results, one per operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse.
51409 51410 51411 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property partialFailureError
51402 51403 51404 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51402 def partial_failure_error @partial_failure_error end |
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResult>
Results, one per operation.
Corresponds to the JSON property results
51407 51408 51409 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51407 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51414 51415 51416 51417 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51414 def update!(**args) @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error) @results = args[:results] if args.key?(:results) end |