Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for RecommendationSubscriptionService. MutateRecommendationSubscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse.



51397
51398
51399
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



51390
51391
51392
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51390

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResult>

Results, one per operation. Corresponds to the JSON property results



51395
51396
51397
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51395

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51402
51403
51404
51405
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51402

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end