Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for RecommendationSubscriptionService. MutateRecommendationSubscription
Instance Attribute Summary collapse
-
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResult>
Results, one per operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResponse.
51325 51326 51327 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property partialFailureError
51318 51319 51320 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51318 def partial_failure_error @partial_failure_error end |
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRecommendationSubscriptionResult>
Results, one per operation.
Corresponds to the JSON property results
51323 51324 51325 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51323 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51330 51331 51332 51333 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51330 def update!(**args) @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error) @results = args[:results] if args.key?(:results) end |