Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateRemarketingActionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for RemarketingActionService.MutateRemarketingActions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateRemarketingActionsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateRemarketingActionsRequest.



51477
51478
51479
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemarketingActionOperation>

Required. The list of operations to perform on individual remarketing actions. Corresponds to the JSON property operations



51460
51461
51462
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51460

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


51467
51468
51469
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51467

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


51474
51475
51476
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51474

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51482
51483
51484
51485
51486
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51482

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end