Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSearchAds360CampaignsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for SearchAds360CampaignService.MutateSearchAds360Campaigns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSearchAds360CampaignsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateSearchAds360CampaignsRequest.



51575
51576
51577
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51575

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation>

Required. The list of operations to perform on individual Search Ads 360 campaigns. Corresponds to the JSON property operations



51552
51553
51554
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51552

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


51559
51560
51561
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51559

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


51566
51567
51568
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51566

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


51572
51573
51574
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51572

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51580
51581
51582
51583
51584
51585
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51580

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end