Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSearchAds360CampaignsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for SearchAds360CampaignService.MutateSearchAds360Campaigns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSearchAds360CampaignsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateSearchAds360CampaignsRequest.



51503
51504
51505
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51503

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation>

Required. The list of operations to perform on individual Search Ads 360 campaigns. Corresponds to the JSON property operations



51480
51481
51482
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51480

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


51487
51488
51489
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51487

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


51494
51495
51496
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51494

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


51500
51501
51502
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51500

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51508
51509
51510
51511
51512
51513
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51508

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end