Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSearchAds360Request

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for Service.Mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSearchAds360Request

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateSearchAds360Request.



51566
51567
51568
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51566

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mutate_operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperation>

Required. The list of operations to perform on individual resources. Corresponds to the JSON property mutateOperations



51542
51543
51544
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51542

def mutate_operations
  @mutate_operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


51549
51550
51551
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51549

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. The mutable resource will only be returned if the resource has the appropriate response field. For example, . Corresponds to the JSON property responseContentType

Returns:

  • (String)


51558
51559
51560
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51558

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


51563
51564
51565
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51563

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51571
51572
51573
51574
51575
51576
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51571

def update!(**args)
  @mutate_operations = args[:mutate_operations] if args.key?(:mutate_operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end