Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSearchAds360Request
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSearchAds360Request
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for Service.Mutate.
Instance Attribute Summary collapse
-
#mutate_operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Corresponds to the JSON property
validateOnly.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSearchAds360Request
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateSearchAds360Request.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSearchAds360Request
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateSearchAds360Request.
50807 50808 50809 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50807 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mutate_operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperation>
Required. The list of operations to perform on individual resources.
Corresponds to the JSON property mutateOperations
50783 50784 50785 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50783 def mutate_operations @mutate_operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
50790 50791 50792 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50790 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation. The mutable resource
will only be returned if the resource has the appropriate response field. For
example, .
Corresponds to the JSON property responseContentType
50799 50800 50801 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50799 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
Corresponds to the JSON property validateOnly
50804 50805 50806 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50804 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50812 50813 50814 50815 50816 50817 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50812 def update!(**args) @mutate_operations = args[:mutate_operations] if args.key?(:mutate_operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |