Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSearchAds360Response

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for Service.Mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSearchAds360Response

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateSearchAds360Response.



51670
51671
51672
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51670

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mutate_operation_responsesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateOperationResponse>

All responses for the mutate. Corresponds to the JSON property mutateOperationResponses



51658
51659
51660
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51658

def mutate_operation_responses
  @mutate_operation_responses
end

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



51668
51669
51670
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51668

def partial_failure_error
  @partial_failure_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51675
51676
51677
51678
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51675

def update!(**args)
  @mutate_operation_responses = args[:mutate_operation_responses] if args.key?(:mutate_operation_responses)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
end