Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedCriteriaRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedCriteriaRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for SharedCriterionService.MutateSharedCriteria.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedCriterionOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSharedCriteriaRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateSharedCriteriaRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSharedCriteriaRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateSharedCriteriaRequest.
51711 51712 51713 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedCriterionOperation>
Required. The list of operations to perform on individual shared criteria.
Corresponds to the JSON property operations
51688 51689 51690 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51688 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
51695 51696 51697 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51695 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
51702 51703 51704 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51702 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
51708 51709 51710 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51708 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51716 51717 51718 51719 51720 51721 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51716 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |