Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedCriteriaResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for a shared criterion mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSharedCriteriaResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateSharedCriteriaResponse.



51743
51744
51745
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51743

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



51736
51737
51738
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51736

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedCriterionResult>

All results for the mutate. Corresponds to the JSON property results



51741
51742
51743
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51741

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51748
51749
51750
51751
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51748

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end