Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for SharedSetService.MutateSharedSets.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedSetOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest.
51846 51847 51848 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51846 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedSetOperation>
Required. The list of operations to perform on individual shared sets.
Corresponds to the JSON property operations
51823 51824 51825 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51823 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
51830 51831 51832 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51830 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
51837 51838 51839 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51837 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
51843 51844 51845 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51843 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51851 51852 51853 51854 51855 51856 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51851 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |