Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for SharedSetService.MutateSharedSets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest.



51834
51835
51836
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51834

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedSetOperation>

Required. The list of operations to perform on individual shared sets. Corresponds to the JSON property operations



51811
51812
51813
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51811

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


51818
51819
51820
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51818

def partial_failure
  @partial_failure
end

#response_content_typeString

The response content type setting. Determines whether the mutable resource or just the resource name should be returned post mutation. Corresponds to the JSON property responseContentType

Returns:

  • (String)


51825
51826
51827
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51825

def response_content_type
  @response_content_type
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


51831
51832
51833
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51831

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51839
51840
51841
51842
51843
51844
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51839

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @response_content_type = args[:response_content_type] if args.key?(:response_content_type)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end