Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for SharedSetService.MutateSharedSets.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedSetOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
If true, successful operations will be carried out and invalid operations will return errors.
-
#response_content_type ⇒ String
The response content type setting.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesMutateSharedSetsRequest.
51003 51004 51005 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51003 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedSetOperation>
Required. The list of operations to perform on individual shared sets.
Corresponds to the JSON property operations
50980 50981 50982 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50980 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
If true, successful operations will be carried out and invalid operations will
return errors. If false, all operations will be carried out in one transaction
if and only if they are all valid. Default is false.
Corresponds to the JSON property partialFailure
50987 50988 50989 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50987 def partial_failure @partial_failure end |
#response_content_type ⇒ String
The response content type setting. Determines whether the mutable resource or
just the resource name should be returned post mutation.
Corresponds to the JSON property responseContentType
50994 50995 50996 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 50994 def response_content_type @response_content_type end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
51000 51001 51002 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51000 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51008 51009 51010 51011 51012 51013 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51008 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @response_content_type = args[:response_content_type] if args.key?(:response_content_type) @validate_only = args[:validate_only] if args.key?(:validate_only) end |