Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateUserListsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for UserListService.MutateUserLists.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateUserListsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateUserListsRequest.



51273
51274
51275
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUserListOperation>

Required. The list of operations to perform on individual user lists. Corresponds to the JSON property operations



51256
51257
51258
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51256

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Default is false. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


51263
51264
51265
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51263

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


51270
51271
51272
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51270

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51278
51279
51280
51281
51282
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51278

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end