Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateUserListsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for user list mutate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesMutateUserListsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesMutateUserListsResponse.



52063
52064
52065
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



52056
52057
52058
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52056

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMutateUserListResult>

All results for the mutate. Corresponds to the JSON property results



52061
52062
52063
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52061

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52068
52069
52070
52071
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52068

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end