Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesOnTargetAudienceMetrics
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesOnTargetAudienceMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Audience metrics for the planned products. These metrics consider the following targeting dimensions: - Location - PlannableAgeRange - Gender - AudienceTargeting (only for youtube_audience_size)
Instance Attribute Summary collapse
-
#census_audience_size ⇒ Fixnum
Reference audience size matching the considered targeting for Census.
-
#youtube_audience_size ⇒ Fixnum
Reference audience size matching the considered targeting for YouTube.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesOnTargetAudienceMetrics
constructor
A new instance of GoogleAdsSearchads360V23ServicesOnTargetAudienceMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesOnTargetAudienceMetrics
Returns a new instance of GoogleAdsSearchads360V23ServicesOnTargetAudienceMetrics.
52122 52123 52124 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52122 def initialize(**args) update!(**args) end |
Instance Attribute Details
#census_audience_size ⇒ Fixnum
Reference audience size matching the considered targeting for Census.
Corresponds to the JSON property censusAudienceSize
52115 52116 52117 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52115 def census_audience_size @census_audience_size end |
#youtube_audience_size ⇒ Fixnum
Reference audience size matching the considered targeting for YouTube.
Corresponds to the JSON property youtubeAudienceSize
52120 52121 52122 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52120 def youtube_audience_size @youtube_audience_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52127 52128 52129 52130 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52127 def update!(**args) @census_audience_size = args[:census_audience_size] if args.key?(:census_audience_size) @youtube_audience_size = args[:youtube_audience_size] if args.key?(:youtube_audience_size) end |