Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesOnTargetAudienceMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Audience metrics for the planned products. These metrics consider the following targeting dimensions: - Location - PlannableAgeRange - Gender - AudienceTargeting (only for youtube_audience_size)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesOnTargetAudienceMetrics

Returns a new instance of GoogleAdsSearchads360V23ServicesOnTargetAudienceMetrics.



51363
51364
51365
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#census_audience_sizeFixnum

Reference audience size matching the considered targeting for Census. Corresponds to the JSON property censusAudienceSize

Returns:

  • (Fixnum)


51356
51357
51358
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51356

def census_audience_size
  @census_audience_size
end

#youtube_audience_sizeFixnum

Reference audience size matching the considered targeting for YouTube. Corresponds to the JSON property youtubeAudienceSize

Returns:

  • (Fixnum)


51361
51362
51363
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51361

def youtube_audience_size
  @youtube_audience_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51368
51369
51370
51371
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51368

def update!(**args)
  @census_audience_size = args[:census_audience_size] if args.key?(:census_audience_size)
  @youtube_audience_size = args[:youtube_audience_size] if args.key?(:youtube_audience_size)
end