Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannableTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The targeting for which traffic metrics will be reported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannableTargeting

Returns a new instance of GoogleAdsSearchads360V23ServicesPlannableTargeting.



52288
52289
52290
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52288

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_rangesArray<String>

Allowed plannable age ranges for the product for which metrics will be reported. Actual targeting is computed by mapping this age range onto standard Google common.AgeRangeInfo values. Corresponds to the JSON property ageRanges

Returns:

  • (Array<String>)


52259
52260
52261
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52259

def age_ranges
  @age_ranges
end

#devicesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo>

Targetable devices for the ad product. TABLET device targeting is automatically applied to reported metrics when MOBILE targeting is selected for CPM_MASTHEAD, GOOGLE_PREFERRED_BUMPER, and GOOGLE_PREFERRED_SHORT products. Corresponds to the JSON property devices



52266
52267
52268
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52266

def devices
  @devices
end

#gendersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo>

Targetable genders for the ad product. Corresponds to the JSON property genders



52271
52272
52273
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52271

def genders
  @genders
end

#networksArray<String>

Targetable networks for the ad product. Corresponds to the JSON property networks

Returns:

  • (Array<String>)


52276
52277
52278
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52276

def networks
  @networks
end

#surface_targetingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargetingCombinations

The surface targeting combinations available for an ad product. Corresponds to the JSON property surfaceTargeting



52281
52282
52283
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52281

def surface_targeting
  @surface_targeting
end

#youtube_select_lineupsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesYouTubeSelectLineUp>

Targetable YouTube Select Lineups for the ad product. Corresponds to the JSON property youtubeSelectLineups



52286
52287
52288
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52286

def youtube_select_lineups
  @youtube_select_lineups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52293
52294
52295
52296
52297
52298
52299
52300
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52293

def update!(**args)
  @age_ranges = args[:age_ranges] if args.key?(:age_ranges)
  @devices = args[:devices] if args.key?(:devices)
  @genders = args[:genders] if args.key?(:genders)
  @networks = args[:networks] if args.key?(:networks)
  @surface_targeting = args[:surface_targeting] if args.key?(:surface_targeting)
  @youtube_select_lineups = args[:youtube_select_lineups] if args.key?(:youtube_select_lineups)
end