Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannableTargeting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannableTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The targeting for which traffic metrics will be reported.
Instance Attribute Summary collapse
-
#age_ranges ⇒ Array<String>
Allowed plannable age ranges for the product for which metrics will be reported.
-
#devices ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo>
Targetable devices for the ad product.
-
#genders ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo>
Targetable genders for the ad product.
-
#networks ⇒ Array<String>
Targetable networks for the ad product.
-
#surface_targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargetingCombinations
The surface targeting combinations available for an ad product.
-
#youtube_select_lineups ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesYouTubeSelectLineUp>
Targetable YouTube Select Lineups for the ad product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannableTargeting
constructor
A new instance of GoogleAdsSearchads360V23ServicesPlannableTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannableTargeting
Returns a new instance of GoogleAdsSearchads360V23ServicesPlannableTargeting.
52216 52217 52218 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52216 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age_ranges ⇒ Array<String>
Allowed plannable age ranges for the product for which metrics will be
reported. Actual targeting is computed by mapping this age range onto standard
Google common.AgeRangeInfo values.
Corresponds to the JSON property ageRanges
52187 52188 52189 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52187 def age_ranges @age_ranges end |
#devices ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo>
Targetable devices for the ad product. TABLET device targeting is
automatically applied to reported metrics when MOBILE targeting is selected
for CPM_MASTHEAD, GOOGLE_PREFERRED_BUMPER, and GOOGLE_PREFERRED_SHORT products.
Corresponds to the JSON property devices
52194 52195 52196 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52194 def devices @devices end |
#genders ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo>
Targetable genders for the ad product.
Corresponds to the JSON property genders
52199 52200 52201 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52199 def genders @genders end |
#networks ⇒ Array<String>
Targetable networks for the ad product.
Corresponds to the JSON property networks
52204 52205 52206 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52204 def networks @networks end |
#surface_targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargetingCombinations
The surface targeting combinations available for an ad product.
Corresponds to the JSON property surfaceTargeting
52209 52210 52211 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52209 def surface_targeting @surface_targeting end |
#youtube_select_lineups ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesYouTubeSelectLineUp>
Targetable YouTube Select Lineups for the ad product.
Corresponds to the JSON property youtubeSelectLineups
52214 52215 52216 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52214 def youtube_select_lineups @youtube_select_lineups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52221 52222 52223 52224 52225 52226 52227 52228 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52221 def update!(**args) @age_ranges = args[:age_ranges] if args.key?(:age_ranges) @devices = args[:devices] if args.key?(:devices) @genders = args[:genders] if args.key?(:genders) @networks = args[:networks] if args.key?(:networks) @surface_targeting = args[:surface_targeting] if args.key?(:surface_targeting) @youtube_select_lineups = args[:youtube_select_lineups] if args.key?(:youtube_select_lineups) end |