Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannableTargeting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannableTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The targeting for which traffic metrics will be reported.
Instance Attribute Summary collapse
-
#age_ranges ⇒ Array<String>
Allowed plannable age ranges for the product for which metrics will be reported.
-
#devices ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo>
Targetable devices for the ad product.
-
#genders ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo>
Targetable genders for the ad product.
-
#networks ⇒ Array<String>
Targetable networks for the ad product.
-
#surface_targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargetingCombinations
The surface targeting combinations available for an ad product.
-
#youtube_select_lineups ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesYouTubeSelectLineUp>
Targetable YouTube Select Lineups for the ad product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannableTargeting
constructor
A new instance of GoogleAdsSearchads360V23ServicesPlannableTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannableTargeting
Returns a new instance of GoogleAdsSearchads360V23ServicesPlannableTargeting.
51457 51458 51459 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51457 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age_ranges ⇒ Array<String>
Allowed plannable age ranges for the product for which metrics will be
reported. Actual targeting is computed by mapping this age range onto standard
Google common.AgeRangeInfo values.
Corresponds to the JSON property ageRanges
51428 51429 51430 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51428 def age_ranges @age_ranges end |
#devices ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo>
Targetable devices for the ad product. TABLET device targeting is
automatically applied to reported metrics when MOBILE targeting is selected
for CPM_MASTHEAD, GOOGLE_PREFERRED_BUMPER, and GOOGLE_PREFERRED_SHORT products.
Corresponds to the JSON property devices
51435 51436 51437 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51435 def devices @devices end |
#genders ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo>
Targetable genders for the ad product.
Corresponds to the JSON property genders
51440 51441 51442 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51440 def genders @genders end |
#networks ⇒ Array<String>
Targetable networks for the ad product.
Corresponds to the JSON property networks
51445 51446 51447 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51445 def networks @networks end |
#surface_targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargetingCombinations
The surface targeting combinations available for an ad product.
Corresponds to the JSON property surfaceTargeting
51450 51451 51452 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51450 def surface_targeting @surface_targeting end |
#youtube_select_lineups ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesYouTubeSelectLineUp>
Targetable YouTube Select Lineups for the ad product.
Corresponds to the JSON property youtubeSelectLineups
51455 51456 51457 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51455 def youtube_select_lineups @youtube_select_lineups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51462 51463 51464 51465 51466 51467 51468 51469 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51462 def update!(**args) @age_ranges = args[:age_ranges] if args.key?(:age_ranges) @devices = args[:devices] if args.key?(:devices) @genders = args[:genders] if args.key?(:genders) @networks = args[:networks] if args.key?(:networks) @surface_targeting = args[:surface_targeting] if args.key?(:surface_targeting) @youtube_select_lineups = args[:youtube_select_lineups] if args.key?(:youtube_select_lineups) end |