Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProduct

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A product being planned for reach.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannedProduct

Returns a new instance of GoogleAdsSearchads360V23ServicesPlannedProduct.



51605
51606
51607
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51605

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_product_targetingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAdvancedProductTargeting

Advanced targeting settings for products. Corresponds to the JSON property advancedProductTargeting



51581
51582
51583
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51581

def advanced_product_targeting
  @advanced_product_targeting
end

#budget_microsFixnum

Required. Maximum budget allocation in micros for the selected product. The value is specified in the selected planning currency_code. For example: 1 000 000$ = 1 000 000 000 000 micros. Corresponds to the JSON property budgetMicros

Returns:

  • (Fixnum)


51588
51589
51590
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51588

def budget_micros
  @budget_micros
end

#conversion_rateFloat

Conversion rate as a decimal between 0 and 1, exclusive. For example: if 2% of ad interactions are expected to lead to conversions, conversion_rate should be 0.02. This field is required for DEMAND_GEN plannable products. It is not supported for other plannable products. Corresponds to the JSON property conversionRate

Returns:

  • (Float)


51596
51597
51598
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51596

def conversion_rate
  @conversion_rate
end

#plannable_product_codeString

Required. Selected product for planning. The code associated with the ad product (for example: Trueview, Bumper). To list the available plannable product codes use ReachPlanService.ListPlannableProducts. Corresponds to the JSON property plannableProductCode

Returns:

  • (String)


51603
51604
51605
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51603

def plannable_product_code
  @plannable_product_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51610
51611
51612
51613
51614
51615
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51610

def update!(**args)
  @advanced_product_targeting = args[:advanced_product_targeting] if args.key?(:advanced_product_targeting)
  @budget_micros = args[:budget_micros] if args.key?(:budget_micros)
  @conversion_rate = args[:conversion_rate] if args.key?(:conversion_rate)
  @plannable_product_code = args[:plannable_product_code] if args.key?(:plannable_product_code)
end