Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProductForecast
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProductForecast
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Forecasted traffic metrics for a planned product.
Instance Attribute Summary collapse
-
#average_frequency ⇒ Float
The number of times per selected time unit a user will see an ad, averaged over the number of time units in the forecast length.
-
#conversions ⇒ Float
The number of conversions.
-
#on_target_coview_impressions ⇒ Fixnum
Number of ad impressions that exactly matches the Targeting including co- viewers.
-
#on_target_coview_reach ⇒ Fixnum
Number of unique people reached that exactly matches the Targeting including co-viewers.
-
#on_target_impressions ⇒ Fixnum
Number of ad impressions that exactly matches the Targeting.
-
#on_target_reach ⇒ Fixnum
Number of unique people reached that exactly matches the Targeting.
-
#total_coview_impressions ⇒ Fixnum
Total number of ad impressions including co-viewers.
-
#total_coview_reach ⇒ Fixnum
Number of unique people reached including co-viewers.
-
#total_impressions ⇒ Fixnum
Total number of ad impressions.
-
#total_reach ⇒ Fixnum
Number of unique people reached.
-
#trueview_views ⇒ Fixnum
Number of ad views forecasted for the specified product and targeting.
-
#viewable_impressions ⇒ Fixnum
Number of times the ad's impressions were considered viewable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannedProductForecast
constructor
A new instance of GoogleAdsSearchads360V23ServicesPlannedProductForecast.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannedProductForecast
Returns a new instance of GoogleAdsSearchads360V23ServicesPlannedProductForecast.
52465 52466 52467 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52465 def initialize(**args) update!(**args) end |
Instance Attribute Details
#average_frequency ⇒ Float
The number of times per selected time unit a user will see an ad, averaged
over the number of time units in the forecast length. This field will only be
populated for a Target Frequency campaign. See https://support.google.com/
google-ads/answer/12400225 for more information about Target Frequency
campaigns.
Corresponds to the JSON property averageFrequency
52388 52389 52390 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52388 def average_frequency @average_frequency end |
#conversions ⇒ Float
The number of conversions. This metric is only available for DEMAND_GEN
plannable products. See https://support.google.com/google-ads/answer/2375431
for more information on conversions.
Corresponds to the JSON property conversions
52395 52396 52397 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52395 def conversions @conversions end |
#on_target_coview_impressions ⇒ Fixnum
Number of ad impressions that exactly matches the Targeting including co-
viewers.
Corresponds to the JSON property onTargetCoviewImpressions
52401 52402 52403 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52401 def on_target_coview_impressions @on_target_coview_impressions end |
#on_target_coview_reach ⇒ Fixnum
Number of unique people reached that exactly matches the Targeting including
co-viewers.
Corresponds to the JSON property onTargetCoviewReach
52407 52408 52409 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52407 def on_target_coview_reach @on_target_coview_reach end |
#on_target_impressions ⇒ Fixnum
Number of ad impressions that exactly matches the Targeting.
Corresponds to the JSON property onTargetImpressions
52412 52413 52414 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52412 def on_target_impressions @on_target_impressions end |
#on_target_reach ⇒ Fixnum
Number of unique people reached that exactly matches the Targeting. Note that
a minimum number of unique people must be reached in order for data to be
reported. If the minimum number is not met, the on_target_reach value will be
rounded to 0.
Corresponds to the JSON property onTargetReach
52420 52421 52422 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52420 def on_target_reach @on_target_reach end |
#total_coview_impressions ⇒ Fixnum
Total number of ad impressions including co-viewers. This includes impressions
that may fall outside the specified Targeting, due to insufficient information
on signed-in users.
Corresponds to the JSON property totalCoviewImpressions
52427 52428 52429 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52427 def total_coview_impressions @total_coview_impressions end |
#total_coview_reach ⇒ Fixnum
Number of unique people reached including co-viewers. This includes people
that may fall outside the specified Targeting.
Corresponds to the JSON property totalCoviewReach
52433 52434 52435 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52433 def total_coview_reach @total_coview_reach end |
#total_impressions ⇒ Fixnum
Total number of ad impressions. This includes impressions that may fall
outside the specified Targeting, due to insufficient information on signed-in
users.
Corresponds to the JSON property totalImpressions
52440 52441 52442 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52440 def total_impressions @total_impressions end |
#total_reach ⇒ Fixnum
Number of unique people reached. This includes people that may fall outside
the specified Targeting. Note that a minimum number of unique people must be
reached in order for data to be reported. If the minimum number is not met,
the total_reach value will be rounded to 0.
Corresponds to the JSON property totalReach
52448 52449 52450 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52448 def total_reach @total_reach end |
#trueview_views ⇒ Fixnum
Number of ad views forecasted for the specified product and targeting. A
TrueView View is counted when a viewer views a larger portion or the entirety
of an ad beyond an impression. See https://support.google.com/google-ads/
answer/2375431 for more information on TrueView Views.
Corresponds to the JSON property trueviewViews
52456 52457 52458 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52456 def trueview_views @trueview_views end |
#viewable_impressions ⇒ Fixnum
Number of times the ad's impressions were considered viewable. See https://
support.google.com/google-ads/answer/7029393 for more information about what
makes an ad viewable and how viewability is measured.
Corresponds to the JSON property viewableImpressions
52463 52464 52465 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52463 def viewable_impressions @viewable_impressions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52470 52471 52472 52473 52474 52475 52476 52477 52478 52479 52480 52481 52482 52483 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52470 def update!(**args) @average_frequency = args[:average_frequency] if args.key?(:average_frequency) @conversions = args[:conversions] if args.key?(:conversions) @on_target_coview_impressions = args[:on_target_coview_impressions] if args.key?(:on_target_coview_impressions) @on_target_coview_reach = args[:on_target_coview_reach] if args.key?(:on_target_coview_reach) @on_target_impressions = args[:on_target_impressions] if args.key?(:on_target_impressions) @on_target_reach = args[:on_target_reach] if args.key?(:on_target_reach) @total_coview_impressions = args[:total_coview_impressions] if args.key?(:total_coview_impressions) @total_coview_reach = args[:total_coview_reach] if args.key?(:total_coview_reach) @total_impressions = args[:total_impressions] if args.key?(:total_impressions) @total_reach = args[:total_reach] if args.key?(:total_reach) @trueview_views = args[:trueview_views] if args.key?(:trueview_views) @viewable_impressions = args[:viewable_impressions] if args.key?(:viewable_impressions) end |