Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProductForecast
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProductForecast
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Forecasted traffic metrics for a planned product.
Instance Attribute Summary collapse
-
#average_frequency ⇒ Float
The number of times per selected time unit a user will see an ad, averaged over the number of time units in the forecast length.
-
#conversions ⇒ Float
The number of conversions.
-
#on_target_coview_impressions ⇒ Fixnum
Number of ad impressions that exactly matches the Targeting including co- viewers.
-
#on_target_coview_reach ⇒ Fixnum
Number of unique people reached that exactly matches the Targeting including co-viewers.
-
#on_target_impressions ⇒ Fixnum
Number of ad impressions that exactly matches the Targeting.
-
#on_target_reach ⇒ Fixnum
Number of unique people reached that exactly matches the Targeting.
-
#total_coview_impressions ⇒ Fixnum
Total number of ad impressions including co-viewers.
-
#total_coview_reach ⇒ Fixnum
Number of unique people reached including co-viewers.
-
#total_impressions ⇒ Fixnum
Total number of ad impressions.
-
#total_reach ⇒ Fixnum
Number of unique people reached.
-
#trueview_views ⇒ Fixnum
Number of ad views forecasted for the specified product and targeting.
-
#viewable_impressions ⇒ Fixnum
Number of times the ad's impressions were considered viewable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannedProductForecast
constructor
A new instance of GoogleAdsSearchads360V23ServicesPlannedProductForecast.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannedProductForecast
Returns a new instance of GoogleAdsSearchads360V23ServicesPlannedProductForecast.
51706 51707 51708 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51706 def initialize(**args) update!(**args) end |
Instance Attribute Details
#average_frequency ⇒ Float
The number of times per selected time unit a user will see an ad, averaged
over the number of time units in the forecast length. This field will only be
populated for a Target Frequency campaign. See https://support.google.com/
google-ads/answer/12400225 for more information about Target Frequency
campaigns.
Corresponds to the JSON property averageFrequency
51629 51630 51631 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51629 def average_frequency @average_frequency end |
#conversions ⇒ Float
The number of conversions. This metric is only available for DEMAND_GEN
plannable products. See https://support.google.com/google-ads/answer/2375431
for more information on conversions.
Corresponds to the JSON property conversions
51636 51637 51638 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51636 def conversions @conversions end |
#on_target_coview_impressions ⇒ Fixnum
Number of ad impressions that exactly matches the Targeting including co-
viewers.
Corresponds to the JSON property onTargetCoviewImpressions
51642 51643 51644 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51642 def on_target_coview_impressions @on_target_coview_impressions end |
#on_target_coview_reach ⇒ Fixnum
Number of unique people reached that exactly matches the Targeting including
co-viewers.
Corresponds to the JSON property onTargetCoviewReach
51648 51649 51650 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51648 def on_target_coview_reach @on_target_coview_reach end |
#on_target_impressions ⇒ Fixnum
Number of ad impressions that exactly matches the Targeting.
Corresponds to the JSON property onTargetImpressions
51653 51654 51655 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51653 def on_target_impressions @on_target_impressions end |
#on_target_reach ⇒ Fixnum
Number of unique people reached that exactly matches the Targeting. Note that
a minimum number of unique people must be reached in order for data to be
reported. If the minimum number is not met, the on_target_reach value will be
rounded to 0.
Corresponds to the JSON property onTargetReach
51661 51662 51663 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51661 def on_target_reach @on_target_reach end |
#total_coview_impressions ⇒ Fixnum
Total number of ad impressions including co-viewers. This includes impressions
that may fall outside the specified Targeting, due to insufficient information
on signed-in users.
Corresponds to the JSON property totalCoviewImpressions
51668 51669 51670 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51668 def total_coview_impressions @total_coview_impressions end |
#total_coview_reach ⇒ Fixnum
Number of unique people reached including co-viewers. This includes people
that may fall outside the specified Targeting.
Corresponds to the JSON property totalCoviewReach
51674 51675 51676 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51674 def total_coview_reach @total_coview_reach end |
#total_impressions ⇒ Fixnum
Total number of ad impressions. This includes impressions that may fall
outside the specified Targeting, due to insufficient information on signed-in
users.
Corresponds to the JSON property totalImpressions
51681 51682 51683 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51681 def total_impressions @total_impressions end |
#total_reach ⇒ Fixnum
Number of unique people reached. This includes people that may fall outside
the specified Targeting. Note that a minimum number of unique people must be
reached in order for data to be reported. If the minimum number is not met,
the total_reach value will be rounded to 0.
Corresponds to the JSON property totalReach
51689 51690 51691 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51689 def total_reach @total_reach end |
#trueview_views ⇒ Fixnum
Number of ad views forecasted for the specified product and targeting. A
TrueView View is counted when a viewer views a larger portion or the entirety
of an ad beyond an impression. See https://support.google.com/google-ads/
answer/2375431 for more information on TrueView Views.
Corresponds to the JSON property trueviewViews
51697 51698 51699 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51697 def trueview_views @trueview_views end |
#viewable_impressions ⇒ Fixnum
Number of times the ad's impressions were considered viewable. See https://
support.google.com/google-ads/answer/7029393 for more information about what
makes an ad viewable and how viewability is measured.
Corresponds to the JSON property viewableImpressions
51704 51705 51706 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51704 def viewable_impressions @viewable_impressions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51711 51712 51713 51714 51715 51716 51717 51718 51719 51720 51721 51722 51723 51724 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51711 def update!(**args) @average_frequency = args[:average_frequency] if args.key?(:average_frequency) @conversions = args[:conversions] if args.key?(:conversions) @on_target_coview_impressions = args[:on_target_coview_impressions] if args.key?(:on_target_coview_impressions) @on_target_coview_reach = args[:on_target_coview_reach] if args.key?(:on_target_coview_reach) @on_target_impressions = args[:on_target_impressions] if args.key?(:on_target_impressions) @on_target_reach = args[:on_target_reach] if args.key?(:on_target_reach) @total_coview_impressions = args[:total_coview_impressions] if args.key?(:total_coview_impressions) @total_coview_reach = args[:total_coview_reach] if args.key?(:total_coview_reach) @total_impressions = args[:total_impressions] if args.key?(:total_impressions) @total_reach = args[:total_reach] if args.key?(:total_reach) @trueview_views = args[:trueview_views] if args.key?(:trueview_views) @viewable_impressions = args[:viewable_impressions] if args.key?(:viewable_impressions) end |