Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProductReachForecast
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProductReachForecast
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The forecasted allocation and traffic metrics for a specific product at a point on the reach curve.
Instance Attribute Summary collapse
-
#cost_micros ⇒ Fixnum
The cost in micros.
-
#plannable_product_code ⇒ String
Selected product for planning.
-
#planned_product_forecast ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProductForecast
Forecasted traffic metrics for a planned product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannedProductReachForecast
constructor
A new instance of GoogleAdsSearchads360V23ServicesPlannedProductReachForecast.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannedProductReachForecast
Returns a new instance of GoogleAdsSearchads360V23ServicesPlannedProductReachForecast.
52593 52594 52595 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52593 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cost_micros ⇒ Fixnum
The cost in micros. This may differ from the product's input allocation if one
or more planned products cannot fulfill the budget because of limited
inventory.
Corresponds to the JSON property costMicros
52580 52581 52582 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52580 def cost_micros @cost_micros end |
#plannable_product_code ⇒ String
Selected product for planning. The product codes returned are within the set
of the ones returned by ListPlannableProducts when using the same location ID.
Corresponds to the JSON property plannableProductCode
52586 52587 52588 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52586 def plannable_product_code @plannable_product_code end |
#planned_product_forecast ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProductForecast
Forecasted traffic metrics for a planned product.
Corresponds to the JSON property plannedProductForecast
52591 52592 52593 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52591 def planned_product_forecast @planned_product_forecast end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52598 52599 52600 52601 52602 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52598 def update!(**args) @cost_micros = args[:cost_micros] if args.key?(:cost_micros) @plannable_product_code = args[:plannable_product_code] if args.key?(:plannable_product_code) @planned_product_forecast = args[:planned_product_forecast] if args.key?(:planned_product_forecast) end |