Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProductReachForecast

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The forecasted allocation and traffic metrics for a specific product at a point on the reach curve.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPlannedProductReachForecast

Returns a new instance of GoogleAdsSearchads360V23ServicesPlannedProductReachForecast.



51750
51751
51752
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51750

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cost_microsFixnum

The cost in micros. This may differ from the product's input allocation if one or more planned products cannot fulfill the budget because of limited inventory. Corresponds to the JSON property costMicros

Returns:

  • (Fixnum)


51737
51738
51739
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51737

def cost_micros
  @cost_micros
end

#plannable_product_codeString

Selected product for planning. The product codes returned are within the set of the ones returned by ListPlannableProducts when using the same location ID. Corresponds to the JSON property plannableProductCode

Returns:

  • (String)


51743
51744
51745
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51743

def plannable_product_code
  @plannable_product_code
end

#planned_product_forecastGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProductForecast

Forecasted traffic metrics for a planned product. Corresponds to the JSON property plannedProductForecast



51748
51749
51750
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51748

def planned_product_forecast
  @planned_product_forecast
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51755
51756
51757
51758
51759
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51755

def update!(**args)
  @cost_micros = args[:cost_micros] if args.key?(:cost_micros)
  @plannable_product_code = args[:plannable_product_code] if args.key?(:plannable_product_code)
  @planned_product_forecast = args[:planned_product_forecast] if args.key?(:planned_product_forecast)
end