Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesProductMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The metadata associated with an available plannable product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesProductMetadata

Returns a new instance of GoogleAdsSearchads360V23ServicesProductMetadata.



52639
52640
52641
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52639

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#plannable_product_codeString

The code associated with the ad product (for example: BUMPER, TRUEVIEW_IN_STREAM). To list the available plannable product codes use ReachPlanService.ListPlannableProducts. Corresponds to the JSON property plannableProductCode

Returns:

  • (String)


52627
52628
52629
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52627

def plannable_product_code
  @plannable_product_code
end

#plannable_product_nameString

The name associated with the ad product. Corresponds to the JSON property plannableProductName

Returns:

  • (String)


52632
52633
52634
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52632

def plannable_product_name
  @plannable_product_name
end

#plannable_targetingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannableTargeting

The targeting for which traffic metrics will be reported. Corresponds to the JSON property plannableTargeting



52637
52638
52639
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52637

def plannable_targeting
  @plannable_targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52644
52645
52646
52647
52648
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52644

def update!(**args)
  @plannable_product_code = args[:plannable_product_code] if args.key?(:plannable_product_code)
  @plannable_product_name = args[:plannable_product_name] if args.key?(:plannable_product_name)
  @plannable_targeting = args[:plannable_targeting] if args.key?(:plannable_targeting)
end