Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesProductMetadata
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesProductMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The metadata associated with an available plannable product.
Instance Attribute Summary collapse
-
#plannable_product_code ⇒ String
The code associated with the ad product (for example: BUMPER, TRUEVIEW_IN_STREAM).
-
#plannable_product_name ⇒ String
The name associated with the ad product.
-
#plannable_targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannableTargeting
The targeting for which traffic metrics will be reported.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesProductMetadata
constructor
A new instance of GoogleAdsSearchads360V23ServicesProductMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesProductMetadata
Returns a new instance of GoogleAdsSearchads360V23ServicesProductMetadata.
52567 52568 52569 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52567 def initialize(**args) update!(**args) end |
Instance Attribute Details
#plannable_product_code ⇒ String
The code associated with the ad product (for example: BUMPER,
TRUEVIEW_IN_STREAM). To list the available plannable product codes use
ReachPlanService.ListPlannableProducts.
Corresponds to the JSON property plannableProductCode
52555 52556 52557 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52555 def plannable_product_code @plannable_product_code end |
#plannable_product_name ⇒ String
The name associated with the ad product.
Corresponds to the JSON property plannableProductName
52560 52561 52562 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52560 def plannable_product_name @plannable_product_name end |
#plannable_targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannableTargeting
The targeting for which traffic metrics will be reported.
Corresponds to the JSON property plannableTargeting
52565 52566 52567 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52565 def plannable_targeting @plannable_targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52572 52573 52574 52575 52576 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52572 def update!(**args) @plannable_product_code = args[:plannable_product_code] if args.key?(:plannable_product_code) @plannable_product_name = args[:plannable_product_name] if args.key?(:plannable_product_name) @plannable_targeting = args[:plannable_targeting] if args.key?(:plannable_targeting) end |