Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesProductMetadata
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesProductMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The metadata associated with an available plannable product.
Instance Attribute Summary collapse
-
#plannable_product_code ⇒ String
The code associated with the ad product (for example: BUMPER, TRUEVIEW_IN_STREAM).
-
#plannable_product_name ⇒ String
The name associated with the ad product.
-
#plannable_targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannableTargeting
The targeting for which traffic metrics will be reported.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesProductMetadata
constructor
A new instance of GoogleAdsSearchads360V23ServicesProductMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesProductMetadata
Returns a new instance of GoogleAdsSearchads360V23ServicesProductMetadata.
51808 51809 51810 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51808 def initialize(**args) update!(**args) end |
Instance Attribute Details
#plannable_product_code ⇒ String
The code associated with the ad product (for example: BUMPER,
TRUEVIEW_IN_STREAM). To list the available plannable product codes use
ReachPlanService.ListPlannableProducts.
Corresponds to the JSON property plannableProductCode
51796 51797 51798 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51796 def plannable_product_code @plannable_product_code end |
#plannable_product_name ⇒ String
The name associated with the ad product.
Corresponds to the JSON property plannableProductName
51801 51802 51803 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51801 def plannable_product_name @plannable_product_name end |
#plannable_targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannableTargeting
The targeting for which traffic metrics will be reported.
Corresponds to the JSON property plannableTargeting
51806 51807 51808 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51806 def plannable_targeting @plannable_targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51813 51814 51815 51816 51817 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51813 def update!(**args) @plannable_product_code = args[:plannable_product_code] if args.key?(:plannable_product_code) @plannable_product_name = args[:plannable_product_name] if args.key?(:plannable_product_name) @plannable_targeting = args[:plannable_targeting] if args.key?(:plannable_targeting) end |