Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPromoteCampaignDraftRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPromoteCampaignDraftRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for CampaignDraftService.PromoteCampaignDraft.
Instance Attribute Summary collapse
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but no Long Running Operation is created.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPromoteCampaignDraftRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesPromoteCampaignDraftRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesPromoteCampaignDraftRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesPromoteCampaignDraftRequest.
51831 51832 51833 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but no Long Running Operation is created.
Only errors are returned.
Corresponds to the JSON property validateOnly
51828 51829 51830 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51828 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51836 51837 51838 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51836 def update!(**args) @validate_only = args[:validate_only] if args.key?(:validate_only) end |