Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesProvideLeadFeedbackRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesProvideLeadFeedbackRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for LocalServicesLeadService.ProvideLeadFeedback.
Instance Attribute Summary collapse
-
#survey_answer ⇒ String
Required.
-
#survey_dissatisfied ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurveyDissatisfied
Details about various factors for not being satisfied with the lead.
-
#survey_satisfied ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurveySatisfied
Details about various factors for being satisfied with the lead.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesProvideLeadFeedbackRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesProvideLeadFeedbackRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesProvideLeadFeedbackRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesProvideLeadFeedbackRequest.
51900 51901 51902 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51900 def initialize(**args) update!(**args) end |
Instance Attribute Details
#survey_answer ⇒ String
Required. Survey answer for Local Services Ads Lead.
Corresponds to the JSON property surveyAnswer
51888 51889 51890 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51888 def survey_answer @survey_answer end |
#survey_dissatisfied ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurveyDissatisfied
Details about various factors for not being satisfied with the lead.
Corresponds to the JSON property surveyDissatisfied
51893 51894 51895 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51893 def survey_dissatisfied @survey_dissatisfied end |
#survey_satisfied ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurveySatisfied
Details about various factors for being satisfied with the lead.
Corresponds to the JSON property surveySatisfied
51898 51899 51900 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51898 def survey_satisfied @survey_satisfied end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51905 51906 51907 51908 51909 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51905 def update!(**args) @survey_answer = args[:survey_answer] if args.key?(:survey_answer) @survey_dissatisfied = args[:survey_dissatisfied] if args.key?(:survey_dissatisfied) @survey_satisfied = args[:survey_satisfied] if args.key?(:survey_satisfied) end |