Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRateMetrics
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRateMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Average rate metrics. Metrics that represent monetary values are returned in USD by default, if unspecified in the request.
Instance Attribute Summary collapse
-
#active_view_viewability ⇒ Float
The percentage of time when your ad appeared on an Active View enabled site ( measurable impressions) and was viewable (viewable impressions).
-
#average_active_view_cpm ⇒ Float
Average cost-per-thousand viewable impressions.
-
#average_cpc ⇒ Float
The average cost-per-click (CPC) is defined by the total cost of all clicks divided by the total number of clicks received.
-
#average_cpe ⇒ Float
The average cost-per-engagement (CPE) is defined by the total cost of all ad engagements divided by the total number of ad engagements.
-
#average_cpi ⇒ Float
The average cost-per-interaction (CPI) is defined by the total cost of all interactions divided by the total number of interactions.
-
#average_cpm ⇒ Float
Average cost-per-thousand impressions (CPM).
-
#click_through_rate ⇒ Float
The number of clicks your ad receives (Clicks) divided by the number of times your ad is shown (Impressions).
-
#engagement_rate ⇒ Float
How often people engage with your ad after it's shown to them.
-
#interaction_rate ⇒ Float
How often people interact with your ad after it is shown to them.
-
#trueview_average_cpv ⇒ Float
The average TrueView cost-per-view (CPV) is defined by the total cost of all ad TrueView views divided by the number of TrueView views.
-
#trueview_view_rate ⇒ Float
Number of completed TrueView views divided by the number of impressions.
-
#video_completion_p100_rate ⇒ Float
Percentage of impressions where the viewer watched all of your video.
-
#video_completion_p25_rate ⇒ Float
Percentage of impressions where the viewer watched 25% of your video.
-
#video_completion_p50_rate ⇒ Float
Percentage of impressions where the viewer watched 50% of your video.
-
#video_completion_p75_rate ⇒ Float
Percentage of impressions where the viewer watched 75% of your video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRateMetrics
constructor
A new instance of GoogleAdsSearchads360V23ServicesRateMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRateMetrics
Returns a new instance of GoogleAdsSearchads360V23ServicesRateMetrics.
52020 52021 52022 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_view_viewability ⇒ Float
The percentage of time when your ad appeared on an Active View enabled site (
measurable impressions) and was viewable (viewable impressions).
Corresponds to the JSON property activeViewViewability
51941 51942 51943 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51941 def active_view_viewability @active_view_viewability end |
#average_active_view_cpm ⇒ Float
Average cost-per-thousand viewable impressions.
Corresponds to the JSON property averageActiveViewCpm
51946 51947 51948 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51946 def average_active_view_cpm @average_active_view_cpm end |
#average_cpc ⇒ Float
The average cost-per-click (CPC) is defined by the total cost of all clicks
divided by the total number of clicks received.
Corresponds to the JSON property averageCpc
51952 51953 51954 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51952 def average_cpc @average_cpc end |
#average_cpe ⇒ Float
The average cost-per-engagement (CPE) is defined by the total cost of all ad
engagements divided by the total number of ad engagements.
Corresponds to the JSON property averageCpe
51958 51959 51960 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51958 def average_cpe @average_cpe end |
#average_cpi ⇒ Float
The average cost-per-interaction (CPI) is defined by the total cost of all
interactions divided by the total number of interactions.
Corresponds to the JSON property averageCpi
51964 51965 51966 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51964 def average_cpi @average_cpi end |
#average_cpm ⇒ Float
Average cost-per-thousand impressions (CPM).
Corresponds to the JSON property averageCpm
51969 51970 51971 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51969 def average_cpm @average_cpm end |
#click_through_rate ⇒ Float
The number of clicks your ad receives (Clicks) divided by the number of times
your ad is shown (Impressions).
Corresponds to the JSON property clickThroughRate
51975 51976 51977 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51975 def click_through_rate @click_through_rate end |
#engagement_rate ⇒ Float
How often people engage with your ad after it's shown to them. This is the
number of ad expansions divided by the number of times your ad is shown.
Corresponds to the JSON property engagementRate
51981 51982 51983 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51981 def engagement_rate @engagement_rate end |
#interaction_rate ⇒ Float
How often people interact with your ad after it is shown to them. This is the
number of interactions divided by the number of times your ad is shown.
Corresponds to the JSON property interactionRate
51987 51988 51989 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51987 def interaction_rate @interaction_rate end |
#trueview_average_cpv ⇒ Float
The average TrueView cost-per-view (CPV) is defined by the total cost of all
ad TrueView views divided by the number of TrueView views.
Corresponds to the JSON property trueviewAverageCpv
51993 51994 51995 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51993 def trueview_average_cpv @trueview_average_cpv end |
#trueview_view_rate ⇒ Float
Number of completed TrueView views divided by the number of impressions.
Corresponds to the JSON property trueviewViewRate
51998 51999 52000 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 51998 def trueview_view_rate @trueview_view_rate end |
#video_completion_p100_rate ⇒ Float
Percentage of impressions where the viewer watched all of your video.
Corresponds to the JSON property videoCompletionP100Rate
52003 52004 52005 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52003 def video_completion_p100_rate @video_completion_p100_rate end |
#video_completion_p25_rate ⇒ Float
Percentage of impressions where the viewer watched 25% of your video.
Corresponds to the JSON property videoCompletionP25Rate
52008 52009 52010 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52008 def video_completion_p25_rate @video_completion_p25_rate end |
#video_completion_p50_rate ⇒ Float
Percentage of impressions where the viewer watched 50% of your video.
Corresponds to the JSON property videoCompletionP50Rate
52013 52014 52015 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52013 def video_completion_p50_rate @video_completion_p50_rate end |
#video_completion_p75_rate ⇒ Float
Percentage of impressions where the viewer watched 75% of your video.
Corresponds to the JSON property videoCompletionP75Rate
52018 52019 52020 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52018 def video_completion_p75_rate @video_completion_p75_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52025 52026 52027 52028 52029 52030 52031 52032 52033 52034 52035 52036 52037 52038 52039 52040 52041 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52025 def update!(**args) @active_view_viewability = args[:active_view_viewability] if args.key?(:active_view_viewability) @average_active_view_cpm = args[:average_active_view_cpm] if args.key?(:average_active_view_cpm) @average_cpc = args[:average_cpc] if args.key?(:average_cpc) @average_cpe = args[:average_cpe] if args.key?(:average_cpe) @average_cpi = args[:average_cpi] if args.key?(:average_cpi) @average_cpm = args[:average_cpm] if args.key?(:average_cpm) @click_through_rate = args[:click_through_rate] if args.key?(:click_through_rate) @engagement_rate = args[:engagement_rate] if args.key?(:engagement_rate) @interaction_rate = args[:interaction_rate] if args.key?(:interaction_rate) @trueview_average_cpv = args[:trueview_average_cpv] if args.key?(:trueview_average_cpv) @trueview_view_rate = args[:trueview_view_rate] if args.key?(:trueview_view_rate) @video_completion_p100_rate = args[:video_completion_p100_rate] if args.key?(:video_completion_p100_rate) @video_completion_p25_rate = args[:video_completion_p25_rate] if args.key?(:video_completion_p25_rate) @video_completion_p50_rate = args[:video_completion_p50_rate] if args.key?(:video_completion_p50_rate) @video_completion_p75_rate = args[:video_completion_p75_rate] if args.key?(:video_completion_p75_rate) end |