Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Message for raw event conversion dimension header.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
The conversion custom variable ID.
-
#name ⇒ String
The user defined name of the raw event dimension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader
constructor
A new instance of GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader
Returns a new instance of GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader.
52889 52890 52891 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
The conversion custom variable ID.
Corresponds to the JSON property id
52882 52883 52884 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52882 def id @id end |
#name ⇒ String
The user defined name of the raw event dimension.
Corresponds to the JSON property name
52887 52888 52889 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52887 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52894 52895 52896 52897 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52894 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) end |