Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Message for raw event conversion dimension header.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
The conversion custom variable ID.
-
#name ⇒ String
The user defined name of the raw event dimension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader
constructor
A new instance of GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader
Returns a new instance of GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader.
52058 52059 52060 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52058 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
The conversion custom variable ID.
Corresponds to the JSON property id
52051 52052 52053 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52051 def id @id end |
#name ⇒ String
The user defined name of the raw event dimension.
Corresponds to the JSON property name
52056 52057 52058 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52056 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52063 52064 52065 52066 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52063 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) end |