Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRawEventConversionMetricHeader
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRawEventConversionMetricHeader
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Message for raw event conversion metric header.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
The conversion custom variable ID.
-
#name ⇒ String
The user defined name of the raw event metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRawEventConversionMetricHeader
constructor
A new instance of GoogleAdsSearchads360V23ServicesRawEventConversionMetricHeader.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRawEventConversionMetricHeader
Returns a new instance of GoogleAdsSearchads360V23ServicesRawEventConversionMetricHeader.
52083 52084 52085 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52083 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
The conversion custom variable ID.
Corresponds to the JSON property id
52076 52077 52078 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52076 def id @id end |
#name ⇒ String
The user defined name of the raw event metric.
Corresponds to the JSON property name
52081 52082 52083 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52081 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52088 52089 52090 52091 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52088 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) end |