Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesReachForecast

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A point on reach curve.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesReachForecast

Returns a new instance of GoogleAdsSearchads360V23ServicesReachForecast.



52892
52893
52894
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cost_microsFixnum

The cost in micros. Corresponds to the JSON property costMicros

Returns:

  • (Fixnum)


52879
52880
52881
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52879

def cost_micros
  @cost_micros
end

#forecastGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecast

Forecasted traffic metrics for the planned products and targeting. Corresponds to the JSON property forecast



52884
52885
52886
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52884

def forecast
  @forecast
end

#planned_product_reach_forecastsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProductReachForecast>

The forecasted allocation and traffic metrics for each planned product at this point on the reach curve. Corresponds to the JSON property plannedProductReachForecasts



52890
52891
52892
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52890

def planned_product_reach_forecasts
  @planned_product_reach_forecasts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52897
52898
52899
52900
52901
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52897

def update!(**args)
  @cost_micros = args[:cost_micros] if args.key?(:cost_micros)
  @forecast = args[:forecast] if args.key?(:forecast)
  @planned_product_reach_forecasts = args[:planned_product_reach_forecasts] if args.key?(:planned_product_reach_forecasts)
end