Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesReachForecast
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesReachForecast
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A point on reach curve.
Instance Attribute Summary collapse
-
#cost_micros ⇒ Fixnum
The cost in micros.
-
#forecast ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecast
Forecasted traffic metrics for the planned products and targeting.
-
#planned_product_reach_forecasts ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProductReachForecast>
The forecasted allocation and traffic metrics for each planned product at this point on the reach curve.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesReachForecast
constructor
A new instance of GoogleAdsSearchads360V23ServicesReachForecast.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesReachForecast
Returns a new instance of GoogleAdsSearchads360V23ServicesReachForecast.
52133 52134 52135 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52133 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cost_micros ⇒ Fixnum
The cost in micros.
Corresponds to the JSON property costMicros
52120 52121 52122 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52120 def cost_micros @cost_micros end |
#forecast ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesForecast
Forecasted traffic metrics for the planned products and targeting.
Corresponds to the JSON property forecast
52125 52126 52127 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52125 def forecast @forecast end |
#planned_product_reach_forecasts ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesPlannedProductReachForecast>
The forecasted allocation and traffic metrics for each planned product at this
point on the reach curve.
Corresponds to the JSON property plannedProductReachForecasts
52131 52132 52133 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52131 def planned_product_reach_forecasts @planned_product_reach_forecasts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52138 52139 52140 52141 52142 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52138 def update!(**args) @cost_micros = args[:cost_micros] if args.key?(:cost_micros) @forecast = args[:forecast] if args.key?(:forecast) @planned_product_reach_forecasts = args[:planned_product_reach_forecasts] if args.key?(:planned_product_reach_forecasts) end |