Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemarketingActionOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemarketingActionOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update) on a remarketing action.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRemarketingAction
A remarketing action.
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRemarketingAction
A remarketing action.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRemarketingActionOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesRemarketingActionOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRemarketingActionOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesRemarketingActionOperation.
53072 53073 53074 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53072 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRemarketingAction
A remarketing action. A snippet of JavaScript code that will collect the
product id and the type of page people visited (product page, shopping cart
page, purchase page, general site visit) on an advertiser's website.
Corresponds to the JSON property create
53058 53059 53060 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53058 def create @create end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesRemarketingAction
A remarketing action. A snippet of JavaScript code that will collect the
product id and the type of page people visited (product page, shopping cart
page, purchase page, general site visit) on an advertiser's website.
Corresponds to the JSON property update
53065 53066 53067 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53065 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
53070 53071 53072 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53070 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53077 53078 53079 53080 53081 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53077 def update!(**args) @create = args[:create] if args.key?(:create) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |