Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for AutomaticallyCreatedAssetRemovalService. RemoveCampaignAutomaticallyCreatedAsset.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetOperation>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetRequest.
53140 53141 53142 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53140 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetOperation>
Required. The list of operations.
Corresponds to the JSON property operations
53130 53131 53132 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53130 def operations @operations end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
Required. If true, successful operations will be carried out and invalid
operations will return errors. If false, all operations will be carried out in
one transaction if and only if they are all valid.
Corresponds to the JSON property partialFailure
53137 53138 53139 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53137 def partial_failure @partial_failure end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53145 53146 53147 53148 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53145 def update!(**args) @operations = args[:operations] if args.key?(:operations) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) end |