Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for AutomaticallyCreatedAssetRemovalService. RemoveCampaignAutomaticallyCreatedAsset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetRequest.



53068
53069
53070
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53068

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetOperation>

Required. The list of operations. Corresponds to the JSON property operations



53058
53059
53060
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53058

def operations
  @operations
end

#partial_failureBoolean Also known as: partial_failure?

Required. If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


53065
53066
53067
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53065

def partial_failure
  @partial_failure
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53073
53074
53075
53076
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53073

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
end