Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for AutomaticallyCreatedAssetRemovalService. RemoveCampaignAutomaticallyCreatedAsset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetResponse.



53166
53167
53168
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



53164
53165
53166
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53164

def partial_failure_error
  @partial_failure_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53171
53172
53173
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53171

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
end