Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRemoveProductLinkRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ProductLinkService.RemoveProductLink.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesRemoveProductLinkRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesRemoveProductLinkRequest.



52439
52440
52441
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52439

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_nameString

Required. Remove operation: A resource name for the product link to remove is expected, in this format: Corresponds to the JSON property resourceName

Returns:

  • (String)


52430
52431
52432
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52430

def resource_name
  @resource_name
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


52436
52437
52438
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52436

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52444
52445
52446
52447
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52444

def update!(**args)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end