Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (update) on a Search Ads 360 campaign.
Instance Attribute Summary collapse
-
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSearchAds360Campaign
A Search Ads 360 campaign.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesSearchAds360CampaignOperation.
52557 52558 52559 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52557 def initialize(**args) update!(**args) end |
Instance Attribute Details
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSearchAds360Campaign
A Search Ads 360 campaign.
Corresponds to the JSON property update
52550 52551 52552 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52550 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
52555 52556 52557 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52555 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52562 52563 52564 52565 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 52562 def update!(**args) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |