Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchSearchAds360FieldsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchSearchAds360FieldsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for SearchAds360FieldService.SearchSearchAds360Fields.
Instance Attribute Summary collapse
-
#page_size ⇒ Fixnum
Number of elements to retrieve in a single page.
-
#page_token ⇒ String
Token of the page to retrieve.
-
#query ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSearchSearchAds360FieldsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesSearchSearchAds360FieldsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSearchSearchAds360FieldsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesSearchSearchAds360FieldsRequest.
53950 53951 53952 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53950 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_size ⇒ Fixnum
Number of elements to retrieve in a single page. When too large a page is
requested, the server may decide to further limit the number of returned
resources.
Corresponds to the JSON property pageSize
53936 53937 53938 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53936 def page_size @page_size end |
#page_token ⇒ String
Token of the page to retrieve. If not specified, the first page of results
will be returned. Use the value obtained from next_page_token in the
previous response in order to request the next page of results.
Corresponds to the JSON property pageToken
53943 53944 53945 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53943 def page_token @page_token end |
#query ⇒ String
Required. The query string.
Corresponds to the JSON property query
53948 53949 53950 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53948 def query @query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53955 53956 53957 53958 53959 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 53955 def update!(**args) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @query = args[:query] if args.key?(:query) end |