Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchSearchAds360Request

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for SearchAds360Service.Search.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSearchSearchAds360Request

Returns a new instance of GoogleAdsSearchads360V23ServicesSearchSearchAds360Request.



54029
54030
54031
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#page_sizeFixnum

Number of elements to retrieve in a single page. When too large a page is requested, the server may decide to further limit the number of returned resources. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


54004
54005
54006
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54004

def page_size
  @page_size
end

#page_tokenString

Token of the page to retrieve. If not specified, the first page of results will be returned. Use the value obtained from next_page_token in the previous response in order to request the next page of results. Corresponds to the JSON property pageToken

Returns:

  • (String)


54011
54012
54013
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54011

def page_token
  @page_token
end

#queryString

Required. The query string. Corresponds to the JSON property query

Returns:

  • (String)


54016
54017
54018
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54016

def query
  @query
end

#search_settingsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchSettings

Indicates search settings in request parameter. Corresponds to the JSON property searchSettings



54021
54022
54023
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54021

def search_settings
  @search_settings
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


54026
54027
54028
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54026

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54034
54035
54036
54037
54038
54039
54040
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54034

def update!(**args)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @query = args[:query] if args.key?(:query)
  @search_settings = args[:search_settings] if args.key?(:search_settings)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end