Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchSearchAds360Response
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchSearchAds360Response
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for SearchAds360Service.Search.
Instance Attribute Summary collapse
-
#conversion_custom_dimension_headers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomDimensionHeader>
The headers of the conversion custom dimensions in the results.
-
#conversion_custom_metric_headers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomMetricHeader>
The headers of the conversion custom metrics in the results.
-
#custom_column_headers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomColumnHeader>
The headers of the custom columns in the results.
-
#field_mask ⇒ String
FieldMask that represents what fields were requested by the user.
-
#metric_attributes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMetricAttributes>
The metric attributes of the metrics in the results.
-
#next_page_token ⇒ String
Pagination token used to retrieve the next page of results.
-
#query_resource_consumption ⇒ Fixnum
The amount of resources consumed to serve the query.
-
#raw_event_conversion_dimension_headers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader>
The headers of the raw event conversion dimensions in the results.
-
#raw_event_conversion_metric_headers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRawEventConversionMetricHeader>
The headers of the raw event conversion metrics in the results.
-
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360Row>
The list of rows that matched the query.
-
#summary_row ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360Row
A returned row from the query.
-
#total_results_count ⇒ Fixnum
Total number of results that match the query ignoring the LIMIT clause.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSearchSearchAds360Response
constructor
A new instance of GoogleAdsSearchads360V23ServicesSearchSearchAds360Response.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSearchSearchAds360Response
Returns a new instance of GoogleAdsSearchads360V23ServicesSearchSearchAds360Response.
54919 54920 54921 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_custom_dimension_headers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomDimensionHeader>
The headers of the conversion custom dimensions in the results.
Corresponds to the JSON property conversionCustomDimensionHeaders
54860 54861 54862 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54860 def conversion_custom_dimension_headers @conversion_custom_dimension_headers end |
#conversion_custom_metric_headers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionCustomMetricHeader>
The headers of the conversion custom metrics in the results.
Corresponds to the JSON property conversionCustomMetricHeaders
54865 54866 54867 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54865 def conversion_custom_metric_headers @conversion_custom_metric_headers end |
#custom_column_headers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCustomColumnHeader>
The headers of the custom columns in the results.
Corresponds to the JSON property customColumnHeaders
54870 54871 54872 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54870 def custom_column_headers @custom_column_headers end |
#field_mask ⇒ String
FieldMask that represents what fields were requested by the user.
Corresponds to the JSON property fieldMask
54875 54876 54877 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54875 def field_mask @field_mask end |
#metric_attributes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesMetricAttributes>
The metric attributes of the metrics in the results.
Corresponds to the JSON property metricAttributes
54880 54881 54882 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54880 def metric_attributes @metric_attributes end |
#next_page_token ⇒ String
Pagination token used to retrieve the next page of results. Pass the content
of this string as the page_token attribute of the next request.
next_page_token is not returned for the last page.
Corresponds to the JSON property nextPageToken
54887 54888 54889 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54887 def next_page_token @next_page_token end |
#query_resource_consumption ⇒ Fixnum
The amount of resources consumed to serve the query.
Corresponds to the JSON property queryResourceConsumption
54892 54893 54894 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54892 def query_resource_consumption @query_resource_consumption end |
#raw_event_conversion_dimension_headers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRawEventConversionDimensionHeader>
The headers of the raw event conversion dimensions in the results.
Corresponds to the JSON property rawEventConversionDimensionHeaders
54897 54898 54899 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54897 def raw_event_conversion_dimension_headers @raw_event_conversion_dimension_headers end |
#raw_event_conversion_metric_headers ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesRawEventConversionMetricHeader>
The headers of the raw event conversion metrics in the results.
Corresponds to the JSON property rawEventConversionMetricHeaders
54902 54903 54904 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54902 def raw_event_conversion_metric_headers @raw_event_conversion_metric_headers end |
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360Row>
The list of rows that matched the query.
Corresponds to the JSON property results
54907 54908 54909 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54907 def results @results end |
#summary_row ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchAds360Row
A returned row from the query.
Corresponds to the JSON property summaryRow
54912 54913 54914 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54912 def summary_row @summary_row end |
#total_results_count ⇒ Fixnum
Total number of results that match the query ignoring the LIMIT clause.
Corresponds to the JSON property totalResultsCount
54917 54918 54919 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54917 def total_results_count @total_results_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54924 54925 54926 54927 54928 54929 54930 54931 54932 54933 54934 54935 54936 54937 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54924 def update!(**args) @conversion_custom_dimension_headers = args[:conversion_custom_dimension_headers] if args.key?(:conversion_custom_dimension_headers) @conversion_custom_metric_headers = args[:conversion_custom_metric_headers] if args.key?(:conversion_custom_metric_headers) @custom_column_headers = args[:custom_column_headers] if args.key?(:custom_column_headers) @field_mask = args[:field_mask] if args.key?(:field_mask) @metric_attributes = args[:metric_attributes] if args.key?(:metric_attributes) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @query_resource_consumption = args[:query_resource_consumption] if args.key?(:query_resource_consumption) @raw_event_conversion_dimension_headers = args[:raw_event_conversion_dimension_headers] if args.key?(:raw_event_conversion_dimension_headers) @raw_event_conversion_metric_headers = args[:raw_event_conversion_metric_headers] if args.key?(:raw_event_conversion_metric_headers) @results = args[:results] if args.key?(:results) @summary_row = args[:summary_row] if args.key?(:summary_row) @total_results_count = args[:total_results_count] if args.key?(:total_results_count) end |