Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Indicates search settings in request parameter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSearchSettings

Returns a new instance of GoogleAdsSearchads360V23ServicesSearchSettings.



55037
55038
55039
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#omit_resultsBoolean Also known as: omit_results?

If true, results will be excluded from the response. Otherwise, results will be returned. Default is false. Corresponds to the JSON property omitResults

Returns:

  • (Boolean)


55020
55021
55022
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55020

def omit_results
  @omit_results
end

#return_summary_rowBoolean Also known as: return_summary_row?

If true, summary row will be included in the response and sent in a response by itself after all other query results are returned. Default is false. Corresponds to the JSON property returnSummaryRow

Returns:

  • (Boolean)


55027
55028
55029
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55027

def return_summary_row
  @return_summary_row
end

#return_total_results_countBoolean Also known as: return_total_results_count?

If true, the total number of results that match the query ignoring the LIMIT clause will be included in the response. Default is false. Corresponds to the JSON property returnTotalResultsCount

Returns:

  • (Boolean)


55034
55035
55036
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55034

def return_total_results_count
  @return_total_results_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55042
55043
55044
55045
55046
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55042

def update!(**args)
  @omit_results = args[:omit_results] if args.key?(:omit_results)
  @return_summary_row = args[:return_summary_row] if args.key?(:return_summary_row)
  @return_total_results_count = args[:return_total_results_count] if args.key?(:return_total_results_count)
end