Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchSettings
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSearchSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Indicates search settings in request parameter.
Instance Attribute Summary collapse
-
#omit_results ⇒ Boolean
(also: #omit_results?)
If true, results will be excluded from the response.
-
#return_summary_row ⇒ Boolean
(also: #return_summary_row?)
If true, summary row will be included in the response and sent in a response by itself after all other query results are returned.
-
#return_total_results_count ⇒ Boolean
(also: #return_total_results_count?)
If true, the total number of results that match the query ignoring the LIMIT clause will be included in the response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSearchSettings
constructor
A new instance of GoogleAdsSearchads360V23ServicesSearchSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSearchSettings
Returns a new instance of GoogleAdsSearchads360V23ServicesSearchSettings.
54155 54156 54157 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54155 def initialize(**args) update!(**args) end |
Instance Attribute Details
#omit_results ⇒ Boolean Also known as: omit_results?
If true, results will be excluded from the response. Otherwise, results will
be returned. Default is false.
Corresponds to the JSON property omitResults
54138 54139 54140 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54138 def omit_results @omit_results end |
#return_summary_row ⇒ Boolean Also known as: return_summary_row?
If true, summary row will be included in the response and sent in a response
by itself after all other query results are returned. Default is false.
Corresponds to the JSON property returnSummaryRow
54145 54146 54147 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54145 def return_summary_row @return_summary_row end |
#return_total_results_count ⇒ Boolean Also known as: return_total_results_count?
If true, the total number of results that match the query ignoring the LIMIT
clause will be included in the response. Default is false.
Corresponds to the JSON property returnTotalResultsCount
54152 54153 54154 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54152 def return_total_results_count @return_total_results_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54160 54161 54162 54163 54164 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54160 def update!(**args) @omit_results = args[:omit_results] if args.key?(:omit_results) @return_summary_row = args[:return_summary_row] if args.key?(:return_summary_row) @return_total_results_count = args[:return_total_results_count] if args.key?(:return_total_results_count) end |