Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedSetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on an shared set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSharedSetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesSharedSetOperation.



55145
55146
55147
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedSet

SharedSets are used for sharing criterion exclusions across multiple campaigns. Corresponds to the JSON property create



55127
55128
55129
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55127

def create
  @create
end

#removeString

Remove operation: A resource name for the removed shared set is expected, in this format: customers/customer_id/sharedSets/shared_set_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


55133
55134
55135
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55133

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedSet

SharedSets are used for sharing criterion exclusions across multiple campaigns. Corresponds to the JSON property update



55138
55139
55140
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55138

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


55143
55144
55145
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55143

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55150
55151
55152
55153
55154
55155
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55150

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end