Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedSetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on an shared set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSharedSetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesSharedSetOperation.



55073
55074
55075
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55073

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedSet

SharedSets are used for sharing criterion exclusions across multiple campaigns. Corresponds to the JSON property create



55055
55056
55057
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55055

def create
  @create
end

#removeString

Remove operation: A resource name for the removed shared set is expected, in this format: customers/customer_id/sharedSets/shared_set_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


55061
55062
55063
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55061

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedSet

SharedSets are used for sharing criterion exclusions across multiple campaigns. Corresponds to the JSON property update



55066
55067
55068
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55066

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


55071
55072
55073
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55071

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55078
55079
55080
55081
55082
55083
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55078

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end