Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSharedSetOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation (create, update, remove) on an shared set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSharedSetOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesSharedSetOperation.



54219
54220
54221
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54219

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedSet

SharedSets are used for sharing criterion exclusions across multiple campaigns. Corresponds to the JSON property create



54201
54202
54203
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54201

def create
  @create
end

#removeString

Remove operation: A resource name for the removed shared set is expected, in this format: customers/customer_id/sharedSets/shared_set_id` Corresponds to the JSON propertyremove`

Returns:

  • (String)


54207
54208
54209
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54207

def remove
  @remove
end

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSharedSet

SharedSets are used for sharing criterion exclusions across multiple campaigns. Corresponds to the JSON property update



54212
54213
54214
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54212

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


54217
54218
54219
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54217

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54224
54225
54226
54227
54228
54229
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54224

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @remove = args[:remove] if args.key?(:remove)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end