Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Details related to Smart campaigns that are eligible to serve.
Instance Attribute Summary collapse
-
#end_date_time ⇒ String
The timestamp of when the campaign will end, if applicable.
-
#last_impression_date_time ⇒ String
The timestamp of the last impression observed in the last 48 hours for this campaign.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails
constructor
A new instance of GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails
Returns a new instance of GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails.
55123 55124 55125 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date_time ⇒ String
The timestamp of when the campaign will end, if applicable. The timestamp is
in the customer’s timezone and in “yyyy-MM-dd HH:mm:ss” format.
Corresponds to the JSON property endDateTime
55114 55115 55116 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55114 def end_date_time @end_date_time end |
#last_impression_date_time ⇒ String
The timestamp of the last impression observed in the last 48 hours for this
campaign. The timestamp is in the customer’s timezone and in “yyyy-MM-dd HH:mm:
ss” format.
Corresponds to the JSON property lastImpressionDateTime
55121 55122 55123 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55121 def last_impression_date_time @last_impression_date_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55128 55129 55130 55131 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55128 def update!(**args) @end_date_time = args[:end_date_time] if args.key?(:end_date_time) @last_impression_date_time = args[:last_impression_date_time] if args.key?(:last_impression_date_time) end |