Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Details related to Smart campaigns that are eligible to serve.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails

Returns a new instance of GoogleAdsSearchads360V23ServicesSmartCampaignEligibleDetails.



54269
54270
54271
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54269

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_date_timeString

The timestamp of when the campaign will end, if applicable. The timestamp is in the customer’s timezone and in “yyyy-MM-dd HH:mm:ss” format. Corresponds to the JSON property endDateTime

Returns:

  • (String)


54260
54261
54262
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54260

def end_date_time
  @end_date_time
end

#last_impression_date_timeString

The timestamp of the last impression observed in the last 48 hours for this campaign. The timestamp is in the customer’s timezone and in “yyyy-MM-dd HH:mm: ss” format. Corresponds to the JSON property lastImpressionDateTime

Returns:

  • (String)


54267
54268
54269
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54267

def last_impression_date_time
  @last_impression_date_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54274
54275
54276
54277
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54274

def update!(**args)
  @end_date_time = args[:end_date_time] if args.key?(:end_date_time)
  @last_impression_date_time = args[:last_impression_date_time] if args.key?(:last_impression_date_time)
end