Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Details related to Smart campaigns that are not eligible to serve.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails

Returns a new instance of GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails.



55163
55164
55165
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#not_eligible_reasonString

The reason why the Smart campaign is not eligible to serve. Corresponds to the JSON property notEligibleReason

Returns:

  • (String)


55161
55162
55163
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55161

def not_eligible_reason
  @not_eligible_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55168
55169
55170
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55168

def update!(**args)
  @not_eligible_reason = args[:not_eligible_reason] if args.key?(:not_eligible_reason)
end