Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Details related to Smart campaigns that are not eligible to serve.
Instance Attribute Summary collapse
-
#not_eligible_reason ⇒ String
The reason why the Smart campaign is not eligible to serve.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails
constructor
A new instance of GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails
Returns a new instance of GoogleAdsSearchads360V23ServicesSmartCampaignNotEligibleDetails.
54309 54310 54311 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54309 def initialize(**args) update!(**args) end |
Instance Attribute Details
#not_eligible_reason ⇒ String
The reason why the Smart campaign is not eligible to serve.
Corresponds to the JSON property notEligibleReason
54307 54308 54309 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54307 def not_eligible_reason @not_eligible_reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54314 54315 54316 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54314 def update!(**args) @not_eligible_reason = args[:not_eligible_reason] if args.key?(:not_eligible_reason) end |