Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSettingOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A single operation to update Smart campaign settings for a campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSmartCampaignSettingOperation

Returns a new instance of GoogleAdsSearchads360V23ServicesSmartCampaignSettingOperation.



54373
54374
54375
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#updateGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesSmartCampaignSetting

Settings for configuring Smart campaigns. Corresponds to the JSON property update



54366
54367
54368
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54366

def update
  @update
end

#update_maskString

FieldMask that determines which resource fields are modified in an update. Corresponds to the JSON property updateMask

Returns:

  • (String)


54371
54372
54373
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54371

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54378
54379
54380
54381
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54378

def update!(**args)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end