Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfo
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Information needed to get suggestion for Smart Campaign. More information provided will help the system to derive better suggestions.
Instance Attribute Summary collapse
-
#ad_schedules ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>
Optional.
-
#business_context ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfoBusinessContext
A context that describes a business.
-
#business_profile_location ⇒ String
Optional.
-
#final_url ⇒ String
Optional.
-
#keyword_themes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordThemeInfo>
Optional.
-
#language_code ⇒ String
Optional.
-
#location_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfoLocationList
A list of locations.
-
#proximity ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProximityInfo
A Proximity criterion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfo
constructor
A new instance of GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfo
Returns a new instance of GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfo.
55294 55295 55296 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55294 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_schedules ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAdScheduleInfo>
Optional. The business ad schedule.
Corresponds to the JSON property adSchedules
55246 55247 55248 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55246 def ad_schedules @ad_schedules end |
#business_context ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfoBusinessContext
A context that describes a business.
Corresponds to the JSON property businessContext
55251 55252 55253 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55251 def business_context @business_context end |
#business_profile_location ⇒ String
Optional. The resource name of a Business Profile location. Business Profile
location resource names can be fetched through the Business Profile API and
adhere to the following format: locations/locationId`. See the [Business
Profile API] (https://developers.google.com/my-business/reference/
businessinformation/rest/v1/accounts.locations) for additional details.
Corresponds to the JSON propertybusinessProfileLocation`
55260 55261 55262 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55260 def business_profile_location @business_profile_location end |
#final_url ⇒ String
Optional. Landing page URL of the campaign.
Corresponds to the JSON property finalUrl
55265 55266 55267 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55265 def final_url @final_url end |
#keyword_themes ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonKeywordThemeInfo>
Optional. Smart campaign keyword themes. This field may greatly improve
suggestion accuracy and we recommend always setting it if possible.
Corresponds to the JSON property keywordThemes
55271 55272 55273 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55271 def keyword_themes @keyword_themes end |
#language_code ⇒ String
Optional. The two letter advertising language for the Smart campaign to be
constructed, default to 'en' if not set.
Corresponds to the JSON property languageCode
55277 55278 55279 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55277 def language_code @language_code end |
#location_list ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfoLocationList
A list of locations.
Corresponds to the JSON property locationList
55282 55283 55284 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55282 def location_list @location_list end |
#proximity ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonProximityInfo
A Proximity criterion. The geo point and radius determine what geographical
area is included. The address is a description of the geo point that does not
affect ad serving. There are two ways to create a proximity. First, by setting
an address and radius. The geo point will be automatically computed. Second,
by setting a geo point and radius. The address is an optional label that won't
be validated.
Corresponds to the JSON property proximity
55292 55293 55294 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55292 def proximity @proximity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55299 def update!(**args) @ad_schedules = args[:ad_schedules] if args.key?(:ad_schedules) @business_context = args[:business_context] if args.key?(:business_context) @business_profile_location = args[:business_profile_location] if args.key?(:business_profile_location) @final_url = args[:final_url] if args.key?(:final_url) @keyword_themes = args[:keyword_themes] if args.key?(:keyword_themes) @language_code = args[:language_code] if args.key?(:language_code) @location_list = args[:location_list] if args.key?(:location_list) @proximity = args[:proximity] if args.key?(:proximity) end |