Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for GeoTargetConstantService.SuggestGeoTargetConstants.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequest.



55428
55429
55430
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Returned geo targets are restricted to this country code. Corresponds to the JSON property countryCode

Returns:

  • (String)


55410
55411
55412
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55410

def country_code
  @country_code
end

#geo_targetsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequestGeoTargets

A list of geo target constant resource names. Corresponds to the JSON property geoTargets



55415
55416
55417
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55415

def geo_targets
  @geo_targets
end

#localeString

If possible, returned geo targets are translated using this locale. If not, en is used by default. This is also used as a hint for returned geo targets. Corresponds to the JSON property locale

Returns:

  • (String)


55421
55422
55423
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55421

def locale
  @locale
end

#location_namesGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequestLocationNames

A list of location names. Corresponds to the JSON property locationNames



55426
55427
55428
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55426

def location_names
  @location_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55433
55434
55435
55436
55437
55438
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55433

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @geo_targets = args[:geo_targets] if args.key?(:geo_targets)
  @locale = args[:locale] if args.key?(:locale)
  @location_names = args[:location_names] if args.key?(:location_names)
end