Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for GeoTargetConstantService.SuggestGeoTargetConstants.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequest.



54502
54503
54504
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Returned geo targets are restricted to this country code. Corresponds to the JSON property countryCode

Returns:

  • (String)


54484
54485
54486
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54484

def country_code
  @country_code
end

#geo_targetsGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequestGeoTargets

A list of geo target constant resource names. Corresponds to the JSON property geoTargets



54489
54490
54491
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54489

def geo_targets
  @geo_targets
end

#localeString

If possible, returned geo targets are translated using this locale. If not, en is used by default. This is also used as a hint for returned geo targets. Corresponds to the JSON property locale

Returns:

  • (String)


54495
54496
54497
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54495

def locale
  @locale
end

#location_namesGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequestLocationNames

A list of location names. Corresponds to the JSON property locationNames



54500
54501
54502
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54500

def location_names
  @location_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54507
54508
54509
54510
54511
54512
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54507

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @geo_targets = args[:geo_targets] if args.key?(:geo_targets)
  @locale = args[:locale] if args.key?(:locale)
  @location_names = args[:location_names] if args.key?(:location_names)
end