Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for KeywordThemeConstantService.SuggestKeywordThemeConstants.
Instance Attribute Summary collapse
-
#country_code ⇒ String
Upper-case, two-letter country code as defined by ISO-3166.
-
#language_code ⇒ String
The two letter language code for get corresponding keyword theme for refining the scope of the query, default to 'en' if not set.
-
#query_text ⇒ String
The query text of a keyword theme that will be used to map to similar keyword themes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest.
55482 55483 55484 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_code ⇒ String
Upper-case, two-letter country code as defined by ISO-3166. This for refining
the scope of the query, default to 'US' if not set.
Corresponds to the JSON property countryCode
55468 55469 55470 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55468 def country_code @country_code end |
#language_code ⇒ String
The two letter language code for get corresponding keyword theme for refining
the scope of the query, default to 'en' if not set.
Corresponds to the JSON property languageCode
55474 55475 55476 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55474 def language_code @language_code end |
#query_text ⇒ String
The query text of a keyword theme that will be used to map to similar keyword
themes. For example, "plumber" or "roofer".
Corresponds to the JSON property queryText
55480 55481 55482 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55480 def query_text @query_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55487 55488 55489 55490 55491 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55487 def update!(**args) @country_code = args[:country_code] if args.key?(:country_code) @language_code = args[:language_code] if args.key?(:language_code) @query_text = args[:query_text] if args.key?(:query_text) end |