Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for KeywordThemeConstantService.SuggestKeywordThemeConstants.
Instance Attribute Summary collapse
-
#country_code ⇒ String
Upper-case, two-letter country code as defined by ISO-3166.
-
#language_code ⇒ String
The two letter language code for get corresponding keyword theme for refining the scope of the query, default to 'en' if not set.
-
#query_text ⇒ String
The query text of a keyword theme that will be used to map to similar keyword themes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest.
55410 55411 55412 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55410 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country_code ⇒ String
Upper-case, two-letter country code as defined by ISO-3166. This for refining
the scope of the query, default to 'US' if not set.
Corresponds to the JSON property countryCode
55396 55397 55398 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55396 def country_code @country_code end |
#language_code ⇒ String
The two letter language code for get corresponding keyword theme for refining
the scope of the query, default to 'en' if not set.
Corresponds to the JSON property languageCode
55402 55403 55404 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55402 def language_code @language_code end |
#query_text ⇒ String
The query text of a keyword theme that will be used to map to similar keyword
themes. For example, "plumber" or "roofer".
Corresponds to the JSON property queryText
55408 55409 55410 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55408 def query_text @query_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55415 55416 55417 55418 55419 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55415 def update!(**args) @country_code = args[:country_code] if args.key?(:country_code) @language_code = args[:language_code] if args.key?(:language_code) @query_text = args[:query_text] if args.key?(:query_text) end |