Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for KeywordThemeConstantService.SuggestKeywordThemeConstants.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesSuggestKeywordThemeConstantsRequest.



54556
54557
54558
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Upper-case, two-letter country code as defined by ISO-3166. This for refining the scope of the query, default to 'US' if not set. Corresponds to the JSON property countryCode

Returns:

  • (String)


54542
54543
54544
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54542

def country_code
  @country_code
end

#language_codeString

The two letter language code for get corresponding keyword theme for refining the scope of the query, default to 'en' if not set. Corresponds to the JSON property languageCode

Returns:

  • (String)


54548
54549
54550
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54548

def language_code
  @language_code
end

#query_textString

The query text of a keyword theme that will be used to map to similar keyword themes. For example, "plumber" or "roofer". Corresponds to the JSON property queryText

Returns:

  • (String)


54554
54555
54556
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54554

def query_text
  @query_text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54561
54562
54563
54564
54565
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54561

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @language_code = args[:language_code] if args.key?(:language_code)
  @query_text = args[:query_text] if args.key?(:query_text)
end