Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for SmartCampaignSuggestService. SuggestSmartCampaignBudgetOptions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsRequest.



55607
55608
55609
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaignString

Required. The resource name of the campaign to get suggestion for. Corresponds to the JSON property campaign

Returns:

  • (String)


55599
55600
55601
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55599

def campaign
  @campaign
end

#suggestion_infoGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfo

Information needed to get suggestion for Smart Campaign. More information provided will help the system to derive better suggestions. Corresponds to the JSON property suggestionInfo



55605
55606
55607
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55605

def suggestion_info
  @suggestion_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55612
55613
55614
55615
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55612

def update!(**args)
  @campaign = args[:campaign] if args.key?(:campaign)
  @suggestion_info = args[:suggestion_info] if args.key?(:suggestion_info)
end