Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for SmartCampaignSuggestService. SuggestSmartCampaignBudgetOptions.
Instance Attribute Summary collapse
-
#campaign ⇒ String
Required.
-
#suggestion_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfo
Information needed to get suggestion for Smart Campaign.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsRequest.
54681 54682 54683 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54681 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign ⇒ String
Required. The resource name of the campaign to get suggestion for.
Corresponds to the JSON property campaign
54673 54674 54675 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54673 def campaign @campaign end |
#suggestion_info ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSmartCampaignSuggestionInfo
Information needed to get suggestion for Smart Campaign. More information
provided will help the system to derive better suggestions.
Corresponds to the JSON property suggestionInfo
54679 54680 54681 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54679 def suggestion_info @suggestion_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54686 54687 54688 54689 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54686 def update!(**args) @campaign = args[:campaign] if args.key?(:campaign) @suggestion_info = args[:suggestion_info] if args.key?(:suggestion_info) end |