Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for SmartCampaignSuggestService. SuggestSmartCampaignBudgetOptions. Depending on whether the system could suggest the options, either all of the options or none of them might be returned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponse.



55568
55569
55570
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#highGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponseBudgetOption

Smart Campaign budget option. Corresponds to the JSON property high



55556
55557
55558
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55556

def high
  @high
end

#lowGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponseBudgetOption

Smart Campaign budget option. Corresponds to the JSON property low



55561
55562
55563
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55561

def low
  @low
end

Smart Campaign budget option. Corresponds to the JSON property recommended



55566
55567
55568
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55566

def recommended
  @recommended
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55573
55574
55575
55576
55577
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55573

def update!(**args)
  @high = args[:high] if args.key?(:high)
  @low = args[:low] if args.key?(:low)
  @recommended = args[:recommended] if args.key?(:recommended)
end