Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for SmartCampaignSuggestService. SuggestSmartCampaignBudgetOptions. Depending on whether the system could suggest the options, either all of the options or none of them might be returned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponse.



54714
54715
54716
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54714

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#highGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponseBudgetOption

Smart Campaign budget option. Corresponds to the JSON property high



54702
54703
54704
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54702

def high
  @high
end

#lowGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponseBudgetOption

Smart Campaign budget option. Corresponds to the JSON property low



54707
54708
54709
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54707

def low
  @low
end

Smart Campaign budget option. Corresponds to the JSON property recommended



54712
54713
54714
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54712

def recommended
  @recommended
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54719
54720
54721
54722
54723
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54719

def update!(**args)
  @high = args[:high] if args.key?(:high)
  @low = args[:low] if args.key?(:low)
  @recommended = args[:recommended] if args.key?(:recommended)
end