Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponseBudgetOption
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponseBudgetOption
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Smart Campaign budget option.
Instance Attribute Summary collapse
-
#daily_amount_micros ⇒ Fixnum
The amount of the budget, in the local currency for the account.
-
#metrics ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponseMetrics
Performance metrics for a given budget option.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponseBudgetOption
constructor
A new instance of GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponseBudgetOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponseBudgetOption
Returns a new instance of GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponseBudgetOption.
35884 35885 35886 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35884 def initialize(**args) update!(**args) end |
Instance Attribute Details
#daily_amount_micros ⇒ Fixnum
The amount of the budget, in the local currency for the account. Amount is
specified in micros, where one million is equivalent to one currency unit.
Corresponds to the JSON property dailyAmountMicros
35877 35878 35879 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35877 def daily_amount_micros @daily_amount_micros end |
#metrics ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponseMetrics
Performance metrics for a given budget option.
Corresponds to the JSON property metrics
35882 35883 35884 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35882 def metrics @metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35889 35890 35891 35892 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 35889 def update!(**args) @daily_amount_micros = args[:daily_amount_micros] if args.key?(:daily_amount_micros) @metrics = args[:metrics] if args.key?(:metrics) end |