Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargetingCombinations

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The surface targeting combinations available for an ad product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesSurfaceTargetingCombinations

Returns a new instance of GoogleAdsSearchads360V23ServicesSurfaceTargetingCombinations.



54808
54809
54810
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_targeting_combinationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargeting>

Available surface target combinations for the ad product. Corresponds to the JSON property availableTargetingCombinations



54800
54801
54802
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54800

def available_targeting_combinations
  @available_targeting_combinations
end

#default_targetingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesSurfaceTargeting

Container for surfaces for a product. Surfaces refer to the available types of ad inventories such as In-Feed, In-Stream, and Shorts. Corresponds to the JSON property defaultTargeting



54806
54807
54808
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54806

def default_targeting
  @default_targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54813
54814
54815
54816
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54813

def update!(**args)
  @available_targeting_combinations = args[:available_targeting_combinations] if args.key?(:available_targeting_combinations)
  @default_targeting = args[:default_targeting] if args.key?(:default_targeting)
end