Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

The targeting for which traffic metrics will be reported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesTargeting

Returns a new instance of GoogleAdsSearchads360V23ServicesTargeting.



54947
54948
54949
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54947

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_rangeString

Targeted age range. An unset value is equivalent to targeting all ages. Corresponds to the JSON property ageRange

Returns:

  • (String)


54903
54904
54905
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54903

def age_range
  @age_range
end

#audience_targetingGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceTargeting

Audience targeting for reach forecast. Corresponds to the JSON property audienceTargeting



54908
54909
54910
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54908

def audience_targeting
  @audience_targeting
end

#devicesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo>

Targeted devices. If not specified, targets all applicable devices. Applicable devices vary by product and region and can be obtained from ReachPlanService. ListPlannableProducts. Corresponds to the JSON property devices



54915
54916
54917
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54915

def devices
  @devices
end

#gendersArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo>

Targeted genders. An unset value is equivalent to targeting MALE and FEMALE. Corresponds to the JSON property genders



54920
54921
54922
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54920

def genders
  @genders
end

#networkString

Targetable network for the ad product. If not specified, targets all applicable networks. Applicable networks vary by product and region and can be obtained from ReachPlanService.ListPlannableProducts. Corresponds to the JSON property network

Returns:

  • (String)


54927
54928
54929
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54927

def network
  @network
end

#plannable_location_idString

The ID of the selected location. Plannable location IDs can be obtained from ReachPlanService.ListPlannableLocations. Requests must set either this field or plannable_location_ids. This field is deprecated as of V12 and will be removed in a future release. Use plannable_location_ids instead. Corresponds to the JSON property plannableLocationId

Returns:

  • (String)


54935
54936
54937
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54935

def plannable_location_id
  @plannable_location_id
end

#plannable_location_idsArray<String>

The list of plannable location IDs to target with this forecast. If more than one ID is provided, all IDs must have the same parent_country_id. Planning for more than parent_county is not supported. Plannable location IDs and their parent_country_id can be obtained from ReachPlanService. ListPlannableLocations. Requests must set either this field or plannable_location_id. Corresponds to the JSON property plannableLocationIds

Returns:

  • (Array<String>)


54945
54946
54947
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54945

def plannable_location_ids
  @plannable_location_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54952
54953
54954
54955
54956
54957
54958
54959
54960
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54952

def update!(**args)
  @age_range = args[:age_range] if args.key?(:age_range)
  @audience_targeting = args[:audience_targeting] if args.key?(:audience_targeting)
  @devices = args[:devices] if args.key?(:devices)
  @genders = args[:genders] if args.key?(:genders)
  @network = args[:network] if args.key?(:network)
  @plannable_location_id = args[:plannable_location_id] if args.key?(:plannable_location_id)
  @plannable_location_ids = args[:plannable_location_ids] if args.key?(:plannable_location_ids)
end