Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesTargeting
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
The targeting for which traffic metrics will be reported.
Instance Attribute Summary collapse
-
#age_range ⇒ String
Targeted age range.
-
#audience_targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceTargeting
Audience targeting for reach forecast.
-
#devices ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo>
Targeted devices.
-
#genders ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo>
Targeted genders.
-
#network ⇒ String
Targetable network for the ad product.
-
#plannable_location_id ⇒ String
The ID of the selected location.
-
#plannable_location_ids ⇒ Array<String>
The list of plannable location IDs to target with this forecast.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesTargeting
constructor
A new instance of GoogleAdsSearchads360V23ServicesTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesTargeting
Returns a new instance of GoogleAdsSearchads360V23ServicesTargeting.
54947 54948 54949 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54947 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age_range ⇒ String
Targeted age range. An unset value is equivalent to targeting all ages.
Corresponds to the JSON property ageRange
54903 54904 54905 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54903 def age_range @age_range end |
#audience_targeting ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesAudienceTargeting
Audience targeting for reach forecast.
Corresponds to the JSON property audienceTargeting
54908 54909 54910 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54908 def audience_targeting @audience_targeting end |
#devices ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonDeviceInfo>
Targeted devices. If not specified, targets all applicable devices. Applicable
devices vary by product and region and can be obtained from ReachPlanService.
ListPlannableProducts.
Corresponds to the JSON property devices
54915 54916 54917 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54915 def devices @devices end |
#genders ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo>
Targeted genders. An unset value is equivalent to targeting MALE and FEMALE.
Corresponds to the JSON property genders
54920 54921 54922 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54920 def genders @genders end |
#network ⇒ String
Targetable network for the ad product. If not specified, targets all
applicable networks. Applicable networks vary by product and region and can be
obtained from ReachPlanService.ListPlannableProducts.
Corresponds to the JSON property network
54927 54928 54929 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54927 def network @network end |
#plannable_location_id ⇒ String
The ID of the selected location. Plannable location IDs can be obtained from
ReachPlanService.ListPlannableLocations. Requests must set either this field
or plannable_location_ids. This field is deprecated as of V12 and will be
removed in a future release. Use plannable_location_ids instead.
Corresponds to the JSON property plannableLocationId
54935 54936 54937 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54935 def plannable_location_id @plannable_location_id end |
#plannable_location_ids ⇒ Array<String>
The list of plannable location IDs to target with this forecast. If more than
one ID is provided, all IDs must have the same parent_country_id. Planning
for more than parent_county is not supported. Plannable location IDs and
their parent_country_id can be obtained from ReachPlanService.
ListPlannableLocations. Requests must set either this field or
plannable_location_id.
Corresponds to the JSON property plannableLocationIds
54945 54946 54947 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54945 def plannable_location_ids @plannable_location_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54952 54953 54954 54955 54956 54957 54958 54959 54960 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54952 def update!(**args) @age_range = args[:age_range] if args.key?(:age_range) @audience_targeting = args[:audience_targeting] if args.key?(:audience_targeting) @devices = args[:devices] if args.key?(:devices) @genders = args[:genders] if args.key?(:genders) @network = args[:network] if args.key?(:network) @plannable_location_id = args[:plannable_location_id] if args.key?(:plannable_location_id) @plannable_location_ids = args[:plannable_location_ids] if args.key?(:plannable_location_ids) end |