Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesTargetingSuggestionMetrics
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesTargetingSuggestionMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A suggested targetable audience relevant to the requested audience.
Instance Attribute Summary collapse
-
#age_ranges ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo>
Suggested age targeting; may be empty indicating no age targeting.
-
#coverage ⇒ Float
The fraction (from 0 to 1 inclusive) of the requested audience that can be reached using the suggested targeting.
-
#gender ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo
A gender criterion.
-
#index ⇒ Float
The ratio of coverage to the coverage of the baseline audience or zero if this ratio is undefined or is not meaningful.
-
#locations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata>
Suggested location targeting.
-
#parental_status ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo
A parental status criterion.
-
#potential_youtube_reach ⇒ Fixnum
The approximate estimated number of people that can be reached on YouTube using this targeting.
-
#user_interests ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup>
List of user interest attributes with metadata defining the audience.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesTargetingSuggestionMetrics
constructor
A new instance of GoogleAdsSearchads360V23ServicesTargetingSuggestionMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesTargetingSuggestionMetrics
Returns a new instance of GoogleAdsSearchads360V23ServicesTargetingSuggestionMetrics.
55868 55869 55870 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55868 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age_ranges ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo>
Suggested age targeting; may be empty indicating no age targeting.
Corresponds to the JSON property ageRanges
55824 55825 55826 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55824 def age_ranges @age_ranges end |
#coverage ⇒ Float
The fraction (from 0 to 1 inclusive) of the requested audience that can be
reached using the suggested targeting.
Corresponds to the JSON property coverage
55830 55831 55832 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55830 def coverage @coverage end |
#gender ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo
A gender criterion.
Corresponds to the JSON property gender
55835 55836 55837 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55835 def gender @gender end |
#index ⇒ Float
The ratio of coverage to the coverage of the baseline audience or zero if this
ratio is undefined or is not meaningful.
Corresponds to the JSON property index
55841 55842 55843 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55841 def index @index end |
#locations ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata>
Suggested location targeting. These attributes all have dimension
GEO_TARGET_COUNTRY or SUB_COUNTRY_LOCATION
Corresponds to the JSON property locations
55847 55848 55849 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55847 def locations @locations end |
#parental_status ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo
A parental status criterion.
Corresponds to the JSON property parentalStatus
55852 55853 55854 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55852 def parental_status @parental_status end |
#potential_youtube_reach ⇒ Fixnum
The approximate estimated number of people that can be reached on YouTube
using this targeting.
Corresponds to the JSON property potentialYoutubeReach
55858 55859 55860 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55858 def potential_youtube_reach @potential_youtube_reach end |
#user_interests ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup>
List of user interest attributes with metadata defining the audience. The
combination has a logical AND-of-ORs structure: The attributes within each
AudienceInsightsAttributeMetadataGroup are ORed, and the groups themselves are
ANDed.
Corresponds to the JSON property userInterests
55866 55867 55868 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55866 def user_interests @user_interests end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55873 55874 55875 55876 55877 55878 55879 55880 55881 55882 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55873 def update!(**args) @age_ranges = args[:age_ranges] if args.key?(:age_ranges) @coverage = args[:coverage] if args.key?(:coverage) @gender = args[:gender] if args.key?(:gender) @index = args[:index] if args.key?(:index) @locations = args[:locations] if args.key?(:locations) @parental_status = args[:parental_status] if args.key?(:parental_status) @potential_youtube_reach = args[:potential_youtube_reach] if args.key?(:potential_youtube_reach) @user_interests = args[:user_interests] if args.key?(:user_interests) end |