Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesTargetingSuggestionMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

A suggested targetable audience relevant to the requested audience.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesTargetingSuggestionMetrics

Returns a new instance of GoogleAdsSearchads360V23ServicesTargetingSuggestionMetrics.



55014
55015
55016
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_rangesArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAgeRangeInfo>

Suggested age targeting; may be empty indicating no age targeting. Corresponds to the JSON property ageRanges



54970
54971
54972
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54970

def age_ranges
  @age_ranges
end

#coverageFloat

The fraction (from 0 to 1 inclusive) of the requested audience that can be reached using the suggested targeting. Corresponds to the JSON property coverage

Returns:

  • (Float)


54976
54977
54978
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54976

def coverage
  @coverage
end

#genderGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonGenderInfo

A gender criterion. Corresponds to the JSON property gender



54981
54982
54983
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54981

def gender
  @gender
end

#indexFloat

The ratio of coverage to the coverage of the baseline audience or zero if this ratio is undefined or is not meaningful. Corresponds to the JSON property index

Returns:

  • (Float)


54987
54988
54989
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54987

def index
  @index
end

#locationsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadata>

Suggested location targeting. These attributes all have dimension GEO_TARGET_COUNTRY or SUB_COUNTRY_LOCATION Corresponds to the JSON property locations



54993
54994
54995
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54993

def locations
  @locations
end

#parental_statusGoogle::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonParentalStatusInfo

A parental status criterion. Corresponds to the JSON property parentalStatus



54998
54999
55000
# File 'lib/google/apis/searchads360_v23/classes.rb', line 54998

def parental_status
  @parental_status
end

#potential_youtube_reachFixnum

The approximate estimated number of people that can be reached on YouTube using this targeting. Corresponds to the JSON property potentialYoutubeReach

Returns:

  • (Fixnum)


55004
55005
55006
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55004

def potential_youtube_reach
  @potential_youtube_reach
end

#user_interestsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23CommonAudienceInsightsAttributeMetadataGroup>

List of user interest attributes with metadata defining the audience. The combination has a logical AND-of-ORs structure: The attributes within each AudienceInsightsAttributeMetadataGroup are ORed, and the groups themselves are ANDed. Corresponds to the JSON property userInterests



55012
55013
55014
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55012

def user_interests
  @user_interests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55019
55020
55021
55022
55023
55024
55025
55026
55027
55028
# File 'lib/google/apis/searchads360_v23/classes.rb', line 55019

def update!(**args)
  @age_ranges = args[:age_ranges] if args.key?(:age_ranges)
  @coverage = args[:coverage] if args.key?(:coverage)
  @gender = args[:gender] if args.key?(:gender)
  @index = args[:index] if args.key?(:index)
  @locations = args[:locations] if args.key?(:locations)
  @parental_status = args[:parental_status] if args.key?(:parental_status)
  @potential_youtube_reach = args[:potential_youtube_reach] if args.key?(:potential_youtube_reach)
  @user_interests = args[:user_interests] if args.key?(:user_interests)
end