Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadCallConversionsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadCallConversionsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for ConversionUploadService.UploadCallConversions.
Instance Attribute Summary collapse
-
#conversions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCallConversion>
Required.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
Required.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadCallConversionsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesUploadCallConversionsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadCallConversionsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesUploadCallConversionsRequest.
56111 56112 56113 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56111 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCallConversion>
Required. The conversions that are being uploaded.
Corresponds to the JSON property conversions
56093 56094 56095 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56093 def conversions @conversions end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
Required. If true, successful operations will be carried out and invalid
operations will return errors. If false, all operations will be carried out
in one transaction if and only if they are all valid. This should always be
set to true.
Corresponds to the JSON property partialFailure
56101 56102 56103 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56101 def partial_failure @partial_failure end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
56108 56109 56110 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56108 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56116 56117 56118 56119 56120 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56116 def update!(**args) @conversions = args[:conversions] if args.key?(:conversions) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @validate_only = args[:validate_only] if args.key?(:validate_only) end |