Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadCallConversionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ConversionUploadService.UploadCallConversions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadCallConversionsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesUploadCallConversionsRequest.



56027
56028
56029
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCallConversion>

Required. The conversions that are being uploaded. Corresponds to the JSON property conversions



56009
56010
56011
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56009

def conversions
  @conversions
end

#partial_failureBoolean Also known as: partial_failure?

Required. If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. This should always be set to true. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


56017
56018
56019
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56017

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


56024
56025
56026
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56024

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56032
56033
56034
56035
56036
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56032

def update!(**args)
  @conversions = args[:conversions] if args.key?(:conversions)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end