Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadCallConversionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for ConversionUploadService.UploadCallConversions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadCallConversionsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesUploadCallConversionsResponse.



56060
56061
56062
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56060

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



56051
56052
56053
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56051

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesCallConversionResult>

Returned for successfully processed conversions. Proto will be empty for rows that received an error. Results are not returned when validate_only is true . Corresponds to the JSON property results



56058
56059
56060
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56058

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56065
56066
56067
56068
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56065

def update!(**args)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end