Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadClickConversionsRequest
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadClickConversionsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Request message for ConversionUploadService.UploadClickConversions.
Instance Attribute Summary collapse
-
#conversions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesClickConversion>
Required.
-
#job_id ⇒ Fixnum
Optional.
-
#partial_failure ⇒ Boolean
(also: #partial_failure?)
Required.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If
true, the request is validated but not executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadClickConversionsRequest
constructor
A new instance of GoogleAdsSearchads360V23ServicesUploadClickConversionsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadClickConversionsRequest
Returns a new instance of GoogleAdsSearchads360V23ServicesUploadClickConversionsRequest.
56176 56177 56178 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56176 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversions ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesClickConversion>
Required. The conversions that are being uploaded.
Corresponds to the JSON property conversions
56150 56151 56152 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56150 def conversions @conversions end |
#job_id ⇒ Fixnum
Optional. Optional input to set job ID. Must be a non-negative number that is
less than 2^31 if provided. If this field is not provided, the API will
generate a job ID in the range [2^31, (2^63)-1]. The API will return the value
for this request in the job_id field of the UploadClickConversionsResponse.
Corresponds to the JSON property jobId
56158 56159 56160 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56158 def job_id @job_id end |
#partial_failure ⇒ Boolean Also known as: partial_failure?
Required. If true, successful operations will be carried out and invalid
operations will return errors. If false, all operations will be carried out
in one transaction if and only if they are all valid. This should always be
set to true.
Corresponds to the JSON property partialFailure
56166 56167 56168 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56166 def partial_failure @partial_failure end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is validated but not executed. Only errors are returned,
not results.
Corresponds to the JSON property validateOnly
56173 56174 56175 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56173 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56181 56182 56183 56184 56185 56186 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56181 def update!(**args) @conversions = args[:conversions] if args.key?(:conversions) @job_id = args[:job_id] if args.key?(:job_id) @partial_failure = args[:partial_failure] if args.key?(:partial_failure) @validate_only = args[:validate_only] if args.key?(:validate_only) end |