Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadClickConversionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Request message for ConversionUploadService.UploadClickConversions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadClickConversionsRequest

Returns a new instance of GoogleAdsSearchads360V23ServicesUploadClickConversionsRequest.



56104
56105
56106
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56104

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversionsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesClickConversion>

Required. The conversions that are being uploaded. Corresponds to the JSON property conversions



56078
56079
56080
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56078

def conversions
  @conversions
end

#job_idFixnum

Optional. Optional input to set job ID. Must be a non-negative number that is less than 2^31 if provided. If this field is not provided, the API will generate a job ID in the range [2^31, (2^63)-1]. The API will return the value for this request in the job_id field of the UploadClickConversionsResponse. Corresponds to the JSON property jobId

Returns:

  • (Fixnum)


56086
56087
56088
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56086

def job_id
  @job_id
end

#partial_failureBoolean Also known as: partial_failure?

Required. If true, successful operations will be carried out and invalid operations will return errors. If false, all operations will be carried out in one transaction if and only if they are all valid. This should always be set to true. Corresponds to the JSON property partialFailure

Returns:

  • (Boolean)


56094
56095
56096
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56094

def partial_failure
  @partial_failure
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is validated but not executed. Only errors are returned, not results. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


56101
56102
56103
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56101

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56109
56110
56111
56112
56113
56114
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56109

def update!(**args)
  @conversions = args[:conversions] if args.key?(:conversions)
  @job_id = args[:job_id] if args.key?(:job_id)
  @partial_failure = args[:partial_failure] if args.key?(:partial_failure)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end