Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadClickConversionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb

Overview

Response message for ConversionUploadService.UploadClickConversions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadClickConversionsResponse

Returns a new instance of GoogleAdsSearchads360V23ServicesUploadClickConversionsResponse.



56143
56144
56145
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56143

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#job_idFixnum

Job ID for the upload batch. Corresponds to the JSON property jobId

Returns:

  • (Fixnum)


56124
56125
56126
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56124

def job_id
  @job_id
end

#partial_failure_errorGoogle::Apis::Searchads360V23::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property partialFailureError



56134
56135
56136
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56134

def partial_failure_error
  @partial_failure_error
end

#resultsArray<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesClickConversionResult>

Returned for successfully processed conversions. Proto will be empty for rows that received an error. Results are not returned when validate_only is true . Corresponds to the JSON property results



56141
56142
56143
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56141

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56148
56149
56150
56151
56152
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56148

def update!(**args)
  @job_id = args[:job_id] if args.key?(:job_id)
  @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error)
  @results = args[:results] if args.key?(:results)
end