Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadConversionAdjustmentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadConversionAdjustmentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for ConversionAdjustmentUploadService. UploadConversionAdjustments.
Instance Attribute Summary collapse
-
#job_id ⇒ Fixnum
Job ID for the upload batch.
-
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionAdjustmentResult>
Returned for successfully processed conversion adjustments.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadConversionAdjustmentsResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesUploadConversionAdjustmentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadConversionAdjustmentsResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesUploadConversionAdjustmentsResponse.
56231 56232 56233 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56231 def initialize(**args) update!(**args) end |
Instance Attribute Details
#job_id ⇒ Fixnum
Job ID for the upload batch.
Corresponds to the JSON property jobId
56212 56213 56214 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56212 def job_id @job_id end |
#partial_failure_error ⇒ Google::Apis::Searchads360V23::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property partialFailureError
56222 56223 56224 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56222 def partial_failure_error @partial_failure_error end |
#results ⇒ Array<Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesConversionAdjustmentResult>
Returned for successfully processed conversion adjustments. Proto will be
empty for rows that received an error. Results are not returned when
validate_only is true.
Corresponds to the JSON property results
56229 56230 56231 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56229 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56236 56237 56238 56239 56240 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56236 def update!(**args) @job_id = args[:job_id] if args.key?(:job_id) @partial_failure_error = args[:partial_failure_error] if args.key?(:partial_failure_error) @results = args[:results] if args.key?(:results) end |