Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadUserDataResponse
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUploadUserDataResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
Response message for UserDataService.UploadUserData Uploads made through this service will not be visible under the 'Segment members' section for the Customer Match List in the Google Ads UI.
Instance Attribute Summary collapse
-
#received_operations_count ⇒ Fixnum
Number of upload data operations received by API.
-
#upload_date_time ⇒ String
The date time at which the request was received by API, formatted as "yyyy-mm- dd hh:mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08:00".
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadUserDataResponse
constructor
A new instance of GoogleAdsSearchads360V23ServicesUploadUserDataResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUploadUserDataResponse
Returns a new instance of GoogleAdsSearchads360V23ServicesUploadUserDataResponse.
56357 56358 56359 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#received_operations_count ⇒ Fixnum
Number of upload data operations received by API.
Corresponds to the JSON property receivedOperationsCount
56349 56350 56351 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56349 def received_operations_count @received_operations_count end |
#upload_date_time ⇒ String
The date time at which the request was received by API, formatted as "yyyy-mm-
dd hh:mm:ss+|-hh:mm", for example, "2019-01-01 12:32:45-08:00".
Corresponds to the JSON property uploadDateTime
56355 56356 56357 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56355 def upload_date_time @upload_date_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56362 56363 56364 56365 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56362 def update!(**args) @received_operations_count = args[:received_operations_count] if args.key?(:received_operations_count) @upload_date_time = args[:upload_date_time] if args.key?(:upload_date_time) end |