Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUserListOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUserListOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update) on a user list.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserList
A user list.
-
#remove ⇒ String
Remove operation: A resource name for the removed user list is expected, in this format:
customers/customer_id/userLists/user_list_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserList
A user list.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUserListOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesUserListOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUserListOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesUserListOperation.
56472 56473 56474 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56472 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserList
A user list. This is a list of users a customer may target. The unique key of
a user list consists of the following fields: id. Note that the name must
also be unique for user lists owned by a given customer, except in some cases
where access_reason is set to SHARED. Violating the unique name constraint
produces error: UserListError.INVALID_NAME.
Corresponds to the JSON property create
56450 56451 56452 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56450 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed user list is expected, in
this format: customers/customer_id/userLists/user_list_id`
Corresponds to the JSON propertyremove`
56456 56457 56458 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56456 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserList
A user list. This is a list of users a customer may target. The unique key of
a user list consists of the following fields: id. Note that the name must
also be unique for user lists owned by a given customer, except in some cases
where access_reason is set to SHARED. Violating the unique name constraint
produces error: UserListError.INVALID_NAME.
Corresponds to the JSON property update
56465 56466 56467 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56465 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
56470 56471 56472 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56470 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56477 56478 56479 56480 56481 56482 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56477 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |