Class: Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUserListOperation
- Inherits:
-
Object
- Object
- Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ServicesUserListOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/searchads360_v23/classes.rb,
lib/google/apis/searchads360_v23/representations.rb,
lib/google/apis/searchads360_v23/representations.rb
Overview
A single operation (create, update) on a user list.
Instance Attribute Summary collapse
-
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserList
A user list.
-
#remove ⇒ String
Remove operation: A resource name for the removed user list is expected, in this format:
customers/customer_id/userLists/user_list_id`Corresponds to the JSON propertyremove`. -
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserList
A user list.
-
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUserListOperation
constructor
A new instance of GoogleAdsSearchads360V23ServicesUserListOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAdsSearchads360V23ServicesUserListOperation
Returns a new instance of GoogleAdsSearchads360V23ServicesUserListOperation.
56400 56401 56402 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserList
A user list. This is a list of users a customer may target. The unique key of
a user list consists of the following fields: id. Note that the name must
also be unique for user lists owned by a given customer, except in some cases
where access_reason is set to SHARED. Violating the unique name constraint
produces error: UserListError.INVALID_NAME.
Corresponds to the JSON property create
56378 56379 56380 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56378 def create @create end |
#remove ⇒ String
Remove operation: A resource name for the removed user list is expected, in
this format: customers/customer_id/userLists/user_list_id`
Corresponds to the JSON propertyremove`
56384 56385 56386 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56384 def remove @remove end |
#update ⇒ Google::Apis::Searchads360V23::GoogleAdsSearchads360V23ResourcesUserList
A user list. This is a list of users a customer may target. The unique key of
a user list consists of the following fields: id. Note that the name must
also be unique for user lists owned by a given customer, except in some cases
where access_reason is set to SHARED. Violating the unique name constraint
produces error: UserListError.INVALID_NAME.
Corresponds to the JSON property update
56393 56394 56395 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56393 def update @update end |
#update_mask ⇒ String
FieldMask that determines which resource fields are modified in an update.
Corresponds to the JSON property updateMask
56398 56399 56400 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56398 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56405 56406 56407 56408 56409 56410 |
# File 'lib/google/apis/searchads360_v23/classes.rb', line 56405 def update!(**args) @create = args[:create] if args.key?(:create) @remove = args[:remove] if args.key?(:remove) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) end |